// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qanimationcallback_wrapper.h"

// Argument includes
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

using namespace Qt3DAnimation;

// Native ---------------------------------------------------------

void QAnimationCallbackWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAnimationCallbackWrapper::QAnimationCallbackWrapper() : Qt3DAnimation::QAnimationCallback()
{
    resetPyMethodCache();
    // ... middle
}

void QAnimationCallbackWrapper::valueChanged(const ::QVariant & value)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAnimationCallback.valueChanged");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "valueChanged";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAnimationCallback.valueChanged");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QAnimationCallbackWrapper::~QAnimationCallbackWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QAnimationCallback_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("Qt3DAnimation::QAnimationCallback");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QAnimationCallback >()))
        return -1;

    ::QAnimationCallbackWrapper *cptr{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAnimationCallback()
            cptr = new ::QAnimationCallbackWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DAnimation::QAnimationCallback >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationCallbackFunc_valueChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationCallback *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback.valueChanged";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationCallback::valueChanged(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // valueChanged(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueChanged(QVariant)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAnimationCallback.valueChanged");
                return {};
            }
            cppSelf->valueChanged(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DAnimation_QAnimationCallback_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Qt3DAnimation_QAnimationCallback_EnumFlagInfo[] = {
    "Flag:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QAnimationCallback_methods[] = {
    {"valueChanged", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationCallbackFunc_valueChanged), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DAnimation_QAnimationCallback_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DAnimation::QAnimationCallback *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAnimationCallbackWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QAnimationCallback_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QAnimationCallback_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QAnimationCallback_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QAnimationCallback_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QAnimationCallback_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QAnimationCallback_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationCallback_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationCallback_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationCallback_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationCallback_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationCallback_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QAnimationCallback_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QAnimationCallback_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Qt3DAnimation_QAnimationCallback_Flag_PythonToCpp_Qt3DAnimation_QAnimationCallback_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DAnimation::QAnimationCallback::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DAnimation::QAnimationCallback::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Qt3DAnimation_QAnimationCallback_Flag_PythonToCpp_Qt3DAnimation_QAnimationCallback_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_Flag_IDX])))
        return Qt3DAnimation_QAnimationCallback_Flag_PythonToCpp_Qt3DAnimation_QAnimationCallback_Flag;
    return {};
}
static PyObject *Qt3DAnimation_QAnimationCallback_Flag_CppToPython_Qt3DAnimation_QAnimationCallback_Flag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DAnimation::QAnimationCallback::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_Flag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAnimationCallback_PythonToCpp_QAnimationCallback_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QAnimationCallback_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAnimationCallback_PythonToCpp_QAnimationCallback_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QAnimationCallback_TypeF()))
        return QAnimationCallback_PythonToCpp_QAnimationCallback_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAnimationCallback_PTR_CppToPython_QAnimationCallback(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::Qt3DAnimation::QAnimationCallback *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DAnimation_QAnimationCallback_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DAnimation_QAnimationCallback_SignatureStrings[] = {
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback(self)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback.valueChanged(self,value:QVariant)",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DAnimation_QAnimationCallback(PyObject *enclosingClass)
{
    _Sbk_Qt3DAnimation_QAnimationCallback_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAnimationCallback",
        "Qt3DAnimation::QAnimationCallback*",
        &Sbk_Qt3DAnimation_QAnimationCallback_spec,
        &Shiboken::callCppDestructor< ::Qt3DAnimation::QAnimationCallback >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DAnimation_QAnimationCallback_TypeF(); // references _Sbk_Qt3DAnimation_QAnimationCallback_Type
    InitSignatureStrings(pyType, Qt3DAnimation_QAnimationCallback_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QAnimationCallback_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAnimationCallback_PythonToCpp_QAnimationCallback_PTR,
        is_QAnimationCallback_PythonToCpp_QAnimationCallback_PTR_Convertible,
        QAnimationCallback_PTR_CppToPython_QAnimationCallback);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationCallback");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationCallback*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationCallback&");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationCallback");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationCallback*");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationCallback&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QAnimationCallback).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAnimationCallbackWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DAnimation_QAnimationCallback_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "OnOwningThread",
        "OnThreadPool",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(Qt3DAnimation::QAnimationCallback::Flag::OnOwningThread), //  0x00  0
        uint8_t(Qt3DAnimation::QAnimationCallback::Flag::OnThreadPool)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DAnimation_QAnimationCallback_TypeF(),
        "2:PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QAnimationCallback_Flag_IDX].type = EType;
    // Register converter for enum 'Qt3DAnimation::QAnimationCallback::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DAnimation_QAnimationCallback_Flag_CppToPython_Qt3DAnimation_QAnimationCallback_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Qt3DAnimation_QAnimationCallback_Flag_PythonToCpp_Qt3DAnimation_QAnimationCallback_Flag,
            is_Qt3DAnimation_QAnimationCallback_Flag_PythonToCpp_Qt3DAnimation_QAnimationCallback_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationCallback::Flag");
        Shiboken::Conversions::registerConverterName(converter, "QAnimationCallback::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
    }
    // End of 'Flag' enum.

    qRegisterMetaType< ::Qt3DAnimation::QAnimationCallback *>();
    qRegisterMetaType< ::Qt3DAnimation::QAnimationCallback::Flag >("QAnimationCallback::Flag");
    qRegisterMetaType< ::Qt3DAnimation::QAnimationCallback::Flag >("Qt3DAnimation::QAnimationCallback::Flag");

    return pyType;
}
