// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qt3drender_python.h"

#include <QList>
#include <QMap>
#include <QString>
#include <Qt3DCore/qcomponent.h>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DRender/qabstracttextureimage.h>
#include <Qt3DRender/qfilterkey.h>
#include <Qt3DRender/qlayer.h>
#include <Qt3DRender/qparameter.h>
#include <Qt3DRender/qraycasterhit.h>
#include <Qt3DRender/qrenderpass.h>
#include <Qt3DRender/qrenderstate.h>
#include <Qt3DRender/qrendertargetoutput.h>
#include <Qt3DRender/qshaderdata.h>
#include <Qt3DRender/qsortpolicy.h>
#include <Qt3DRender/qtechnique.h>
#include <Qt3DRender/qtextureimagedata.h>
#include <Qt3DRender/qtextureimagedatagenerator.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qsharedpointer.h>
#include <qvariant.h>
#include <vector>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DRenderTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_Qt3DRenderTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_Qt3DRenderModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_Qt3DRenderTypeConverters = nullptr;

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_Qt3DRender_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_Qt3DRenderTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_Qt3DRenderTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------

static PyMethodDef Qt3DRender_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_Qt3DRenderQt3DRender(PyObject *module);
PyTypeObject *init_Qt3DRender_QTextureWrapMode(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureImageData(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureDataUpdate(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureData(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QStencilTestArguments(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QStencilOperationArguments(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderCaptureReply(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderCapabilities(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRayCasterHit(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickEvent(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickTriangleEvent(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickPointEvent(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickLineEvent(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLevelOfDetailBoundingSphere(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QGraphicsApiFilter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_PropertyReaderInterface(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTechnique(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QShaderProgramBuilder(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QShaderProgram(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QShaderImage(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderTargetOutput(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderState(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QStencilTest(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QStencilOperation(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QStencilMask(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSeamlessCubemap(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QScissorTest(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRasterMode(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPolygonOffset(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPointSize(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QNoDepthMask(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QMultiSampleAntiAliasing(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLineWidth(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QFrontFace(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QDithering(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QDepthTest(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QDepthRange(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QCullFace(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QColorMask(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QClipPlane(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QBlendEquationArguments(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QBlendEquation(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAlphaTest(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAlphaCoverage(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderPass(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickingSettings(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QParameter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QFrameGraphNode(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QWaitFence(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QViewport(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTechniqueFilter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSubtreeEnabler(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSortPolicy(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSetFence(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderTargetSelector(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderSurfaceSelector(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderStateSet(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderPassFilter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderCapture(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QProximityFilter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QNoPicking(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QNoDraw(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QMemoryBarrier(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLayerFilter(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QFrustumCulling(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QDispatchCompute(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QClearBuffers(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QCameraSelector(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QBufferCapture(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QBlitFramebuffer(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QFilterKey(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QEffect(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAbstractTextureImage(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureImage(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPaintedTextureImage(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAbstractTexture(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureRectangle(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureLoader(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureCubeMapArray(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureCubeMap(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureBuffer(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture3D(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture2DMultisampleArray(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture2DMultisample(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture2DArray(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture2D(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture1DArray(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTexture1D(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSharedGLTexture(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QCamera(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QShaderData(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSceneLoader(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderTarget(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderSettings(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QObjectPicker(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QMaterial(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLevelOfDetail(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLevelOfDetailSwitch(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QLayer(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QEnvironmentLight(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QComputeCommand(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QCameraLens(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAbstractRayCaster(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QScreenRayCaster(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRayCaster(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QAbstractLight(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QSpotLight(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPointLight(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QDirectionalLight(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QPickingProxy(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QGeometryRenderer(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QMesh(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureImageDataGenerator(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QRenderAspect(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureImageDataPtr(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_QTextureImageDataGeneratorPtr(PyObject *enclosingClass);
PyTypeObject *init_Qt3DRender_PropertyReaderInterfacePtr(PyObject *enclosingClass);

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DCoreTypeStructs;
SbkConverter **SbkPySide6_Qt3DCoreTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtGuiTypeStructs;
SbkConverter **SbkPySide6_QtGuiTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtOpenGLTypeStructs;
SbkConverter **SbkPySide6_QtOpenGLTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.Qt3DRender.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QEntity*>'.
static PyObject *_QList_Qt3DCore_QEntityPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QEntity*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QEntity*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QEntity* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRayCasterHit>'.
static PyObject *_QList_Qt3DRender_QRayCasterHit__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRayCasterHit> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRayCasterHit_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRayCasterHit> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRayCasterHit cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRayCasterHit_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRayCasterHit_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QLayer*>'.
static PyObject *_QList_Qt3DRender_QLayerPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QLayer*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QLayer_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QLayer*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QLayer* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QLayer_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QLayer_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QAbstractTextureImage*>'.
static PyObject *_QList_Qt3DRender_QAbstractTextureImagePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QAbstractTextureImage*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTextureImage_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QAbstractTextureImage*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QAbstractTextureImage* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTextureImage_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTextureImage_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QNode*>'.
static PyObject *_QList_Qt3DCore_QNodePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QNode*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QNode*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QNode* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QFilterKey*>'.
static PyObject *_QList_Qt3DRender_QFilterKeyPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QFilterKey*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFilterKey_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QFilterKey*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QFilterKey* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFilterKey_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QFilterKey_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QParameter*>'.
static PyObject *_QList_Qt3DRender_QParameterPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QParameter*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QParameter_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QParameter*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QParameter* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QParameter_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QParameter_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderState*>'.
static PyObject *_QList_Qt3DRender_QRenderStatePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderState*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderState*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderState* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderState_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QSortPolicy::SortType>'.
static PyObject *_QList_Qt3DRender_QSortPolicy_SortType__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QSortPolicy::SortType> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QSortPolicy_SortType_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QSortPolicy::SortType> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QSortPolicy::SortType cppItem = static_cast< ::Qt3DRender::QSortPolicy::SortType>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QSortPolicy_SortType_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QSortPolicy_SortType_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderTargetOutput*>'.
static PyObject *_QList_Qt3DRender_QRenderTargetOutputPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderTargetOutput*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderTargetOutput_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderTargetOutput*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderTargetOutput* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderTargetOutput_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderTargetOutput_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DCore::QComponent*>'.
static PyObject *_QList_Qt3DCore_QComponentPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DCore::QComponent*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QComponent_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DCore::QComponent*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DCore::QComponent* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QComponent_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QComponent_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QTechnique*>'.
static PyObject *_QList_Qt3DRender_QTechniquePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QTechnique*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QTechnique*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QTechnique* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTechnique_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'std::vector<QSharedPointer< Qt3DCore::QAspectJob>>'.
static PyObject *std_vector_QSharedPointer_Qt3DCore_QAspectJob___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::vector<QSharedPointer< Qt3DCore::QAspectJob>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::vector<QSharedPointer< Qt3DCore::QAspectJob>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSharedPointer<Qt3DCore::QAspectJob> cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QAspectJob_IDX]), pyIn))
        return PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt3DRender::QRenderPass*>'.
static PyObject *_QList_Qt3DRender_QRenderPassPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt3DRender::QRenderPass*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderPass_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt3DRender::QRenderPass*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt3DRender::QRenderPass* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderPass_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QRenderPass_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSharedPointer< Qt3DRender::QTextureImageData>>'.
static PyObject *_QList_QSharedPointer_Qt3DRender_QTextureImageData___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSharedPointer< Qt3DRender::QTextureImageData>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSharedPointer< Qt3DRender::QTextureImageData>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSharedPointer<Qt3DRender::QTextureImageData> cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_QSharedPointer_Qt3DRender_QTextureImageData_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


// SmartPointers converters.

// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::QTextureImageData>'.
// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::QTextureImageDataGenerator>'.
// Register smartpointer conversion for all derived classes
// C++ to Python conversion for smart pointer type 'QSharedPointer<Qt3DRender::PropertyReaderInterface>'.

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "Qt3DRender",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ Qt3DRender_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DRender_SignatureStrings[] = {
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_Qt3DRender()
{
    if (SbkPySide6_Qt3DRenderModuleObject != nullptr)
        return SbkPySide6_Qt3DRenderModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.Qt3DCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_Qt3DCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_Qt3DCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtGui"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtGuiTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtGuiTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtOpenGL"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtOpenGLTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtOpenGLTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QClearBuffers.BufferTypeFlags"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMemoryBarrier.Operations"},
        {nullptr, "+++ unknown entry #2 in Qt3DRender"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.API"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.PropertyReaderInterface"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractLight"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractLight.Type"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractRayCaster"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractRayCaster.FilterMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractRayCaster.RunMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonFunction"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.ComparisonMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.CubeMapFace"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Filter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.HandleType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Status"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.Target"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTexture.TextureFormat"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAbstractTextureImage"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAlphaCoverage"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAlphaTest"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QAlphaTest.AlphaFunction"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlendEquation"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlendEquation.BlendFunction"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlitFramebuffer"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBlitFramebuffer.InterpolationMethod"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QBufferCapture"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCamera"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCamera.CameraTranslationOption"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCameraLens"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCameraLens.ProjectionType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCameraSelector"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QClearBuffers"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QClearBuffers.BufferType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QClipPlane"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QColorMask"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QComputeCommand"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QComputeCommand.RunType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCullFace"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QCullFace.CullingMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDepthRange"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDepthTest"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDepthTest.DepthFunction"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDirectionalLight"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDispatchCompute"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QDithering"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QEffect"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QEnvironmentLight"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QFilterKey"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QFrameGraphNode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QFrontFace"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QFrontFace.WindingDirection"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QFrustumCulling"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.Api"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QGraphicsApiFilter.OpenGLProfile"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLayer"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLayerFilter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLayerFilter.FilterMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLevelOfDetail"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLevelOfDetail.ThresholdType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLevelOfDetailBoundingSphere"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLevelOfDetailSwitch"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QLineWidth"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMaterial"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMemoryBarrier"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMemoryBarrier.Operation"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMesh"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMesh.Status"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QMultiSampleAntiAliasing"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QNoDepthMask"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QNoDraw"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QNoPicking"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QObjectPicker"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPaintedTextureImage"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QParameter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickEvent"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickEvent.Buttons"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickEvent.Modifiers"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickLineEvent"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickPointEvent"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickTriangleEvent"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickingProxy"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickingSettings"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.FaceOrientationPickingMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickMethod"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPickingSettings.PickResultMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPointLight"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPointSize"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPointSize.SizeMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QPolygonOffset"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QProximityFilter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRasterMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRasterMode.FaceMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRasterMode.RasterMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRayCaster"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRayCasterHit"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRayCasterHit.HitType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderAspect"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderAspect.SubmissionType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.API"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderCapabilities.Profile"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderCapture"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderCaptureReply"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderPass"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderPassFilter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderSettings"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderSettings.RenderPolicy"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderState"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderStateSet"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderSurfaceSelector"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderTarget"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderTargetOutput"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderTargetOutput.AttachmentPoint"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QRenderTargetSelector"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSceneLoader"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSceneLoader.ComponentType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSceneLoader.Status"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QScissorTest"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QScreenRayCaster"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSeamlessCubemap"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSetFence"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSetFence.HandleType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderData"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderImage"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderImage.Access"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderImage.ImageFormat"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderProgram"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Format"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.ShaderType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderProgram.Status"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QShaderProgramBuilder"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSharedGLTexture"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSortPolicy"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSortPolicy.SortType"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSpotLight"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilMask"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilOperation"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.FaceMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilOperationArguments.Operation"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilTest"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFaceMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QStencilTestArguments.StencilFunction"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSubtreeEnabler"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QSubtreeEnabler.Enablement"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTechnique"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTechniqueFilter"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture1D"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture1DArray"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture2D"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture2DArray"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture2DMultisample"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture2DMultisampleArray"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTexture3D"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureBuffer"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureCubeMap"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureCubeMapArray"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureData"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureDataUpdate"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureImage"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureImage.Status"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureImageData"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureImageDataGenerator"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureLoader"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureRectangle"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QTextureWrapMode.WrapMode"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QViewport"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QWaitFence"},
        {nullptr, "PySide6.Qt3DRender.Qt3DRender.QWaitFence.HandleType"},
        {nullptr, "PySide6.Qt3DRender.QSharedPointer"},
        {nullptr, "PySide6.Qt3DRender.QSharedPointer"},
        {nullptr, "PySide6.Qt3DRender.QSharedPointer"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_Qt3DRenderTypeStructs = cppApi;
    // The backward compatible alias with upper case indexes.
    SbkPySide6_Qt3DRenderTypes = reinterpret_cast<PyTypeObject **>(cppApi);

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_Qt3DRender_CONVERTERS_IDX_COUNT];
    SbkPySide6_Qt3DRenderTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("Qt3DRender", &moduledef);

    // Make module available from global scope
    SbkPySide6_Qt3DRenderModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "Qt3DRender", init_Qt3DRenderQt3DRender);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureWrapMode", init_Qt3DRender_QTextureWrapMode, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureImageData", init_Qt3DRender_QTextureImageData, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureDataUpdate", init_Qt3DRender_QTextureDataUpdate, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureData", init_Qt3DRender_QTextureData, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QStencilTestArguments", init_Qt3DRender_QStencilTestArguments, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QStencilOperationArguments", init_Qt3DRender_QStencilOperationArguments, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderCaptureReply", init_Qt3DRender_QRenderCaptureReply, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderCapabilities", init_Qt3DRender_QRenderCapabilities, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRayCasterHit", init_Qt3DRender_QRayCasterHit, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickEvent", init_Qt3DRender_QPickEvent, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickTriangleEvent", init_Qt3DRender_QPickTriangleEvent, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickPointEvent", init_Qt3DRender_QPickPointEvent, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickLineEvent", init_Qt3DRender_QPickLineEvent, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLevelOfDetailBoundingSphere", init_Qt3DRender_QLevelOfDetailBoundingSphere, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsApiFilter", init_Qt3DRender_QGraphicsApiFilter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "PropertyReaderInterface", init_Qt3DRender_PropertyReaderInterface, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTechnique", init_Qt3DRender_QTechnique, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderProgramBuilder", init_Qt3DRender_QShaderProgramBuilder, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderProgram", init_Qt3DRender_QShaderProgram, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderImage", init_Qt3DRender_QShaderImage, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderTargetOutput", init_Qt3DRender_QRenderTargetOutput, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderState", init_Qt3DRender_QRenderState, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QStencilTest", init_Qt3DRender_QStencilTest, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QStencilOperation", init_Qt3DRender_QStencilOperation, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QStencilMask", init_Qt3DRender_QStencilMask, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSeamlessCubemap", init_Qt3DRender_QSeamlessCubemap, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QScissorTest", init_Qt3DRender_QScissorTest, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRasterMode", init_Qt3DRender_QRasterMode, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPolygonOffset", init_Qt3DRender_QPolygonOffset, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPointSize", init_Qt3DRender_QPointSize, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QNoDepthMask", init_Qt3DRender_QNoDepthMask, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QMultiSampleAntiAliasing", init_Qt3DRender_QMultiSampleAntiAliasing, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLineWidth", init_Qt3DRender_QLineWidth, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QFrontFace", init_Qt3DRender_QFrontFace, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QDithering", init_Qt3DRender_QDithering, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QDepthTest", init_Qt3DRender_QDepthTest, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QDepthRange", init_Qt3DRender_QDepthRange, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QCullFace", init_Qt3DRender_QCullFace, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QColorMask", init_Qt3DRender_QColorMask, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QClipPlane", init_Qt3DRender_QClipPlane, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QBlendEquationArguments", init_Qt3DRender_QBlendEquationArguments, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QBlendEquation", init_Qt3DRender_QBlendEquation, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAlphaTest", init_Qt3DRender_QAlphaTest, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAlphaCoverage", init_Qt3DRender_QAlphaCoverage, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderPass", init_Qt3DRender_QRenderPass, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickingSettings", init_Qt3DRender_QPickingSettings, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QParameter", init_Qt3DRender_QParameter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QFrameGraphNode", init_Qt3DRender_QFrameGraphNode, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QWaitFence", init_Qt3DRender_QWaitFence, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QViewport", init_Qt3DRender_QViewport, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTechniqueFilter", init_Qt3DRender_QTechniqueFilter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSubtreeEnabler", init_Qt3DRender_QSubtreeEnabler, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSortPolicy", init_Qt3DRender_QSortPolicy, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSetFence", init_Qt3DRender_QSetFence, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderTargetSelector", init_Qt3DRender_QRenderTargetSelector, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderSurfaceSelector", init_Qt3DRender_QRenderSurfaceSelector, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderStateSet", init_Qt3DRender_QRenderStateSet, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderPassFilter", init_Qt3DRender_QRenderPassFilter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderCapture", init_Qt3DRender_QRenderCapture, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QProximityFilter", init_Qt3DRender_QProximityFilter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QNoPicking", init_Qt3DRender_QNoPicking, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QNoDraw", init_Qt3DRender_QNoDraw, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QMemoryBarrier", init_Qt3DRender_QMemoryBarrier, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLayerFilter", init_Qt3DRender_QLayerFilter, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QFrustumCulling", init_Qt3DRender_QFrustumCulling, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QDispatchCompute", init_Qt3DRender_QDispatchCompute, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QClearBuffers", init_Qt3DRender_QClearBuffers, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QCameraSelector", init_Qt3DRender_QCameraSelector, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QBufferCapture", init_Qt3DRender_QBufferCapture, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QBlitFramebuffer", init_Qt3DRender_QBlitFramebuffer, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QFilterKey", init_Qt3DRender_QFilterKey, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QEffect", init_Qt3DRender_QEffect, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractTextureImage", init_Qt3DRender_QAbstractTextureImage, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureImage", init_Qt3DRender_QTextureImage, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintedTextureImage", init_Qt3DRender_QPaintedTextureImage, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractTexture", init_Qt3DRender_QAbstractTexture, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureRectangle", init_Qt3DRender_QTextureRectangle, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureLoader", init_Qt3DRender_QTextureLoader, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureCubeMapArray", init_Qt3DRender_QTextureCubeMapArray, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureCubeMap", init_Qt3DRender_QTextureCubeMap, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureBuffer", init_Qt3DRender_QTextureBuffer, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture3D", init_Qt3DRender_QTexture3D, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture2DMultisampleArray", init_Qt3DRender_QTexture2DMultisampleArray, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture2DMultisample", init_Qt3DRender_QTexture2DMultisample, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture2DArray", init_Qt3DRender_QTexture2DArray, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture2D", init_Qt3DRender_QTexture2D, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture1DArray", init_Qt3DRender_QTexture1DArray, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTexture1D", init_Qt3DRender_QTexture1D, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSharedGLTexture", init_Qt3DRender_QSharedGLTexture, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QCamera", init_Qt3DRender_QCamera, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderData", init_Qt3DRender_QShaderData, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSceneLoader", init_Qt3DRender_QSceneLoader, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderTarget", init_Qt3DRender_QRenderTarget, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderSettings", init_Qt3DRender_QRenderSettings, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QObjectPicker", init_Qt3DRender_QObjectPicker, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QMaterial", init_Qt3DRender_QMaterial, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLevelOfDetail", init_Qt3DRender_QLevelOfDetail, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLevelOfDetailSwitch", init_Qt3DRender_QLevelOfDetailSwitch, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QLayer", init_Qt3DRender_QLayer, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QEnvironmentLight", init_Qt3DRender_QEnvironmentLight, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QComputeCommand", init_Qt3DRender_QComputeCommand, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QCameraLens", init_Qt3DRender_QCameraLens, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractRayCaster", init_Qt3DRender_QAbstractRayCaster, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QScreenRayCaster", init_Qt3DRender_QScreenRayCaster, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRayCaster", init_Qt3DRender_QRayCaster, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractLight", init_Qt3DRender_QAbstractLight, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSpotLight", init_Qt3DRender_QSpotLight, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPointLight", init_Qt3DRender_QPointLight, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QDirectionalLight", init_Qt3DRender_QDirectionalLight, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QPickingProxy", init_Qt3DRender_QPickingProxy, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QGeometryRenderer", init_Qt3DRender_QGeometryRenderer, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QMesh", init_Qt3DRender_QMesh, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextureImageDataGenerator", init_Qt3DRender_QTextureImageDataGenerator, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QRenderAspect", init_Qt3DRender_QRenderAspect, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSharedPointer", init_Qt3DRender_QTextureImageDataPtr, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSharedPointer", init_Qt3DRender_QTextureImageDataGeneratorPtr, "Qt3DRender");
    Shiboken::Module::AddTypeCreationFunction(module, "QSharedPointer", init_Qt3DRender_PropertyReaderInterfacePtr, "Qt3DRender");

    // Register converter for type 'QList<int>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<Qt3DCore::QEntity*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QEntityPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QEntityPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QEntityPTR_IDX], "QList<Qt3DCore::QEntity*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QEntityPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QEntityPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QRayCasterHit>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRayCasterHit__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX], "QList<Qt3DRender::QRayCasterHit>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRayCasterHit__Convertible);
    // Register converters for type aliases of QList<Qt3DRender::QRayCasterHit>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRayCasterHit_IDX], "Qt3DRender::QAbstractRayCaster::Hits");

    // Register converter for type 'QList<Qt3DRender::QLayer*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QLayerPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QLayerPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QLayerPTR_IDX], "QList<Qt3DRender::QLayer*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QLayerPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QLayerPTR__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<Qt3DRender::QAbstractTextureImage*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QAbstractTextureImagePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX], "QList<Qt3DRender::QAbstractTextureImage*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QAbstractTextureImagePTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QAbstractTextureImagePTR__Convertible);

    // Register converter for type 'QList<Qt3DCore::QNode*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QNodePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QNodePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QNodePTR_IDX], "QList<Qt3DCore::QNode*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QNodePTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QNodePTR__Convertible);
    // Register converters for type aliases of QList<Qt3DCore::QNode*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QNodePTR_IDX], "Qt3DCore::QNodeVector");

    // Register converter for type 'QList<Qt3DRender::QFilterKey*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QFilterKeyPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX], "QList<Qt3DRender::QFilterKey*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QFilterKeyPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QFilterKeyPTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QParameter*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QParameterPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX], "QList<Qt3DRender::QParameter*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QParameterPTR__Convertible);
    // Register converters for type aliases of QList<Qt3DRender::QParameter*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QParameterPTR_IDX], "Qt3DRender::ParameterList");

    // Register converter for type 'QList<Qt3DRender::QRenderState*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderStatePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX], "QList<Qt3DRender::QRenderState*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderStatePTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderStatePTR__Convertible);

    // Register converter for type 'QList<Qt3DRender::QSortPolicy::SortType>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QSortPolicy_SortType_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QSortPolicy_SortType__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QSortPolicy_SortType_IDX], "QList<Qt3DRender::QSortPolicy::SortType>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QSortPolicy_SortType_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QSortPolicy_SortType__Convertible);

    // Register converter for type 'QList<Qt3DRender::QRenderTargetOutput*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderTargetOutputPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderTargetOutputPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderTargetOutputPTR_IDX], "QList<Qt3DRender::QRenderTargetOutput*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderTargetOutputPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderTargetOutputPTR__Convertible);

    // Register converter for type 'QList<Qt3DCore::QComponent*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QComponentPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DCore_QComponentPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QComponentPTR_IDX], "QList<Qt3DCore::QComponent*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QComponentPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DCore_QComponentPTR__Convertible);
    // Register converters for type aliases of QList<Qt3DCore::QComponent*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DCore_QComponentPTR_IDX], "Qt3DCore::QComponentVector");

    // Register converter for type 'QList<Qt3DRender::QTechnique*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QTechniquePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QTechniquePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QTechniquePTR_IDX], "QList<Qt3DRender::QTechnique*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QTechniquePTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QTechniquePTR__Convertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_qreal_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_qreal_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_qreal_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'std::vector<QSharedPointer<Qt3DCore::QAspectJob>>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_vector_QSharedPointer_Qt3DCore_QAspectJob___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX], "std::vector<QSharedPointer<Qt3DCore::QAspectJob>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_std_vector_QSharedPointer_Qt3DCore_QAspectJob_IDX],
        PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob__,
        is_PySequence_PythonToCpp_std_vector_QSharedPointer_Qt3DCore_QAspectJob___Convertible);

    // Register converter for type 'QList<Qt3DRender::QRenderPass*>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_Qt3DRender_QRenderPassPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX], "QList<Qt3DRender::QRenderPass*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_Qt3DRender_QRenderPassPTR_IDX],
        PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR_,
        is_PySequence_PythonToCpp__QList_Qt3DRender_QRenderPassPTR__Convertible);

    // Register converter for type 'QList<QSharedPointer<Qt3DRender::QTextureImageData>>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSharedPointer_Qt3DRender_QTextureImageData___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX], "QList<QSharedPointer<Qt3DRender::QTextureImageData>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QSharedPointer_Qt3DRender_QTextureImageData_IDX],
        PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData__,
        is_PySequence_PythonToCpp__QList_QSharedPointer_Qt3DRender_QTextureImageData___Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QString>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_Qt3DRenderTypeConverters[SBK_Qt3DRender_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);



    // Register SmartPointer converter for type 'QSharedPointer<Qt3DRender::QTextureImageDataGenerator>'.
    ///////////////////////////////////////////////////////////////////////////////////////

    // Class not found:Qt3DRender::QTextureImageDataGenerator///////////////////////////////////////////////////////////////////////////////////////



    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_Qt3DRenderTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_Qt3DRenderTypeConverters);

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module Qt3DRender");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, Qt3DRender_SignatureStrings);

    return module;
}
