// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qjsonvalue_wrapper.h"

// Extra includes
#include <QJsonArray>
#include <QJsonObject>
#include <QVariant>

// Argument includes
#include <QString>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qjsonarray.h>
#include <qjsonobject.h>
#include <qjsonvalue.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJsonValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJsonValue >()))
        return -1;

    ::QJsonValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:QJsonValue", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJsonValue::QJsonValue(QJsonValue::Type=)
    // 1: QJsonValue::QJsonValue(QLatin1String)
    // 2: QJsonValue::QJsonValue(bool)
    // 3: QJsonValue::QJsonValue(QJsonArray)
    // 4: QJsonValue::QJsonValue(QJsonObject)
    // 5: QJsonValue::QJsonValue(QJsonValue)
    // 6: QJsonValue::QJsonValue(QString)
    // 7: QJsonValue::QJsonValue(const char*)
    // 8: QJsonValue::QJsonValue(double)
    // 9: QJsonValue::QJsonValue(int)
    // 10: QJsonValue::QJsonValue(qint64)
    if (numArgs == 0) {
        overloadId = 0; // QJsonValue(QJsonValue::Type)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        overloadId = 4; // QJsonValue(QJsonObject)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QJsonValue(QJsonArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 1; // QJsonValue(QLatin1String)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QJsonValue(QJsonValue::Type)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 8; // QJsonValue(double)
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 7; // QJsonValue(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 6; // QJsonValue(QString)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 2; // QJsonValue(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 10; // QJsonValue(qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 9; // QJsonValue(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArgs[0])))) {
        overloadId = 5; // QJsonValue(QJsonValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJsonValue(QJsonValue::Type arg__1)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
                if (PyDict_Contains(kwds, key_arg__1) != 0) {
                    value = PyDict_GetItem(kwds, key_arg__1);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_arg__1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_arg__1);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QJsonValue::Type cppArg0(QJsonValue::Type::Null);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonValue::Type)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 1: // QJsonValue(QLatin1String s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QLatin1String)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 2: // QJsonValue(bool b)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(bool)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 3: // QJsonValue(const QJsonArray & a)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonArray)
                cptr = new ::QJsonValue(*cppArg0);
            }
            break;
        }
        case 4: // QJsonValue(const QJsonObject & o)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonObject)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 5: // QJsonValue(const QJsonValue & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJsonValue cppArg0_local;
            ::QJsonValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QJsonValue)
                cptr = new ::QJsonValue(*cppArg0);
            }
            break;
        }
        case 6: // QJsonValue(const QString & s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(QString)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 7: // QJsonValue(const char * s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(const char*)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 8: // QJsonValue(double n)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(double)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 9: // QJsonValue(int n)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(int)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
        case 10: // QJsonValue(qint64 v)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJsonValue(qint64)
                cptr = new ::QJsonValue(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJsonValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJsonValueFunc_fromVariant(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.fromVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QJsonValue::fromVariant(QVariant)->QJsonValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVariant(QVariant)
            QJsonValue cppResult = ::QJsonValue::fromVariant(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isArray()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isBool()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isBool();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDouble()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isDouble();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isObject()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isObject();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isString()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isString();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.isUndefined";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUndefined()const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->isUndefined();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJsonValue::swap(QJsonValue&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QJsonValue&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonValue cppArg0_local;
        ::QJsonValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QJsonValue&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJsonValueFunc_toArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toArray()const->QJsonArray
    // 1: QJsonValue::toArray(QJsonArray)const->QJsonArray
    if (numArgs == 0) {
        overloadId = 0; // toArray()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // toArray(QJsonArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toArray() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toArray()const
                QJsonArray cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toArray();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toArray(const QJsonArray & defaultValue) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJsonArray cppArg0_local;
            ::QJsonArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // toArray(QJsonArray)const
                QJsonArray cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toArray(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toBool(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toBool", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toBool(bool=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // toBool(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // toBool(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toBool(bool)const
            bool cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toBool(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toDouble(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toDouble", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toDouble(double=)const->double
    if (numArgs == 0) {
        overloadId = 0; // toDouble(double)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 0; // toDouble(double)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        double cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDouble(double)const
            double cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toDouble(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toInt(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toInt", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toInt(int=)const->int
    if (numArgs == 0) {
        overloadId = 0; // toInt(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toInt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInt(int)const
            int cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toInt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toInteger(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toInteger";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toInteger", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toInteger(qint64=)const->qint64
    if (numArgs == 0) {
        overloadId = 0; // toInteger(qint64)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 0; // toInteger(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qint64 cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInteger(qint64)const
            qint64 cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toInteger(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toObject(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toObject", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toObject()const->QJsonObject
    // 1: QJsonValue::toObject(QJsonObject)const->QJsonObject
    if (numArgs == 0) {
        overloadId = 0; // toObject()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArgs[0])))) {
        overloadId = 1; // toObject(QJsonObject)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toObject() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toObject()const
                QJsonObject cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toObject();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], &cppResult);
            }
            break;
        }
        case 1: // toObject(const QJsonObject & defaultValue) const
        {
            ::QJsonObject cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toObject(QJsonObject)const
                QJsonObject cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toObject(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toString", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJsonValue::toString()const->QString
    // 1: QJsonValue::toString(QString)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // toString(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toString() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString()const
                QString cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toString();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toString(const QString & defaultValue) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QString)const
                QString cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.toVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toVariant()const
            QVariant cppResult = const_cast<const ::QJsonValue *>(cppSelf)->toVariant();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValueFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QJsonValue.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QJsonValue::Type cppResult = const_cast<const ::QJsonValue *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJsonValue__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJsonValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJsonValue_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJsonValue_methods[] = {
    {"fromVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_fromVariant), METH_O|METH_STATIC, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isArray), METH_NOARGS, nullptr},
    {"isBool", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isBool), METH_NOARGS, nullptr},
    {"isDouble", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isDouble), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isNull), METH_NOARGS, nullptr},
    {"isObject", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isObject), METH_NOARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isString), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_isUndefined), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_swap), METH_O, nullptr},
    {"toArray", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toArray), METH_VARARGS, nullptr},
    {"toBool", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toBool), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toDouble), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInt", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toInt), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toInteger), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toObject", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toObject), METH_VARARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toString), METH_VARARGS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_toVariant), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QJsonValueFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJsonValue__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJsonValue___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QJsonValue_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
                // operator!=(const QJsonValue & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
                // operator==(const QJsonValue & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QJsonValue_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QJsonValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJsonValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QJsonValue__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJsonValue_Type = nullptr;
static PyTypeObject *Sbk_QJsonValue_TypeF(void)
{
    return _Sbk_QJsonValue_Type;
}

static PyType_Slot Sbk_QJsonValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QJsonValue__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QJsonValue_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJsonValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJsonValue_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QJsonValue_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJsonValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJsonValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QJsonValue___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJsonValue_spec = {
    "2:PySide6.QtCore.QJsonValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJsonValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QJsonValue_Type_PythonToCpp_QJsonValue_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJsonValue::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJsonValue::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QJsonValue_Type_PythonToCpp_QJsonValue_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))
        return QJsonValue_Type_PythonToCpp_QJsonValue_Type;
    return {};
}
static PyObject *QJsonValue_Type_CppToPython_QJsonValue_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QJsonValue::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJsonValue_PythonToCpp_QJsonValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJsonValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJsonValue_PythonToCpp_QJsonValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonValue_TypeF()))
        return QJsonValue_PythonToCpp_QJsonValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJsonValue_PTR_CppToPython_QJsonValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QJsonValue *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QJsonValue_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QJsonValue_COPY_CppToPython_QJsonValue(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJsonValue *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJsonValue_TypeF(), new ::QJsonValue(*source), true, true);
}

// Python to C++ copy conversion.
static void QJsonValue_PythonToCpp_QJsonValue_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonValue *>(cppOut) = *reinterpret_cast< ::QJsonValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJsonValue_PythonToCpp_QJsonValue_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJsonValue_TypeF()))
        return QJsonValue_PythonToCpp_QJsonValue_COPY;
    return {};
}

// Implicit conversions.
static void QJsonValue_Type_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QJsonValue::Type cppIn{QJsonValue::Null};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_QJsonValue_Type_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX]), pyIn))
        return QJsonValue_Type_PythonToCpp_QJsonValue;
    return {};
}

static void QLatin1String_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QLatin1String cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_QLatin1String_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return QLatin1String_PythonToCpp_QJsonValue;
    return {};
}

static void bool_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    bool cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_bool_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return bool_PythonToCpp_QJsonValue;
    return {};
}

static void constQJsonArrayREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue( *reinterpret_cast< ::QJsonArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQJsonArrayREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), pyIn))
        return constQJsonArrayREF_PythonToCpp_QJsonValue;
    return {};
}

static void constQJsonObjectREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QJsonObject cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constQJsonObjectREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::isPythonToCppConvertible(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], pyIn))
        return constQJsonObjectREF_PythonToCpp_QJsonValue;
    return {};
}

static void constQStringREF_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QJsonValue;
    return {};
}

static void constcharPTR_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    const char* cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_constcharPTR_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return constcharPTR_PythonToCpp_QJsonValue;
    return {};
}

static void double_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    double cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_double_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return double_PythonToCpp_QJsonValue;
    return {};
}

static void int_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QJsonValue;
    return {};
}

static void qint64_PythonToCpp_QJsonValue(PyObject *pyIn, void *cppOut)
{
    qint64 cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyIn, &cppIn);
    *reinterpret_cast<::QJsonValue *>(cppOut) = ::QJsonValue(cppIn);
}
static PythonToCppFunc is_qint64_PythonToCpp_QJsonValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return qint64_PythonToCpp_QJsonValue;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QJsonValue_SignatureStrings[] = {
    "10:PySide6.QtCore.QJsonValue(self,arg__1:PySide6.QtCore.QJsonValue.Type=QJsonValue.Type.Null)",
    "9:PySide6.QtCore.QJsonValue(self,s:QLatin1String)",
    "8:PySide6.QtCore.QJsonValue(self,b:bool)",
    "7:PySide6.QtCore.QJsonValue(self,a:PySide6.QtCore.QJsonArray)",
    "6:PySide6.QtCore.QJsonValue(self,o:QJsonObject)",
    "5:PySide6.QtCore.QJsonValue(self,other:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])",
    "4:PySide6.QtCore.QJsonValue(self,s:QString)",
    "3:PySide6.QtCore.QJsonValue(self,s:char*)",
    "2:PySide6.QtCore.QJsonValue(self,n:double)",
    "1:PySide6.QtCore.QJsonValue(self,n:int)",
    "0:PySide6.QtCore.QJsonValue(self,v:qint64)",
    "PySide6.QtCore.QJsonValue.fromVariant(variant:QVariant)->PySide6.QtCore.QJsonValue",
    "PySide6.QtCore.QJsonValue.isArray(self)->bool",
    "PySide6.QtCore.QJsonValue.isBool(self)->bool",
    "PySide6.QtCore.QJsonValue.isDouble(self)->bool",
    "PySide6.QtCore.QJsonValue.isNull(self)->bool",
    "PySide6.QtCore.QJsonValue.isObject(self)->bool",
    "PySide6.QtCore.QJsonValue.isString(self)->bool",
    "PySide6.QtCore.QJsonValue.isUndefined(self)->bool",
    "PySide6.QtCore.QJsonValue.swap(self,other:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])",
    "1:PySide6.QtCore.QJsonValue.toArray(self)->PySide6.QtCore.QJsonArray",
    "0:PySide6.QtCore.QJsonValue.toArray(self,defaultValue:PySide6.QtCore.QJsonArray)->PySide6.QtCore.QJsonArray",
    "PySide6.QtCore.QJsonValue.toBool(self,defaultValue:bool=false)->bool",
    "PySide6.QtCore.QJsonValue.toDouble(self,defaultValue:double=0)->double",
    "PySide6.QtCore.QJsonValue.toInt(self,defaultValue:int=0)->int",
    "PySide6.QtCore.QJsonValue.toInteger(self,defaultValue:qint64=0)->qint64",
    "1:PySide6.QtCore.QJsonValue.toObject(self)->QJsonObject",
    "0:PySide6.QtCore.QJsonValue.toObject(self,defaultValue:QJsonObject)->QJsonObject",
    "1:PySide6.QtCore.QJsonValue.toString(self)->QString",
    "0:PySide6.QtCore.QJsonValue.toString(self,defaultValue:QString)->QString",
    "PySide6.QtCore.QJsonValue.toVariant(self)->QVariant",
    "PySide6.QtCore.QJsonValue.type(self)->PySide6.QtCore.QJsonValue.Type",
    "PySide6.QtCore.QJsonValue.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QJsonValue(PyObject *module)
{
    _Sbk_QJsonValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJsonValue",
        "QJsonValue",
        &Sbk_QJsonValue_spec,
        &Shiboken::callCppDestructor< ::QJsonValue >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJsonValue_TypeF(); // references _Sbk_QJsonValue_Type
    InitSignatureStrings(pyType, QJsonValue_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJsonValue_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJsonValue_PythonToCpp_QJsonValue_PTR,
        is_QJsonValue_PythonToCpp_QJsonValue_PTR_Convertible,
        QJsonValue_PTR_CppToPython_QJsonValue,
        QJsonValue_COPY_CppToPython_QJsonValue);

    Shiboken::Conversions::registerConverterName(converter, "QJsonValue");
    Shiboken::Conversions::registerConverterName(converter, "QJsonValue*");
    Shiboken::Conversions::registerConverterName(converter, "QJsonValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJsonValue).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonValue_PythonToCpp_QJsonValue_COPY,
        is_QJsonValue_PythonToCpp_QJsonValue_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJsonValue_Type_PythonToCpp_QJsonValue,
        is_QJsonValue_Type_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLatin1String_PythonToCpp_QJsonValue,
        is_QLatin1String_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        bool_PythonToCpp_QJsonValue,
        is_bool_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQJsonArrayREF_PythonToCpp_QJsonValue,
        is_constQJsonArrayREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQJsonObjectREF_PythonToCpp_QJsonValue,
        is_constQJsonObjectREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QJsonValue,
        is_constQStringREF_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constcharPTR_PythonToCpp_QJsonValue,
        is_constcharPTR_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        double_PythonToCpp_QJsonValue,
        is_double_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QJsonValue,
        is_int_PythonToCpp_QJsonValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        qint64_PythonToCpp_QJsonValue,
        is_qint64_PythonToCpp_QJsonValue_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJsonValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Null",
        "Bool",
        "Double",
        "String",
        "Array",
        "Object",
        "Undefined",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QJsonValue::Type::Null),     //  0x00  0
        uint8_t(QJsonValue::Type::Bool),     //  0x01  1
        uint8_t(QJsonValue::Type::Double),   //  0x02  2
        uint8_t(QJsonValue::Type::String),   //  0x03  3
        uint8_t(QJsonValue::Type::Array),    //  0x04  4
        uint8_t(QJsonValue::Type::Object),   //  0x05  5
        uint8_t(QJsonValue::Type::Undefined) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJsonValue_TypeF(),
        "2:PySide6.QtCore.QJsonValue.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_Type_IDX].type = EType;
    // Register converter for enum 'QJsonValue::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJsonValue_Type_CppToPython_QJsonValue_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QJsonValue_Type_PythonToCpp_QJsonValue_Type,
            is_QJsonValue_Type_PythonToCpp_QJsonValue_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QJsonValue::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QJsonValue >("QJsonValue");
    qRegisterMetaType< ::QJsonValue::Type >("QJsonValue::Type");

    return pyType;
}
