// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmessagelogcontext_wrapper.h"

// Argument includes
#include <qlogging.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMessageLogContext_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMessageLogContext >()))
        return -1;

    ::QMessageLogContext *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMessageLogContext.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1 || numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "QMessageLogContext", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMessageLogContext::QMessageLogContext()
    // 1: QMessageLogContext::QMessageLogContext(const char*,int,const char*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // QMessageLogContext()
    } else if (numArgs == 4
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
        overloadId = 1; // QMessageLogContext(const char*,int,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMessageLogContext()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMessageLogContext()
                cptr = new ::QMessageLogContext();
            }
            break;
        }
        case 1: // QMessageLogContext(const char * fileName, int lineNumber, const char * functionName, const char * categoryName)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMessageLogContext(const char*,int,const char*,const char*)
                cptr = new ::QMessageLogContext(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMessageLogContext >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QMessageLogContext_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMessageLogContext_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QMessageLogContext_get_version(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->version;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QMessageLogContext_set_version(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("version");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("version", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->version;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->version = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMessageLogContext_get_line(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->line;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QMessageLogContext_set_line(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("line");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("line", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->line;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->line = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMessageLogContext_get_file(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const char* cppOut_local = cppSelf->file;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppOut_local);
    return pyOut;
}
static int Sbk_QMessageLogContext_set_file(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("file");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!Shiboken::String::check(pyIn) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("file", "char");
        return -1;
    }

    auto cppOut_local = cppSelf->file;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->file = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMessageLogContext_get_function(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const char* cppOut_local = cppSelf->function;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppOut_local);
    return pyOut;
}
static int Sbk_QMessageLogContext_set_function(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("function");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!Shiboken::String::check(pyIn) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("function", "char");
        return -1;
    }

    auto cppOut_local = cppSelf->function;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->function = cppOut_local;

    return 0;
}

static PyObject *Sbk_QMessageLogContext_get_category(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    const char* cppOut_local = cppSelf->category;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppOut_local);
    return pyOut;
}
static int Sbk_QMessageLogContext_set_category(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QMessageLogContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("category");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!Shiboken::String::check(pyIn) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("category", "char");
        return -1;
    }

    auto cppOut_local = cppSelf->category;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->category = cppOut_local;

    return 0;
}

// Getters and Setters for QMessageLogContext
static PyGetSetDef Sbk_QMessageLogContext_getsetlist[] = {
    {const_cast<char *>("version"), Sbk_QMessageLogContext_get_version, Sbk_QMessageLogContext_set_version, nullptr, nullptr},
    {const_cast<char *>("line"), Sbk_QMessageLogContext_get_line, Sbk_QMessageLogContext_set_line, nullptr, nullptr},
    {const_cast<char *>("file"), Sbk_QMessageLogContext_get_file, Sbk_QMessageLogContext_set_file, nullptr, nullptr},
    {const_cast<char *>("function"), Sbk_QMessageLogContext_get_function, Sbk_QMessageLogContext_set_function, nullptr, nullptr},
    {const_cast<char *>("category"), Sbk_QMessageLogContext_get_category, Sbk_QMessageLogContext_set_category, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMessageLogContext_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMessageLogContext_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMessageLogContext_Type = nullptr;
static PyTypeObject *Sbk_QMessageLogContext_TypeF(void)
{
    return _Sbk_QMessageLogContext_Type;
}

static PyType_Slot Sbk_QMessageLogContext_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMessageLogContext_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMessageLogContext_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMessageLogContext_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QMessageLogContext_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMessageLogContext_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMessageLogContext_spec = {
    "2:PySide6.QtCore.QMessageLogContext",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMessageLogContext_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMessageLogContext_PythonToCpp_QMessageLogContext_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMessageLogContext_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMessageLogContext_PythonToCpp_QMessageLogContext_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMessageLogContext_TypeF()))
        return QMessageLogContext_PythonToCpp_QMessageLogContext_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMessageLogContext_PTR_CppToPython_QMessageLogContext(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QMessageLogContext *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QMessageLogContext_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QMessageLogContext_SignatureStrings[] = {
    "1:PySide6.QtCore.QMessageLogContext(self)",
    "0:PySide6.QtCore.QMessageLogContext(self,fileName:char*,lineNumber:int,functionName:char*,categoryName:char*)",
    nullptr}; // Sentinel

PyTypeObject *init_QMessageLogContext(PyObject *module)
{
    _Sbk_QMessageLogContext_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMessageLogContext",
        "QMessageLogContext*",
        &Sbk_QMessageLogContext_spec,
        &Shiboken::callCppDestructor< ::QMessageLogContext >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QMessageLogContext_TypeF(); // references _Sbk_QMessageLogContext_Type
    InitSignatureStrings(pyType, QMessageLogContext_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMessageLogContext_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMessageLogContext_PythonToCpp_QMessageLogContext_PTR,
        is_QMessageLogContext_PythonToCpp_QMessageLogContext_PTR_Convertible,
        QMessageLogContext_PTR_CppToPython_QMessageLogContext);

    Shiboken::Conversions::registerConverterName(converter, "QMessageLogContext");
    Shiboken::Conversions::registerConverterName(converter, "QMessageLogContext*");
    Shiboken::Conversions::registerConverterName(converter, "QMessageLogContext&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMessageLogContext).name());

    qRegisterMetaType< ::QMessageLogContext *>();

    return pyType;
}
