// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qrandomgenerator64_wrapper.h"

// Argument includes
#include <qrandom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRandomGenerator64_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRandomGenerator64 >()))
        return -1;

    ::QRandomGenerator64 *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QRandomGenerator64", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRandomGenerator64::QRandomGenerator64(QRandomGenerator)
    // 1: QRandomGenerator64::QRandomGenerator64(const quint32*,const quint32*)
    // 2: QRandomGenerator64::QRandomGenerator64(const quint32*,qsizetype)
    // 3: QRandomGenerator64::QRandomGenerator64(quint32=)
    if (numArgs == 0) {
        overloadId = 3; // QRandomGenerator64(quint32)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QRandomGenerator64(quint32)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 2; // QRandomGenerator64(const quint32*,qsizetype)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            overloadId = 1; // QRandomGenerator64(const quint32*,const quint32*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QRandomGenerator64(QRandomGenerator)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRandomGenerator64(const QRandomGenerator & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRandomGenerator *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(QRandomGenerator)
                cptr = new ::QRandomGenerator64(*cppArg0);
            }
            break;
        }
        case 1: // QRandomGenerator64(const quint32 * begin, const quint32 * end)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            quint32 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint32 *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(const quint32*,const quint32*)
                cptr = new ::QRandomGenerator64(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QRandomGenerator64(const quint32 * seedBuffer, qsizetype len)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            quint32 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(const quint32*,qsizetype)
                cptr = new ::QRandomGenerator64(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QRandomGenerator64(quint32 seedValue)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_seedValue = Shiboken::String::createStaticString("seedValue");
                if (PyDict_Contains(kwds, key_seedValue) != 0) {
                    value = PyDict_GetItem(kwds, key_seedValue);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_seedValue);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_seedValue);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            quint32 cppArg0 = 1;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRandomGenerator64(quint32)
                cptr = new ::QRandomGenerator64(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRandomGenerator64 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRandomGenerator64Func_discard(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRandomGenerator64 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.discard";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRandomGenerator::discard(qulonglong)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), (pyArg)))) {
        overloadId = 0; // discard(qulonglong)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // discard(qulonglong)
            cppSelf->discard(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRandomGenerator64Func_generate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRandomGenerator64 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.generate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // generate()
            quint64 cppResult = cppSelf->generate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_global_(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.global_";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // global()
            QRandomGenerator64 * cppResult = ::QRandomGenerator64::global();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_max(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.max";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // max()
            unsigned long long cppResult = ::QRandomGenerator64::max();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_min(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.min";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // min()
            unsigned long long cppResult = ::QRandomGenerator64::min();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_securelySeeded(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.securelySeeded";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // securelySeeded()
            QRandomGenerator64* cppResult = new QRandomGenerator64(::QRandomGenerator64::securelySeeded());
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRandomGenerator64Func_system(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRandomGenerator64.system";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // system()
            QRandomGenerator64 * cppResult = ::QRandomGenerator64::system();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRandomGenerator64_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRandomGenerator64_methods[] = {
    {"discard", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_discard), METH_O, nullptr},
    {"generate", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_generate), METH_NOARGS, nullptr},
    {"global_", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_global_), METH_NOARGS|METH_STATIC, nullptr},
    {"max", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_max), METH_NOARGS|METH_STATIC, nullptr},
    {"min", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_min), METH_NOARGS|METH_STATIC, nullptr},
    {"securelySeeded", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_securelySeeded), METH_NOARGS|METH_STATIC, nullptr},
    {"system", reinterpret_cast<PyCFunction>(Sbk_QRandomGenerator64Func_system), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRandomGenerator64_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRandomGenerator64_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRandomGenerator64_Type = nullptr;
static PyTypeObject *Sbk_QRandomGenerator64_TypeF(void)
{
    return _Sbk_QRandomGenerator64_Type;
}

static PyType_Slot Sbk_QRandomGenerator64_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRandomGenerator64_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRandomGenerator64_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRandomGenerator64_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRandomGenerator64_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRandomGenerator64_spec = {
    "2:PySide6.QtCore.QRandomGenerator64",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRandomGenerator64_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRandomGenerator64_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRandomGenerator64_TypeF()))
        return QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRandomGenerator64_PTR_CppToPython_QRandomGenerator64(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRandomGenerator64 *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRandomGenerator64_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRandomGenerator64_SignatureStrings[] = {
    "3:PySide6.QtCore.QRandomGenerator64(self,other:PySide6.QtCore.QRandomGenerator)",
    "2:PySide6.QtCore.QRandomGenerator64(self,begin:quint32*,end:quint32*)",
    "1:PySide6.QtCore.QRandomGenerator64(self,seedBuffer:quint32*,len:qsizetype)",
    "0:PySide6.QtCore.QRandomGenerator64(self,seedValue:quint32=1)",
    "PySide6.QtCore.QRandomGenerator64.discard(self,z:unsigned long long)",
    "PySide6.QtCore.QRandomGenerator64.generate(self)->quint64",
    "PySide6.QtCore.QRandomGenerator64.global_()->PySide6.QtCore.QRandomGenerator64",
    "PySide6.QtCore.QRandomGenerator64.max()->unsigned long long",
    "PySide6.QtCore.QRandomGenerator64.min()->unsigned long long",
    "PySide6.QtCore.QRandomGenerator64.securelySeeded()->PySide6.QtCore.QRandomGenerator64",
    "PySide6.QtCore.QRandomGenerator64.system()->PySide6.QtCore.QRandomGenerator64",
    nullptr}; // Sentinel

PyTypeObject *init_QRandomGenerator64(PyObject *module)
{
    _Sbk_QRandomGenerator64_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRandomGenerator64",
        "QRandomGenerator64*",
        &Sbk_QRandomGenerator64_spec,
        &Shiboken::callCppDestructor< ::QRandomGenerator64 >,
        Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator_IDX]),
        0,
        0);
    auto *pyType = Sbk_QRandomGenerator64_TypeF(); // references _Sbk_QRandomGenerator64_Type
    InitSignatureStrings(pyType, QRandomGenerator64_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRandomGenerator64_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRandomGenerator64_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR,
        is_QRandomGenerator64_PythonToCpp_QRandomGenerator64_PTR_Convertible,
        QRandomGenerator64_PTR_CppToPython_QRandomGenerator64);

    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64");
    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64*");
    Shiboken::Conversions::registerConverterName(converter, "QRandomGenerator64&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRandomGenerator64).name());

    qRegisterMetaType< ::QRandomGenerator64 *>();

    return pyType;
}
