// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qregularexpression_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qnamespace.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRegularExpression_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRegularExpression >()))
        return -1;

    ::QRegularExpression *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QRegularExpression", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRegularExpression::QRegularExpression()
    // 1: QRegularExpression::QRegularExpression(QRegularExpression)
    // 2: QRegularExpression::QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>=)
    if (numArgs == 0) {
        overloadId = 0; // QRegularExpression()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 2; // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRegularExpression(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRegularExpression()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRegularExpression()
                cptr = new ::QRegularExpression();
            }
            break;
        }
        case 1: // QRegularExpression(const QRegularExpression & re)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRegularExpression(QRegularExpression)
                cptr = new ::QRegularExpression(*cppArg0);
            }
            break;
        }
        case 2: // QRegularExpression(const QString & pattern, QFlags<QRegularExpression::PatternOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRegularExpression::PatternOption> cppArg1(QRegularExpression::PatternOption::NoPatternOption);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRegularExpression(QString,QFlags<QRegularExpression::PatternOption>)
                cptr = new ::QRegularExpression(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRegularExpression >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRegularExpressionFunc_anchoredPattern(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.anchoredPattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRegularExpression::anchoredPattern(QStringView)->QString
    // 1: static QRegularExpression::anchoredPattern(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // anchoredPattern(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // anchoredPattern(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // anchoredPattern(QStringView expression)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // anchoredPattern(QStringView)
                QString cppResult = ::QRegularExpression::anchoredPattern(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // anchoredPattern(const QString & expression)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // anchoredPattern(QString)
                QString cppResult = ::QRegularExpression::anchoredPattern(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_captureCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.captureCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // captureCount()const
            int cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->captureCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_escape(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.escape";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRegularExpression::escape(QStringView)->QString
    // 1: static QRegularExpression::escape(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // escape(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // escape(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // escape(QStringView str)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // escape(QStringView)
                QString cppResult = ::QRegularExpression::escape(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // escape(const QString & str)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // escape(QString)
                QString cppResult = ::QRegularExpression::escape(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_fromWildcard(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.fromWildcard";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:fromWildcard", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRegularExpression::fromWildcard(QStringView,Qt::CaseSensitivity=,QFlags<QRegularExpression::WildcardConversionOption>=)->QRegularExpression
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 0; // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_cs = Shiboken::String::createStaticString("cs");
            if (PyDict_Contains(kwds, key_cs) != 0) {
                value = PyDict_GetItem(kwds, key_cs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_cs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_cs);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::CaseSensitivity cppArg1(Qt::CaseInsensitive);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QRegularExpression::WildcardConversionOption> cppArg2(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromWildcard(QStringView,Qt::CaseSensitivity,QFlags<QRegularExpression::WildcardConversionOption>)
            QRegularExpression cppResult = ::QRegularExpression::fromWildcard(QStringView(cppArg0), cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_globalMatch(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.globalMatch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:globalMatch", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::globalMatch(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatchIterator
    // 1: QRegularExpression::globalMatch(QString,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatchIterator
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 1; // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // globalMatch(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // globalMatch(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // globalMatch(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // globalMatch(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // globalMatch(QStringView subjectView, qsizetype offset, QRegularExpression::MatchType matchType, QFlags<QRegularExpression::MatchOption> matchOptions) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
                if (PyDict_Contains(kwds, key_matchType) != 0) {
                    value = PyDict_GetItem(kwds, key_matchType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchType);
                }
                static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
                if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                    value = PyDict_GetItem(kwds, key_matchOptions);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_matchOptions);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchOptions);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // globalMatch(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                QRegularExpressionMatchIterator cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->globalMatch(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatchIterator_IDX]), &cppResult);
            }
            break;
        }
        case 1: // globalMatch(const QString & subject, qsizetype offset, QRegularExpression::MatchType matchType, QFlags<QRegularExpression::MatchOption> matchOptions) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
                if (PyDict_Contains(kwds, key_matchType) != 0) {
                    value = PyDict_GetItem(kwds, key_matchType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchType);
                }
                static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
                if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                    value = PyDict_GetItem(kwds, key_matchOptions);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_matchOptions);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchOptions);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // globalMatch(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                QRegularExpressionMatchIterator cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->globalMatch(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatchIterator_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_globalMatchView(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.globalMatchView";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:globalMatchView", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::globalMatchView(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatchIterator
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
            if (PyDict_Contains(kwds, key_offset) != 0) {
                value = PyDict_GetItem(kwds, key_offset);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_offset);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_offset);
            }
            static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
            if (PyDict_Contains(kwds, key_matchType) != 0) {
                value = PyDict_GetItem(kwds, key_matchType);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_matchType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_matchType);
            }
            static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
            if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                value = PyDict_GetItem(kwds, key_matchOptions);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_matchOptions);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_matchOptions);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // globalMatchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatchIterator cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->globalMatchView(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatchIterator_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_match(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.match";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:match", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::match(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatch
    // 1: QRegularExpression::match(QString,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatch
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 1; // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // match(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // match(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // match(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // match(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // match(QStringView subjectView, qsizetype offset, QRegularExpression::MatchType matchType, QFlags<QRegularExpression::MatchOption> matchOptions) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
                if (PyDict_Contains(kwds, key_matchType) != 0) {
                    value = PyDict_GetItem(kwds, key_matchType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchType);
                }
                static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
                if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                    value = PyDict_GetItem(kwds, key_matchOptions);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_matchOptions);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchOptions);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // match(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                QRegularExpressionMatch cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->match(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), &cppResult);
            }
            break;
        }
        case 1: // match(const QString & subject, qsizetype offset, QRegularExpression::MatchType matchType, QFlags<QRegularExpression::MatchOption> matchOptions) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
                if (PyDict_Contains(kwds, key_matchType) != 0) {
                    value = PyDict_GetItem(kwds, key_matchType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchType);
                }
                static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
                if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                    value = PyDict_GetItem(kwds, key_matchOptions);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_matchOptions);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchOptions);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // match(QString,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                QRegularExpressionMatch cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->match(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_matchView(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.matchView";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:matchView", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRegularExpression::matchView(QStringView,qsizetype=,QRegularExpression::MatchType=,QFlags<QRegularExpression::MatchOption>=)const->QRegularExpressionMatch
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
            if (PyDict_Contains(kwds, key_offset) != 0) {
                value = PyDict_GetItem(kwds, key_offset);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_offset);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_offset);
            }
            static PyObject *const key_matchType = Shiboken::String::createStaticString("matchType");
            if (PyDict_Contains(kwds, key_matchType) != 0) {
                value = PyDict_GetItem(kwds, key_matchType);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_matchType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_matchType);
            }
            static PyObject *const key_matchOptions = Shiboken::String::createStaticString("matchOptions");
            if (PyDict_Contains(kwds, key_matchOptions) != 0) {
                value = PyDict_GetItem(kwds, key_matchOptions);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_matchOptions);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_matchOptions);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRegularExpression::MatchType cppArg2(QRegularExpression::MatchType::NormalMatch);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRegularExpression::MatchOption> cppArg3(QRegularExpression::MatchOption::NoMatchOption);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matchView(QStringView,qsizetype,QRegularExpression::MatchType,QFlags<QRegularExpression::MatchOption>)const
            QRegularExpressionMatch cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->matchView(QStringView(cppArg0), cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpressionMatch_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_namedCaptureGroups(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.namedCaptureGroups";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // namedCaptureGroups()const
            QStringList cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->namedCaptureGroups();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_optimize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.optimize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // optimize()const
            const_cast<const ::QRegularExpression *>(cppSelf)->optimize();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRegularExpressionFunc_pattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.pattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pattern()const
            QString cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->pattern();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_patternErrorOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.patternErrorOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // patternErrorOffset()const
            qsizetype cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->patternErrorOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_patternOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.patternOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // patternOptions()const
            QFlags<QRegularExpression::PatternOption> cppResult = const_cast<const ::QRegularExpression *>(cppSelf)->patternOptions();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpressionFunc_setPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.setPattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::setPattern(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPattern(QString)
            cppSelf->setPattern(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRegularExpressionFunc_setPatternOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.setPatternOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::setPatternOptions(QFlags<QRegularExpression::PatternOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPatternOptions(QFlags<QRegularExpression::PatternOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QRegularExpression::PatternOption> cppArg0 = QFlags<QRegularExpression::PatternOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPatternOptions(QFlags<QRegularExpression::PatternOption>)
            cppSelf->setPatternOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRegularExpressionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRegularExpression::swap(QRegularExpression&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QRegularExpression&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRegularExpression cppArg0_local;
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QRegularExpression&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRegularExpressionFunc_wildcardToRegularExpression(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRegularExpression.wildcardToRegularExpression";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:wildcardToRegularExpression", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRegularExpression::wildcardToRegularExpression(QStringView,QFlags<QRegularExpression::WildcardConversionOption>=)->QString
    // 1: static QRegularExpression::wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // wildcardToRegularExpression(QStringView,QFlags<QRegularExpression::WildcardConversionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // wildcardToRegularExpression(QStringView,QFlags<QRegularExpression::WildcardConversionOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // wildcardToRegularExpression(QStringView str, QFlags<QRegularExpression::WildcardConversionOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRegularExpression::WildcardConversionOption> cppArg1(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wildcardToRegularExpression(QStringView,QFlags<QRegularExpression::WildcardConversionOption>)
                QString cppResult = ::QRegularExpression::wildcardToRegularExpression(QStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // wildcardToRegularExpression(const QString & str, QFlags<QRegularExpression::WildcardConversionOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRegularExpression::WildcardConversionOption> cppArg1(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // wildcardToRegularExpression(QString,QFlags<QRegularExpression::WildcardConversionOption>)
                QString cppResult = ::QRegularExpression::wildcardToRegularExpression(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRegularExpression__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRegularExpression_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRegularExpression_EnumFlagInfo[] = {
    "MatchOption:Flag:MatchOptions",
    "MatchType:Enum",
    "PatternOption:Flag:PatternOptions",
    "WildcardConversionOption:Flag:WildcardConversionOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRegularExpression_methods[] = {
    {"anchoredPattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_anchoredPattern), METH_O|METH_STATIC, nullptr},
    {"captureCount", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_captureCount), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_errorString), METH_NOARGS, nullptr},
    {"escape", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_escape), METH_O|METH_STATIC, nullptr},
    {"fromWildcard", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_fromWildcard), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"globalMatch", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_globalMatch), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"globalMatchView", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_globalMatchView), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_isValid), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_match), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"matchView", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_matchView), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"namedCaptureGroups", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_namedCaptureGroups), METH_NOARGS, nullptr},
    {"optimize", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_optimize), METH_NOARGS, nullptr},
    {"pattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_pattern), METH_NOARGS, nullptr},
    {"patternErrorOffset", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_patternErrorOffset), METH_NOARGS, nullptr},
    {"patternOptions", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_patternOptions), METH_NOARGS, nullptr},
    {"setPattern", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_setPattern), METH_O, nullptr},
    {"setPatternOptions", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_setPatternOptions), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_swap), METH_O, nullptr},
    {"wildcardToRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QRegularExpressionFunc_wildcardToRegularExpression), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRegularExpression__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRegularExpression_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
                // operator!=(const QRegularExpression & re) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
                // operator==(const QRegularExpression & re) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRegularExpression_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRegularExpression_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRegularExpression_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRegularExpression__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRegularExpression_Type = nullptr;
static PyTypeObject *Sbk_QRegularExpression_TypeF(void)
{
    return _Sbk_QRegularExpression_Type;
}

static PyType_Slot Sbk_QRegularExpression_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRegularExpression__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRegularExpression_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRegularExpression_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRegularExpression_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRegularExpression_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRegularExpression_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRegularExpression_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRegularExpression_spec = {
    "2:PySide6.QtCore.QRegularExpression",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRegularExpression_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QRegularExpression_PatternOption_PythonToCpp_QRegularExpression_PatternOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::PatternOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::PatternOption *>(cppOut) = value;

}
static PythonToCppFunc is_QRegularExpression_PatternOption_PythonToCpp_QRegularExpression_PatternOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX])))
        return QRegularExpression_PatternOption_PythonToCpp_QRegularExpression_PatternOption;
    return {};
}
static PyObject *QRegularExpression_PatternOption_CppToPython_QRegularExpression_PatternOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRegularExpression::PatternOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX]), castCppIn);

}

static void QRegularExpression_MatchType_PythonToCpp_QRegularExpression_MatchType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::MatchType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::MatchType *>(cppOut) = value;

}
static PythonToCppFunc is_QRegularExpression_MatchType_PythonToCpp_QRegularExpression_MatchType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX])))
        return QRegularExpression_MatchType_PythonToCpp_QRegularExpression_MatchType;
    return {};
}
static PyObject *QRegularExpression_MatchType_CppToPython_QRegularExpression_MatchType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRegularExpression::MatchType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX]), castCppIn);

}

static void QRegularExpression_MatchOption_PythonToCpp_QRegularExpression_MatchOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::MatchOption>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QRegularExpression::MatchOption::AnchoredMatchOption:
        Shiboken::Warnings::warnDeprecatedEnumValue("QRegularExpression::MatchOption", "AnchoredMatchOption");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QRegularExpression::MatchOption *>(cppOut) = value;

}
static PythonToCppFunc is_QRegularExpression_MatchOption_PythonToCpp_QRegularExpression_MatchOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX])))
        return QRegularExpression_MatchOption_PythonToCpp_QRegularExpression_MatchOption;
    return {};
}
static PyObject *QRegularExpression_MatchOption_CppToPython_QRegularExpression_MatchOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRegularExpression::MatchOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX]), castCppIn);

}

static void QRegularExpression_WildcardConversionOption_PythonToCpp_QRegularExpression_WildcardConversionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRegularExpression::WildcardConversionOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRegularExpression::WildcardConversionOption *>(cppOut) = value;

}
static PythonToCppFunc is_QRegularExpression_WildcardConversionOption_PythonToCpp_QRegularExpression_WildcardConversionOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX])))
        return QRegularExpression_WildcardConversionOption_PythonToCpp_QRegularExpression_WildcardConversionOption;
    return {};
}
static PyObject *QRegularExpression_WildcardConversionOption_CppToPython_QRegularExpression_WildcardConversionOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRegularExpression::WildcardConversionOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRegularExpression_PythonToCpp_QRegularExpression_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRegularExpression_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRegularExpression_PythonToCpp_QRegularExpression_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRegularExpression_TypeF()))
        return QRegularExpression_PythonToCpp_QRegularExpression_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRegularExpression_PTR_CppToPython_QRegularExpression(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRegularExpression *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRegularExpression_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QRegularExpression_COPY_CppToPython_QRegularExpression(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRegularExpression *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRegularExpression_TypeF(), new ::QRegularExpression(*source), true, true);
}

// Python to C++ copy conversion.
static void QRegularExpression_PythonToCpp_QRegularExpression_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRegularExpression *>(cppOut) = *reinterpret_cast< ::QRegularExpression *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRegularExpression_PythonToCpp_QRegularExpression_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRegularExpression_TypeF()))
        return QRegularExpression_PythonToCpp_QRegularExpression_COPY;
    return {};
}

// Implicit conversions.
static void constQStringREF_PythonToCpp_QRegularExpression(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QRegularExpression *>(cppOut) = ::QRegularExpression(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QRegularExpression_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QRegularExpression;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRegularExpression_SignatureStrings[] = {
    "2:PySide6.QtCore.QRegularExpression(self)",
    "1:PySide6.QtCore.QRegularExpression(self,re:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "0:PySide6.QtCore.QRegularExpression(self,pattern:QString,options:PySide6.QtCore.QRegularExpression.PatternOption=QRegularExpression.PatternOption.NoPatternOption)",
    "1:PySide6.QtCore.QRegularExpression.anchoredPattern(expression:QString)->QString",
    "0:PySide6.QtCore.QRegularExpression.anchoredPattern(expression:QString)->QString",
    "PySide6.QtCore.QRegularExpression.captureCount(self)->int",
    "PySide6.QtCore.QRegularExpression.errorString(self)->QString",
    "1:PySide6.QtCore.QRegularExpression.escape(str:QString)->QString",
    "0:PySide6.QtCore.QRegularExpression.escape(str:QString)->QString",
    "PySide6.QtCore.QRegularExpression.fromWildcard(pattern:QString,cs:PySide6.QtCore.Qt.CaseSensitivity=Qt.CaseInsensitive,options:PySide6.QtCore.QRegularExpression.WildcardConversionOption=QRegularExpression.WildcardConversionOption.DefaultWildcardConversion)->PySide6.QtCore.QRegularExpression",
    "1:PySide6.QtCore.QRegularExpression.globalMatch(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatchIterator",
    "0:PySide6.QtCore.QRegularExpression.globalMatch(self,subject:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatchIterator",
    "PySide6.QtCore.QRegularExpression.globalMatchView(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatchIterator",
    "PySide6.QtCore.QRegularExpression.isValid(self)->bool",
    "1:PySide6.QtCore.QRegularExpression.match(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatch",
    "0:PySide6.QtCore.QRegularExpression.match(self,subject:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatch",
    "PySide6.QtCore.QRegularExpression.matchView(self,subjectView:QString,offset:qsizetype=0,matchType:PySide6.QtCore.QRegularExpression.MatchType=QRegularExpression.MatchType.NormalMatch,matchOptions:PySide6.QtCore.QRegularExpression.MatchOption=QRegularExpression.MatchOption.NoMatchOption)->PySide6.QtCore.QRegularExpressionMatch",
    "PySide6.QtCore.QRegularExpression.namedCaptureGroups(self)->QStringList",
    "PySide6.QtCore.QRegularExpression.optimize(self)",
    "PySide6.QtCore.QRegularExpression.pattern(self)->QString",
    "PySide6.QtCore.QRegularExpression.patternErrorOffset(self)->qsizetype",
    "PySide6.QtCore.QRegularExpression.patternOptions(self)->PySide6.QtCore.QRegularExpression.PatternOption",
    "PySide6.QtCore.QRegularExpression.setPattern(self,pattern:QString)",
    "PySide6.QtCore.QRegularExpression.setPatternOptions(self,options:PySide6.QtCore.QRegularExpression.PatternOption)",
    "PySide6.QtCore.QRegularExpression.swap(self,other:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "1:PySide6.QtCore.QRegularExpression.wildcardToRegularExpression(str:QString,options:PySide6.QtCore.QRegularExpression.WildcardConversionOption=QRegularExpression.WildcardConversionOption.DefaultWildcardConversion)->QString",
    "0:PySide6.QtCore.QRegularExpression.wildcardToRegularExpression(str:QString,options:PySide6.QtCore.QRegularExpression.WildcardConversionOption=QRegularExpression.WildcardConversionOption.DefaultWildcardConversion)->QString",
    "PySide6.QtCore.QRegularExpression.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QRegularExpression(PyObject *module)
{
    _Sbk_QRegularExpression_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRegularExpression",
        "QRegularExpression",
        &Sbk_QRegularExpression_spec,
        &Shiboken::callCppDestructor< ::QRegularExpression >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRegularExpression_TypeF(); // references _Sbk_QRegularExpression_Type
    InitSignatureStrings(pyType, QRegularExpression_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRegularExpression_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRegularExpression_PythonToCpp_QRegularExpression_PTR,
        is_QRegularExpression_PythonToCpp_QRegularExpression_PTR_Convertible,
        QRegularExpression_PTR_CppToPython_QRegularExpression,
        QRegularExpression_COPY_CppToPython_QRegularExpression);

    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression");
    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression*");
    Shiboken::Conversions::registerConverterName(converter, "QRegularExpression&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRegularExpression).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRegularExpression_PythonToCpp_QRegularExpression_COPY,
        is_QRegularExpression_PythonToCpp_QRegularExpression_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QRegularExpression,
        is_constQStringREF_PythonToCpp_QRegularExpression_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRegularExpression_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PatternOption'.
    const char *PatternOption_Initializer[] = {
        "NoPatternOption",
        "CaseInsensitiveOption",
        "DotMatchesEverythingOption",
        "MultilineOption",
        "ExtendedPatternSyntaxOption",
        "InvertedGreedinessOption",
        "DontCaptureOption",
        "UseUnicodePropertiesOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PatternOption_InitializerValues[] = {
        uint8_t(QRegularExpression::PatternOption::NoPatternOption),             //  0x00  0
        uint8_t(QRegularExpression::PatternOption::CaseInsensitiveOption),       //  0x01  1
        uint8_t(QRegularExpression::PatternOption::DotMatchesEverythingOption),  //  0x02  2
        uint8_t(QRegularExpression::PatternOption::MultilineOption),             //  0x04  4
        uint8_t(QRegularExpression::PatternOption::ExtendedPatternSyntaxOption), //  0x08  8
        uint8_t(QRegularExpression::PatternOption::InvertedGreedinessOption),    //  0x10  16
        uint8_t(QRegularExpression::PatternOption::DontCaptureOption),           //  0x20  32
        uint8_t(QRegularExpression::PatternOption::UseUnicodePropertiesOption)   //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.PatternOption",
        PatternOption_Initializer, PatternOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_PatternOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_PatternOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::PatternOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_PatternOption_CppToPython_QRegularExpression_PatternOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRegularExpression_PatternOption_PythonToCpp_QRegularExpression_PatternOption,
            is_QRegularExpression_PatternOption_PythonToCpp_QRegularExpression_PatternOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::PatternOption");
        Shiboken::Conversions::registerConverterName(converter, "PatternOption");
        // Register converter for flag 'QFlags<QRegularExpression::PatternOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRegularExpression::PatternOption>");
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::PatternOptions");
    }
    // End of 'PatternOption' enum/flags.

    // Initialization of enum 'MatchType'.
    const char *MatchType_Initializer[] = {
        "NormalMatch",
        "PartialPreferCompleteMatch",
        "PartialPreferFirstMatch",
        "NoMatch",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MatchType_InitializerValues[] = {
        uint8_t(QRegularExpression::MatchType::NormalMatch),                //  0x00  0
        uint8_t(QRegularExpression::MatchType::PartialPreferCompleteMatch), //  0x01  1
        uint8_t(QRegularExpression::MatchType::PartialPreferFirstMatch),    //  0x02  2
        uint8_t(QRegularExpression::MatchType::NoMatch)                     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.MatchType",
        MatchType_Initializer, MatchType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchType_IDX].type = EType;
    // Register converter for enum 'QRegularExpression::MatchType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_MatchType_CppToPython_QRegularExpression_MatchType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRegularExpression_MatchType_PythonToCpp_QRegularExpression_MatchType,
            is_QRegularExpression_MatchType_PythonToCpp_QRegularExpression_MatchType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::MatchType");
        Shiboken::Conversions::registerConverterName(converter, "MatchType");
    }
    // End of 'MatchType' enum.

    // Initialization of enum 'MatchOption'.
    const char *MatchOption_Initializer[] = {
        "NoMatchOption",
        "AnchorAtOffsetMatchOption",
        "AnchoredMatchOption",
        "DontCheckSubjectStringMatchOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MatchOption_InitializerValues[] = {
        uint8_t(QRegularExpression::MatchOption::NoMatchOption),                    //  0x00  0
        uint8_t(QRegularExpression::MatchOption::AnchorAtOffsetMatchOption),        //  0x01  1
        uint8_t(QRegularExpression::MatchOption::AnchoredMatchOption),              //  0x01  1
        uint8_t(QRegularExpression::MatchOption::DontCheckSubjectStringMatchOption) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.MatchOption",
        MatchOption_Initializer, MatchOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_MatchOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_MatchOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::MatchOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_MatchOption_CppToPython_QRegularExpression_MatchOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRegularExpression_MatchOption_PythonToCpp_QRegularExpression_MatchOption,
            is_QRegularExpression_MatchOption_PythonToCpp_QRegularExpression_MatchOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::MatchOption");
        Shiboken::Conversions::registerConverterName(converter, "MatchOption");
        // Register converter for flag 'QFlags<QRegularExpression::MatchOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRegularExpression::MatchOption>");
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::MatchOptions");
    }
    // End of 'MatchOption' enum/flags.

    // Initialization of enum 'WildcardConversionOption'.
    const char *WildcardConversionOption_Initializer[] = {
        "DefaultWildcardConversion",
        "UnanchoredWildcardConversion",
        "NonPathWildcardConversion",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WildcardConversionOption_InitializerValues[] = {
        uint8_t(QRegularExpression::WildcardConversionOption::DefaultWildcardConversion),    //  0x00  0
        uint8_t(QRegularExpression::WildcardConversionOption::UnanchoredWildcardConversion), //  0x01  1
        uint8_t(QRegularExpression::WildcardConversionOption::NonPathWildcardConversion)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRegularExpression_TypeF(),
        "2:PySide6.QtCore.QRegularExpression.WildcardConversionOption",
        WildcardConversionOption_Initializer, WildcardConversionOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_WildcardConversionOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QRegularExpression_WildcardConversionOption_IDX].type =
        EType;
    // Register converter for enum 'QRegularExpression::WildcardConversionOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRegularExpression_WildcardConversionOption_CppToPython_QRegularExpression_WildcardConversionOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRegularExpression_WildcardConversionOption_PythonToCpp_QRegularExpression_WildcardConversionOption,
            is_QRegularExpression_WildcardConversionOption_PythonToCpp_QRegularExpression_WildcardConversionOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::WildcardConversionOption");
        Shiboken::Conversions::registerConverterName(converter, "WildcardConversionOption");
        // Register converter for flag 'QFlags<QRegularExpression::WildcardConversionOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRegularExpression::WildcardConversionOption>");
        Shiboken::Conversions::registerConverterName(converter, "QRegularExpression::WildcardConversionOptions");
    }
    // End of 'WildcardConversionOption' enum/flags.

    qRegisterMetaType< ::QRegularExpression >("QRegularExpression");
    qRegisterMetaType< ::QRegularExpression::PatternOption >("QRegularExpression::PatternOption");
    qRegisterMetaType< ::QRegularExpression::MatchType >("QRegularExpression::MatchType");
    qRegisterMetaType< ::QRegularExpression::MatchOption >("QRegularExpression::MatchOption");
    qRegisterMetaType< ::QRegularExpression::WildcardConversionOption >("QRegularExpression::WildcardConversionOption");

    return pyType;
}
