// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qsysinfo_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSysInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSysInfo >()))
        return -1;

    ::QSysInfo *cptr{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSysInfo()
            cptr = new ::QSysInfo();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSysInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSysInfoFunc_bootUniqueId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.bootUniqueId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bootUniqueId()
            QByteArray cppResult = ::QSysInfo::bootUniqueId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_buildAbi(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.buildAbi";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // buildAbi()
            QString cppResult = ::QSysInfo::buildAbi();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_buildCpuArchitecture(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.buildCpuArchitecture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // buildCpuArchitecture()
            QString cppResult = ::QSysInfo::buildCpuArchitecture();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_currentCpuArchitecture(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.currentCpuArchitecture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // currentCpuArchitecture()
            QString cppResult = ::QSysInfo::currentCpuArchitecture();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_kernelType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.kernelType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // kernelType()
            QString cppResult = ::QSysInfo::kernelType();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_kernelVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.kernelVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // kernelVersion()
            QString cppResult = ::QSysInfo::kernelVersion();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_machineHostName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.machineHostName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // machineHostName()
            QString cppResult = ::QSysInfo::machineHostName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_machineUniqueId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.machineUniqueId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // machineUniqueId()
            QByteArray cppResult = ::QSysInfo::machineUniqueId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_prettyProductName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.prettyProductName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prettyProductName()
            QString cppResult = ::QSysInfo::prettyProductName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_productType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.productType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // productType()
            QString cppResult = ::QSysInfo::productType();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSysInfoFunc_productVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QSysInfo.productVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // productVersion()
            QString cppResult = ::QSysInfo::productVersion();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSysInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSysInfo_EnumFlagInfo[] = {
    "Endian:Enum",
    "Sizes:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSysInfo_methods[] = {
    {"bootUniqueId", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_bootUniqueId), METH_NOARGS|METH_STATIC, nullptr},
    {"buildAbi", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_buildAbi), METH_NOARGS|METH_STATIC, nullptr},
    {"buildCpuArchitecture", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_buildCpuArchitecture), METH_NOARGS|METH_STATIC, nullptr},
    {"currentCpuArchitecture", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_currentCpuArchitecture), METH_NOARGS|METH_STATIC, nullptr},
    {"kernelType", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_kernelType), METH_NOARGS|METH_STATIC, nullptr},
    {"kernelVersion", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_kernelVersion), METH_NOARGS|METH_STATIC, nullptr},
    {"machineHostName", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_machineHostName), METH_NOARGS|METH_STATIC, nullptr},
    {"machineUniqueId", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_machineUniqueId), METH_NOARGS|METH_STATIC, nullptr},
    {"prettyProductName", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_prettyProductName), METH_NOARGS|METH_STATIC, nullptr},
    {"productType", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_productType), METH_NOARGS|METH_STATIC, nullptr},
    {"productVersion", reinterpret_cast<PyCFunction>(Sbk_QSysInfoFunc_productVersion), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSysInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSysInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSysInfo_Type = nullptr;
static PyTypeObject *Sbk_QSysInfo_TypeF(void)
{
    return _Sbk_QSysInfo_Type;
}

static PyType_Slot Sbk_QSysInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSysInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSysInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSysInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSysInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSysInfo_spec = {
    "2:PySide6.QtCore.QSysInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSysInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSysInfo_Sizes_PythonToCpp_QSysInfo_Sizes(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSysInfo::Sizes>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSysInfo::Sizes *>(cppOut) = value;

}
static PythonToCppFunc is_QSysInfo_Sizes_PythonToCpp_QSysInfo_Sizes_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX])))
        return QSysInfo_Sizes_PythonToCpp_QSysInfo_Sizes;
    return {};
}
static PyObject *QSysInfo_Sizes_CppToPython_QSysInfo_Sizes(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSysInfo::Sizes *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX]), castCppIn);

}

static void QSysInfo_Endian_PythonToCpp_QSysInfo_Endian(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSysInfo::Endian>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSysInfo::Endian *>(cppOut) = value;

}
static PythonToCppFunc is_QSysInfo_Endian_PythonToCpp_QSysInfo_Endian_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX])))
        return QSysInfo_Endian_PythonToCpp_QSysInfo_Endian;
    return {};
}
static PyObject *QSysInfo_Endian_CppToPython_QSysInfo_Endian(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSysInfo::Endian *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSysInfo_PythonToCpp_QSysInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSysInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSysInfo_PythonToCpp_QSysInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSysInfo_TypeF()))
        return QSysInfo_PythonToCpp_QSysInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSysInfo_PTR_CppToPython_QSysInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QSysInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QSysInfo_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSysInfo_SignatureStrings[] = {
    "PySide6.QtCore.QSysInfo(self)",
    "PySide6.QtCore.QSysInfo.bootUniqueId()->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QSysInfo.buildAbi()->QString",
    "PySide6.QtCore.QSysInfo.buildCpuArchitecture()->QString",
    "PySide6.QtCore.QSysInfo.currentCpuArchitecture()->QString",
    "PySide6.QtCore.QSysInfo.kernelType()->QString",
    "PySide6.QtCore.QSysInfo.kernelVersion()->QString",
    "PySide6.QtCore.QSysInfo.machineHostName()->QString",
    "PySide6.QtCore.QSysInfo.machineUniqueId()->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QSysInfo.prettyProductName()->QString",
    "PySide6.QtCore.QSysInfo.productType()->QString",
    "PySide6.QtCore.QSysInfo.productVersion()->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QSysInfo(PyObject *module)
{
    _Sbk_QSysInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSysInfo",
        "QSysInfo*",
        &Sbk_QSysInfo_spec,
        &Shiboken::callCppDestructor< ::QSysInfo >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QSysInfo_TypeF(); // references _Sbk_QSysInfo_Type
    InitSignatureStrings(pyType, QSysInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSysInfo_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSysInfo_PythonToCpp_QSysInfo_PTR,
        is_QSysInfo_PythonToCpp_QSysInfo_PTR_Convertible,
        QSysInfo_PTR_CppToPython_QSysInfo);

    Shiboken::Conversions::registerConverterName(converter, "QSysInfo");
    Shiboken::Conversions::registerConverterName(converter, "QSysInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QSysInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSysInfo).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSysInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Sizes'.
    const char *Sizes_Initializer[] = {
        "WordSize",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Sizes_InitializerValues[] = {
        uint8_t(QSysInfo::Sizes::WordSize) //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSysInfo_TypeF(),
        "2:PySide6.QtCore.QSysInfo.Sizes",
        Sizes_Initializer, Sizes_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Sizes_IDX].type = EType;
    // Register converter for enum 'QSysInfo::Sizes'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSysInfo_Sizes_CppToPython_QSysInfo_Sizes);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSysInfo_Sizes_PythonToCpp_QSysInfo_Sizes,
            is_QSysInfo_Sizes_PythonToCpp_QSysInfo_Sizes_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSysInfo::Sizes");
        Shiboken::Conversions::registerConverterName(converter, "Sizes");
    }
    // End of 'Sizes' enum.

    // Initialization of enum 'Endian'.
    const char *Endian_Initializer[] = {
        "BigEndian",
        "LittleEndian",
        "ByteOrder",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Endian_InitializerValues[] = {
        uint8_t(QSysInfo::Endian::BigEndian),    //  0x00  0
        uint8_t(QSysInfo::Endian::LittleEndian), //  0x01  1
        uint8_t(QSysInfo::Endian::ByteOrder)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSysInfo_TypeF(),
        "2:PySide6.QtCore.QSysInfo.Endian",
        Endian_Initializer, Endian_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QSysInfo_Endian_IDX].type = EType;
    // Register converter for enum 'QSysInfo::Endian'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSysInfo_Endian_CppToPython_QSysInfo_Endian);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSysInfo_Endian_PythonToCpp_QSysInfo_Endian,
            is_QSysInfo_Endian_PythonToCpp_QSysInfo_Endian_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSysInfo::Endian");
        Shiboken::Conversions::registerConverterName(converter, "Endian");
    }
    // End of 'Endian' enum.

    qRegisterMetaType< ::QSysInfo *>();
    qRegisterMetaType< ::QSysInfo::Sizes >("QSysInfo::Sizes");
    qRegisterMetaType< ::QSysInfo::Endian >("QSysInfo::Endian");

    return pyType;
}
