// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamreader_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringView>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamReader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamReader >()))
        return -1;

    ::QXmlStreamReader *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QXmlStreamReader", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamReader::QXmlStreamReader()
    // 1: QXmlStreamReader::QXmlStreamReader(QAnyStringView)
    // 2: QXmlStreamReader::QXmlStreamReader(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamReader()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QXmlStreamReader(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QXmlStreamReader(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamReader()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamReader()
                cptr = new ::QXmlStreamReader();
            }
            break;
        }
        case 1: // QXmlStreamReader(QAnyStringView data)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamReader(QAnyStringView)
                cptr = new ::QXmlStreamReader(QAnyStringView(cppArg0));
            }
            break;
        }
        case 2: // QXmlStreamReader(QIODevice * device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamReader(QIODevice*)
                cptr = new ::QXmlStreamReader(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamReaderFunc_addData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.addData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::addData(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // addData(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addData(QAnyStringView)
            cppSelf->addData(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.addExtraNamespaceDeclaration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNamespaceDeclaration_IDX]), (pyArg)))) {
        overloadId = 0; // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamNamespaceDeclaration cppArg0_local;
        ::QXmlStreamNamespaceDeclaration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
            cppSelf->addExtraNamespaceDeclaration(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.addExtraNamespaceDeclarations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::addExtraNamespaceDeclarations(QList<QXmlStreamNamespaceDeclaration>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX], (pyArg)))) {
        overloadId = 0; // addExtraNamespaceDeclarations(QList<QXmlStreamNamespaceDeclaration>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QXmlStreamNamespaceDeclaration> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addExtraNamespaceDeclarations(QList<QXmlStreamNamespaceDeclaration>)
            cppSelf->addExtraNamespaceDeclarations(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.atEnd";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // atEnd()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->atEnd();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.attributes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // attributes()const
            QXmlStreamAttributes cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->attributes();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_characterOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.characterOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // characterOffset()const
            qint64 cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->characterOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_columnNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.columnNumber";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // columnNumber()const
            qint64 cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->columnNumber();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.device";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // device()const
            QIODevice * cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->device();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_documentEncoding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.documentEncoding";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // documentEncoding()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->documentEncoding();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_documentVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.documentVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // documentVersion()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->documentVersion();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_dtdName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.dtdName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dtdName()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->dtdName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_dtdPublicId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.dtdPublicId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dtdPublicId()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->dtdPublicId();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_dtdSystemId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.dtdSystemId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dtdSystemId()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->dtdSystemId();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_entityDeclarations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.entityDeclarations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // entityDeclarations()const
            QList<QXmlStreamEntityDeclaration> cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->entityDeclarations();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamEntityDeclaration_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_entityExpansionLimit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.entityExpansionLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // entityExpansionLimit()const
            int cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->entityExpansionLimit();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_entityResolver(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.entityResolver";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // entityResolver()const
            QXmlStreamEntityResolver * cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->entityResolver();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.error";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // error()const
            QXmlStreamReader::Error cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->error();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.hasError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasError()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->hasError();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_hasStandaloneDeclaration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.hasStandaloneDeclaration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasStandaloneDeclaration()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->hasStandaloneDeclaration();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isCDATA(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isCDATA";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCDATA()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isCDATA();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isCharacters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isCharacters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCharacters()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isCharacters();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isComment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isComment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isComment()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isComment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isDTD(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isDTD";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDTD()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isDTD();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isEndDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isEndDocument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEndDocument()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isEndDocument();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isEndElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isEndElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEndElement()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isEndElement();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isEntityReference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isEntityReference";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEntityReference()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isEntityReference();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isProcessingInstruction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isProcessingInstruction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isProcessingInstruction()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isProcessingInstruction();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isStandaloneDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isStandaloneDocument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isStandaloneDocument()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isStandaloneDocument();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isStartDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isStartDocument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isStartDocument()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isStartDocument();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isStartElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isStartElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isStartElement()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isStartElement();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_isWhitespace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.isWhitespace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isWhitespace()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->isWhitespace();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_lineNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.lineNumber";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lineNumber()const
            qint64 cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->lineNumber();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_namespaceDeclarations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.namespaceDeclarations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // namespaceDeclarations()const
            QList<QXmlStreamNamespaceDeclaration> cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->namespaceDeclarations();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_namespaceProcessing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.namespaceProcessing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // namespaceProcessing()const
            bool cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->namespaceProcessing();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_namespaceUri(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.namespaceUri";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // namespaceUri()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->namespaceUri();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_notationDeclarations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.notationDeclarations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // notationDeclarations()const
            QList<QXmlStreamNotationDeclaration> cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->notationDeclarations();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNotationDeclaration_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_prefix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.prefix";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prefix()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->prefix();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_processingInstructionData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.processingInstructionData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // processingInstructionData()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->processingInstructionData();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_processingInstructionTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.processingInstructionTarget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // processingInstructionTarget()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->processingInstructionTarget();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_qualifiedName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.qualifiedName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // qualifiedName()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->qualifiedName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_raiseError(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.raiseError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:raiseError", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamReader::raiseError(const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // raiseError(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // raiseError(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_message = Shiboken::String::createStaticString("message");
            if (PyDict_Contains(kwds, key_message) != 0) {
                value = PyDict_GetItem(kwds, key_message);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_message);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_message);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // raiseError(QString)
            cppSelf->raiseError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_readElementText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.readElementText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:readElementText", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamReader::readElementText(QXmlStreamReader::ReadElementTextBehaviour=)->QString
    if (numArgs == 0) {
        overloadId = 0; // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_ReadElementTextBehaviour_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_behaviour = Shiboken::String::createStaticString("behaviour");
            if (PyDict_Contains(kwds, key_behaviour) != 0) {
                value = PyDict_GetItem(kwds, key_behaviour);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_behaviour);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_ReadElementTextBehaviour_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_behaviour);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QXmlStreamReader::ReadElementTextBehaviour cppArg0(QXmlStreamReader::ReadElementTextBehaviour::ErrorOnUnexpectedElement);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
            QString cppResult = cppSelf->readElementText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_readNext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.readNext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readNext()
            QXmlStreamReader::TokenType cppResult = cppSelf->readNext();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_TokenType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_readNextStartElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.readNextStartElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readNextStartElement()
            bool cppResult = cppSelf->readNextStartElement();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.setDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_setEntityExpansionLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.setEntityExpansionLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::setEntityExpansionLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setEntityExpansionLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEntityExpansionLimit(int)
            cppSelf->setEntityExpansionLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_setEntityResolver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.setEntityResolver";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::setEntityResolver(QXmlStreamEntityResolver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), (pyArg)))) {
        overloadId = 0; // setEntityResolver(QXmlStreamEntityResolver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamEntityResolver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEntityResolver(QXmlStreamEntityResolver*)
            cppSelf->setEntityResolver(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_setNamespaceProcessing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.setNamespaceProcessing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamReader::setNamespaceProcessing(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setNamespaceProcessing(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNamespaceProcessing(bool)
            cppSelf->setNamespaceProcessing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_skipCurrentElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.skipCurrentElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipCurrentElement()
            cppSelf->skipCurrentElement();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamReaderFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.text";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // text()const
            QStringView cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->text();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_tokenString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.tokenString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // tokenString()const
            QString cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->tokenString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamReaderFunc_tokenType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamReader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamReader.tokenType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // tokenType()const
            QXmlStreamReader::TokenType cppResult = const_cast<const ::QXmlStreamReader *>(cppSelf)->tokenType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_TokenType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QXmlStreamReader_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QXmlStreamReader_EnumFlagInfo[] = {
    "Error:Enum",
    "ReadElementTextBehaviour:Enum",
    "TokenType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamReader_methods[] = {
    {"addData", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_addData), METH_O, nullptr},
    {"addExtraNamespaceDeclaration", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration), METH_O, nullptr},
    {"addExtraNamespaceDeclarations", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations), METH_O, nullptr},
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_atEnd), METH_NOARGS, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_attributes), METH_NOARGS, nullptr},
    {"characterOffset", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_characterOffset), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_clear), METH_NOARGS, nullptr},
    {"columnNumber", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_columnNumber), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_device), METH_NOARGS, nullptr},
    {"documentEncoding", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_documentEncoding), METH_NOARGS, nullptr},
    {"documentVersion", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_documentVersion), METH_NOARGS, nullptr},
    {"dtdName", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_dtdName), METH_NOARGS, nullptr},
    {"dtdPublicId", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_dtdPublicId), METH_NOARGS, nullptr},
    {"dtdSystemId", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_dtdSystemId), METH_NOARGS, nullptr},
    {"entityDeclarations", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_entityDeclarations), METH_NOARGS, nullptr},
    {"entityExpansionLimit", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_entityExpansionLimit), METH_NOARGS, nullptr},
    {"entityResolver", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_entityResolver), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_errorString), METH_NOARGS, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_hasError), METH_NOARGS, nullptr},
    {"hasStandaloneDeclaration", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_hasStandaloneDeclaration), METH_NOARGS, nullptr},
    {"isCDATA", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isCDATA), METH_NOARGS, nullptr},
    {"isCharacters", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isCharacters), METH_NOARGS, nullptr},
    {"isComment", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isComment), METH_NOARGS, nullptr},
    {"isDTD", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isDTD), METH_NOARGS, nullptr},
    {"isEndDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isEndDocument), METH_NOARGS, nullptr},
    {"isEndElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isEndElement), METH_NOARGS, nullptr},
    {"isEntityReference", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isEntityReference), METH_NOARGS, nullptr},
    {"isProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isProcessingInstruction), METH_NOARGS, nullptr},
    {"isStandaloneDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isStandaloneDocument), METH_NOARGS, nullptr},
    {"isStartDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isStartDocument), METH_NOARGS, nullptr},
    {"isStartElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isStartElement), METH_NOARGS, nullptr},
    {"isWhitespace", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_isWhitespace), METH_NOARGS, nullptr},
    {"lineNumber", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_lineNumber), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_name), METH_NOARGS, nullptr},
    {"namespaceDeclarations", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_namespaceDeclarations), METH_NOARGS, nullptr},
    {"namespaceProcessing", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_namespaceProcessing), METH_NOARGS, nullptr},
    {"namespaceUri", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_namespaceUri), METH_NOARGS, nullptr},
    {"notationDeclarations", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_notationDeclarations), METH_NOARGS, nullptr},
    {"prefix", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_prefix), METH_NOARGS, nullptr},
    {"processingInstructionData", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_processingInstructionData), METH_NOARGS, nullptr},
    {"processingInstructionTarget", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_processingInstructionTarget), METH_NOARGS, nullptr},
    {"qualifiedName", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_qualifiedName), METH_NOARGS, nullptr},
    {"raiseError", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_raiseError), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"readElementText", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_readElementText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"readNext", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_readNext), METH_NOARGS, nullptr},
    {"readNextStartElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_readNextStartElement), METH_NOARGS, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_setDevice), METH_O, nullptr},
    {"setEntityExpansionLimit", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_setEntityExpansionLimit), METH_O, nullptr},
    {"setEntityResolver", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_setEntityResolver), METH_O, nullptr},
    {"setNamespaceProcessing", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_setNamespaceProcessing), METH_O, nullptr},
    {"skipCurrentElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_skipCurrentElement), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_text), METH_NOARGS, nullptr},
    {"tokenString", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_tokenString), METH_NOARGS, nullptr},
    {"tokenType", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamReaderFunc_tokenType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QXmlStreamReader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamReader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamReader_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamReader_TypeF(void)
{
    return _Sbk_QXmlStreamReader_Type;
}

static PyType_Slot Sbk_QXmlStreamReader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamReader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamReader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamReader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamReader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamReader_spec = {
    "2:PySide6.QtCore.QXmlStreamReader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamReader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QXmlStreamReader_TokenType_PythonToCpp_QXmlStreamReader_TokenType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QXmlStreamReader::TokenType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QXmlStreamReader::TokenType *>(cppOut) = value;

}
static PythonToCppFunc is_QXmlStreamReader_TokenType_PythonToCpp_QXmlStreamReader_TokenType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_TokenType_IDX])))
        return QXmlStreamReader_TokenType_PythonToCpp_QXmlStreamReader_TokenType;
    return {};
}
static PyObject *QXmlStreamReader_TokenType_CppToPython_QXmlStreamReader_TokenType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QXmlStreamReader::TokenType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_TokenType_IDX]), castCppIn);

}

static void QXmlStreamReader_ReadElementTextBehaviour_PythonToCpp_QXmlStreamReader_ReadElementTextBehaviour(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QXmlStreamReader::ReadElementTextBehaviour>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QXmlStreamReader::ReadElementTextBehaviour *>(cppOut) = value;

}
static PythonToCppFunc is_QXmlStreamReader_ReadElementTextBehaviour_PythonToCpp_QXmlStreamReader_ReadElementTextBehaviour_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_ReadElementTextBehaviour_IDX])))
        return QXmlStreamReader_ReadElementTextBehaviour_PythonToCpp_QXmlStreamReader_ReadElementTextBehaviour;
    return {};
}
static PyObject *QXmlStreamReader_ReadElementTextBehaviour_CppToPython_QXmlStreamReader_ReadElementTextBehaviour(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QXmlStreamReader::ReadElementTextBehaviour *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_ReadElementTextBehaviour_IDX]), castCppIn);

}

static void QXmlStreamReader_Error_PythonToCpp_QXmlStreamReader_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QXmlStreamReader::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QXmlStreamReader::Error *>(cppOut) = value;

}
static PythonToCppFunc is_QXmlStreamReader_Error_PythonToCpp_QXmlStreamReader_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_Error_IDX])))
        return QXmlStreamReader_Error_PythonToCpp_QXmlStreamReader_Error;
    return {};
}
static PyObject *QXmlStreamReader_Error_CppToPython_QXmlStreamReader_Error(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QXmlStreamReader::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamReader_PythonToCpp_QXmlStreamReader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamReader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamReader_PythonToCpp_QXmlStreamReader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamReader_TypeF()))
        return QXmlStreamReader_PythonToCpp_QXmlStreamReader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamReader_PTR_CppToPython_QXmlStreamReader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QXmlStreamReader *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QXmlStreamReader_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QXmlStreamReader_SignatureStrings[] = {
    "2:PySide6.QtCore.QXmlStreamReader(self)",
    "1:PySide6.QtCore.QXmlStreamReader(self,data:QString)",
    "0:PySide6.QtCore.QXmlStreamReader(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QXmlStreamReader.addData(self,data:QString)",
    "PySide6.QtCore.QXmlStreamReader.addExtraNamespaceDeclaration(self,extraNamespaceDeclaraction:PySide6.QtCore.QXmlStreamNamespaceDeclaration)",
    "PySide6.QtCore.QXmlStreamReader.addExtraNamespaceDeclarations(self,extraNamespaceDeclaractions:QList[PySide6.QtCore.QXmlStreamNamespaceDeclaration])",
    "PySide6.QtCore.QXmlStreamReader.atEnd(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.attributes(self)->PySide6.QtCore.QXmlStreamAttributes",
    "PySide6.QtCore.QXmlStreamReader.characterOffset(self)->qint64",
    "PySide6.QtCore.QXmlStreamReader.clear(self)",
    "PySide6.QtCore.QXmlStreamReader.columnNumber(self)->qint64",
    "PySide6.QtCore.QXmlStreamReader.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QXmlStreamReader.documentEncoding(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.documentVersion(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.dtdName(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.dtdPublicId(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.dtdSystemId(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.entityDeclarations(self)->QList[PySide6.QtCore.QXmlStreamEntityDeclaration]",
    "PySide6.QtCore.QXmlStreamReader.entityExpansionLimit(self)->int",
    "PySide6.QtCore.QXmlStreamReader.entityResolver(self)->PySide6.QtCore.QXmlStreamEntityResolver",
    "PySide6.QtCore.QXmlStreamReader.error(self)->PySide6.QtCore.QXmlStreamReader.Error",
    "PySide6.QtCore.QXmlStreamReader.errorString(self)->QString",
    "PySide6.QtCore.QXmlStreamReader.hasError(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.hasStandaloneDeclaration(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isCDATA(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isCharacters(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isComment(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isDTD(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isEndDocument(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isEndElement(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isEntityReference(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isProcessingInstruction(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isStandaloneDocument(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isStartDocument(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isStartElement(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.isWhitespace(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.lineNumber(self)->qint64",
    "PySide6.QtCore.QXmlStreamReader.name(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.namespaceDeclarations(self)->QList[PySide6.QtCore.QXmlStreamNamespaceDeclaration]",
    "PySide6.QtCore.QXmlStreamReader.namespaceProcessing(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.namespaceUri(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.notationDeclarations(self)->QList[PySide6.QtCore.QXmlStreamNotationDeclaration]",
    "PySide6.QtCore.QXmlStreamReader.prefix(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.processingInstructionData(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.processingInstructionTarget(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.qualifiedName(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.raiseError(self,message:QString=QString())",
    "PySide6.QtCore.QXmlStreamReader.readElementText(self,behaviour:PySide6.QtCore.QXmlStreamReader.ReadElementTextBehaviour=QXmlStreamReader.ReadElementTextBehaviour.ErrorOnUnexpectedElement)->QString",
    "PySide6.QtCore.QXmlStreamReader.readNext(self)->PySide6.QtCore.QXmlStreamReader.TokenType",
    "PySide6.QtCore.QXmlStreamReader.readNextStartElement(self)->bool",
    "PySide6.QtCore.QXmlStreamReader.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QXmlStreamReader.setEntityExpansionLimit(self,limit:int)",
    "PySide6.QtCore.QXmlStreamReader.setEntityResolver(self,resolver:PySide6.QtCore.QXmlStreamEntityResolver)",
    "PySide6.QtCore.QXmlStreamReader.setNamespaceProcessing(self,arg__1:bool)",
    "PySide6.QtCore.QXmlStreamReader.skipCurrentElement(self)",
    "PySide6.QtCore.QXmlStreamReader.text(self)->QStringView",
    "PySide6.QtCore.QXmlStreamReader.tokenString(self)->QString",
    "PySide6.QtCore.QXmlStreamReader.tokenType(self)->PySide6.QtCore.QXmlStreamReader.TokenType",
    nullptr}; // Sentinel

PyTypeObject *init_QXmlStreamReader(PyObject *module)
{
    _Sbk_QXmlStreamReader_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamReader",
        "QXmlStreamReader*",
        &Sbk_QXmlStreamReader_spec,
        &Shiboken::callCppDestructor< ::QXmlStreamReader >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QXmlStreamReader_TypeF(); // references _Sbk_QXmlStreamReader_Type
    InitSignatureStrings(pyType, QXmlStreamReader_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamReader_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamReader_PythonToCpp_QXmlStreamReader_PTR,
        is_QXmlStreamReader_PythonToCpp_QXmlStreamReader_PTR_Convertible,
        QXmlStreamReader_PTR_CppToPython_QXmlStreamReader);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamReader).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QXmlStreamReader_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TokenType'.
    const char *TokenType_Initializer[] = {
        "NoToken",
        "Invalid",
        "StartDocument",
        "EndDocument",
        "StartElement",
        "EndElement",
        "Characters",
        "Comment",
        "DTD",
        "EntityReference",
        "ProcessingInstruction",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TokenType_InitializerValues[] = {
        uint8_t(QXmlStreamReader::TokenType::NoToken),              //  0x00  0
        uint8_t(QXmlStreamReader::TokenType::Invalid),              //  0x01  1
        uint8_t(QXmlStreamReader::TokenType::StartDocument),        //  0x02  2
        uint8_t(QXmlStreamReader::TokenType::EndDocument),          //  0x03  3
        uint8_t(QXmlStreamReader::TokenType::StartElement),         //  0x04  4
        uint8_t(QXmlStreamReader::TokenType::EndElement),           //  0x05  5
        uint8_t(QXmlStreamReader::TokenType::Characters),           //  0x06  6
        uint8_t(QXmlStreamReader::TokenType::Comment),              //  0x07  7
        uint8_t(QXmlStreamReader::TokenType::DTD),                  //  0x08  8
        uint8_t(QXmlStreamReader::TokenType::EntityReference),      //  0x09  9
        uint8_t(QXmlStreamReader::TokenType::ProcessingInstruction) //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QXmlStreamReader_TypeF(),
        "2:PySide6.QtCore.QXmlStreamReader.TokenType",
        TokenType_Initializer, TokenType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_TokenType_IDX].type = EType;
    // Register converter for enum 'QXmlStreamReader::TokenType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QXmlStreamReader_TokenType_CppToPython_QXmlStreamReader_TokenType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QXmlStreamReader_TokenType_PythonToCpp_QXmlStreamReader_TokenType,
            is_QXmlStreamReader_TokenType_PythonToCpp_QXmlStreamReader_TokenType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader::TokenType");
        Shiboken::Conversions::registerConverterName(converter, "TokenType");
    }
    // End of 'TokenType' enum.

    // Initialization of enum 'ReadElementTextBehaviour'.
    const char *ReadElementTextBehaviour_Initializer[] = {
        "ErrorOnUnexpectedElement",
        "IncludeChildElements",
        "SkipChildElements",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ReadElementTextBehaviour_InitializerValues[] = {
        uint8_t(QXmlStreamReader::ReadElementTextBehaviour::ErrorOnUnexpectedElement), //  0x00  0
        uint8_t(QXmlStreamReader::ReadElementTextBehaviour::IncludeChildElements),     //  0x01  1
        uint8_t(QXmlStreamReader::ReadElementTextBehaviour::SkipChildElements)         //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QXmlStreamReader_TypeF(),
        "2:PySide6.QtCore.QXmlStreamReader.ReadElementTextBehaviour",
        ReadElementTextBehaviour_Initializer, ReadElementTextBehaviour_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_ReadElementTextBehaviour_IDX].type = EType;
    // Register converter for enum 'QXmlStreamReader::ReadElementTextBehaviour'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QXmlStreamReader_ReadElementTextBehaviour_CppToPython_QXmlStreamReader_ReadElementTextBehaviour);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QXmlStreamReader_ReadElementTextBehaviour_PythonToCpp_QXmlStreamReader_ReadElementTextBehaviour,
            is_QXmlStreamReader_ReadElementTextBehaviour_PythonToCpp_QXmlStreamReader_ReadElementTextBehaviour_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader::ReadElementTextBehaviour");
        Shiboken::Conversions::registerConverterName(converter, "ReadElementTextBehaviour");
    }
    // End of 'ReadElementTextBehaviour' enum.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "UnexpectedElementError",
        "CustomError",
        "NotWellFormedError",
        "PrematureEndOfDocumentError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QXmlStreamReader::Error::NoError),                    //  0x00  0
        uint8_t(QXmlStreamReader::Error::UnexpectedElementError),     //  0x01  1
        uint8_t(QXmlStreamReader::Error::CustomError),                //  0x02  2
        uint8_t(QXmlStreamReader::Error::NotWellFormedError),         //  0x03  3
        uint8_t(QXmlStreamReader::Error::PrematureEndOfDocumentError) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QXmlStreamReader_TypeF(),
        "2:PySide6.QtCore.QXmlStreamReader.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_Error_IDX].type = EType;
    // Register converter for enum 'QXmlStreamReader::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QXmlStreamReader_Error_CppToPython_QXmlStreamReader_Error);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QXmlStreamReader_Error_PythonToCpp_QXmlStreamReader_Error,
            is_QXmlStreamReader_Error_PythonToCpp_QXmlStreamReader_Error_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QXmlStreamReader::Error");
        Shiboken::Conversions::registerConverterName(converter, "Error");
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QXmlStreamReader *>();
    qRegisterMetaType< ::QXmlStreamReader::TokenType >("QXmlStreamReader::TokenType");
    qRegisterMetaType< ::QXmlStreamReader::ReadElementTextBehaviour >("QXmlStreamReader::ReadElementTextBehaviour");
    qRegisterMetaType< ::QXmlStreamReader::Error >("QXmlStreamReader::Error");

    return pyType;
}
