// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamwriter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamWriter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamWriter >()))
        return -1;

    ::QXmlStreamWriter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QXmlStreamWriter", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QXmlStreamWriter::QXmlStreamWriter()
    // 1: QXmlStreamWriter::QXmlStreamWriter(QByteArray*)
    // 2: QXmlStreamWriter::QXmlStreamWriter(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamWriter()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QXmlStreamWriter(QIODevice*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QXmlStreamWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QXmlStreamWriter()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamWriter()
                cptr = new ::QXmlStreamWriter();
            }
            break;
        }
        case 1: // QXmlStreamWriter(QByteArray * array)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamWriter(QByteArray*)
                cptr = new ::QXmlStreamWriter(cppArg0);
            }
            break;
        }
        case 2: // QXmlStreamWriter(QIODevice * device)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QXmlStreamWriter(QIODevice*)
                cptr = new ::QXmlStreamWriter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QXmlStreamWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamWriterFunc_autoFormatting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.autoFormatting";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // autoFormatting()const
            bool cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->autoFormatting();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_autoFormattingIndent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.autoFormattingIndent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // autoFormattingIndent()const
            int cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->autoFormattingIndent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.device";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // device()const
            QIODevice * cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->device();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_hasError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.hasError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasError()const
            bool cppResult = const_cast<const ::QXmlStreamWriter *>(cppSelf)->hasError();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setAutoFormatting(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.setAutoFormatting";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setAutoFormatting(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoFormatting(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoFormatting(bool)
            cppSelf->setAutoFormatting(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.setAutoFormattingIndent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setAutoFormattingIndent(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAutoFormattingIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoFormattingIndent(int)
            cppSelf->setAutoFormattingIndent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.setDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeAttribute(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeAttribute";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeAttribute", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeAttribute(QAnyStringView,QAnyStringView)
    // 2: QXmlStreamWriter::writeAttribute(QXmlStreamAttribute)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), (pyArgs[0])))) {
        overloadId = 2; // writeAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // writeAttribute(QAnyStringView,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeAttribute(QAnyStringView namespaceUri, QAnyStringView name, QAnyStringView value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QAnyStringView,QAnyStringView,QAnyStringView)
                cppSelf->writeAttribute(QAnyStringView(cppArg0), QAnyStringView(cppArg1), QAnyStringView(cppArg2));
            }
            break;
        }
        case 1: // writeAttribute(QAnyStringView qualifiedName, QAnyStringView value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QAnyStringView,QAnyStringView)
                cppSelf->writeAttribute(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 2: // writeAttribute(const QXmlStreamAttribute & attribute)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QXmlStreamAttribute cppArg0_local;
            ::QXmlStreamAttribute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // writeAttribute(QXmlStreamAttribute)
                cppSelf->writeAttribute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeAttributes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeAttributes(QXmlStreamAttributes)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttributes_IDX]), (pyArg)))) {
        overloadId = 0; // writeAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamAttributes cppArg0_local;
        ::QXmlStreamAttributes *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeAttributes(QXmlStreamAttributes)
            cppSelf->writeAttributes(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCDATA(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeCDATA";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCDATA(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeCDATA(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCDATA(QAnyStringView)
            cppSelf->writeCDATA(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCharacters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeCharacters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCharacters(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeCharacters(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCharacters(QAnyStringView)
            cppSelf->writeCharacters(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeComment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeComment(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeComment(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeComment(QAnyStringView)
            cppSelf->writeComment(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeCurrentToken(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeCurrentToken";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeCurrentToken(QXmlStreamReader)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArg)))) {
        overloadId = 0; // writeCurrentToken(QXmlStreamReader)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QXmlStreamReader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeCurrentToken(QXmlStreamReader)
            cppSelf->writeCurrentToken(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeDTD(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeDTD";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeDTD(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeDTD(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDTD(QAnyStringView)
            cppSelf->writeDTD(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeDefaultNamespace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeDefaultNamespace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeDefaultNamespace(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeDefaultNamespace(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDefaultNamespace(QAnyStringView)
            cppSelf->writeDefaultNamespace(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEmptyElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeEmptyElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeEmptyElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeEmptyElement(QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeEmptyElement(QAnyStringView)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeEmptyElement(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeEmptyElement(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeEmptyElement(QAnyStringView namespaceUri, QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEmptyElement(QAnyStringView,QAnyStringView)
                cppSelf->writeEmptyElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 1: // writeEmptyElement(QAnyStringView qualifiedName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeEmptyElement(QAnyStringView)
                cppSelf->writeEmptyElement(QAnyStringView(cppArg0));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEndDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeEndDocument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeEndDocument()
            cppSelf->writeEndDocument();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEndElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeEndElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeEndElement()
            cppSelf->writeEndElement();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeEntityReference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeEntityReference";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeEntityReference(QAnyStringView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeEntityReference(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeEntityReference(QAnyStringView)
            cppSelf->writeEntityReference(QAnyStringView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeNamespace(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeNamespace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:writeNamespace", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeNamespace(QAnyStringView,QAnyStringView=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeNamespace(QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeNamespace(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_prefix = Shiboken::String::createStaticString("prefix");
            if (PyDict_Contains(kwds, key_prefix) != 0) {
                value = PyDict_GetItem(kwds, key_prefix);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_prefix);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_prefix);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeNamespace(QAnyStringView,QAnyStringView)
            cppSelf->writeNamespace(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeProcessingInstruction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeProcessingInstruction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:writeProcessingInstruction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeProcessingInstruction(QAnyStringView,QAnyStringView=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // writeProcessingInstruction(QAnyStringView,QAnyStringView)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeProcessingInstruction(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_data = Shiboken::String::createStaticString("data");
            if (PyDict_Contains(kwds, key_data) != 0) {
                value = PyDict_GetItem(kwds, key_data);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_data);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_data);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeProcessingInstruction(QAnyStringView,QAnyStringView)
            cppSelf->writeProcessingInstruction(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeStartDocument(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeStartDocument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeStartDocument", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeStartDocument()
    // 1: QXmlStreamWriter::writeStartDocument(QAnyStringView)
    // 2: QXmlStreamWriter::writeStartDocument(QAnyStringView,bool)
    if (numArgs == 0) {
        overloadId = 0; // writeStartDocument()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartDocument(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 2; // writeStartDocument(QAnyStringView,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartDocument()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartDocument()
                cppSelf->writeStartDocument();
            }
            break;
        }
        case 1: // writeStartDocument(QAnyStringView version)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartDocument(QAnyStringView)
                cppSelf->writeStartDocument(QAnyStringView(cppArg0));
            }
            break;
        }
        case 2: // writeStartDocument(QAnyStringView version, bool standalone)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartDocument(QAnyStringView,bool)
                cppSelf->writeStartDocument(QAnyStringView(cppArg0), cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeStartElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeStartElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeStartElement", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeStartElement(QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeStartElement(QAnyStringView)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartElement(QAnyStringView)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // writeStartElement(QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeStartElement(QAnyStringView namespaceUri, QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartElement(QAnyStringView,QAnyStringView)
                cppSelf->writeStartElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
        case 1: // writeStartElement(QAnyStringView qualifiedName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeStartElement(QAnyStringView)
                cppSelf->writeStartElement(QAnyStringView(cppArg0));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QXmlStreamWriterFunc_writeTextElement(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamWriter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamWriter.writeTextElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeTextElement", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamWriter::writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
    // 1: QXmlStreamWriter::writeTextElement(QAnyStringView,QAnyStringView)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // writeTextElement(QAnyStringView,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeTextElement(QAnyStringView namespaceUri, QAnyStringView name, QAnyStringView text)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeTextElement(QAnyStringView,QAnyStringView,QAnyStringView)
                cppSelf->writeTextElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1), QAnyStringView(cppArg2));
            }
            break;
        }
        case 1: // writeTextElement(QAnyStringView qualifiedName, QAnyStringView text)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeTextElement(QAnyStringView,QAnyStringView)
                cppSelf->writeTextElement(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QXmlStreamWriter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamWriter_methods[] = {
    {"autoFormatting", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_autoFormatting), METH_NOARGS, nullptr},
    {"autoFormattingIndent", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_autoFormattingIndent), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_device), METH_NOARGS, nullptr},
    {"hasError", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_hasError), METH_NOARGS, nullptr},
    {"setAutoFormatting", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setAutoFormatting), METH_O, nullptr},
    {"setAutoFormattingIndent", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setAutoFormattingIndent), METH_O, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_setDevice), METH_O, nullptr},
    {"writeAttribute", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeAttribute), METH_VARARGS, nullptr},
    {"writeAttributes", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeAttributes), METH_O, nullptr},
    {"writeCDATA", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCDATA), METH_O, nullptr},
    {"writeCharacters", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCharacters), METH_O, nullptr},
    {"writeComment", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeComment), METH_O, nullptr},
    {"writeCurrentToken", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeCurrentToken), METH_O, nullptr},
    {"writeDTD", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeDTD), METH_O, nullptr},
    {"writeDefaultNamespace", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeDefaultNamespace), METH_O, nullptr},
    {"writeEmptyElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEmptyElement), METH_VARARGS, nullptr},
    {"writeEndDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEndDocument), METH_NOARGS, nullptr},
    {"writeEndElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEndElement), METH_NOARGS, nullptr},
    {"writeEntityReference", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeEntityReference), METH_O, nullptr},
    {"writeNamespace", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeNamespace), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeProcessingInstruction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeStartDocument", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeStartDocument), METH_VARARGS, nullptr},
    {"writeStartElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeStartElement), METH_VARARGS, nullptr},
    {"writeTextElement", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamWriterFunc_writeTextElement), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QXmlStreamWriter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamWriter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamWriter_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamWriter_TypeF(void)
{
    return _Sbk_QXmlStreamWriter_Type;
}

static PyType_Slot Sbk_QXmlStreamWriter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamWriter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamWriter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamWriter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamWriter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamWriter_spec = {
    "2:PySide6.QtCore.QXmlStreamWriter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamWriter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamWriter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamWriter_TypeF()))
        return QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamWriter_PTR_CppToPython_QXmlStreamWriter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QXmlStreamWriter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QXmlStreamWriter_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QXmlStreamWriter_SignatureStrings[] = {
    "2:PySide6.QtCore.QXmlStreamWriter(self)",
    "1:PySide6.QtCore.QXmlStreamWriter(self,array:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtCore.QXmlStreamWriter(self,device:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QXmlStreamWriter.autoFormatting(self)->bool",
    "PySide6.QtCore.QXmlStreamWriter.autoFormattingIndent(self)->int",
    "PySide6.QtCore.QXmlStreamWriter.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QXmlStreamWriter.hasError(self)->bool",
    "PySide6.QtCore.QXmlStreamWriter.setAutoFormatting(self,arg__1:bool)",
    "PySide6.QtCore.QXmlStreamWriter.setAutoFormattingIndent(self,spacesOrTabs:int)",
    "PySide6.QtCore.QXmlStreamWriter.setDevice(self,device:PySide6.QtCore.QIODevice)",
    "2:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,namespaceUri:QString,name:QString,value:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,qualifiedName:QString,value:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeAttribute(self,attribute:PySide6.QtCore.QXmlStreamAttribute)",
    "PySide6.QtCore.QXmlStreamWriter.writeAttributes(self,attributes:PySide6.QtCore.QXmlStreamAttributes)",
    "PySide6.QtCore.QXmlStreamWriter.writeCDATA(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeCharacters(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeComment(self,text:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeCurrentToken(self,reader:PySide6.QtCore.QXmlStreamReader)",
    "PySide6.QtCore.QXmlStreamWriter.writeDTD(self,dtd:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeDefaultNamespace(self,namespaceUri:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeEmptyElement(self,namespaceUri:QString,name:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeEmptyElement(self,qualifiedName:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeEndDocument(self)",
    "PySide6.QtCore.QXmlStreamWriter.writeEndElement(self)",
    "PySide6.QtCore.QXmlStreamWriter.writeEntityReference(self,name:QString)",
    "PySide6.QtCore.QXmlStreamWriter.writeNamespace(self,namespaceUri:QString,prefix:QString={})",
    "PySide6.QtCore.QXmlStreamWriter.writeProcessingInstruction(self,target:QString,data:QString={})",
    "2:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self,version:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeStartDocument(self,version:QString,standalone:bool)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeStartElement(self,namespaceUri:QString,name:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeStartElement(self,qualifiedName:QString)",
    "1:PySide6.QtCore.QXmlStreamWriter.writeTextElement(self,namespaceUri:QString,name:QString,text:QString)",
    "0:PySide6.QtCore.QXmlStreamWriter.writeTextElement(self,qualifiedName:QString,text:QString)",
    nullptr}; // Sentinel

PyTypeObject *init_QXmlStreamWriter(PyObject *module)
{
    _Sbk_QXmlStreamWriter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamWriter",
        "QXmlStreamWriter*",
        &Sbk_QXmlStreamWriter_spec,
        &Shiboken::callCppDestructor< ::QXmlStreamWriter >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QXmlStreamWriter_TypeF(); // references _Sbk_QXmlStreamWriter_Type
    InitSignatureStrings(pyType, QXmlStreamWriter_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamWriter_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamWriter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR,
        is_QXmlStreamWriter_PythonToCpp_QXmlStreamWriter_PTR_Convertible,
        QXmlStreamWriter_PTR_CppToPython_QXmlStreamWriter);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamWriter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamWriter).name());

    qRegisterMetaType< ::QXmlStreamWriter *>();

    return pyType;
}
