// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusunixfiledescriptor_wrapper.h"

// Argument includes
#include <QtDBus/qdbusunixfiledescriptor.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusUnixFileDescriptor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusUnixFileDescriptor >()))
        return -1;

    ::QDBusUnixFileDescriptor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusUnixFileDescriptor", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor()
    // 1: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
    // 2: QDBusUnixFileDescriptor::QDBusUnixFileDescriptor(int)
    if (numArgs == 0) {
        overloadId = 0; // QDBusUnixFileDescriptor()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QDBusUnixFileDescriptor(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusUnixFileDescriptor()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusUnixFileDescriptor()
                cptr = new ::QDBusUnixFileDescriptor();
            }
            break;
        }
        case 1: // QDBusUnixFileDescriptor(const QDBusUnixFileDescriptor & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusUnixFileDescriptor *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusUnixFileDescriptor(QDBusUnixFileDescriptor)
                cptr = new ::QDBusUnixFileDescriptor(*cppArg0);
            }
            break;
        }
        case 2: // QDBusUnixFileDescriptor(int fileDescriptor)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusUnixFileDescriptor(int)
                cptr = new ::QDBusUnixFileDescriptor(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusUnixFileDescriptor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_fileDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.fileDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileDescriptor()const
            int cppResult = const_cast<const ::QDBusUnixFileDescriptor *>(cppSelf)->fileDescriptor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_giveFileDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.giveFileDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::giveFileDescriptor(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // giveFileDescriptor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // giveFileDescriptor(int)
            cppSelf->giveFileDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_isSupported(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.isSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSupported()
            bool cppResult = ::QDBusUnixFileDescriptor::isSupported();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QDBusUnixFileDescriptor *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_setFileDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.setFileDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::setFileDescriptor(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFileDescriptor(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileDescriptor(int)
            cppSelf->setFileDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusUnixFileDescriptor::swap(QDBusUnixFileDescriptor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusUnixFileDescriptor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusUnixFileDescriptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusUnixFileDescriptor&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusUnixFileDescriptorFunc_takeFileDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusUnixFileDescriptor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusUnixFileDescriptor.takeFileDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeFileDescriptor()
            int cppResult = cppSelf->takeFileDescriptor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusUnixFileDescriptor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusUnixFileDescriptor_methods[] = {
    {"fileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_fileDescriptor), METH_NOARGS, nullptr},
    {"giveFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_giveFileDescriptor), METH_O, nullptr},
    {"isSupported", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_isSupported), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_isValid), METH_NOARGS, nullptr},
    {"setFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_setFileDescriptor), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_swap), METH_O, nullptr},
    {"takeFileDescriptor", reinterpret_cast<PyCFunction>(Sbk_QDBusUnixFileDescriptorFunc_takeFileDescriptor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDBusUnixFileDescriptor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusUnixFileDescriptor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusUnixFileDescriptor_Type = nullptr;
static PyTypeObject *Sbk_QDBusUnixFileDescriptor_TypeF(void)
{
    return _Sbk_QDBusUnixFileDescriptor_Type;
}

static PyType_Slot Sbk_QDBusUnixFileDescriptor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusUnixFileDescriptor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusUnixFileDescriptor_spec = {
    "2:PySide6.QtDBus.QDBusUnixFileDescriptor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusUnixFileDescriptor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusUnixFileDescriptor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusUnixFileDescriptor_TypeF()))
        return QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusUnixFileDescriptor_PTR_CppToPython_QDBusUnixFileDescriptor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QDBusUnixFileDescriptor *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QDBusUnixFileDescriptor_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDBusUnixFileDescriptor_SignatureStrings[] = {
    "2:PySide6.QtDBus.QDBusUnixFileDescriptor(self)",
    "1:PySide6.QtDBus.QDBusUnixFileDescriptor(self,other:PySide6.QtDBus.QDBusUnixFileDescriptor)",
    "0:PySide6.QtDBus.QDBusUnixFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.fileDescriptor(self)->int",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.giveFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.isSupported()->bool",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.isValid(self)->bool",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.setFileDescriptor(self,fileDescriptor:int)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.swap(self,other:PySide6.QtDBus.QDBusUnixFileDescriptor)",
    "PySide6.QtDBus.QDBusUnixFileDescriptor.takeFileDescriptor(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QDBusUnixFileDescriptor(PyObject *module)
{
    _Sbk_QDBusUnixFileDescriptor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusUnixFileDescriptor",
        "QDBusUnixFileDescriptor*",
        &Sbk_QDBusUnixFileDescriptor_spec,
        &Shiboken::callCppDestructor< ::QDBusUnixFileDescriptor >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QDBusUnixFileDescriptor_TypeF(); // references _Sbk_QDBusUnixFileDescriptor_Type
    InitSignatureStrings(pyType, QDBusUnixFileDescriptor_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusUnixFileDescriptor_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusUnixFileDescriptor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR,
        is_QDBusUnixFileDescriptor_PythonToCpp_QDBusUnixFileDescriptor_PTR_Convertible,
        QDBusUnixFileDescriptor_PTR_CppToPython_QDBusUnixFileDescriptor);

    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor");
    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusUnixFileDescriptor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusUnixFileDescriptor).name());

    qRegisterMetaType< ::QDBusUnixFileDescriptor *>();

    return pyType;
}
