// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdatavisualization_python.h"

// main header
#include "qbardataitem_wrapper.h"

// Argument includes
#include <QtDataVisualization/qbardataitem.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBarDataItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBarDataItem >()))
        return -1;

    ::QBarDataItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QBarDataItem", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBarDataItem::QBarDataItem()
    // 1: QBarDataItem::QBarDataItem(QBarDataItem)
    // 2: QBarDataItem::QBarDataItem(float)
    // 3: QBarDataItem::QBarDataItem(float,float)
    if (numArgs == 0) {
        overloadId = 0; // QBarDataItem()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QBarDataItem(float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 3; // QBarDataItem(float,float)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QBarDataItem(QBarDataItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBarDataItem()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem()
                cptr = new ::QBarDataItem();
            }
            break;
        }
        case 1: // QBarDataItem(const QBarDataItem & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBarDataItem cppArg0_local;
            ::QBarDataItem *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(QBarDataItem)
                cptr = new ::QBarDataItem(*cppArg0);
            }
            break;
        }
        case 2: // QBarDataItem(float value)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(float)
                cptr = new ::QBarDataItem(cppArg0);
            }
            break;
        }
        case 3: // QBarDataItem(float value, float angle)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBarDataItem(float,float)
                cptr = new ::QBarDataItem(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBarDataItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBarDataItemFunc_createExtraData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.createExtraData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // createExtraData()
            cppSelf->createExtraData();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.rotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rotation()const
            float cppResult = const_cast<const ::QBarDataItem *>(cppSelf)->rotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataItemFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.setRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarDataItem::setRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(float)
            cppSelf->setRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.setValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBarDataItem::setValue(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setValue(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(float)
            cppSelf->setValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBarDataItemFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDataVisualization.QBarDataItem.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // value()const
            float cppResult = const_cast<const ::QBarDataItem *>(cppSelf)->value();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBarDataItem__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBarDataItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBarDataItem_methods[] = {
    {"createExtraData", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_createExtraData), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_rotation), METH_NOARGS, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_setRotation), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_setValue), METH_O, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QBarDataItemFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBarDataItem__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QBarDataItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBarDataItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBarDataItem_Type = nullptr;
static PyTypeObject *Sbk_QBarDataItem_TypeF(void)
{
    return _Sbk_QBarDataItem_Type;
}

static PyType_Slot Sbk_QBarDataItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBarDataItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBarDataItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBarDataItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBarDataItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBarDataItem_spec = {
    "2:PySide6.QtDataVisualization.QBarDataItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBarDataItem_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBarDataItem_PythonToCpp_QBarDataItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBarDataItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBarDataItem_PythonToCpp_QBarDataItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBarDataItem_TypeF()))
        return QBarDataItem_PythonToCpp_QBarDataItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBarDataItem_PTR_CppToPython_QBarDataItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QBarDataItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QBarDataItem_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QBarDataItem_COPY_CppToPython_QBarDataItem(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBarDataItem *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBarDataItem_TypeF(), new ::QBarDataItem(*source), true, true);
}

// Python to C++ copy conversion.
static void QBarDataItem_PythonToCpp_QBarDataItem_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBarDataItem *>(cppOut) = *reinterpret_cast< ::QBarDataItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBarDataItem_PythonToCpp_QBarDataItem_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBarDataItem_TypeF()))
        return QBarDataItem_PythonToCpp_QBarDataItem_COPY;
    return {};
}

// Implicit conversions.
static void float_PythonToCpp_QBarDataItem(PyObject *pyIn, void *cppOut)
{
    float cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn, &cppIn);
    *reinterpret_cast<::QBarDataItem *>(cppOut) = ::QBarDataItem(cppIn);
}
static PythonToCppFunc is_float_PythonToCpp_QBarDataItem_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return float_PythonToCpp_QBarDataItem;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QBarDataItem_SignatureStrings[] = {
    "3:PySide6.QtDataVisualization.QBarDataItem(self)",
    "2:PySide6.QtDataVisualization.QBarDataItem(self,other:typing.Union[PySide6.QtDataVisualization.QBarDataItem, float])",
    "1:PySide6.QtDataVisualization.QBarDataItem(self,value:float)",
    "0:PySide6.QtDataVisualization.QBarDataItem(self,value:float,angle:float)",
    "PySide6.QtDataVisualization.QBarDataItem.createExtraData(self)",
    "PySide6.QtDataVisualization.QBarDataItem.rotation(self)->float",
    "PySide6.QtDataVisualization.QBarDataItem.setRotation(self,angle:float)",
    "PySide6.QtDataVisualization.QBarDataItem.setValue(self,val:float)",
    "PySide6.QtDataVisualization.QBarDataItem.value(self)->float",
    "PySide6.QtDataVisualization.QBarDataItem.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QBarDataItem(PyObject *module)
{
    _Sbk_QBarDataItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBarDataItem",
        "QBarDataItem",
        &Sbk_QBarDataItem_spec,
        &Shiboken::callCppDestructor< ::QBarDataItem >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBarDataItem_TypeF(); // references _Sbk_QBarDataItem_Type
    InitSignatureStrings(pyType, QBarDataItem_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBarDataItem_PropertyStrings);
    SbkPySide6_QtDataVisualizationTypeStructs[SBK_QBarDataItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBarDataItem_PythonToCpp_QBarDataItem_PTR,
        is_QBarDataItem_PythonToCpp_QBarDataItem_PTR_Convertible,
        QBarDataItem_PTR_CppToPython_QBarDataItem,
        QBarDataItem_COPY_CppToPython_QBarDataItem);

    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem*");
    Shiboken::Conversions::registerConverterName(converter, "QBarDataItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBarDataItem).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBarDataItem_PythonToCpp_QBarDataItem_COPY,
        is_QBarDataItem_PythonToCpp_QBarDataItem_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        float_PythonToCpp_QBarDataItem,
        is_float_PythonToCpp_QBarDataItem_Convertible);

    qRegisterMetaType< ::QBarDataItem >("QBarDataItem");

    return pyType;
}
