// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdesigner_python.h"

// main header
#include "qdesignerformwindowcursorinterface_wrapper.h"

// Argument includes
#include <QString>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractformwindowcursor.h>
#include <QtWidgets/qwidget.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDesignerFormWindowCursorInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDesignerFormWindowCursorInterfaceWrapper::QDesignerFormWindowCursorInterfaceWrapper() : QDesignerFormWindowCursorInterface()
{
    resetPyMethodCache();
    // ... middle
}

::QWidget * QDesignerFormWindowCursorInterfaceWrapper::current() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.current");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "current";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.current");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QDesignerFormWindowInterface * QDesignerFormWindowCursorInterfaceWrapper::formWindow() const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.formWindow");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "formWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.formWindow");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, Shiboken::SbkType< QDesignerFormWindowInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDesignerFormWindowInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDesignerFormWindowCursorInterfaceWrapper::hasSelection() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.hasSelection");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasSelection";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.hasSelection");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDesignerFormWindowCursorInterfaceWrapper::movePosition(::QDesignerFormWindowCursorInterface::MoveOperation op, ::QDesignerFormWindowCursorInterface::MoveMode mode)
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.movePosition");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "movePosition";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.movePosition");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX])))->converter, &op),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX])))->converter, &op),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QDesignerFormWindowCursorInterfaceWrapper::position() const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.position");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "position";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.position");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDesignerFormWindowCursorInterfaceWrapper::resetWidgetProperty(::QWidget * widget, const ::QString & name)
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.resetWidgetProperty");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resetWidgetProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.resetWidgetProperty");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QWidget * QDesignerFormWindowCursorInterfaceWrapper::selectedWidget(int index) const
{
    if (m_PyMethodCache[6]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidget");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "selectedWidget";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidget");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        index
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QDesignerFormWindowCursorInterfaceWrapper::selectedWidgetCount() const
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidgetCount");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "selectedWidgetCount";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidgetCount");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDesignerFormWindowCursorInterfaceWrapper::setPosition(int pos, ::QDesignerFormWindowCursorInterface::MoveMode mode)
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setPosition");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPosition";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setPosition");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &pos),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        pos,
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QDesignerFormWindowCursorInterfaceWrapper::setProperty(const ::QString & name, const ::QVariant & value)
{
    if (m_PyMethodCache[9]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setProperty");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setProperty");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QDesignerFormWindowCursorInterfaceWrapper::setWidgetProperty(::QWidget * widget, const ::QString & name, const ::QVariant & value)
{
    if (m_PyMethodCache[10]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setWidgetProperty");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setWidgetProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setWidgetProperty");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QWidget * QDesignerFormWindowCursorInterfaceWrapper::widget(int index) const
{
    if (m_PyMethodCache[11]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widget");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "widget";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widget");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &index)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        index
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QDesignerFormWindowCursorInterfaceWrapper::widgetCount() const
{
    if (m_PyMethodCache[12]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widgetCount");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "widgetCount";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widgetCount");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDesignerFormWindowCursorInterface", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QDesignerFormWindowCursorInterfaceWrapper::~QDesignerFormWindowCursorInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesignerFormWindowCursorInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QDesignerFormWindowCursorInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesignerFormWindowCursorInterface >()))
        return -1;

    ::QDesignerFormWindowCursorInterfaceWrapper *cptr{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesignerFormWindowCursorInterface()
            cptr = new ::QDesignerFormWindowCursorInterfaceWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDesignerFormWindowCursorInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_current(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.current";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // current()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.current");
                return {};
            }
            QWidget * cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->current();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_formWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.formWindow";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // formWindow()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.formWindow");
                return {};
            }
            QDesignerFormWindowInterface * cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->formWindow();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowInterface_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_hasSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.hasSelection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasSelection()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.hasSelection");
                return {};
            }
            bool cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->hasSelection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_isWidgetSelected(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.isWidgetSelected";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::isWidgetSelected(QWidget*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // isWidgetSelected(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isWidgetSelected(QWidget*)const
            bool cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->isWidgetSelected(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_movePosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.movePosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:movePosition", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::movePosition(QDesignerFormWindowCursorInterface::MoveOperation,QDesignerFormWindowCursorInterface::MoveMode=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // movePosition(QDesignerFormWindowCursorInterface::MoveOperation,QDesignerFormWindowCursorInterface::MoveMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // movePosition(QDesignerFormWindowCursorInterface::MoveOperation,QDesignerFormWindowCursorInterface::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QDesignerFormWindowCursorInterface::MoveOperation cppArg0{QDesignerFormWindowCursorInterface::NoMove};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QDesignerFormWindowCursorInterface::MoveMode cppArg1(QDesignerFormWindowCursorInterface::MoveMode::MoveAnchor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // movePosition(QDesignerFormWindowCursorInterface::MoveOperation,QDesignerFormWindowCursorInterface::MoveMode)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.movePosition");
                return {};
            }
            bool cppResult = cppSelf->movePosition(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.position";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // position()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.position");
                return {};
            }
            int cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->position();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_resetWidgetProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.resetWidgetProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resetWidgetProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::resetWidgetProperty(QWidget*,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // resetWidgetProperty(QWidget*,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetWidgetProperty(QWidget*,QString)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.resetWidgetProperty");
                return {};
            }
            cppSelf->resetWidgetProperty(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_selectedWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.selectedWidget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::selectedWidget(int)const->QWidget*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // selectedWidget(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedWidget(int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidget");
                return {};
            }
            QWidget * cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->selectedWidget(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_selectedWidgetCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.selectedWidgetCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedWidgetCount()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.selectedWidgetCount");
                return {};
            }
            int cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->selectedWidgetCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_setPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setPosition", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::setPosition(int,QDesignerFormWindowCursorInterface::MoveMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPosition(int,QDesignerFormWindowCursorInterface::MoveMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setPosition(int,QDesignerFormWindowCursorInterface::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QDesignerFormWindowCursorInterface::MoveMode cppArg1(QDesignerFormWindowCursorInterface::MoveMode::MoveAnchor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(int,QDesignerFormWindowCursorInterface::MoveMode)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setPosition");
                return {};
            }
            cppSelf->setPosition(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::setProperty(QString,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setProperty(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProperty(QString,QVariant)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setProperty");
                return {};
            }
            cppSelf->setProperty(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_setWidgetProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setWidgetProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setWidgetProperty", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::setWidgetProperty(QWidget*,QString,QVariant)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        overloadId = 0; // setWidgetProperty(QWidget*,QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidgetProperty(QWidget*,QString,QVariant)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.setWidgetProperty");
                return {};
            }
            cppSelf->setWidgetProperty(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_widget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.widget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDesignerFormWindowCursorInterface::widget(int)const->QWidget*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // widget(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // widget(int)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widget");
                return {};
            }
            QWidget * cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->widget(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesignerFormWindowCursorInterfaceFunc_widgetCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.widgetCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // widgetCount()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QDesignerFormWindowCursorInterface.widgetCount");
                return {};
            }
            int cppResult = const_cast<const ::QDesignerFormWindowCursorInterface *>(cppSelf)->widgetCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDesignerFormWindowCursorInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDesignerFormWindowCursorInterface_EnumFlagInfo[] = {
    "MoveMode:Enum",
    "MoveOperation:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesignerFormWindowCursorInterface_methods[] = {
    {"current", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_current), METH_NOARGS, nullptr},
    {"formWindow", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_formWindow), METH_NOARGS, nullptr},
    {"hasSelection", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_hasSelection), METH_NOARGS, nullptr},
    {"isWidgetSelected", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_isWidgetSelected), METH_O, nullptr},
    {"movePosition", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_movePosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_position), METH_NOARGS, nullptr},
    {"resetWidgetProperty", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_resetWidgetProperty), METH_VARARGS, nullptr},
    {"selectedWidget", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_selectedWidget), METH_O, nullptr},
    {"selectedWidgetCount", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_selectedWidgetCount), METH_NOARGS, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_setPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_setProperty), METH_VARARGS, nullptr},
    {"setWidgetProperty", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_setWidgetProperty), METH_VARARGS, nullptr},
    {"widget", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_widget), METH_O, nullptr},
    {"widgetCount", reinterpret_cast<PyCFunction>(Sbk_QDesignerFormWindowCursorInterfaceFunc_widgetCount), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDesignerFormWindowCursorInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDesignerFormWindowCursorInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDesignerFormWindowCursorInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDesignerFormWindowCursorInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesignerFormWindowCursorInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesignerFormWindowCursorInterface_Type = nullptr;
static PyTypeObject *Sbk_QDesignerFormWindowCursorInterface_TypeF(void)
{
    return _Sbk_QDesignerFormWindowCursorInterface_Type;
}

static PyType_Slot Sbk_QDesignerFormWindowCursorInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowCursorInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesignerFormWindowCursorInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesignerFormWindowCursorInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesignerFormWindowCursorInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesignerFormWindowCursorInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesignerFormWindowCursorInterface_spec = {
    "2:PySide6.QtDesigner.QDesignerFormWindowCursorInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesignerFormWindowCursorInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QDesignerFormWindowCursorInterface_MoveOperation_PythonToCpp_QDesignerFormWindowCursorInterface_MoveOperation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowCursorInterface::MoveOperation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowCursorInterface::MoveOperation *>(cppOut) = value;

}
static PythonToCppFunc is_QDesignerFormWindowCursorInterface_MoveOperation_PythonToCpp_QDesignerFormWindowCursorInterface_MoveOperation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX])))
        return QDesignerFormWindowCursorInterface_MoveOperation_PythonToCpp_QDesignerFormWindowCursorInterface_MoveOperation;
    return {};
}
static PyObject *QDesignerFormWindowCursorInterface_MoveOperation_CppToPython_QDesignerFormWindowCursorInterface_MoveOperation(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDesignerFormWindowCursorInterface::MoveOperation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX]), castCppIn);

}

static void QDesignerFormWindowCursorInterface_MoveMode_PythonToCpp_QDesignerFormWindowCursorInterface_MoveMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDesignerFormWindowCursorInterface::MoveMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDesignerFormWindowCursorInterface::MoveMode *>(cppOut) = value;

}
static PythonToCppFunc is_QDesignerFormWindowCursorInterface_MoveMode_PythonToCpp_QDesignerFormWindowCursorInterface_MoveMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX])))
        return QDesignerFormWindowCursorInterface_MoveMode_PythonToCpp_QDesignerFormWindowCursorInterface_MoveMode;
    return {};
}
static PyObject *QDesignerFormWindowCursorInterface_MoveMode_CppToPython_QDesignerFormWindowCursorInterface_MoveMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDesignerFormWindowCursorInterface::MoveMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesignerFormWindowCursorInterface_PythonToCpp_QDesignerFormWindowCursorInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesignerFormWindowCursorInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesignerFormWindowCursorInterface_PythonToCpp_QDesignerFormWindowCursorInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesignerFormWindowCursorInterface_TypeF()))
        return QDesignerFormWindowCursorInterface_PythonToCpp_QDesignerFormWindowCursorInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesignerFormWindowCursorInterface_PTR_CppToPython_QDesignerFormWindowCursorInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QDesignerFormWindowCursorInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QDesignerFormWindowCursorInterface_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDesignerFormWindowCursorInterface_SignatureStrings[] = {
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface(self)",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.current(self)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.formWindow(self)->PySide6.QtDesigner.QDesignerFormWindowInterface",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.hasSelection(self)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.isWidgetSelected(self,widget:PySide6.QtWidgets.QWidget)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.movePosition(self,op:PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveOperation,mode:PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveMode=QDesignerFormWindowCursorInterface.MoveMode.MoveAnchor)->bool",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.position(self)->int",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.resetWidgetProperty(self,widget:PySide6.QtWidgets.QWidget,name:QString)",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.selectedWidget(self,index:int)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.selectedWidgetCount(self)->int",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setPosition(self,pos:int,mode:PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveMode=QDesignerFormWindowCursorInterface.MoveMode.MoveAnchor)",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setProperty(self,name:QString,value:QVariant)",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.setWidgetProperty(self,widget:PySide6.QtWidgets.QWidget,name:QString,value:QVariant)",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.widget(self,index:int)->PySide6.QtWidgets.QWidget",
    "PySide6.QtDesigner.QDesignerFormWindowCursorInterface.widgetCount(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QDesignerFormWindowCursorInterface(PyObject *module)
{
    _Sbk_QDesignerFormWindowCursorInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesignerFormWindowCursorInterface",
        "QDesignerFormWindowCursorInterface*",
        &Sbk_QDesignerFormWindowCursorInterface_spec,
        &Shiboken::callCppDestructor< ::QDesignerFormWindowCursorInterface >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QDesignerFormWindowCursorInterface_TypeF(); // references _Sbk_QDesignerFormWindowCursorInterface_Type
    InitSignatureStrings(pyType, QDesignerFormWindowCursorInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesignerFormWindowCursorInterface_PropertyStrings);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesignerFormWindowCursorInterface_PythonToCpp_QDesignerFormWindowCursorInterface_PTR,
        is_QDesignerFormWindowCursorInterface_PythonToCpp_QDesignerFormWindowCursorInterface_PTR_Convertible,
        QDesignerFormWindowCursorInterface_PTR_CppToPython_QDesignerFormWindowCursorInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowCursorInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowCursorInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowCursorInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerFormWindowCursorInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesignerFormWindowCursorInterfaceWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDesignerFormWindowCursorInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MoveOperation'.
    const char *MoveOperation_Initializer[] = {
        "NoMove",
        "Start",
        "End",
        "Next",
        "Prev",
        "Left",
        "Right",
        "Up",
        "Down",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MoveOperation_InitializerValues[] = {
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::NoMove), //  0x00  0
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Start),  //  0x01  1
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::End),    //  0x02  2
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Next),   //  0x03  3
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Prev),   //  0x04  4
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Left),   //  0x05  5
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Right),  //  0x06  6
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Up),     //  0x07  7
        uint8_t(QDesignerFormWindowCursorInterface::MoveOperation::Down)    //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowCursorInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveOperation",
        MoveOperation_Initializer, MoveOperation_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveOperation_IDX].type = EType;
    // Register converter for enum 'QDesignerFormWindowCursorInterface::MoveOperation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowCursorInterface_MoveOperation_CppToPython_QDesignerFormWindowCursorInterface_MoveOperation);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDesignerFormWindowCursorInterface_MoveOperation_PythonToCpp_QDesignerFormWindowCursorInterface_MoveOperation,
            is_QDesignerFormWindowCursorInterface_MoveOperation_PythonToCpp_QDesignerFormWindowCursorInterface_MoveOperation_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowCursorInterface::MoveOperation");
        Shiboken::Conversions::registerConverterName(converter, "MoveOperation");
    }
    // End of 'MoveOperation' enum.

    // Initialization of enum 'MoveMode'.
    const char *MoveMode_Initializer[] = {
        "MoveAnchor",
        "KeepAnchor",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MoveMode_InitializerValues[] = {
        uint8_t(QDesignerFormWindowCursorInterface::MoveMode::MoveAnchor), //  0x00  0
        uint8_t(QDesignerFormWindowCursorInterface::MoveMode::KeepAnchor)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDesignerFormWindowCursorInterface_TypeF(),
        "2:PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveMode",
        MoveMode_Initializer, MoveMode_InitializerValues);
    SbkPySide6_QtDesignerTypeStructs[SBK_QDesignerFormWindowCursorInterface_MoveMode_IDX].type = EType;
    // Register converter for enum 'QDesignerFormWindowCursorInterface::MoveMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDesignerFormWindowCursorInterface_MoveMode_CppToPython_QDesignerFormWindowCursorInterface_MoveMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDesignerFormWindowCursorInterface_MoveMode_PythonToCpp_QDesignerFormWindowCursorInterface_MoveMode,
            is_QDesignerFormWindowCursorInterface_MoveMode_PythonToCpp_QDesignerFormWindowCursorInterface_MoveMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDesignerFormWindowCursorInterface::MoveMode");
        Shiboken::Conversions::registerConverterName(converter, "MoveMode");
    }
    // End of 'MoveMode' enum.

    qRegisterMetaType< ::QDesignerFormWindowCursorInterface *>();
    qRegisterMetaType< ::QDesignerFormWindowCursorInterface::MoveOperation >("QDesignerFormWindowCursorInterface::MoveOperation");
    qRegisterMetaType< ::QDesignerFormWindowCursorInterface::MoveMode >("QDesignerFormWindowCursorInterface::MoveMode");

    return pyType;
}
