// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qaccessibletextupdateevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qaccessible.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAccessibleTextUpdateEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAccessibleTextUpdateEventWrapper::QAccessibleTextUpdateEventWrapper(::QAccessibleInterface * iface, int position, const ::QString & oldText, const ::QString & text) : QAccessibleTextUpdateEvent(iface, position, oldText, text)
{
    resetPyMethodCache();
    // ... middle
}

QAccessibleTextUpdateEventWrapper::QAccessibleTextUpdateEventWrapper(::QObject * obj, int position, const ::QString & oldText, const ::QString & text) : QAccessibleTextUpdateEvent(obj, position, oldText, text)
{
    resetPyMethodCache();
    // ... middle
}

::QAccessibleInterface * QAccessibleTextUpdateEventWrapper::accessibleInterface() const
{
    if (m_PyMethodCache[0])
        return this->::QAccessibleEvent::accessibleInterface();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accessibleInterface";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAccessibleEvent::accessibleInterface();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAccessibleTextUpdateEvent", funcName, Shiboken::SbkType< QAccessibleInterface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QAccessibleInterface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAccessibleTextUpdateEventWrapper::~QAccessibleTextUpdateEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAccessibleTextUpdateEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAccessibleTextUpdateEvent >()))
        return -1;

    ::QAccessibleTextUpdateEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QAccessibleTextUpdateEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAccessibleTextUpdateEvent", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAccessibleTextUpdateEvent::QAccessibleTextUpdateEvent(QAccessibleInterface*,int,QString,QString)
    // 1: QAccessibleTextUpdateEvent::QAccessibleTextUpdateEvent(QObject*,int,QString,QString)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 1; // QAccessibleTextUpdateEvent(QObject*,int,QString,QString)
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 0; // QAccessibleTextUpdateEvent(QAccessibleInterface*,int,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAccessibleTextUpdateEvent(QAccessibleInterface * iface, int position, const QString & oldText, const QString & text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAccessibleInterface *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextUpdateEvent(QAccessibleInterface*,int,QString,QString)
                cptr = new ::QAccessibleTextUpdateEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // QAccessibleTextUpdateEvent(QObject * obj, int position, const QString & oldText, const QString & text)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAccessibleTextUpdateEvent(QObject*,int,QString,QString)
                cptr = new ::QAccessibleTextUpdateEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAccessibleTextUpdateEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAccessibleTextUpdateEventFunc_changePosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextUpdateEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextUpdateEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QAccessibleTextUpdateEvent.changePosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // changePosition()const
            int cppResult = const_cast<const ::QAccessibleTextUpdateEvent *>(cppSelf)->changePosition();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTextUpdateEventFunc_textInserted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextUpdateEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextUpdateEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QAccessibleTextUpdateEvent.textInserted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textInserted()const
            QString cppResult = const_cast<const ::QAccessibleTextUpdateEvent *>(cppSelf)->textInserted();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAccessibleTextUpdateEventFunc_textRemoved(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAccessibleTextUpdateEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextUpdateEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QAccessibleTextUpdateEvent.textRemoved";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textRemoved()const
            QString cppResult = const_cast<const ::QAccessibleTextUpdateEvent *>(cppSelf)->textRemoved();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAccessibleTextUpdateEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAccessibleTextUpdateEvent_methods[] = {
    {"changePosition", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextUpdateEventFunc_changePosition), METH_NOARGS, nullptr},
    {"textInserted", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextUpdateEventFunc_textInserted), METH_NOARGS, nullptr},
    {"textRemoved", reinterpret_cast<PyCFunction>(Sbk_QAccessibleTextUpdateEventFunc_textRemoved), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAccessibleTextUpdateEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAccessibleTextUpdateEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextUpdateEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAccessibleTextUpdateEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAccessibleTextUpdateEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAccessibleTextUpdateEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAccessibleTextUpdateEvent_Type = nullptr;
static PyTypeObject *Sbk_QAccessibleTextUpdateEvent_TypeF(void)
{
    return _Sbk_QAccessibleTextUpdateEvent_Type;
}

static PyType_Slot Sbk_QAccessibleTextUpdateEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAccessibleTextUpdateEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAccessibleTextUpdateEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAccessibleTextUpdateEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAccessibleTextUpdateEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAccessibleTextUpdateEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAccessibleTextUpdateEvent_spec = {
    "2:PySide6.QtGui.QAccessibleTextUpdateEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAccessibleTextUpdateEvent_slots
};

} //extern "C"

static void *Sbk_QAccessibleTextUpdateEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
     if ( reinterpret_cast< ::QAccessibleTextUpdateEvent *>(cptr)->type() == QAccessible::TextUpdated)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAccessibleTextUpdateEvent_PythonToCpp_QAccessibleTextUpdateEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAccessibleTextUpdateEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAccessibleTextUpdateEvent_PythonToCpp_QAccessibleTextUpdateEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAccessibleTextUpdateEvent_TypeF()))
        return QAccessibleTextUpdateEvent_PythonToCpp_QAccessibleTextUpdateEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAccessibleTextUpdateEvent_PTR_CppToPython_QAccessibleTextUpdateEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QAccessibleTextUpdateEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QAccessibleTextUpdateEvent_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAccessibleTextUpdateEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QAccessibleTextUpdateEvent(self,iface:PySide6.QtGui.QAccessibleInterface,position:int,oldText:QString,text:QString)",
    "0:PySide6.QtGui.QAccessibleTextUpdateEvent(self,obj:PySide6.QtCore.QObject,position:int,oldText:QString,text:QString)",
    "PySide6.QtGui.QAccessibleTextUpdateEvent.changePosition(self)->int",
    "PySide6.QtGui.QAccessibleTextUpdateEvent.textInserted(self)->QString",
    "PySide6.QtGui.QAccessibleTextUpdateEvent.textRemoved(self)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QAccessibleTextUpdateEvent(PyObject *module)
{
    _Sbk_QAccessibleTextUpdateEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAccessibleTextUpdateEvent",
        "QAccessibleTextUpdateEvent*",
        &Sbk_QAccessibleTextUpdateEvent_spec,
        &Shiboken::callCppDestructor< ::QAccessibleTextUpdateEvent >,
        Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextCursorEvent_IDX]),
        0,
        0);
    auto *pyType = Sbk_QAccessibleTextUpdateEvent_TypeF(); // references _Sbk_QAccessibleTextUpdateEvent_Type
    InitSignatureStrings(pyType, QAccessibleTextUpdateEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAccessibleTextUpdateEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleTextUpdateEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAccessibleTextUpdateEvent_PythonToCpp_QAccessibleTextUpdateEvent_PTR,
        is_QAccessibleTextUpdateEvent_PythonToCpp_QAccessibleTextUpdateEvent_PTR_Convertible,
        QAccessibleTextUpdateEvent_PTR_CppToPython_QAccessibleTextUpdateEvent);

    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextUpdateEvent");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextUpdateEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QAccessibleTextUpdateEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTextUpdateEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAccessibleTextUpdateEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAccessibleTextUpdateEvent_TypeF(), &Sbk_QAccessibleTextUpdateEvent_typeDiscovery);

    qRegisterMetaType< ::QAccessibleTextUpdateEvent *>();

    return pyType;
}
