// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qcolorspace_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qcolorspace.h>
#include <QtGui/qcolortransform.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QColorSpace_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QColorSpace >()))
        return -1;

    ::QColorSpace *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    if (numArgs == 4)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOO:QColorSpace", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QColorSpace::QColorSpace()
    // 1: QColorSpace::QColorSpace(QColorSpace::NamedColorSpace)
    // 2: QColorSpace::QColorSpace(QColorSpace::Primaries,QColorSpace::TransferFunction,float=)
    // 3: QColorSpace::QColorSpace(QColorSpace::Primaries,QList<uint16_t>)
    // 4: QColorSpace::QColorSpace(QColorSpace::Primaries,float)
    // 5: QColorSpace::QColorSpace(QColorSpace)
    // 6: QColorSpace::QColorSpace(QPointF,QPointF,QPointF,QPointF,QColorSpace::TransferFunction,float=)
    // 7: QColorSpace::QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
    // 8: QColorSpace::QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>)
    if (numArgs == 0) {
        overloadId = 0; // QColorSpace()
    } else if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))) {
        if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))->converter, (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 6; // QColorSpace(QPointF,QPointF,QPointF,QPointF,QColorSpace::TransferFunction,float)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
                overloadId = 6; // QColorSpace(QPointF,QPointF,QPointF,QPointF,QColorSpace::TransferFunction,float)
            }
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 8; // QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>)
            } else if (numArgs == 7
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[5])))
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[6])))) {
                overloadId = 7; // QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QColorSpace(QColorSpace::Primaries,QColorSpace::TransferFunction,float)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
                overloadId = 2; // QColorSpace(QColorSpace::Primaries,QColorSpace::TransferFunction,float)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 4; // QColorSpace(QColorSpace::Primaries,float)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[1])))) {
            overloadId = 3; // QColorSpace(QColorSpace::Primaries,QList<uint16_t>)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QColorSpace(QColorSpace::NamedColorSpace)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArgs[0])))) {
        overloadId = 5; // QColorSpace(QColorSpace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QColorSpace()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace()
                cptr = new ::QColorSpace();
            }
            break;
        }
        case 1: // QColorSpace(QColorSpace::NamedColorSpace namedColorSpace)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QColorSpace::NamedColorSpace cppArg0 = static_cast< ::QColorSpace::NamedColorSpace>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QColorSpace::NamedColorSpace)
                cptr = new ::QColorSpace(cppArg0);
            }
            break;
        }
        case 2: // QColorSpace(QColorSpace::Primaries primaries, QColorSpace::TransferFunction transferFunction, float gamma)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_gamma = Shiboken::String::createStaticString("gamma");
                if (PyDict_Contains(kwds, key_gamma) != 0) {
                    value = PyDict_GetItem(kwds, key_gamma);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_gamma);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_gamma);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QColorSpace::Primaries cppArg0{QColorSpace::Primaries::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QColorSpace::TransferFunction cppArg1{QColorSpace::TransferFunction::Custom};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2 = 0.0f;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QColorSpace::Primaries,QColorSpace::TransferFunction,float)
                cptr = new ::QColorSpace(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QColorSpace(QColorSpace::Primaries primaries, const QList<uint16_t> & transferFunctionTable)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QColorSpace::Primaries cppArg0{QColorSpace::Primaries::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<uint16_t> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QColorSpace::Primaries,QList<uint16_t>)
                cptr = new ::QColorSpace(cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QColorSpace(QColorSpace::Primaries primaries, float gamma)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QColorSpace::Primaries cppArg0{QColorSpace::Primaries::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QColorSpace::Primaries,float)
                cptr = new ::QColorSpace(cppArg0, cppArg1);
            }
            break;
        }
        case 5: // QColorSpace(const QColorSpace & colorSpace)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QColorSpace cppArg0_local;
            ::QColorSpace *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QColorSpace)
                cptr = new ::QColorSpace(*cppArg0);
            }
            break;
        }
        case 6: // QColorSpace(const QPointF & whitePoint, const QPointF & redPoint, const QPointF & greenPoint, const QPointF & bluePoint, QColorSpace::TransferFunction transferFunction, float gamma)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_gamma = Shiboken::String::createStaticString("gamma");
                if (PyDict_Contains(kwds, key_gamma) != 0) {
                    value = PyDict_GetItem(kwds, key_gamma);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_gamma);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_gamma);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::QColorSpace::TransferFunction cppArg4{QColorSpace::TransferFunction::Custom};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            float cppArg5 = 0.0f;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QPointF,QPointF,QPointF,QPointF,QColorSpace::TransferFunction,float)
                cptr = new ::QColorSpace(*cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 7: // QColorSpace(const QPointF & whitePoint, const QPointF & redPoint, const QPointF & greenPoint, const QPointF & bluePoint, const QList<uint16_t> & redTransferFunctionTable, const QList<uint16_t> & greenTransferFunctionTable, const QList<uint16_t> & blueTransferFunctionTable)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::QList<uint16_t> cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QList<uint16_t> cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QList<uint16_t> cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
                cptr = new ::QColorSpace(*cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
        case 8: // QColorSpace(const QPointF & whitePoint, const QPointF & redPoint, const QPointF & greenPoint, const QPointF & bluePoint, const QList<uint16_t> & transferFunctionTable)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            ::QList<uint16_t> cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColorSpace(QPointF,QPointF,QPointF,QPointF,QList<uint16_t>)
                cptr = new ::QColorSpace(*cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QColorSpace >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QColorSpaceFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QColorSpace *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_fromIccProfile(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.fromIccProfile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QColorSpace::fromIccProfile(QByteArray)->QColorSpace
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromIccProfile(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromIccProfile(QByteArray)
            QColorSpace cppResult = ::QColorSpace::fromIccProfile(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_gamma(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.gamma";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // gamma()const
            float cppResult = const_cast<const ::QColorSpace *>(cppSelf)->gamma();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_iccProfile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.iccProfile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // iccProfile()const
            QByteArray cppResult = const_cast<const ::QColorSpace *>(cppSelf)->iccProfile();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QColorSpace *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_primaries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.primaries";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // primaries()const
            QColorSpace::Primaries cppResult = const_cast<const ::QColorSpace *>(cppSelf)->primaries();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_setDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.setDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColorSpace::setDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescription(QString)
            cppSelf->setDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorSpaceFunc_setPrimaries(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.setPrimaries";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "setPrimaries", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColorSpace::setPrimaries(QColorSpace::Primaries)
    // 1: QColorSpace::setPrimaries(QPointF,QPointF,QPointF,QPointF)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[3])))) {
        overloadId = 1; // setPrimaries(QPointF,QPointF,QPointF,QPointF)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // setPrimaries(QColorSpace::Primaries)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setPrimaries(QColorSpace::Primaries primariesId)
        {
            ::QColorSpace::Primaries cppArg0{QColorSpace::Primaries::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPrimaries(QColorSpace::Primaries)
                cppSelf->setPrimaries(cppArg0);
            }
            break;
        }
        case 1: // setPrimaries(const QPointF & whitePoint, const QPointF & redPoint, const QPointF & greenPoint, const QPointF & bluePoint)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPointF cppArg2_local;
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPointF cppArg3_local;
            ::QPointF *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPrimaries(QPointF,QPointF,QPointF,QPointF)
                cppSelf->setPrimaries(*cppArg0, *cppArg1, *cppArg2, *cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorSpaceFunc_setTransferFunction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.setTransferFunction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setTransferFunction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColorSpace::setTransferFunction(QColorSpace::TransferFunction,float=)
    // 1: QColorSpace::setTransferFunction(QList<uint16_t>)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setTransferFunction(QColorSpace::TransferFunction,float)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 0; // setTransferFunction(QColorSpace::TransferFunction,float)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[0])))) {
        overloadId = 1; // setTransferFunction(QList<uint16_t>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setTransferFunction(QColorSpace::TransferFunction transferFunction, float gamma)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_gamma = Shiboken::String::createStaticString("gamma");
                if (PyDict_Contains(kwds, key_gamma) != 0) {
                    value = PyDict_GetItem(kwds, key_gamma);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_gamma);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_gamma);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QColorSpace::TransferFunction cppArg0{QColorSpace::TransferFunction::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1 = 0.0f;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setTransferFunction(QColorSpace::TransferFunction,float)
                cppSelf->setTransferFunction(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setTransferFunction(const QList<uint16_t> & transferFunctionTable)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QList<uint16_t> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setTransferFunction(QList<uint16_t>)
                cppSelf->setTransferFunction(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorSpaceFunc_setTransferFunctions(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.setTransferFunctions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setTransferFunctions", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColorSpace::setTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[2])))) {
        overloadId = 0; // setTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QList<uint16_t> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<uint16_t> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<uint16_t> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)
            cppSelf->setTransferFunctions(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorSpaceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColorSpace::swap(QColorSpace&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QColorSpace&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColorSpace cppArg0_local;
        ::QColorSpace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QColorSpace&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorSpaceFunc_transferFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.transferFunction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // transferFunction()const
            QColorSpace::TransferFunction cppResult = const_cast<const ::QColorSpace *>(cppSelf)->transferFunction();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_transformationToColorSpace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.transformationToColorSpace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColorSpace::transformationToColorSpace(QColorSpace)const->QColorTransform
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
        overloadId = 0; // transformationToColorSpace(QColorSpace)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColorSpace cppArg0_local;
        ::QColorSpace *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // transformationToColorSpace(QColorSpace)const
            QColorTransform cppResult = const_cast<const ::QColorSpace *>(cppSelf)->transformationToColorSpace(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_withTransferFunction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.withTransferFunction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:withTransferFunction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColorSpace::withTransferFunction(QColorSpace::TransferFunction,float=)const->QColorSpace
    // 1: QColorSpace::withTransferFunction(QList<uint16_t>)const->QColorSpace
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // withTransferFunction(QColorSpace::TransferFunction,float)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            overloadId = 0; // withTransferFunction(QColorSpace::TransferFunction,float)const
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[0])))) {
        overloadId = 1; // withTransferFunction(QList<uint16_t>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // withTransferFunction(QColorSpace::TransferFunction transferFunction, float gamma) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_gamma = Shiboken::String::createStaticString("gamma");
                if (PyDict_Contains(kwds, key_gamma) != 0) {
                    value = PyDict_GetItem(kwds, key_gamma);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_gamma);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_gamma);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QColorSpace::TransferFunction cppArg0{QColorSpace::TransferFunction::Custom};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1 = 0.0f;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // withTransferFunction(QColorSpace::TransferFunction,float)const
                QColorSpace cppResult = const_cast<const ::QColorSpace *>(cppSelf)->withTransferFunction(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
            }
            break;
        }
        case 1: // withTransferFunction(const QList<uint16_t> & transferFunctionTable) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QList<uint16_t> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // withTransferFunction(QList<uint16_t>)const
                QColorSpace cppResult = const_cast<const ::QColorSpace *>(cppSelf)->withTransferFunction(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc_withTransferFunctions(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.withTransferFunctions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "withTransferFunctions", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColorSpace::withTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)const->QColorSpace
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], (pyArgs[2])))) {
        overloadId = 0; // withTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QList<uint16_t> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<uint16_t> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<uint16_t> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // withTransferFunctions(QList<uint16_t>,QList<uint16_t>,QList<uint16_t>)const
            QColorSpace cppResult = const_cast<const ::QColorSpace *>(cppSelf)->withTransferFunctions(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpace__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QColorSpace_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QColorSpace_EnumFlagInfo[] = {
    "NamedColorSpace:Enum",
    "Primaries:Enum",
    "TransferFunction:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QColorSpace_methods[] = {
    {"description", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_description), METH_NOARGS, nullptr},
    {"fromIccProfile", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_fromIccProfile), METH_O|METH_STATIC, nullptr},
    {"gamma", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_gamma), METH_NOARGS, nullptr},
    {"iccProfile", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_iccProfile), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_isValid), METH_NOARGS, nullptr},
    {"primaries", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_primaries), METH_NOARGS, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_setDescription), METH_O, nullptr},
    {"setPrimaries", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_setPrimaries), METH_VARARGS, nullptr},
    {"setTransferFunction", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_setTransferFunction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTransferFunctions", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_setTransferFunctions), METH_VARARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_swap), METH_O, nullptr},
    {"transferFunction", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_transferFunction), METH_NOARGS, nullptr},
    {"transformationToColorSpace", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_transformationToColorSpace), METH_O, nullptr},
    {"withTransferFunction", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_withTransferFunction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"withTransferFunctions", reinterpret_cast<PyCFunction>(Sbk_QColorSpaceFunc_withTransferFunctions), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QColorSpace__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QColorSpaceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.__lshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QColorSpace::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QColorSpace)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QColorSpace) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorSpaceFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QColorSpace.__rshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QColorSpace::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QColorSpace&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QColorSpace&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QColorSpace_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
                // operator!=(const QColorSpace & colorSpace2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColorSpace cppArg0_local;
                ::QColorSpace *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
                // operator==(const QColorSpace & colorSpace2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColorSpace cppArg0_local;
                ::QColorSpace *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QColorSpace_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QColorSpace_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QColorSpace__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QColorSpace_Type = nullptr;
static PyTypeObject *Sbk_QColorSpace_TypeF(void)
{
    return _Sbk_QColorSpace_Type;
}

static PyType_Slot Sbk_QColorSpace_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QColorSpace__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QColorSpace_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QColorSpace_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QColorSpace_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QColorSpace_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QColorSpace_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QColorSpaceFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QColorSpaceFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QColorSpace_spec = {
    "2:PySide6.QtGui.QColorSpace",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QColorSpace_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_NamedColorSpace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColorSpace::NamedColorSpace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColorSpace::NamedColorSpace *>(cppOut) = value;

}
static PythonToCppFunc is_QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_NamedColorSpace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX])))
        return QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_NamedColorSpace;
    return {};
}
static PyObject *QColorSpace_NamedColorSpace_CppToPython_QColorSpace_NamedColorSpace(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QColorSpace::NamedColorSpace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX]), castCppIn);

}

static void QColorSpace_Primaries_PythonToCpp_QColorSpace_Primaries(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColorSpace::Primaries>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColorSpace::Primaries *>(cppOut) = value;

}
static PythonToCppFunc is_QColorSpace_Primaries_PythonToCpp_QColorSpace_Primaries_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX])))
        return QColorSpace_Primaries_PythonToCpp_QColorSpace_Primaries;
    return {};
}
static PyObject *QColorSpace_Primaries_CppToPython_QColorSpace_Primaries(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QColorSpace::Primaries *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX]), castCppIn);

}

static void QColorSpace_TransferFunction_PythonToCpp_QColorSpace_TransferFunction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColorSpace::TransferFunction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColorSpace::TransferFunction *>(cppOut) = value;

}
static PythonToCppFunc is_QColorSpace_TransferFunction_PythonToCpp_QColorSpace_TransferFunction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX])))
        return QColorSpace_TransferFunction_PythonToCpp_QColorSpace_TransferFunction;
    return {};
}
static PyObject *QColorSpace_TransferFunction_CppToPython_QColorSpace_TransferFunction(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QColorSpace::TransferFunction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QColorSpace_PythonToCpp_QColorSpace_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QColorSpace_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QColorSpace_PythonToCpp_QColorSpace_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QColorSpace_TypeF()))
        return QColorSpace_PythonToCpp_QColorSpace_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QColorSpace_PTR_CppToPython_QColorSpace(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QColorSpace *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QColorSpace_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QColorSpace_COPY_CppToPython_QColorSpace(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QColorSpace *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QColorSpace_TypeF(), new ::QColorSpace(*source), true, true);
}

// Python to C++ copy conversion.
static void QColorSpace_PythonToCpp_QColorSpace_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QColorSpace *>(cppOut) = *reinterpret_cast< ::QColorSpace *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QColorSpace_PythonToCpp_QColorSpace_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QColorSpace_TypeF()))
        return QColorSpace_PythonToCpp_QColorSpace_COPY;
    return {};
}

// Implicit conversions.
static void QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace(PyObject *pyIn, void *cppOut)
{
    ::QColorSpace::NamedColorSpace cppIn = static_cast< ::QColorSpace::NamedColorSpace>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QColorSpace *>(cppOut) = ::QColorSpace(cppIn);
}
static PythonToCppFunc is_QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX]), pyIn))
        return QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QColorSpace_SignatureStrings[] = {
    "8:PySide6.QtGui.QColorSpace(self)",
    "7:PySide6.QtGui.QColorSpace(self,namedColorSpace:PySide6.QtGui.QColorSpace.NamedColorSpace)",
    "6:PySide6.QtGui.QColorSpace(self,primaries:PySide6.QtGui.QColorSpace.Primaries,transferFunction:PySide6.QtGui.QColorSpace.TransferFunction,gamma:float=0.0f)",
    "5:PySide6.QtGui.QColorSpace(self,primaries:PySide6.QtGui.QColorSpace.Primaries,transferFunctionTable:QList[uint16_t])",
    "4:PySide6.QtGui.QColorSpace(self,primaries:PySide6.QtGui.QColorSpace.Primaries,gamma:float)",
    "3:PySide6.QtGui.QColorSpace(self,colorSpace:typing.Union[PySide6.QtGui.QColorSpace, PySide6.QtGui.QColorSpace.NamedColorSpace])",
    "2:PySide6.QtGui.QColorSpace(self,whitePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],redPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],greenPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],bluePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],transferFunction:PySide6.QtGui.QColorSpace.TransferFunction,gamma:float=0.0f)",
    "1:PySide6.QtGui.QColorSpace(self,whitePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],redPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],greenPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],bluePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],redTransferFunctionTable:QList[uint16_t],greenTransferFunctionTable:QList[uint16_t],blueTransferFunctionTable:QList[uint16_t])",
    "0:PySide6.QtGui.QColorSpace(self,whitePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],redPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],greenPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],bluePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],transferFunctionTable:QList[uint16_t])",
    "PySide6.QtGui.QColorSpace.description(self)->QString",
    "PySide6.QtGui.QColorSpace.fromIccProfile(iccProfile:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtGui.QColorSpace",
    "PySide6.QtGui.QColorSpace.gamma(self)->float",
    "PySide6.QtGui.QColorSpace.iccProfile(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QColorSpace.isValid(self)->bool",
    "PySide6.QtGui.QColorSpace.primaries(self)->PySide6.QtGui.QColorSpace.Primaries",
    "PySide6.QtGui.QColorSpace.setDescription(self,description:QString)",
    "1:PySide6.QtGui.QColorSpace.setPrimaries(self,primariesId:PySide6.QtGui.QColorSpace.Primaries)",
    "0:PySide6.QtGui.QColorSpace.setPrimaries(self,whitePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],redPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],greenPoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],bluePoint:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "1:PySide6.QtGui.QColorSpace.setTransferFunction(self,transferFunction:PySide6.QtGui.QColorSpace.TransferFunction,gamma:float=0.0f)",
    "0:PySide6.QtGui.QColorSpace.setTransferFunction(self,transferFunctionTable:QList[uint16_t])",
    "PySide6.QtGui.QColorSpace.setTransferFunctions(self,redTransferFunctionTable:QList[uint16_t],greenTransferFunctionTable:QList[uint16_t],blueTransferFunctionTable:QList[uint16_t])",
    "PySide6.QtGui.QColorSpace.swap(self,colorSpace:typing.Union[PySide6.QtGui.QColorSpace, PySide6.QtGui.QColorSpace.NamedColorSpace])",
    "PySide6.QtGui.QColorSpace.transferFunction(self)->PySide6.QtGui.QColorSpace.TransferFunction",
    "PySide6.QtGui.QColorSpace.transformationToColorSpace(self,colorspace:typing.Union[PySide6.QtGui.QColorSpace, PySide6.QtGui.QColorSpace.NamedColorSpace])->PySide6.QtGui.QColorTransform",
    "1:PySide6.QtGui.QColorSpace.withTransferFunction(self,transferFunction:PySide6.QtGui.QColorSpace.TransferFunction,gamma:float=0.0f)->PySide6.QtGui.QColorSpace",
    "0:PySide6.QtGui.QColorSpace.withTransferFunction(self,transferFunctionTable:QList[uint16_t])->PySide6.QtGui.QColorSpace",
    "PySide6.QtGui.QColorSpace.withTransferFunctions(self,redTransferFunctionTable:QList[uint16_t],greenTransferFunctionTable:QList[uint16_t],blueTransferFunctionTable:QList[uint16_t])->PySide6.QtGui.QColorSpace",
    "PySide6.QtGui.QColorSpace.__copy__()",
    "PySide6.QtGui.QColorSpace.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QColorSpace.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel

PyTypeObject *init_QColorSpace(PyObject *module)
{
    _Sbk_QColorSpace_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QColorSpace",
        "QColorSpace",
        &Sbk_QColorSpace_spec,
        &Shiboken::callCppDestructor< ::QColorSpace >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QColorSpace_TypeF(); // references _Sbk_QColorSpace_Type
    InitSignatureStrings(pyType, QColorSpace_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QColorSpace_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QColorSpace_PythonToCpp_QColorSpace_PTR,
        is_QColorSpace_PythonToCpp_QColorSpace_PTR_Convertible,
        QColorSpace_PTR_CppToPython_QColorSpace,
        QColorSpace_COPY_CppToPython_QColorSpace);

    Shiboken::Conversions::registerConverterName(converter, "QColorSpace");
    Shiboken::Conversions::registerConverterName(converter, "QColorSpace*");
    Shiboken::Conversions::registerConverterName(converter, "QColorSpace&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QColorSpace).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QColorSpace_PythonToCpp_QColorSpace_COPY,
        is_QColorSpace_PythonToCpp_QColorSpace_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace,
        is_QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QColorSpace_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'NamedColorSpace'.
    const char *NamedColorSpace_Initializer[] = {
        "SRgb",
        "SRgbLinear",
        "AdobeRgb",
        "DisplayP3",
        "ProPhotoRgb",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NamedColorSpace_InitializerValues[] = {
        uint8_t(QColorSpace::NamedColorSpace::SRgb),       //  0x01  1
        uint8_t(QColorSpace::NamedColorSpace::SRgbLinear), //  0x02  2
        uint8_t(QColorSpace::NamedColorSpace::AdobeRgb),   //  0x03  3
        uint8_t(QColorSpace::NamedColorSpace::DisplayP3),  //  0x04  4
        uint8_t(QColorSpace::NamedColorSpace::ProPhotoRgb) //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColorSpace_TypeF(),
        "2:PySide6.QtGui.QColorSpace.NamedColorSpace",
        NamedColorSpace_Initializer, NamedColorSpace_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_NamedColorSpace_IDX].type = EType;
    // Register converter for enum 'QColorSpace::NamedColorSpace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColorSpace_NamedColorSpace_CppToPython_QColorSpace_NamedColorSpace);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_NamedColorSpace,
            is_QColorSpace_NamedColorSpace_PythonToCpp_QColorSpace_NamedColorSpace_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QColorSpace::NamedColorSpace");
        Shiboken::Conversions::registerConverterName(converter, "NamedColorSpace");
    }
    // End of 'NamedColorSpace' enum.

    // Initialization of enum 'Primaries'.
    const char *Primaries_Initializer[] = {
        "Custom",
        "SRgb",
        "AdobeRgb",
        "DciP3D65",
        "ProPhotoRgb",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Primaries_InitializerValues[] = {
        int8_t(QColorSpace::Primaries::Custom),     //  0x00  0
        int8_t(QColorSpace::Primaries::SRgb),       //  0x01  1
        int8_t(QColorSpace::Primaries::AdobeRgb),   //  0x02  2
        int8_t(QColorSpace::Primaries::DciP3D65),   //  0x03  3
        int8_t(QColorSpace::Primaries::ProPhotoRgb) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColorSpace_TypeF(),
        "2:PySide6.QtGui.QColorSpace.Primaries",
        Primaries_Initializer, Primaries_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_Primaries_IDX].type = EType;
    // Register converter for enum 'QColorSpace::Primaries'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColorSpace_Primaries_CppToPython_QColorSpace_Primaries);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QColorSpace_Primaries_PythonToCpp_QColorSpace_Primaries,
            is_QColorSpace_Primaries_PythonToCpp_QColorSpace_Primaries_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QColorSpace::Primaries");
        Shiboken::Conversions::registerConverterName(converter, "Primaries");
    }
    // End of 'Primaries' enum.

    // Initialization of enum 'TransferFunction'.
    const char *TransferFunction_Initializer[] = {
        "Custom",
        "Linear",
        "Gamma",
        "SRgb",
        "ProPhotoRgb",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t TransferFunction_InitializerValues[] = {
        int8_t(QColorSpace::TransferFunction::Custom),     //  0x00  0
        int8_t(QColorSpace::TransferFunction::Linear),     //  0x01  1
        int8_t(QColorSpace::TransferFunction::Gamma),      //  0x02  2
        int8_t(QColorSpace::TransferFunction::SRgb),       //  0x03  3
        int8_t(QColorSpace::TransferFunction::ProPhotoRgb) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColorSpace_TypeF(),
        "2:PySide6.QtGui.QColorSpace.TransferFunction",
        TransferFunction_Initializer, TransferFunction_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_TransferFunction_IDX].type = EType;
    // Register converter for enum 'QColorSpace::TransferFunction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColorSpace_TransferFunction_CppToPython_QColorSpace_TransferFunction);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QColorSpace_TransferFunction_PythonToCpp_QColorSpace_TransferFunction,
            is_QColorSpace_TransferFunction_PythonToCpp_QColorSpace_TransferFunction_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QColorSpace::TransferFunction");
        Shiboken::Conversions::registerConverterName(converter, "TransferFunction");
    }
    // End of 'TransferFunction' enum.

    qRegisterMetaType< ::QColorSpace >("QColorSpace");
    qRegisterMetaType< ::QColorSpace::NamedColorSpace >("QColorSpace::NamedColorSpace");
    qRegisterMetaType< ::QColorSpace::Primaries >("QColorSpace::Primaries");
    qRegisterMetaType< ::QColorSpace::TransferFunction >("QColorSpace::TransferFunction");

    return pyType;
}
