// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qkeyevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qkeysequence.h>
#include <qcoreevent.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QKeyEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QKeyEventWrapper::QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QString & text, bool autorep, quint16 count) : QKeyEvent(type, key, modifiers, text, autorep, count)
{
    resetPyMethodCache();
    // ... middle
}

QKeyEventWrapper::QKeyEventWrapper(::QEvent::Type type, int key, ::QFlags<Qt::KeyboardModifier> modifiers, quint32 nativeScanCode, quint32 nativeVirtualKey, quint32 nativeModifiers, const ::QString & text, bool autorep, quint16 count, const ::QInputDevice * device) : QKeyEvent(type, key, modifiers, nativeScanCode, nativeVirtualKey, nativeModifiers, text, autorep, count, device)
{
    resetPyMethodCache();
    // ... middle
}

::QKeyEvent * QKeyEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QKeyEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QKeyEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QKeyEvent", funcName, Shiboken::SbkType< QKeyEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QKeyEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QKeyEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QKeyEventWrapper::setTimestamp(quint64 timestamp)
{
    if (m_PyMethodCache[2]) {
        return this->::QInputEvent::setTimestamp(timestamp);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setTimestamp";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QInputEvent::setTimestamp(timestamp);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &timestamp)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(K)",
        timestamp
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QKeyEventWrapper::~QKeyEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QKeyEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QKeyEvent >()))
        return -1;

    ::QKeyEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:QKeyEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QKeyEvent::QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,const QString&=,bool=,quint16=)
    // 1: QKeyEvent::QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,const QString&=,bool=,quint16=,const QInputDevice*=)
    // 2: QKeyEvent::QKeyEvent(QKeyEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QKeyEvent(QKeyEvent)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->converter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,quint16)
        } else if (numArgs >= 6
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 1; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 1; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 1; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[8])))) {
                        if (numArgs == 9) {
                            overloadId = 1; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
                        } else if (numArgs >= 10
                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), (pyArgs[9])))) {
                            overloadId = 1; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
                        }
                    }
                }
            }
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,quint16)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,quint16)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[5])))) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,quint16)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QKeyEvent(QEvent::Type type, int key, QFlags<Qt::KeyboardModifier> modifiers, const QString & text, bool autorep, quint16 count)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_text = Shiboken::String::createStaticString("text");
                if (PyDict_Contains(kwds, key_text) != 0) {
                    value = PyDict_GetItem(kwds, key_text);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_text);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_text);
                }
                static PyObject *const key_autorep = Shiboken::String::createStaticString("autorep");
                if (PyDict_Contains(kwds, key_autorep) != 0) {
                    value = PyDict_GetItem(kwds, key_autorep);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_autorep);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_autorep);
                }
                static PyObject *const key_count = Shiboken::String::createStaticString("count");
                if (PyDict_Contains(kwds, key_count) != 0) {
                    value = PyDict_GetItem(kwds, key_count);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_count);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_count);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            bool cppArg4 = false;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            quint16 cppArg5 = 1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,quint16)
                cptr = new ::QKeyEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 1: // QKeyEvent(QEvent::Type type, int key, QFlags<Qt::KeyboardModifier> modifiers, quint32 nativeScanCode, quint32 nativeVirtualKey, quint32 nativeModifiers, const QString & text, bool autorep, quint16 count, const QInputDevice * device)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_text = Shiboken::String::createStaticString("text");
                if (PyDict_Contains(kwds, key_text) != 0) {
                    value = PyDict_GetItem(kwds, key_text);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_text);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[6]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_text);
                }
                static PyObject *const key_autorep = Shiboken::String::createStaticString("autorep");
                if (PyDict_Contains(kwds, key_autorep) != 0) {
                    value = PyDict_GetItem(kwds, key_autorep);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_autorep);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_autorep);
                }
                static PyObject *const key_count = Shiboken::String::createStaticString("count");
                if (PyDict_Contains(kwds, key_count) != 0) {
                    value = PyDict_GetItem(kwds, key_count);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_count);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_count);
                }
                static PyObject *const key_device = Shiboken::String::createStaticString("device");
                if (PyDict_Contains(kwds, key_device) != 0) {
                    value = PyDict_GetItem(kwds, key_device);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_device);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_device);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            quint32 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            quint32 cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            quint32 cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QString cppArg6 = QString();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            bool cppArg7 = false;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            quint16 cppArg8 = 1;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return -1;
            ::QInputDevice *cppArg9 = const_cast<::QInputDevice *>(QInputDevice::primaryKeyboard());
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,quint16,const QInputDevice*)
                cptr = new ::QKeyEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 2: // QKeyEvent(const QKeyEvent & arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QKeyEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyEvent(QKeyEvent)
                cptr = new ::QKeyEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QKeyEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QKeyEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // TEMPLATE - repr_qdebug_gui - START
            // TEMPLATE - repr_qdebug - START
            QString result;
            QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
            pyResult = Shiboken::String::fromCString(qPrintable(result));
            // TEMPLATE - repr_qdebug - END
            // TEMPLATE - repr_qdebug_gui - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QKeyEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QKeyEvent *>(cppSelf)->::QKeyEvent::clone()
                : const_cast<const ::QKeyEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.count";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // count()const
            int cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->count();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_isAutoRepeat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.isAutoRepeat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAutoRepeat()const
            bool cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->isAutoRepeat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_key(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.key";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // key()const
            int cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->key();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_keyCombination(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.keyCombination";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyCombination()const
            QKeyCombination cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->keyCombination();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_matches(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.matches";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyEvent::matches(QKeySequence::StandardKey)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // matches(QKeySequence::StandardKey)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matches(QKeySequence::StandardKey)const
            bool cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->matches(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_modifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.modifiers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // modifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->modifiers();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_nativeModifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.nativeModifiers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeModifiers()const
            quint32 cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->nativeModifiers();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_nativeScanCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.nativeScanCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeScanCode()const
            quint32 cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->nativeScanCode();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_nativeVirtualKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.nativeVirtualKey";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeVirtualKey()const
            quint32 cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->nativeVirtualKey();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QKeyEventFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QKeyEvent.text";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // text()const
            QString cppResult = const_cast<const ::QKeyEvent *>(cppSelf)->text();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QKeyEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QKeyEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_clone), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_count), METH_NOARGS, nullptr},
    {"isAutoRepeat", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_isAutoRepeat), METH_NOARGS, nullptr},
    {"key", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_key), METH_NOARGS, nullptr},
    {"keyCombination", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_keyCombination), METH_NOARGS, nullptr},
    {"matches", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_matches), METH_O, nullptr},
    {"modifiers", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_modifiers), METH_NOARGS, nullptr},
    {"nativeModifiers", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_nativeModifiers), METH_NOARGS, nullptr},
    {"nativeScanCode", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_nativeScanCode), METH_NOARGS, nullptr},
    {"nativeVirtualKey", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_nativeVirtualKey), METH_NOARGS, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QKeyEventFunc_text), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QKeyEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QKeyEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_QKeyEvent_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QKeyEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
                // operator!=(QKeySequence::StandardKey arg__1)
                ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
                pythonToCpp(pyArg, &cppArg0);
                SBK_UNUSED(cppArg0)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qkeyevent-operatornotequal)]
                bool ret = !(&cppSelf == cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ret);
                // END of custom code block [file: ../glue/qtgui.cpp (qkeyevent-operatornotequal)]
                // ========================================================================
                // End of code injection

            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
                // operator==(QKeySequence::StandardKey key)
                ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = &cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_StandardKey_IDX])))->converter, (pyArg)))) {
                // operator==(QKeySequence::StandardKey key)
                ::QKeySequence::StandardKey cppArg0{QKeySequence::UnknownKey};
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = &cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QKeyEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QKeyEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QKeyEvent_Type = nullptr;
static PyTypeObject *Sbk_QKeyEvent_TypeF(void)
{
    return _Sbk_QKeyEvent_Type;
}

static PyType_Slot Sbk_QKeyEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QKeyEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QKeyEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QKeyEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QKeyEvent_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QKeyEvent_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QKeyEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QKeyEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QKeyEvent_spec = {
    "2:PySide6.QtGui.QKeyEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QKeyEvent_slots
};

} //extern "C"

static void *Sbk_QKeyEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
     if ( reinterpret_cast< ::QKeyEvent *>(cptr)->type() == QEvent::KeyPress ||  reinterpret_cast< ::QKeyEvent *>(cptr)->type() == QEvent::KeyRelease ||  reinterpret_cast< ::QKeyEvent *>(cptr)->type() == QEvent::ShortcutOverride)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QKeyEvent_PythonToCpp_QKeyEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QKeyEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QKeyEvent_PythonToCpp_QKeyEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QKeyEvent_TypeF()))
        return QKeyEvent_PythonToCpp_QKeyEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QKeyEvent_PTR_CppToPython_QKeyEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QKeyEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QKeyEvent_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QKeyEvent_SignatureStrings[] = {
    "2:PySide6.QtGui.QKeyEvent(self,type:PySide6.QtCore.QEvent.Type,key:int,modifiers:PySide6.QtCore.Qt.KeyboardModifier,text:QString=QString(),autorep:bool=false,count:quint16=1)",
    "1:PySide6.QtGui.QKeyEvent(self,type:PySide6.QtCore.QEvent.Type,key:int,modifiers:PySide6.QtCore.Qt.KeyboardModifier,nativeScanCode:quint32,nativeVirtualKey:quint32,nativeModifiers:quint32,text:QString=QString(),autorep:bool=false,count:quint16=1,device:PySide6.QtGui.QInputDevice=QInputDevice.primaryKeyboard())",
    "0:PySide6.QtGui.QKeyEvent(self,arg__1:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtGui.QKeyEvent.__repr__(self)->PyObject",
    "PySide6.QtGui.QKeyEvent.clone(self)->PySide6.QtGui.QKeyEvent",
    "PySide6.QtGui.QKeyEvent.count(self)->int",
    "PySide6.QtGui.QKeyEvent.isAutoRepeat(self)->bool",
    "PySide6.QtGui.QKeyEvent.key(self)->int",
    "PySide6.QtGui.QKeyEvent.keyCombination(self)->PySide6.QtCore.QKeyCombination",
    "PySide6.QtGui.QKeyEvent.matches(self,key:PySide6.QtGui.QKeySequence.StandardKey)->bool",
    "PySide6.QtGui.QKeyEvent.modifiers(self)->PySide6.QtCore.Qt.KeyboardModifier",
    "PySide6.QtGui.QKeyEvent.nativeModifiers(self)->quint32",
    "PySide6.QtGui.QKeyEvent.nativeScanCode(self)->quint32",
    "PySide6.QtGui.QKeyEvent.nativeVirtualKey(self)->quint32",
    "PySide6.QtGui.QKeyEvent.text(self)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QKeyEvent(PyObject *module)
{
    _Sbk_QKeyEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QKeyEvent",
        "QKeyEvent*",
        &Sbk_QKeyEvent_spec,
        &Shiboken::callCppDestructor< ::QKeyEvent >,
        Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputEvent_IDX]),
        0,
        0);
    auto *pyType = Sbk_QKeyEvent_TypeF(); // references _Sbk_QKeyEvent_Type
    InitSignatureStrings(pyType, QKeyEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QKeyEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QKeyEvent_PythonToCpp_QKeyEvent_PTR,
        is_QKeyEvent_PythonToCpp_QKeyEvent_PTR_Convertible,
        QKeyEvent_PTR_CppToPython_QKeyEvent);

    Shiboken::Conversions::registerConverterName(converter, "QKeyEvent");
    Shiboken::Conversions::registerConverterName(converter, "QKeyEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QKeyEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QKeyEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QKeyEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QKeyEvent_TypeF(), &Sbk_QKeyEvent_typeDiscovery);


    return pyType;
}
