// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpixmapcache_key_wrapper.h"

// Argument includes
#include <QtGui/qpixmapcache.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPixmapCache_Key_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPixmapCache::Key >()))
        return -1;

    ::QPixmapCache::Key *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.Key.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Key", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Key::Key()
    // 1: Key::Key(QPixmapCache::Key)
    if (numArgs == 0) {
        overloadId = 0; // Key()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Key(QPixmapCache::Key)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Key()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // Key()
                cptr = new ::QPixmapCache::Key();
            }
            break;
        }
        case 1: // Key(const QPixmapCache::Key & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPixmapCache::Key cppArg0_local;
            ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Key(QPixmapCache::Key)
                cptr = new ::QPixmapCache::Key(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPixmapCache::Key >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPixmapCache_KeyFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.Key.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QPixmapCache::Key *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPixmapCache_KeyFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.Key.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Key::swap(QPixmapCache::Key&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPixmapCache::Key&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPixmapCache::Key cppArg0_local;
        ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPixmapCache::Key&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPixmapCache_Key__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPixmapCache_Key_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPixmapCache_Key_methods[] = {
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPixmapCache_KeyFunc_isValid), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPixmapCache_KeyFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPixmapCache_Key__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPixmapCache_Key_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArg)))) {
                // operator!=(const QPixmapCache::Key & key) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPixmapCache::Key cppArg0_local;
                ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArg)))) {
                // operator==(const QPixmapCache::Key & key) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPixmapCache::Key cppArg0_local;
                ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QPixmapCache_Key_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QPixmapCache_Key_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPixmapCache_Key_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPixmapCache_Key_Type = nullptr;
static PyTypeObject *Sbk_QPixmapCache_Key_TypeF(void)
{
    return _Sbk_QPixmapCache_Key_Type;
}

static PyType_Slot Sbk_QPixmapCache_Key_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QPixmapCache_Key_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPixmapCache_Key_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPixmapCache_Key_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPixmapCache_Key_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPixmapCache_Key_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPixmapCache_Key_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPixmapCache_Key_spec = {
    "2:PySide6.QtGui.QPixmapCache.Key",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPixmapCache_Key_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Key_PythonToCpp_Key_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPixmapCache_Key_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Key_PythonToCpp_Key_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPixmapCache_Key_TypeF()))
        return Key_PythonToCpp_Key_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Key_PTR_CppToPython_Key(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QPixmapCache::Key *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QPixmapCache_Key_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *Key_COPY_CppToPython_Key(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPixmapCache::Key *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPixmapCache_Key_TypeF(), new ::QPixmapCache::Key(*source), true, true);
}

// Python to C++ copy conversion.
static void Key_PythonToCpp_Key_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPixmapCache::Key *>(cppOut) = *reinterpret_cast< ::QPixmapCache::Key *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Key_PythonToCpp_Key_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPixmapCache_Key_TypeF()))
        return Key_PythonToCpp_Key_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPixmapCache_Key_SignatureStrings[] = {
    "1:PySide6.QtGui.QPixmapCache.Key(self)",
    "0:PySide6.QtGui.QPixmapCache.Key(self,other:PySide6.QtGui.QPixmapCache.Key)",
    "PySide6.QtGui.QPixmapCache.Key.isValid(self)->bool",
    "PySide6.QtGui.QPixmapCache.Key.swap(self,other:PySide6.QtGui.QPixmapCache.Key)",
    "PySide6.QtGui.QPixmapCache.Key.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QPixmapCache_Key(PyObject *enclosingClass)
{
    _Sbk_QPixmapCache_Key_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Key",
        "QPixmapCache::Key",
        &Sbk_QPixmapCache_Key_spec,
        &Shiboken::callCppDestructor< ::QPixmapCache::Key >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPixmapCache_Key_TypeF(); // references _Sbk_QPixmapCache_Key_Type
    InitSignatureStrings(pyType, QPixmapCache_Key_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPixmapCache_Key_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Key_PythonToCpp_Key_PTR,
        is_Key_PythonToCpp_Key_PTR_Convertible,
        Key_PTR_CppToPython_Key,
        Key_COPY_CppToPython_Key);

    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache::Key");
    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache::Key*");
    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache::Key&");
    Shiboken::Conversions::registerConverterName(converter, "Key");
    Shiboken::Conversions::registerConverterName(converter, "Key*");
    Shiboken::Conversions::registerConverterName(converter, "Key&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPixmapCache::Key).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Key_PythonToCpp_Key_COPY,
        is_Key_PythonToCpp_Key_COPY_Convertible);

    qRegisterMetaType< ::QPixmapCache::Key >("Key");
    qRegisterMetaType< ::QPixmapCache::Key >("QPixmapCache::Key");

    return pyType;
}
