// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhidriverinfo_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiDriverInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiDriverInfo >()))
        return -1;

    ::QRhiDriverInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiDriverInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiDriverInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiDriverInfo::QRhiDriverInfo()
    // 1: QRhiDriverInfo::QRhiDriverInfo(QRhiDriverInfo)
    if (numArgs == 0) {
        overloadId = 0; // QRhiDriverInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiDriverInfo(QRhiDriverInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiDriverInfo()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiDriverInfo()
                cptr = new ::QRhiDriverInfo();
            }
            break;
        }
        case 1: // QRhiDriverInfo(const QRhiDriverInfo & QRhiDriverInfo)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiDriverInfo cppArg0_local;
            ::QRhiDriverInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiDriverInfo(QRhiDriverInfo)
                cptr = new ::QRhiDriverInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiDriverInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiDriverInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiDriverInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiDriverInfo_EnumFlagInfo[] = {
    "DeviceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiDriverInfo_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiDriverInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QRhiDriverInfo_get_deviceName(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->deviceName)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->deviceName))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->deviceName)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &(cppSelf->deviceName), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiDriverInfo_set_deviceName(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("deviceName");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("deviceName", "QByteArray");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->deviceName;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiDriverInfo_get_deviceId(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->deviceId;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiDriverInfo_set_deviceId(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("deviceId");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("deviceId", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->deviceId;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->deviceId = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiDriverInfo_get_vendorId(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint64 cppOut_local = cppSelf->vendorId;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiDriverInfo_set_vendorId(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("vendorId");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("vendorId", "quint64");
        return -1;
    }

    auto cppOut_local = cppSelf->vendorId;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->vendorId = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiDriverInfo_get_deviceType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiDriverInfo::DeviceType cppOut_local = cppSelf->deviceType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_DeviceType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiDriverInfo_set_deviceType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("deviceType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_DeviceType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("deviceType", "DeviceType");
        return -1;
    }

    auto cppOut_local = cppSelf->deviceType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->deviceType = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiDriverInfo
static PyGetSetDef Sbk_QRhiDriverInfo_getsetlist[] = {
    {const_cast<char *>("deviceName"), Sbk_QRhiDriverInfo_get_deviceName, Sbk_QRhiDriverInfo_set_deviceName, nullptr, nullptr},
    {const_cast<char *>("deviceId"), Sbk_QRhiDriverInfo_get_deviceId, Sbk_QRhiDriverInfo_set_deviceId, nullptr, nullptr},
    {const_cast<char *>("vendorId"), Sbk_QRhiDriverInfo_get_vendorId, Sbk_QRhiDriverInfo_set_vendorId, nullptr, nullptr},
    {const_cast<char *>("deviceType"), Sbk_QRhiDriverInfo_get_deviceType, Sbk_QRhiDriverInfo_set_deviceType, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiDriverInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiDriverInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiDriverInfo__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiDriverInfo_Type = nullptr;
static PyTypeObject *Sbk_QRhiDriverInfo_TypeF(void)
{
    return _Sbk_QRhiDriverInfo_Type;
}

static PyType_Slot Sbk_QRhiDriverInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiDriverInfo__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiDriverInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiDriverInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiDriverInfo_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiDriverInfo_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiDriverInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiDriverInfo_spec = {
    "2:PySide6.QtGui.QRhiDriverInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiDriverInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QRhiDriverInfo_DeviceType_PythonToCpp_QRhiDriverInfo_DeviceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiDriverInfo::DeviceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiDriverInfo::DeviceType *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiDriverInfo_DeviceType_PythonToCpp_QRhiDriverInfo_DeviceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_DeviceType_IDX])))
        return QRhiDriverInfo_DeviceType_PythonToCpp_QRhiDriverInfo_DeviceType;
    return {};
}
static PyObject *QRhiDriverInfo_DeviceType_CppToPython_QRhiDriverInfo_DeviceType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiDriverInfo::DeviceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_DeviceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiDriverInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiDriverInfo_TypeF()))
        return QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiDriverInfo_PTR_CppToPython_QRhiDriverInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiDriverInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiDriverInfo_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QRhiDriverInfo_COPY_CppToPython_QRhiDriverInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiDriverInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiDriverInfo_TypeF(), new ::QRhiDriverInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiDriverInfo *>(cppOut) = *reinterpret_cast< ::QRhiDriverInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiDriverInfo_TypeF()))
        return QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiDriverInfo_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiDriverInfo(self)",
    "0:PySide6.QtGui.QRhiDriverInfo(self,QRhiDriverInfo:PySide6.QtGui.QRhiDriverInfo)",
    "PySide6.QtGui.QRhiDriverInfo.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiDriverInfo(PyObject *module)
{
    _Sbk_QRhiDriverInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiDriverInfo",
        "QRhiDriverInfo",
        &Sbk_QRhiDriverInfo_spec,
        &Shiboken::callCppDestructor< ::QRhiDriverInfo >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiDriverInfo_TypeF(); // references _Sbk_QRhiDriverInfo_Type
    InitSignatureStrings(pyType, QRhiDriverInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiDriverInfo_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_PTR,
        is_QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_PTR_Convertible,
        QRhiDriverInfo_PTR_CppToPython_QRhiDriverInfo,
        QRhiDriverInfo_COPY_CppToPython_QRhiDriverInfo);

    Shiboken::Conversions::registerConverterName(converter, "QRhiDriverInfo");
    Shiboken::Conversions::registerConverterName(converter, "QRhiDriverInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiDriverInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiDriverInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_COPY,
        is_QRhiDriverInfo_PythonToCpp_QRhiDriverInfo_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiDriverInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DeviceType'.
    const char *DeviceType_Initializer[] = {
        "UnknownDevice",
        "IntegratedDevice",
        "DiscreteDevice",
        "ExternalDevice",
        "VirtualDevice",
        "CpuDevice",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DeviceType_InitializerValues[] = {
        uint8_t(QRhiDriverInfo::DeviceType::UnknownDevice),    //  0x00  0
        uint8_t(QRhiDriverInfo::DeviceType::IntegratedDevice), //  0x01  1
        uint8_t(QRhiDriverInfo::DeviceType::DiscreteDevice),   //  0x02  2
        uint8_t(QRhiDriverInfo::DeviceType::ExternalDevice),   //  0x03  3
        uint8_t(QRhiDriverInfo::DeviceType::VirtualDevice),    //  0x04  4
        uint8_t(QRhiDriverInfo::DeviceType::CpuDevice)         //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiDriverInfo_TypeF(),
        "2:PySide6.QtGui.QRhiDriverInfo.DeviceType",
        DeviceType_Initializer, DeviceType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_DeviceType_IDX].type = EType;
    // Register converter for enum 'QRhiDriverInfo::DeviceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiDriverInfo_DeviceType_CppToPython_QRhiDriverInfo_DeviceType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiDriverInfo_DeviceType_PythonToCpp_QRhiDriverInfo_DeviceType,
            is_QRhiDriverInfo_DeviceType_PythonToCpp_QRhiDriverInfo_DeviceType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiDriverInfo::DeviceType");
        Shiboken::Conversions::registerConverterName(converter, "DeviceType");
    }
    // End of 'DeviceType' enum.

    qRegisterMetaType< ::QRhiDriverInfo >("QRhiDriverInfo");
    qRegisterMetaType< ::QRhiDriverInfo::DeviceType >("QRhiDriverInfo::DeviceType");

    return pyType;
}
