// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhisampler_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiSamplerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiSamplerWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSampler.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSampler.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSampler", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiSamplerWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSampler.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiSampler.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QRhiResource::Type QRhiSamplerWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiSampler::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiSampler::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiSampler", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiSamplerWrapper::~QRhiSamplerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiSamplerFunc_addressU(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.addressU";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addressU()const
            QRhiSampler::AddressMode cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->addressU();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_addressV(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.addressV";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addressV()const
            QRhiSampler::AddressMode cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->addressV();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_addressW(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.addressW";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addressW()const
            QRhiSampler::AddressMode cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->addressW();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiSampler.create");
                return {};
            }
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_magFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.magFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // magFilter()const
            QRhiSampler::Filter cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->magFilter();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_minFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.minFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minFilter()const
            QRhiSampler::Filter cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->minFilter();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_mipmapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.mipmapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipmapMode()const
            QRhiSampler::Filter cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->mipmapMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.resourceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceType()const
            QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRhiSampler *>(cppSelf)->::QRhiSampler::resourceType()
                : const_cast<const ::QRhiSampler *>(cppSelf)->resourceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiSamplerFunc_setAddressU(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setAddressU";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setAddressU(QRhiSampler::AddressMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAddressU(QRhiSampler::AddressMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::AddressMode cppArg0{QRhiSampler::Repeat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddressU(QRhiSampler::AddressMode)
            cppSelf->setAddressU(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setAddressV(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setAddressV";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setAddressV(QRhiSampler::AddressMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAddressV(QRhiSampler::AddressMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::AddressMode cppArg0{QRhiSampler::Repeat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddressV(QRhiSampler::AddressMode)
            cppSelf->setAddressV(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setAddressW(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setAddressW";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setAddressW(QRhiSampler::AddressMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAddressW(QRhiSampler::AddressMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::AddressMode cppArg0{QRhiSampler::Repeat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddressW(QRhiSampler::AddressMode)
            cppSelf->setAddressW(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setMagFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setMagFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setMagFilter(QRhiSampler::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMagFilter(QRhiSampler::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::Filter cppArg0{QRhiSampler::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMagFilter(QRhiSampler::Filter)
            cppSelf->setMagFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setMinFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setMinFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setMinFilter(QRhiSampler::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMinFilter(QRhiSampler::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::Filter cppArg0{QRhiSampler::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinFilter(QRhiSampler::Filter)
            cppSelf->setMinFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setMipmapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setMipmapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setMipmapMode(QRhiSampler::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMipmapMode(QRhiSampler::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::Filter cppArg0{QRhiSampler::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipmapMode(QRhiSampler::Filter)
            cppSelf->setMipmapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_setTextureCompareOp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.setTextureCompareOp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiSampler::setTextureCompareOp(QRhiSampler::CompareOp)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTextureCompareOp(QRhiSampler::CompareOp)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiSampler::CompareOp cppArg0{QRhiSampler::Never};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextureCompareOp(QRhiSampler::CompareOp)
            cppSelf->setTextureCompareOp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiSamplerFunc_textureCompareOp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiSampler.textureCompareOp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textureCompareOp()const
            QRhiSampler::CompareOp cppResult = const_cast<const ::QRhiSampler *>(cppSelf)->textureCompareOp();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiSampler_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiSampler_EnumFlagInfo[] = {
    "AddressMode:Enum",
    "CompareOp:Enum",
    "Filter:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiSampler_methods[] = {
    {"addressU", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_addressU), METH_NOARGS, nullptr},
    {"addressV", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_addressV), METH_NOARGS, nullptr},
    {"addressW", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_addressW), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_create), METH_NOARGS, nullptr},
    {"magFilter", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_magFilter), METH_NOARGS, nullptr},
    {"minFilter", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_minFilter), METH_NOARGS, nullptr},
    {"mipmapMode", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_mipmapMode), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_resourceType), METH_NOARGS, nullptr},
    {"setAddressU", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setAddressU), METH_O, nullptr},
    {"setAddressV", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setAddressV), METH_O, nullptr},
    {"setAddressW", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setAddressW), METH_O, nullptr},
    {"setMagFilter", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setMagFilter), METH_O, nullptr},
    {"setMinFilter", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setMinFilter), METH_O, nullptr},
    {"setMipmapMode", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setMipmapMode), METH_O, nullptr},
    {"setTextureCompareOp", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_setTextureCompareOp), METH_O, nullptr},
    {"textureCompareOp", reinterpret_cast<PyCFunction>(Sbk_QRhiSamplerFunc_textureCompareOp), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiSampler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiSamplerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiSampler_get_m_magFilter(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::Filter cppOut_local = cppSelf->m_magFilter;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_magFilter(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_magFilter");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_magFilter", "Filter");
        return -1;
    }

    auto cppOut_local = cppSelf->m_magFilter;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_magFilter = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_minFilter(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::Filter cppOut_local = cppSelf->m_minFilter;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_minFilter(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_minFilter");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_minFilter", "Filter");
        return -1;
    }

    auto cppOut_local = cppSelf->m_minFilter;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_minFilter = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_mipmapMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::Filter cppOut_local = cppSelf->m_mipmapMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_mipmapMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_mipmapMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_mipmapMode", "Filter");
        return -1;
    }

    auto cppOut_local = cppSelf->m_mipmapMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_mipmapMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_addressU(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::AddressMode cppOut_local = cppSelf->m_addressU;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_addressU(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_addressU");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_addressU", "AddressMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_addressU;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_addressU = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_addressV(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::AddressMode cppOut_local = cppSelf->m_addressV;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_addressV(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_addressV");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_addressV", "AddressMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_addressV;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_addressV = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_addressW(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::AddressMode cppOut_local = cppSelf->m_addressW;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_addressW(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_addressW");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_addressW", "AddressMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_addressW;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_addressW = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiSampler_get_m_compareOp(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiSampler::CompareOp cppOut_local = cppSelf->m_compareOp;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiSampler_set_m_compareOp(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiSampler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_compareOp");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_compareOp", "CompareOp");
        return -1;
    }

    auto cppOut_local = cppSelf->m_compareOp;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_compareOp = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiSampler
static PyGetSetDef Sbk_QRhiSampler_getsetlist[] = {
    {const_cast<char *>("m_magFilter"), Sbk_QRhiSampler_get_m_magFilter, Sbk_QRhiSampler_set_m_magFilter, nullptr, nullptr},
    {const_cast<char *>("m_minFilter"), Sbk_QRhiSampler_get_m_minFilter, Sbk_QRhiSampler_set_m_minFilter, nullptr, nullptr},
    {const_cast<char *>("m_mipmapMode"), Sbk_QRhiSampler_get_m_mipmapMode, Sbk_QRhiSampler_set_m_mipmapMode, nullptr, nullptr},
    {const_cast<char *>("m_addressU"), Sbk_QRhiSampler_get_m_addressU, Sbk_QRhiSampler_set_m_addressU, nullptr, nullptr},
    {const_cast<char *>("m_addressV"), Sbk_QRhiSampler_get_m_addressV, Sbk_QRhiSampler_set_m_addressV, nullptr, nullptr},
    {const_cast<char *>("m_addressW"), Sbk_QRhiSampler_get_m_addressW, Sbk_QRhiSampler_set_m_addressW, nullptr, nullptr},
    {const_cast<char *>("m_compareOp"), Sbk_QRhiSampler_get_m_compareOp, Sbk_QRhiSampler_set_m_compareOp, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiSampler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiSampler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiSampler_Type = nullptr;
static PyTypeObject *Sbk_QRhiSampler_TypeF(void)
{
    return _Sbk_QRhiSampler_Type;
}

static PyType_Slot Sbk_QRhiSampler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiSampler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiSampler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiSampler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiSampler_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiSampler_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiSampler_spec = {
    "2:PySide6.QtGui.QRhiSampler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiSampler_slots
};

} //extern "C"

static void *Sbk_QRhiSampler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiSampler *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QRhiSampler_Filter_PythonToCpp_QRhiSampler_Filter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSampler::Filter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSampler::Filter *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiSampler_Filter_PythonToCpp_QRhiSampler_Filter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))
        return QRhiSampler_Filter_PythonToCpp_QRhiSampler_Filter;
    return {};
}
static PyObject *QRhiSampler_Filter_CppToPython_QRhiSampler_Filter(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiSampler::Filter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX]), castCppIn);

}

static void QRhiSampler_AddressMode_PythonToCpp_QRhiSampler_AddressMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSampler::AddressMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSampler::AddressMode *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiSampler_AddressMode_PythonToCpp_QRhiSampler_AddressMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))
        return QRhiSampler_AddressMode_PythonToCpp_QRhiSampler_AddressMode;
    return {};
}
static PyObject *QRhiSampler_AddressMode_CppToPython_QRhiSampler_AddressMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiSampler::AddressMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX]), castCppIn);

}

static void QRhiSampler_CompareOp_PythonToCpp_QRhiSampler_CompareOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiSampler::CompareOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiSampler::CompareOp *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiSampler_CompareOp_PythonToCpp_QRhiSampler_CompareOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX])))
        return QRhiSampler_CompareOp_PythonToCpp_QRhiSampler_CompareOp;
    return {};
}
static PyObject *QRhiSampler_CompareOp_CppToPython_QRhiSampler_CompareOp(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiSampler::CompareOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiSampler_PythonToCpp_QRhiSampler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiSampler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiSampler_PythonToCpp_QRhiSampler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiSampler_TypeF()))
        return QRhiSampler_PythonToCpp_QRhiSampler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiSampler_PTR_CppToPython_QRhiSampler(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiSampler *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiSampler_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiSampler_SignatureStrings[] = {
    "PySide6.QtGui.QRhiSampler.addressU(self)->PySide6.QtGui.QRhiSampler.AddressMode",
    "PySide6.QtGui.QRhiSampler.addressV(self)->PySide6.QtGui.QRhiSampler.AddressMode",
    "PySide6.QtGui.QRhiSampler.addressW(self)->PySide6.QtGui.QRhiSampler.AddressMode",
    "PySide6.QtGui.QRhiSampler.create(self)->bool",
    "PySide6.QtGui.QRhiSampler.magFilter(self)->PySide6.QtGui.QRhiSampler.Filter",
    "PySide6.QtGui.QRhiSampler.minFilter(self)->PySide6.QtGui.QRhiSampler.Filter",
    "PySide6.QtGui.QRhiSampler.mipmapMode(self)->PySide6.QtGui.QRhiSampler.Filter",
    "PySide6.QtGui.QRhiSampler.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiSampler.setAddressU(self,mode:PySide6.QtGui.QRhiSampler.AddressMode)",
    "PySide6.QtGui.QRhiSampler.setAddressV(self,mode:PySide6.QtGui.QRhiSampler.AddressMode)",
    "PySide6.QtGui.QRhiSampler.setAddressW(self,mode:PySide6.QtGui.QRhiSampler.AddressMode)",
    "PySide6.QtGui.QRhiSampler.setMagFilter(self,f:PySide6.QtGui.QRhiSampler.Filter)",
    "PySide6.QtGui.QRhiSampler.setMinFilter(self,f:PySide6.QtGui.QRhiSampler.Filter)",
    "PySide6.QtGui.QRhiSampler.setMipmapMode(self,f:PySide6.QtGui.QRhiSampler.Filter)",
    "PySide6.QtGui.QRhiSampler.setTextureCompareOp(self,op:PySide6.QtGui.QRhiSampler.CompareOp)",
    "PySide6.QtGui.QRhiSampler.textureCompareOp(self)->PySide6.QtGui.QRhiSampler.CompareOp",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiSampler(PyObject *module)
{
    _Sbk_QRhiSampler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiSampler",
        "QRhiSampler*",
        &Sbk_QRhiSampler_spec,
        &Shiboken::callCppDestructor< ::QRhiSampler >,
        Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]),
        0,
        0);
    auto *pyType = Sbk_QRhiSampler_TypeF(); // references _Sbk_QRhiSampler_Type
    InitSignatureStrings(pyType, QRhiSampler_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiSampler_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiSampler_PythonToCpp_QRhiSampler_PTR,
        is_QRhiSampler_PythonToCpp_QRhiSampler_PTR_Convertible,
        QRhiSampler_PTR_CppToPython_QRhiSampler);

    Shiboken::Conversions::registerConverterName(converter, "QRhiSampler");
    Shiboken::Conversions::registerConverterName(converter, "QRhiSampler*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiSampler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiSampler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiSamplerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiSampler_TypeF(), &Sbk_QRhiSampler_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiSampler_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Filter'.
    const char *Filter_Initializer[] = {
        "None_",
        "Nearest",
        "Linear",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Filter_InitializerValues[] = {
        uint8_t(QRhiSampler::Filter::None),    //  0x00  0
        uint8_t(QRhiSampler::Filter::Nearest), //  0x01  1
        uint8_t(QRhiSampler::Filter::Linear)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSampler_TypeF(),
        "2:PySide6.QtGui.QRhiSampler.Filter",
        Filter_Initializer, Filter_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX].type = EType;
    // Register converter for enum 'QRhiSampler::Filter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSampler_Filter_CppToPython_QRhiSampler_Filter);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiSampler_Filter_PythonToCpp_QRhiSampler_Filter,
            is_QRhiSampler_Filter_PythonToCpp_QRhiSampler_Filter_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSampler::Filter");
        Shiboken::Conversions::registerConverterName(converter, "Filter");
    }
    // End of 'Filter' enum.

    // Initialization of enum 'AddressMode'.
    const char *AddressMode_Initializer[] = {
        "Repeat",
        "ClampToEdge",
        "Mirror",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AddressMode_InitializerValues[] = {
        uint8_t(QRhiSampler::AddressMode::Repeat),      //  0x00  0
        uint8_t(QRhiSampler::AddressMode::ClampToEdge), //  0x01  1
        uint8_t(QRhiSampler::AddressMode::Mirror)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSampler_TypeF(),
        "2:PySide6.QtGui.QRhiSampler.AddressMode",
        AddressMode_Initializer, AddressMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX].type = EType;
    // Register converter for enum 'QRhiSampler::AddressMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSampler_AddressMode_CppToPython_QRhiSampler_AddressMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiSampler_AddressMode_PythonToCpp_QRhiSampler_AddressMode,
            is_QRhiSampler_AddressMode_PythonToCpp_QRhiSampler_AddressMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSampler::AddressMode");
        Shiboken::Conversions::registerConverterName(converter, "AddressMode");
    }
    // End of 'AddressMode' enum.

    // Initialization of enum 'CompareOp'.
    const char *CompareOp_Initializer[] = {
        "Never",
        "Less",
        "Equal",
        "LessOrEqual",
        "Greater",
        "NotEqual",
        "GreaterOrEqual",
        "Always",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CompareOp_InitializerValues[] = {
        uint8_t(QRhiSampler::CompareOp::Never),          //  0x00  0
        uint8_t(QRhiSampler::CompareOp::Less),           //  0x01  1
        uint8_t(QRhiSampler::CompareOp::Equal),          //  0x02  2
        uint8_t(QRhiSampler::CompareOp::LessOrEqual),    //  0x03  3
        uint8_t(QRhiSampler::CompareOp::Greater),        //  0x04  4
        uint8_t(QRhiSampler::CompareOp::NotEqual),       //  0x05  5
        uint8_t(QRhiSampler::CompareOp::GreaterOrEqual), //  0x06  6
        uint8_t(QRhiSampler::CompareOp::Always)          //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiSampler_TypeF(),
        "2:PySide6.QtGui.QRhiSampler.CompareOp",
        CompareOp_Initializer, CompareOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_CompareOp_IDX].type = EType;
    // Register converter for enum 'QRhiSampler::CompareOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiSampler_CompareOp_CppToPython_QRhiSampler_CompareOp);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiSampler_CompareOp_PythonToCpp_QRhiSampler_CompareOp,
            is_QRhiSampler_CompareOp_PythonToCpp_QRhiSampler_CompareOp_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiSampler::CompareOp");
        Shiboken::Conversions::registerConverterName(converter, "CompareOp");
    }
    // End of 'CompareOp' enum.

    qRegisterMetaType< ::QRhiSampler *>();
    qRegisterMetaType< ::QRhiSampler::Filter >("QRhiSampler::Filter");
    qRegisterMetaType< ::QRhiSampler::AddressMode >("QRhiSampler::AddressMode");
    qRegisterMetaType< ::QRhiSampler::CompareOp >("QRhiSampler::CompareOp");

    return pyType;
}
