// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhishaderresourcebinding_wrapper.h"

// inner classes
#include "qrhishaderresourcebinding_data_wrapper.h"
#include "qrhishaderresourcebinding_textureandsampler_wrapper.h"

// Argument includes
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhiShaderResourceBinding_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhiShaderResourceBinding >()))
        return -1;

    ::QRhiShaderResourceBinding *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QRhiShaderResourceBinding", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QRhiShaderResourceBinding::QRhiShaderResourceBinding()
    // 1: QRhiShaderResourceBinding::QRhiShaderResourceBinding(QRhiShaderResourceBinding)
    if (numArgs == 0) {
        overloadId = 0; // QRhiShaderResourceBinding()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QRhiShaderResourceBinding(QRhiShaderResourceBinding)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QRhiShaderResourceBinding()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiShaderResourceBinding()
                cptr = new ::QRhiShaderResourceBinding();
            }
            break;
        }
        case 1: // QRhiShaderResourceBinding(const QRhiShaderResourceBinding & QRhiShaderResourceBinding)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRhiShaderResourceBinding cppArg0_local;
            ::QRhiShaderResourceBinding *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QRhiShaderResourceBinding(QRhiShaderResourceBinding)
                cptr = new ::QRhiShaderResourceBinding(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhiShaderResourceBinding >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_bufferLoad(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.bufferLoad";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "bufferLoad", 3, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)->QRhiShaderResourceBinding
    // 1: static QRhiShaderResourceBinding::bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)->QRhiShaderResourceBinding
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
        } else if (numArgs == 5
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))) {
            overloadId = 1; // bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bufferLoad(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferLoad(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
        case 1: // bufferLoad(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf, quint32 offset, quint32 size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            quint32 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            quint32 cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferLoad(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_bufferLoadStore(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.bufferLoadStore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "bufferLoadStore", 3, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)->QRhiShaderResourceBinding
    // 1: static QRhiShaderResourceBinding::bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)->QRhiShaderResourceBinding
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
        } else if (numArgs == 5
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))) {
            overloadId = 1; // bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bufferLoadStore(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferLoadStore(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
        case 1: // bufferLoadStore(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf, quint32 offset, quint32 size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            quint32 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            quint32 cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferLoadStore(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_bufferStore(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.bufferStore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "bufferStore", 3, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)->QRhiShaderResourceBinding
    // 1: static QRhiShaderResourceBinding::bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)->QRhiShaderResourceBinding
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
        } else if (numArgs == 5
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))) {
            overloadId = 1; // bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bufferStore(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferStore(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
        case 1: // bufferStore(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf, quint32 offset, quint32 size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            quint32 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            quint32 cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bufferStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::bufferStore(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_imageLoad(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.imageLoad";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "imageLoad", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::imageLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // imageLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiTexture *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // imageLoad(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::imageLoad(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_imageLoadStore(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.imageLoadStore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "imageLoadStore", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::imageLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // imageLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiTexture *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // imageLoadStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::imageLoadStore(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_imageStore(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.imageStore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "imageStore", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::imageStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // imageStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiTexture *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // imageStore(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,int)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::imageStore(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_isLayoutCompatible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.isLayoutCompatible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiShaderResourceBinding::isLayoutCompatible(QRhiShaderResourceBinding)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), (pyArg)))) {
        overloadId = 0; // isLayoutCompatible(QRhiShaderResourceBinding)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderResourceBinding cppArg0_local;
        ::QRhiShaderResourceBinding *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isLayoutCompatible(QRhiShaderResourceBinding)const
            bool cppResult = const_cast<const ::QRhiShaderResourceBinding *>(cppSelf)->isLayoutCompatible(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_sampledTexture(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.sampledTexture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sampledTexture", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::sampledTexture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,QRhiSampler*)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), (pyArgs[3])))) {
        overloadId = 0; // sampledTexture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,QRhiSampler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiTexture *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRhiSampler *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampledTexture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*,QRhiSampler*)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::sampledTexture(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_sampledTextures(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.sampledTextures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sampledTextures", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::sampledTextures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,const QRhiShaderResourceBinding::TextureAndSampler*)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_TextureAndSampler_IDX]), (pyArgs[3])))) {
        overloadId = 0; // sampledTextures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,const QRhiShaderResourceBinding::TextureAndSampler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRhiShaderResourceBinding::TextureAndSampler *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampledTextures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,const QRhiShaderResourceBinding::TextureAndSampler*)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::sampledTextures(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_sampler(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.sampler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sampler", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::sampler(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiSampler*)->QRhiShaderResourceBinding
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), (pyArgs[2])))) {
        overloadId = 0; // sampler(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiSampler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiSampler *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampler(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiSampler*)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::sampler(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_texture(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.texture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "texture", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::texture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*)->QRhiShaderResourceBinding
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[2])))) {
        overloadId = 0; // texture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiTexture *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // texture(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiTexture*)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::texture(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_textures(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.textures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "textures", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::textures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,QRhiTexture**)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), (pyArgs[3])))) {
        overloadId = 0; // textures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,QRhiTexture**)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRhiTexture *cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // textures(int,QFlags<QRhiShaderResourceBinding::StageFlag>,int,QRhiTexture**)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::textures(cppArg0, cppArg1, cppArg2, &cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_uniformBuffer(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.uniformBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "uniformBuffer", 3, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)->QRhiShaderResourceBinding
    // 1: static QRhiShaderResourceBinding::uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)->QRhiShaderResourceBinding
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
        } else if (numArgs == 5
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[4])))) {
            overloadId = 1; // uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // uniformBuffer(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::uniformBuffer(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
        case 1: // uniformBuffer(int binding, QFlags<QRhiShaderResourceBinding::StageFlag> stage, QRhiBuffer * buf, quint32 offset, quint32 size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRhiBuffer *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            quint32 cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            quint32 cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // uniformBuffer(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32,quint32)
                QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::uniformBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingFunc_uniformBufferWithDynamicOffset(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBinding.uniformBufferWithDynamicOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "uniformBufferWithDynamicOffset", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhiShaderResourceBinding::uniformBufferWithDynamicOffset(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32)->QRhiShaderResourceBinding
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[3])))) {
        overloadId = 0; // uniformBufferWithDynamicOffset(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiShaderResourceBinding::StageFlag> cppArg1 = QFlags<QRhiShaderResourceBinding::StageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRhiBuffer *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        quint32 cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // uniformBufferWithDynamicOffset(int,QFlags<QRhiShaderResourceBinding::StageFlag>,QRhiBuffer*,quint32)
            QRhiShaderResourceBinding cppResult = ::QRhiShaderResourceBinding::uniformBufferWithDynamicOffset(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBinding__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiShaderResourceBinding_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiShaderResourceBinding_EnumFlagInfo[] = {
    "StageFlag:Flag:StageFlags",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiShaderResourceBinding_methods[] = {
    {"bufferLoad", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_bufferLoad), METH_VARARGS|METH_STATIC, nullptr},
    {"bufferLoadStore", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_bufferLoadStore), METH_VARARGS|METH_STATIC, nullptr},
    {"bufferStore", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_bufferStore), METH_VARARGS|METH_STATIC, nullptr},
    {"imageLoad", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_imageLoad), METH_VARARGS|METH_STATIC, nullptr},
    {"imageLoadStore", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_imageLoadStore), METH_VARARGS|METH_STATIC, nullptr},
    {"imageStore", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_imageStore), METH_VARARGS|METH_STATIC, nullptr},
    {"isLayoutCompatible", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_isLayoutCompatible), METH_O, nullptr},
    {"sampledTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_sampledTexture), METH_VARARGS|METH_STATIC, nullptr},
    {"sampledTextures", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_sampledTextures), METH_VARARGS|METH_STATIC, nullptr},
    {"sampler", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_sampler), METH_VARARGS|METH_STATIC, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_texture), METH_VARARGS|METH_STATIC, nullptr},
    {"textures", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_textures), METH_VARARGS|METH_STATIC, nullptr},
    {"uniformBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_uniformBuffer), METH_VARARGS|METH_STATIC, nullptr},
    {"uniformBufferWithDynamicOffset", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingFunc_uniformBufferWithDynamicOffset), METH_VARARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBinding__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QRhiShaderResourceBinding_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), (pyArg)))) {
                // operator!=(const QRhiShaderResourceBinding & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiShaderResourceBinding cppArg0_local;
                ::QRhiShaderResourceBinding *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), (pyArg)))) {
                // operator==(const QRhiShaderResourceBinding & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRhiShaderResourceBinding cppArg0_local;
                ::QRhiShaderResourceBinding *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QRhiShaderResourceBinding_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QRhiShaderResourceBinding_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiShaderResourceBinding_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiShaderResourceBinding__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiShaderResourceBinding_Type = nullptr;
static PyTypeObject *Sbk_QRhiShaderResourceBinding_TypeF(void)
{
    return _Sbk_QRhiShaderResourceBinding_Type;
}

static PyType_Slot Sbk_QRhiShaderResourceBinding_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QRhiShaderResourceBinding_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhiShaderResourceBinding_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiShaderResourceBinding_spec = {
    "2:PySide6.QtGui.QRhiShaderResourceBinding",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiShaderResourceBinding_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QRhiShaderResourceBinding_Type_PythonToCpp_QRhiShaderResourceBinding_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiShaderResourceBinding::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiShaderResourceBinding::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiShaderResourceBinding_Type_PythonToCpp_QRhiShaderResourceBinding_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Type_IDX])))
        return QRhiShaderResourceBinding_Type_PythonToCpp_QRhiShaderResourceBinding_Type;
    return {};
}
static PyObject *QRhiShaderResourceBinding_Type_CppToPython_QRhiShaderResourceBinding_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiShaderResourceBinding::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Type_IDX]), castCppIn);

}

static void QRhiShaderResourceBinding_StageFlag_PythonToCpp_QRhiShaderResourceBinding_StageFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiShaderResourceBinding::StageFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiShaderResourceBinding::StageFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiShaderResourceBinding_StageFlag_PythonToCpp_QRhiShaderResourceBinding_StageFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_StageFlag_IDX])))
        return QRhiShaderResourceBinding_StageFlag_PythonToCpp_QRhiShaderResourceBinding_StageFlag;
    return {};
}
static PyObject *QRhiShaderResourceBinding_StageFlag_CppToPython_QRhiShaderResourceBinding_StageFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiShaderResourceBinding::StageFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_StageFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiShaderResourceBinding_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiShaderResourceBinding_TypeF()))
        return QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiShaderResourceBinding_PTR_CppToPython_QRhiShaderResourceBinding(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiShaderResourceBinding *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiShaderResourceBinding_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QRhiShaderResourceBinding_COPY_CppToPython_QRhiShaderResourceBinding(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QRhiShaderResourceBinding *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QRhiShaderResourceBinding_TypeF(), new ::QRhiShaderResourceBinding(*source), true, true);
}

// Python to C++ copy conversion.
static void QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QRhiShaderResourceBinding *>(cppOut) = *reinterpret_cast< ::QRhiShaderResourceBinding *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiShaderResourceBinding_TypeF()))
        return QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiShaderResourceBinding_SignatureStrings[] = {
    "1:PySide6.QtGui.QRhiShaderResourceBinding(self)",
    "0:PySide6.QtGui.QRhiShaderResourceBinding(self,QRhiShaderResourceBinding:PySide6.QtGui.QRhiShaderResourceBinding)",
    "1:PySide6.QtGui.QRhiShaderResourceBinding.bufferLoad(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer)->PySide6.QtGui.QRhiShaderResourceBinding",
    "0:PySide6.QtGui.QRhiShaderResourceBinding.bufferLoad(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer,offset:quint32,size:quint32)->PySide6.QtGui.QRhiShaderResourceBinding",
    "1:PySide6.QtGui.QRhiShaderResourceBinding.bufferLoadStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer)->PySide6.QtGui.QRhiShaderResourceBinding",
    "0:PySide6.QtGui.QRhiShaderResourceBinding.bufferLoadStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer,offset:quint32,size:quint32)->PySide6.QtGui.QRhiShaderResourceBinding",
    "1:PySide6.QtGui.QRhiShaderResourceBinding.bufferStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer)->PySide6.QtGui.QRhiShaderResourceBinding",
    "0:PySide6.QtGui.QRhiShaderResourceBinding.bufferStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer,offset:quint32,size:quint32)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.imageLoad(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,tex:PySide6.QtGui.QRhiTexture,level:int)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.imageLoadStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,tex:PySide6.QtGui.QRhiTexture,level:int)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.imageStore(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,tex:PySide6.QtGui.QRhiTexture,level:int)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.isLayoutCompatible(self,other:PySide6.QtGui.QRhiShaderResourceBinding)->bool",
    "PySide6.QtGui.QRhiShaderResourceBinding.sampledTexture(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,tex:PySide6.QtGui.QRhiTexture,sampler:PySide6.QtGui.QRhiSampler)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.sampledTextures(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,count:int,texSamplers:PySide6.QtGui.QRhiShaderResourceBinding.TextureAndSampler)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.sampler(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,sampler:PySide6.QtGui.QRhiSampler)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.texture(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,tex:PySide6.QtGui.QRhiTexture)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.textures(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,count:int,tex:PySide6.QtGui.QRhiTexture)->PySide6.QtGui.QRhiShaderResourceBinding",
    "1:PySide6.QtGui.QRhiShaderResourceBinding.uniformBuffer(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer)->PySide6.QtGui.QRhiShaderResourceBinding",
    "0:PySide6.QtGui.QRhiShaderResourceBinding.uniformBuffer(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer,offset:quint32,size:quint32)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.uniformBufferWithDynamicOffset(binding:int,stage:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag,buf:PySide6.QtGui.QRhiBuffer,size:quint32)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBinding.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiShaderResourceBinding(PyObject *module)
{
    _Sbk_QRhiShaderResourceBinding_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiShaderResourceBinding",
        "QRhiShaderResourceBinding",
        &Sbk_QRhiShaderResourceBinding_spec,
        &Shiboken::callCppDestructor< ::QRhiShaderResourceBinding >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QRhiShaderResourceBinding_TypeF(); // references _Sbk_QRhiShaderResourceBinding_Type
    InitSignatureStrings(pyType, QRhiShaderResourceBinding_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiShaderResourceBinding_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_PTR,
        is_QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_PTR_Convertible,
        QRhiShaderResourceBinding_PTR_CppToPython_QRhiShaderResourceBinding,
        QRhiShaderResourceBinding_COPY_CppToPython_QRhiShaderResourceBinding);

    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiShaderResourceBinding).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_COPY,
        is_QRhiShaderResourceBinding_PythonToCpp_QRhiShaderResourceBinding_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiShaderResourceBinding_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "UniformBuffer",
        "SampledTexture",
        "Texture",
        "Sampler",
        "ImageLoad",
        "ImageStore",
        "ImageLoadStore",
        "BufferLoad",
        "BufferStore",
        "BufferLoadStore",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QRhiShaderResourceBinding::Type::UniformBuffer),  //  0x00  0
        uint8_t(QRhiShaderResourceBinding::Type::SampledTexture), //  0x01  1
        uint8_t(QRhiShaderResourceBinding::Type::Texture),        //  0x02  2
        uint8_t(QRhiShaderResourceBinding::Type::Sampler),        //  0x03  3
        uint8_t(QRhiShaderResourceBinding::Type::ImageLoad),      //  0x04  4
        uint8_t(QRhiShaderResourceBinding::Type::ImageStore),     //  0x05  5
        uint8_t(QRhiShaderResourceBinding::Type::ImageLoadStore), //  0x06  6
        uint8_t(QRhiShaderResourceBinding::Type::BufferLoad),     //  0x07  7
        uint8_t(QRhiShaderResourceBinding::Type::BufferStore),    //  0x08  8
        uint8_t(QRhiShaderResourceBinding::Type::BufferLoadStore) //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiShaderResourceBinding_TypeF(),
        "2:PySide6.QtGui.QRhiShaderResourceBinding.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_Type_IDX].type = EType;
    // Register converter for enum 'QRhiShaderResourceBinding::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiShaderResourceBinding_Type_CppToPython_QRhiShaderResourceBinding_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiShaderResourceBinding_Type_PythonToCpp_QRhiShaderResourceBinding_Type,
            is_QRhiShaderResourceBinding_Type_PythonToCpp_QRhiShaderResourceBinding_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    // Initialization of enum 'StageFlag'.
    const char *StageFlag_Initializer[] = {
        "VertexStage",
        "TessellationControlStage",
        "TessellationEvaluationStage",
        "GeometryStage",
        "FragmentStage",
        "ComputeStage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StageFlag_InitializerValues[] = {
        uint8_t(QRhiShaderResourceBinding::StageFlag::VertexStage),                 //  0x01  1
        uint8_t(QRhiShaderResourceBinding::StageFlag::TessellationControlStage),    //  0x02  2
        uint8_t(QRhiShaderResourceBinding::StageFlag::TessellationEvaluationStage), //  0x04  4
        uint8_t(QRhiShaderResourceBinding::StageFlag::GeometryStage),               //  0x08  8
        uint8_t(QRhiShaderResourceBinding::StageFlag::FragmentStage),               //  0x10  16
        uint8_t(QRhiShaderResourceBinding::StageFlag::ComputeStage)                 //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiShaderResourceBinding_TypeF(),
        "2:PySide6.QtGui.QRhiShaderResourceBinding.StageFlag",
        StageFlag_Initializer, StageFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_StageFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBinding_StageFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhiShaderResourceBinding::StageFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiShaderResourceBinding_StageFlag_CppToPython_QRhiShaderResourceBinding_StageFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiShaderResourceBinding_StageFlag_PythonToCpp_QRhiShaderResourceBinding_StageFlag,
            is_QRhiShaderResourceBinding_StageFlag_PythonToCpp_QRhiShaderResourceBinding_StageFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::StageFlag");
        Shiboken::Conversions::registerConverterName(converter, "StageFlag");
        // Register converter for flag 'QFlags<QRhiShaderResourceBinding::StageFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhiShaderResourceBinding::StageFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBinding::StageFlags");
    }
    // End of 'StageFlag' enum/flags.

    qRegisterMetaType< ::QRhiShaderResourceBinding >("QRhiShaderResourceBinding");
    qRegisterMetaType< ::QRhiShaderResourceBinding::Type >("QRhiShaderResourceBinding::Type");
    qRegisterMetaType< ::QRhiShaderResourceBinding::StageFlag >("QRhiShaderResourceBinding::StageFlag");

    return pyType;
}

PyTypeObject *init_QRhiShaderResourceBindingStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QRhiShaderResourceBinding");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "LAYOUT_DESC_ENTRIES_PER_BINDING",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QRhiShaderResourceBinding::LAYOUT_DESC_ENTRIES_PER_BINDING));
    return type;
}
