// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhishaderresourcebindings_wrapper.h"

// Argument includes
#include <QList>
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiShaderResourceBindingsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiShaderResourceBindingsWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiShaderResourceBindings", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiShaderResourceBindingsWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QRhiResource::Type QRhiShaderResourceBindingsWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiShaderResourceBindings::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiShaderResourceBindings::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiShaderResourceBindings", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiShaderResourceBindingsWrapper::updateResources(::QFlags<QRhiShaderResourceBindings::UpdateFlag> flags)
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.updateResources");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateResources";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.updateResources");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBindings_UpdateFlag_IDX])))->converter, &flags)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBindings_UpdateFlag_IDX])))->converter, &flags)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QRhiShaderResourceBindingsWrapper::~QRhiShaderResourceBindingsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiShaderResourceBindingsFunc_bindingAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.bindingAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiShaderResourceBindings::bindingAt(qsizetype)const->const QRhiShaderResourceBinding*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // bindingAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bindingAt(qsizetype)const
            const QRhiShaderResourceBinding * cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->bindingAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_bindingCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.bindingCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bindingCount()const
            qsizetype cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->bindingCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_cbeginBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.cbeginBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cbeginBindings()const
            const QRhiShaderResourceBinding * cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->cbeginBindings();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_cendBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.cendBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cendBindings()const
            const QRhiShaderResourceBinding * cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->cendBindings();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.create");
                return {};
            }
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_isLayoutCompatible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.isLayoutCompatible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiShaderResourceBindings::isLayoutCompatible(const QRhiShaderResourceBindings*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArg)))) {
        overloadId = 0; // isLayoutCompatible(const QRhiShaderResourceBindings*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderResourceBindings *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLayoutCompatible(const QRhiShaderResourceBindings*)const
            bool cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->isLayoutCompatible(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.resourceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceType()const
            QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->::QRhiShaderResourceBindings::resourceType()
                : const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->resourceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_serializedLayoutDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.serializedLayoutDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serializedLayoutDescription()const
            QList<quint32> cppResult = const_cast<const ::QRhiShaderResourceBindings *>(cppSelf)->serializedLayoutDescription();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_setBindings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.setBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiShaderResourceBindings::setBindings(QList<QRhiShaderResourceBinding>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderResourceBinding_IDX], (pyArg)))) {
        overloadId = 0; // setBindings(QList<QRhiShaderResourceBinding>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QRhiShaderResourceBinding> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBindings(QList<QRhiShaderResourceBinding>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setBindings(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiShaderResourceBindingsFunc_updateResources(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiShaderResourceBindings.updateResources";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:updateResources", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhiShaderResourceBindings::updateResources(QFlags<QRhiShaderResourceBindings::UpdateFlag>=)
    if (numArgs == 0) {
        overloadId = 0; // updateResources(QFlags<QRhiShaderResourceBindings::UpdateFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBindings_UpdateFlag_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // updateResources(QFlags<QRhiShaderResourceBindings::UpdateFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBindings_UpdateFlag_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QRhiShaderResourceBindings::UpdateFlag> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateResources(QFlags<QRhiShaderResourceBindings::UpdateFlag>)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiShaderResourceBindings.updateResources");
                return {};
            }
            cppSelf->updateResources(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRhiShaderResourceBindings_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiShaderResourceBindings_EnumFlagInfo[] = {
    "UpdateFlag:Flag:UpdateFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiShaderResourceBindings_methods[] = {
    {"bindingAt", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_bindingAt), METH_O, nullptr},
    {"bindingCount", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_bindingCount), METH_NOARGS, nullptr},
    {"cbeginBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_cbeginBindings), METH_NOARGS, nullptr},
    {"cendBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_cendBindings), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_create), METH_NOARGS, nullptr},
    {"isLayoutCompatible", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_isLayoutCompatible), METH_O, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_resourceType), METH_NOARGS, nullptr},
    {"serializedLayoutDescription", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_serializedLayoutDescription), METH_NOARGS, nullptr},
    {"setBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_setBindings), METH_O, nullptr},
    {"updateResources", reinterpret_cast<PyCFunction>(Sbk_QRhiShaderResourceBindingsFunc_updateResources), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiShaderResourceBindings_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiShaderResourceBindingsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiShaderResourceBindings_get_m_layoutDescHash(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    size_t cppOut_local = cppSelf->m_layoutDescHash;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiShaderResourceBindings_set_m_layoutDescHash(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_layoutDescHash");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_layoutDescHash", "size_t");
        return -1;
    }

    auto cppOut_local = cppSelf->m_layoutDescHash;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_layoutDescHash = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiShaderResourceBindings_get_m_layoutDesc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], &cppSelf->m_layoutDesc);
    return pyOut;
}
static int Sbk_QRhiShaderResourceBindings_set_m_layoutDesc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_layoutDesc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_layoutDesc", "QList");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_layoutDesc;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QRhiShaderResourceBindings
static PyGetSetDef Sbk_QRhiShaderResourceBindings_getsetlist[] = {
    {const_cast<char *>("m_layoutDescHash"), Sbk_QRhiShaderResourceBindings_get_m_layoutDescHash, Sbk_QRhiShaderResourceBindings_set_m_layoutDescHash, nullptr, nullptr},
    {const_cast<char *>("m_layoutDesc"), Sbk_QRhiShaderResourceBindings_get_m_layoutDesc, Sbk_QRhiShaderResourceBindings_set_m_layoutDesc, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiShaderResourceBindings_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiShaderResourceBindings_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QRhiShaderResourceBindings__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiShaderResourceBindings *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiShaderResourceBindings_Type = nullptr;
static PyTypeObject *Sbk_QRhiShaderResourceBindings_TypeF(void)
{
    return _Sbk_QRhiShaderResourceBindings_Type;
}

static PyType_Slot Sbk_QRhiShaderResourceBindings_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiShaderResourceBindings_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiShaderResourceBindings_spec = {
    "2:PySide6.QtGui.QRhiShaderResourceBindings",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiShaderResourceBindings_slots
};

} //extern "C"

static void *Sbk_QRhiShaderResourceBindings_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiShaderResourceBindings *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QRhiShaderResourceBindings_UpdateFlag_PythonToCpp_QRhiShaderResourceBindings_UpdateFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiShaderResourceBindings::UpdateFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiShaderResourceBindings::UpdateFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QRhiShaderResourceBindings_UpdateFlag_PythonToCpp_QRhiShaderResourceBindings_UpdateFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_UpdateFlag_IDX])))
        return QRhiShaderResourceBindings_UpdateFlag_PythonToCpp_QRhiShaderResourceBindings_UpdateFlag;
    return {};
}
static PyObject *QRhiShaderResourceBindings_UpdateFlag_CppToPython_QRhiShaderResourceBindings_UpdateFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiShaderResourceBindings::UpdateFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_UpdateFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiShaderResourceBindings_PythonToCpp_QRhiShaderResourceBindings_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiShaderResourceBindings_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiShaderResourceBindings_PythonToCpp_QRhiShaderResourceBindings_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiShaderResourceBindings_TypeF()))
        return QRhiShaderResourceBindings_PythonToCpp_QRhiShaderResourceBindings_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiShaderResourceBindings_PTR_CppToPython_QRhiShaderResourceBindings(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiShaderResourceBindings *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiShaderResourceBindings_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiShaderResourceBindings_SignatureStrings[] = {
    "PySide6.QtGui.QRhiShaderResourceBindings.bindingAt(self,index:qsizetype)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBindings.bindingCount(self)->qsizetype",
    "PySide6.QtGui.QRhiShaderResourceBindings.cbeginBindings(self)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBindings.cendBindings(self)->PySide6.QtGui.QRhiShaderResourceBinding",
    "PySide6.QtGui.QRhiShaderResourceBindings.create(self)->bool",
    "PySide6.QtGui.QRhiShaderResourceBindings.isLayoutCompatible(self,other:PySide6.QtGui.QRhiShaderResourceBindings)->bool",
    "PySide6.QtGui.QRhiShaderResourceBindings.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiShaderResourceBindings.serializedLayoutDescription(self)->QList[quint32]",
    "PySide6.QtGui.QRhiShaderResourceBindings.setBindings(self,bindings:QList[PySide6.QtGui.QRhiShaderResourceBinding])",
    "PySide6.QtGui.QRhiShaderResourceBindings.updateResources(self,flags:PySide6.QtGui.QRhiShaderResourceBindings.UpdateFlag={})",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiShaderResourceBindings(PyObject *module)
{
    _Sbk_QRhiShaderResourceBindings_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiShaderResourceBindings",
        "QRhiShaderResourceBindings*",
        &Sbk_QRhiShaderResourceBindings_spec,
        &Shiboken::callCppDestructor< ::QRhiShaderResourceBindings >,
        Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]),
        0,
        0);
    auto *pyType = Sbk_QRhiShaderResourceBindings_TypeF(); // references _Sbk_QRhiShaderResourceBindings_Type
    InitSignatureStrings(pyType, QRhiShaderResourceBindings_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiShaderResourceBindings_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiShaderResourceBindings_PythonToCpp_QRhiShaderResourceBindings_PTR,
        is_QRhiShaderResourceBindings_PythonToCpp_QRhiShaderResourceBindings_PTR_Convertible,
        QRhiShaderResourceBindings_PTR_CppToPython_QRhiShaderResourceBindings);

    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBindings");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBindings*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBindings&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiShaderResourceBindings).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiShaderResourceBindingsWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiShaderResourceBindings_TypeF(), &Sbk_QRhiShaderResourceBindings_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiShaderResourceBindings_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'UpdateFlag'.
    const char *UpdateFlag_Initializer[] = {
        "BindingsAreSorted",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UpdateFlag_InitializerValues[] = {
        uint8_t(QRhiShaderResourceBindings::UpdateFlag::BindingsAreSorted) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiShaderResourceBindings_TypeF(),
        "2:PySide6.QtGui.QRhiShaderResourceBindings.UpdateFlag",
        UpdateFlag_Initializer, UpdateFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_UpdateFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiShaderResourceBindings_UpdateFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhiShaderResourceBindings::UpdateFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiShaderResourceBindings_UpdateFlag_CppToPython_QRhiShaderResourceBindings_UpdateFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhiShaderResourceBindings_UpdateFlag_PythonToCpp_QRhiShaderResourceBindings_UpdateFlag,
            is_QRhiShaderResourceBindings_UpdateFlag_PythonToCpp_QRhiShaderResourceBindings_UpdateFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBindings::UpdateFlag");
        Shiboken::Conversions::registerConverterName(converter, "UpdateFlag");
        // Register converter for flag 'QFlags<QRhiShaderResourceBindings::UpdateFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhiShaderResourceBindings::UpdateFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhiShaderResourceBindings::UpdateFlags");
    }
    // End of 'UpdateFlag' enum/flags.

    qRegisterMetaType< ::QRhiShaderResourceBindings *>();
    qRegisterMetaType< ::QRhiShaderResourceBindings::UpdateFlag >("QRhiShaderResourceBindings::UpdateFlag");

    return pyType;
}
