// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"

// main header
#include "qsurfaceformat_wrapper.h"

// Argument includes
#include <QtGui/qcolorspace.h>
#include <QtGui/qsurfaceformat.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSurfaceFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSurfaceFormat >()))
        return -1;

    ::QSurfaceFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSurfaceFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSurfaceFormat::QSurfaceFormat()
    // 1: QSurfaceFormat::QSurfaceFormat(QFlags<QSurfaceFormat::FormatOption>)
    // 2: QSurfaceFormat::QSurfaceFormat(QSurfaceFormat)
    if (numArgs == 0) {
        overloadId = 0; // QSurfaceFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QSurfaceFormat(QFlags<QSurfaceFormat::FormatOption>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSurfaceFormat(QSurfaceFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSurfaceFormat()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceFormat()
                cptr = new ::QSurfaceFormat();
            }
            break;
        }
        case 1: // QSurfaceFormat(QFlags<QSurfaceFormat::FormatOption> options)
        {
            ::QFlags<QSurfaceFormat::FormatOption> cppArg0 = QFlags<QSurfaceFormat::FormatOption>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceFormat(QFlags<QSurfaceFormat::FormatOption>)
                cptr = new ::QSurfaceFormat(cppArg0);
            }
            break;
        }
        case 2: // QSurfaceFormat(const QSurfaceFormat & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSurfaceFormat cppArg0_local;
            ::QSurfaceFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSurfaceFormat(QSurfaceFormat)
                cptr = new ::QSurfaceFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSurfaceFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSurfaceFormatFunc_alphaBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.alphaBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // alphaBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->alphaBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_blueBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.blueBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // blueBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->blueBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_colorSpace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.colorSpace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorSpace()const
            const QColorSpace & cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->colorSpace();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_defaultFormat(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.defaultFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultFormat()
            QSurfaceFormat cppResult = ::QSurfaceFormat::defaultFormat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_depthBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.depthBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // depthBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->depthBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_greenBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.greenBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // greenBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->greenBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_hasAlpha(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.hasAlpha";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasAlpha()const
            bool cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->hasAlpha();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_majorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.majorVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // majorVersion()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->majorVersion();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_minorVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.minorVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minorVersion()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->minorVersion();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.options";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // options()const
            QFlags<QSurfaceFormat::FormatOption> cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->options();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_profile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.profile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // profile()const
            QSurfaceFormat::OpenGLContextProfile cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->profile();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_redBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.redBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // redBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->redBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_renderableType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.renderableType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderableType()const
            QSurfaceFormat::RenderableType cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->renderableType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_RenderableType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_samples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.samples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // samples()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->samples();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_setAlphaBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setAlphaBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setAlphaBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAlphaBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlphaBufferSize(int)
            cppSelf->setAlphaBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setBlueBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setBlueBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setBlueBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBlueBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlueBufferSize(int)
            cppSelf->setBlueBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setColorSpace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setColorSpace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setColorSpace(QSurfaceFormat::ColorSpace)
    // 1: QSurfaceFormat::setColorSpace(QColorSpace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColorSpace_IDX]), (pyArg)))) {
        overloadId = 1; // setColorSpace(QColorSpace)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_ColorSpace_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorSpace(QSurfaceFormat::ColorSpace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setColorSpace(QSurfaceFormat::ColorSpace colorSpace)
        {
            Shiboken::Warnings::warnDeprecated("QSurfaceFormat", "setColorSpace(QSurfaceFormat.ColorSpace colorSpace)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QSurfaceFormat::ColorSpace cppArg0{QSurfaceFormat::DefaultColorSpace};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setColorSpace(QSurfaceFormat::ColorSpace)
                cppSelf->setColorSpace(cppArg0);
            }
            break;
        }
        case 1: // setColorSpace(const QColorSpace & colorSpace)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QColorSpace cppArg0_local;
            ::QColorSpace *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setColorSpace(QColorSpace)
                cppSelf->setColorSpace(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setDefaultFormat(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setDefaultFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSurfaceFormat::setDefaultFormat(QSurfaceFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setDefaultFormat(QSurfaceFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSurfaceFormat cppArg0_local;
        ::QSurfaceFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultFormat(QSurfaceFormat)
            ::QSurfaceFormat::setDefaultFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setDepthBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setDepthBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setDepthBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepthBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthBufferSize(int)
            cppSelf->setDepthBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setGreenBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setGreenBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setGreenBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setGreenBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGreenBufferSize(int)
            cppSelf->setGreenBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setMajorVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setMajorVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setMajorVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMajorVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMajorVersion(int)
            cppSelf->setMajorVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setMinorVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setMinorVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setMinorVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMinorVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinorVersion(int)
            cppSelf->setMinorVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setOption(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setOption";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setOption", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSurfaceFormat::setOption(QSurfaceFormat::FormatOption,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_FormatOption_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QSurfaceFormat::FormatOption,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setOption(QSurfaceFormat::FormatOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QSurfaceFormat::FormatOption cppArg0 = static_cast< ::QSurfaceFormat::FormatOption>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOption(QSurfaceFormat::FormatOption,bool)
            cppSelf->setOption(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setOptions(QFlags<QSurfaceFormat::FormatOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptions(QFlags<QSurfaceFormat::FormatOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QSurfaceFormat::FormatOption> cppArg0 = QFlags<QSurfaceFormat::FormatOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptions(QFlags<QSurfaceFormat::FormatOption>)
            cppSelf->setOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setProfile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setProfile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setProfile(QSurfaceFormat::OpenGLContextProfile)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setProfile(QSurfaceFormat::OpenGLContextProfile)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSurfaceFormat::OpenGLContextProfile cppArg0{QSurfaceFormat::NoProfile};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProfile(QSurfaceFormat::OpenGLContextProfile)
            cppSelf->setProfile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setRedBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setRedBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setRedBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRedBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRedBufferSize(int)
            cppSelf->setRedBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setRenderableType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setRenderableType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setRenderableType(QSurfaceFormat::RenderableType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_RenderableType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRenderableType(QSurfaceFormat::RenderableType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSurfaceFormat::RenderableType cppArg0{QSurfaceFormat::DefaultRenderableType};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderableType(QSurfaceFormat::RenderableType)
            cppSelf->setRenderableType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setSamples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSamples(int)
            cppSelf->setSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setStencilBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setStencilBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setStencilBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStencilBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilBufferSize(int)
            cppSelf->setStencilBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setStereo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setStereo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setStereo(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStereo(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStereo(bool)
            cppSelf->setStereo(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setSwapBehavior(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setSwapBehavior";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setSwapBehavior(QSurfaceFormat::SwapBehavior)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_SwapBehavior_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSwapBehavior(QSurfaceFormat::SwapBehavior)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSurfaceFormat::SwapBehavior cppArg0{QSurfaceFormat::DefaultSwapBehavior};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSwapBehavior(QSurfaceFormat::SwapBehavior)
            cppSelf->setSwapBehavior(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setSwapInterval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setSwapInterval";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::setSwapInterval(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSwapInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSwapInterval(int)
            cppSelf->setSwapInterval(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_setVersion(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.setVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setVersion", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSurfaceFormat::setVersion(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setVersion(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVersion(int,int)
            cppSelf->setVersion(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSurfaceFormatFunc_stencilBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.stencilBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stencilBufferSize()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->stencilBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_stereo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.stereo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stereo()const
            bool cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->stereo();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_swapBehavior(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.swapBehavior";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapBehavior()const
            QSurfaceFormat::SwapBehavior cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->swapBehavior();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_SwapBehavior_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_swapInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.swapInterval";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapInterval()const
            int cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->swapInterval();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_testOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.testOption";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSurfaceFormat::testOption(QSurfaceFormat::FormatOption)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_FormatOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testOption(QSurfaceFormat::FormatOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSurfaceFormat::FormatOption cppArg0 = static_cast< ::QSurfaceFormat::FormatOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testOption(QSurfaceFormat::FormatOption)const
            bool cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->testOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormatFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurfaceFormat.version";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // version()const
            std::pair<int,int> cppResult = const_cast<const ::QSurfaceFormat *>(cppSelf)->version();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSurfaceFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSurfaceFormat_EnumFlagInfo[] = {
    "ColorSpace:Enum",
    "FormatOption:Flag:FormatOptions",
    "OpenGLContextProfile:Enum",
    "RenderableType:Enum",
    "SwapBehavior:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSurfaceFormat_methods[] = {
    {"alphaBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_alphaBufferSize), METH_NOARGS, nullptr},
    {"blueBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_blueBufferSize), METH_NOARGS, nullptr},
    {"colorSpace", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_colorSpace), METH_NOARGS, nullptr},
    {"defaultFormat", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_defaultFormat), METH_NOARGS|METH_STATIC, nullptr},
    {"depthBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_depthBufferSize), METH_NOARGS, nullptr},
    {"greenBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_greenBufferSize), METH_NOARGS, nullptr},
    {"hasAlpha", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_hasAlpha), METH_NOARGS, nullptr},
    {"majorVersion", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_majorVersion), METH_NOARGS, nullptr},
    {"minorVersion", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_minorVersion), METH_NOARGS, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_options), METH_NOARGS, nullptr},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_profile), METH_NOARGS, nullptr},
    {"redBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_redBufferSize), METH_NOARGS, nullptr},
    {"renderableType", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_renderableType), METH_NOARGS, nullptr},
    {"samples", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_samples), METH_NOARGS, nullptr},
    {"setAlphaBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setAlphaBufferSize), METH_O, nullptr},
    {"setBlueBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setBlueBufferSize), METH_O, nullptr},
    {"setColorSpace", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setColorSpace), METH_O, nullptr},
    {"setDefaultFormat", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setDefaultFormat), METH_O|METH_STATIC, nullptr},
    {"setDepthBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setDepthBufferSize), METH_O, nullptr},
    {"setGreenBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setGreenBufferSize), METH_O, nullptr},
    {"setMajorVersion", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setMajorVersion), METH_O, nullptr},
    {"setMinorVersion", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setMinorVersion), METH_O, nullptr},
    {"setOption", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setOption), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setOptions", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setOptions), METH_O, nullptr},
    {"setProfile", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setProfile), METH_O, nullptr},
    {"setRedBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setRedBufferSize), METH_O, nullptr},
    {"setRenderableType", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setRenderableType), METH_O, nullptr},
    {"setSamples", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setSamples), METH_O, nullptr},
    {"setStencilBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setStencilBufferSize), METH_O, nullptr},
    {"setStereo", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setStereo), METH_O, nullptr},
    {"setSwapBehavior", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setSwapBehavior), METH_O, nullptr},
    {"setSwapInterval", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setSwapInterval), METH_O, nullptr},
    {"setVersion", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_setVersion), METH_VARARGS, nullptr},
    {"stencilBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_stencilBufferSize), METH_NOARGS, nullptr},
    {"stereo", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_stereo), METH_NOARGS, nullptr},
    {"swapBehavior", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_swapBehavior), METH_NOARGS, nullptr},
    {"swapInterval", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_swapInterval), METH_NOARGS, nullptr},
    {"testOption", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_testOption), METH_O, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormatFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QSurfaceFormat_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArg)))) {
                // operator!=(const QSurfaceFormat & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSurfaceFormat cppArg0_local;
                ::QSurfaceFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), (pyArg)))) {
                // operator==(const QSurfaceFormat & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSurfaceFormat cppArg0_local;
                ::QSurfaceFormat *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QSurfaceFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSurfaceFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSurfaceFormat__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSurfaceFormat_Type = nullptr;
static PyTypeObject *Sbk_QSurfaceFormat_TypeF(void)
{
    return _Sbk_QSurfaceFormat_Type;
}

static PyType_Slot Sbk_QSurfaceFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSurfaceFormat__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSurfaceFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSurfaceFormat_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QSurfaceFormat_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSurfaceFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSurfaceFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSurfaceFormat_spec = {
    "2:PySide6.QtGui.QSurfaceFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSurfaceFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSurfaceFormat_FormatOption_PythonToCpp_QSurfaceFormat_FormatOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurfaceFormat::FormatOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurfaceFormat::FormatOption *>(cppOut) = value;

}
static PythonToCppFunc is_QSurfaceFormat_FormatOption_PythonToCpp_QSurfaceFormat_FormatOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_FormatOption_IDX])))
        return QSurfaceFormat_FormatOption_PythonToCpp_QSurfaceFormat_FormatOption;
    return {};
}
static PyObject *QSurfaceFormat_FormatOption_CppToPython_QSurfaceFormat_FormatOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurfaceFormat::FormatOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_FormatOption_IDX]), castCppIn);

}

static void QSurfaceFormat_SwapBehavior_PythonToCpp_QSurfaceFormat_SwapBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurfaceFormat::SwapBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurfaceFormat::SwapBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_QSurfaceFormat_SwapBehavior_PythonToCpp_QSurfaceFormat_SwapBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_SwapBehavior_IDX])))
        return QSurfaceFormat_SwapBehavior_PythonToCpp_QSurfaceFormat_SwapBehavior;
    return {};
}
static PyObject *QSurfaceFormat_SwapBehavior_CppToPython_QSurfaceFormat_SwapBehavior(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurfaceFormat::SwapBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_SwapBehavior_IDX]), castCppIn);

}

static void QSurfaceFormat_RenderableType_PythonToCpp_QSurfaceFormat_RenderableType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurfaceFormat::RenderableType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurfaceFormat::RenderableType *>(cppOut) = value;

}
static PythonToCppFunc is_QSurfaceFormat_RenderableType_PythonToCpp_QSurfaceFormat_RenderableType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_RenderableType_IDX])))
        return QSurfaceFormat_RenderableType_PythonToCpp_QSurfaceFormat_RenderableType;
    return {};
}
static PyObject *QSurfaceFormat_RenderableType_CppToPython_QSurfaceFormat_RenderableType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurfaceFormat::RenderableType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_RenderableType_IDX]), castCppIn);

}

static void QSurfaceFormat_OpenGLContextProfile_PythonToCpp_QSurfaceFormat_OpenGLContextProfile(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurfaceFormat::OpenGLContextProfile>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurfaceFormat::OpenGLContextProfile *>(cppOut) = value;

}
static PythonToCppFunc is_QSurfaceFormat_OpenGLContextProfile_PythonToCpp_QSurfaceFormat_OpenGLContextProfile_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX])))
        return QSurfaceFormat_OpenGLContextProfile_PythonToCpp_QSurfaceFormat_OpenGLContextProfile;
    return {};
}
static PyObject *QSurfaceFormat_OpenGLContextProfile_CppToPython_QSurfaceFormat_OpenGLContextProfile(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurfaceFormat::OpenGLContextProfile *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX]), castCppIn);

}

static void QSurfaceFormat_ColorSpace_PythonToCpp_QSurfaceFormat_ColorSpace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurfaceFormat::ColorSpace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurfaceFormat::ColorSpace *>(cppOut) = value;

}
static PythonToCppFunc is_QSurfaceFormat_ColorSpace_PythonToCpp_QSurfaceFormat_ColorSpace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_ColorSpace_IDX])))
        return QSurfaceFormat_ColorSpace_PythonToCpp_QSurfaceFormat_ColorSpace;
    return {};
}
static PyObject *QSurfaceFormat_ColorSpace_CppToPython_QSurfaceFormat_ColorSpace(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurfaceFormat::ColorSpace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_ColorSpace_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSurfaceFormat_PythonToCpp_QSurfaceFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSurfaceFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSurfaceFormat_PythonToCpp_QSurfaceFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSurfaceFormat_TypeF()))
        return QSurfaceFormat_PythonToCpp_QSurfaceFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSurfaceFormat_PTR_CppToPython_QSurfaceFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QSurfaceFormat *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QSurfaceFormat_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QSurfaceFormat_COPY_CppToPython_QSurfaceFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSurfaceFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSurfaceFormat_TypeF(), new ::QSurfaceFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QSurfaceFormat_PythonToCpp_QSurfaceFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSurfaceFormat *>(cppOut) = *reinterpret_cast< ::QSurfaceFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSurfaceFormat_PythonToCpp_QSurfaceFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSurfaceFormat_TypeF()))
        return QSurfaceFormat_PythonToCpp_QSurfaceFormat_COPY;
    return {};
}

// Implicit conversions.
static void QFlags_QSurfaceFormat_FormatOption__PythonToCpp_QSurfaceFormat(PyObject *pyIn, void *cppOut)
{
    ::QFlags<QSurfaceFormat::FormatOption> cppIn = QFlags<QSurfaceFormat::FormatOption>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QSurfaceFormat *>(cppOut) = ::QSurfaceFormat(cppIn);
}
static PythonToCppFunc is_QFlags_QSurfaceFormat_FormatOption__PythonToCpp_QSurfaceFormat_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX]), pyIn))
        return QFlags_QSurfaceFormat_FormatOption__PythonToCpp_QSurfaceFormat;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSurfaceFormat_SignatureStrings[] = {
    "2:PySide6.QtGui.QSurfaceFormat(self)",
    "1:PySide6.QtGui.QSurfaceFormat(self,options:PySide6.QtGui.QSurfaceFormat.FormatOption)",
    "0:PySide6.QtGui.QSurfaceFormat(self,other:typing.Union[PySide6.QtGui.QSurfaceFormat, PySide6.QtGui.QSurfaceFormat.FormatOption])",
    "PySide6.QtGui.QSurfaceFormat.alphaBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.blueBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.colorSpace(self)->PySide6.QtGui.QColorSpace",
    "PySide6.QtGui.QSurfaceFormat.defaultFormat()->PySide6.QtGui.QSurfaceFormat",
    "PySide6.QtGui.QSurfaceFormat.depthBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.greenBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.hasAlpha(self)->bool",
    "PySide6.QtGui.QSurfaceFormat.majorVersion(self)->int",
    "PySide6.QtGui.QSurfaceFormat.minorVersion(self)->int",
    "PySide6.QtGui.QSurfaceFormat.options(self)->PySide6.QtGui.QSurfaceFormat.FormatOption",
    "PySide6.QtGui.QSurfaceFormat.profile(self)->PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile",
    "PySide6.QtGui.QSurfaceFormat.redBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.renderableType(self)->PySide6.QtGui.QSurfaceFormat.RenderableType",
    "PySide6.QtGui.QSurfaceFormat.samples(self)->int",
    "PySide6.QtGui.QSurfaceFormat.setAlphaBufferSize(self,size:int)",
    "PySide6.QtGui.QSurfaceFormat.setBlueBufferSize(self,size:int)",
    "1:PySide6.QtGui.QSurfaceFormat.setColorSpace(self,colorSpace:PySide6.QtGui.QSurfaceFormat.ColorSpace)",
    "0:PySide6.QtGui.QSurfaceFormat.setColorSpace(self,colorSpace:typing.Union[PySide6.QtGui.QColorSpace, PySide6.QtGui.QColorSpace.NamedColorSpace])",
    "PySide6.QtGui.QSurfaceFormat.setDefaultFormat(format:typing.Union[PySide6.QtGui.QSurfaceFormat, PySide6.QtGui.QSurfaceFormat.FormatOption])",
    "PySide6.QtGui.QSurfaceFormat.setDepthBufferSize(self,size:int)",
    "PySide6.QtGui.QSurfaceFormat.setGreenBufferSize(self,size:int)",
    "PySide6.QtGui.QSurfaceFormat.setMajorVersion(self,majorVersion:int)",
    "PySide6.QtGui.QSurfaceFormat.setMinorVersion(self,minorVersion:int)",
    "PySide6.QtGui.QSurfaceFormat.setOption(self,option:PySide6.QtGui.QSurfaceFormat.FormatOption,on:bool=true)",
    "PySide6.QtGui.QSurfaceFormat.setOptions(self,options:PySide6.QtGui.QSurfaceFormat.FormatOption)",
    "PySide6.QtGui.QSurfaceFormat.setProfile(self,profile:PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile)",
    "PySide6.QtGui.QSurfaceFormat.setRedBufferSize(self,size:int)",
    "PySide6.QtGui.QSurfaceFormat.setRenderableType(self,type:PySide6.QtGui.QSurfaceFormat.RenderableType)",
    "PySide6.QtGui.QSurfaceFormat.setSamples(self,numSamples:int)",
    "PySide6.QtGui.QSurfaceFormat.setStencilBufferSize(self,size:int)",
    "PySide6.QtGui.QSurfaceFormat.setStereo(self,enable:bool)",
    "PySide6.QtGui.QSurfaceFormat.setSwapBehavior(self,behavior:PySide6.QtGui.QSurfaceFormat.SwapBehavior)",
    "PySide6.QtGui.QSurfaceFormat.setSwapInterval(self,interval:int)",
    "PySide6.QtGui.QSurfaceFormat.setVersion(self,major:int,minor:int)",
    "PySide6.QtGui.QSurfaceFormat.stencilBufferSize(self)->int",
    "PySide6.QtGui.QSurfaceFormat.stereo(self)->bool",
    "PySide6.QtGui.QSurfaceFormat.swapBehavior(self)->PySide6.QtGui.QSurfaceFormat.SwapBehavior",
    "PySide6.QtGui.QSurfaceFormat.swapInterval(self)->int",
    "PySide6.QtGui.QSurfaceFormat.testOption(self,option:PySide6.QtGui.QSurfaceFormat.FormatOption)->bool",
    "PySide6.QtGui.QSurfaceFormat.version(self)->std.pair[int, int]",
    "PySide6.QtGui.QSurfaceFormat.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QSurfaceFormat(PyObject *module)
{
    _Sbk_QSurfaceFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSurfaceFormat",
        "QSurfaceFormat",
        &Sbk_QSurfaceFormat_spec,
        &Shiboken::callCppDestructor< ::QSurfaceFormat >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSurfaceFormat_TypeF(); // references _Sbk_QSurfaceFormat_Type
    InitSignatureStrings(pyType, QSurfaceFormat_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSurfaceFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSurfaceFormat_PythonToCpp_QSurfaceFormat_PTR,
        is_QSurfaceFormat_PythonToCpp_QSurfaceFormat_PTR_Convertible,
        QSurfaceFormat_PTR_CppToPython_QSurfaceFormat,
        QSurfaceFormat_COPY_CppToPython_QSurfaceFormat);

    Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat");
    Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSurfaceFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSurfaceFormat_PythonToCpp_QSurfaceFormat_COPY,
        is_QSurfaceFormat_PythonToCpp_QSurfaceFormat_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFlags_QSurfaceFormat_FormatOption__PythonToCpp_QSurfaceFormat,
        is_QFlags_QSurfaceFormat_FormatOption__PythonToCpp_QSurfaceFormat_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSurfaceFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FormatOption'.
    const char *FormatOption_Initializer[] = {
        "StereoBuffers",
        "DebugContext",
        "DeprecatedFunctions",
        "ResetNotification",
        "ProtectedContent",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FormatOption_InitializerValues[] = {
        uint8_t(QSurfaceFormat::FormatOption::StereoBuffers),       //  0x01  1
        uint8_t(QSurfaceFormat::FormatOption::DebugContext),        //  0x02  2
        uint8_t(QSurfaceFormat::FormatOption::DeprecatedFunctions), //  0x04  4
        uint8_t(QSurfaceFormat::FormatOption::ResetNotification),   //  0x08  8
        uint8_t(QSurfaceFormat::FormatOption::ProtectedContent)     //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurfaceFormat_TypeF(),
        "2:PySide6.QtGui.QSurfaceFormat.FormatOption",
        FormatOption_Initializer, FormatOption_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_FormatOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QSurfaceFormat_FormatOption_IDX].type =
        EType;
    // Register converter for enum 'QSurfaceFormat::FormatOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurfaceFormat_FormatOption_CppToPython_QSurfaceFormat_FormatOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurfaceFormat_FormatOption_PythonToCpp_QSurfaceFormat_FormatOption,
            is_QSurfaceFormat_FormatOption_PythonToCpp_QSurfaceFormat_FormatOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::FormatOption");
        Shiboken::Conversions::registerConverterName(converter, "FormatOption");
        // Register converter for flag 'QFlags<QSurfaceFormat::FormatOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSurfaceFormat::FormatOption>");
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::FormatOptions");
    }
    // End of 'FormatOption' enum/flags.

    // Initialization of enum 'SwapBehavior'.
    const char *SwapBehavior_Initializer[] = {
        "DefaultSwapBehavior",
        "SingleBuffer",
        "DoubleBuffer",
        "TripleBuffer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SwapBehavior_InitializerValues[] = {
        uint8_t(QSurfaceFormat::SwapBehavior::DefaultSwapBehavior), //  0x00  0
        uint8_t(QSurfaceFormat::SwapBehavior::SingleBuffer),        //  0x01  1
        uint8_t(QSurfaceFormat::SwapBehavior::DoubleBuffer),        //  0x02  2
        uint8_t(QSurfaceFormat::SwapBehavior::TripleBuffer)         //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurfaceFormat_TypeF(),
        "2:PySide6.QtGui.QSurfaceFormat.SwapBehavior",
        SwapBehavior_Initializer, SwapBehavior_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_SwapBehavior_IDX].type = EType;
    // Register converter for enum 'QSurfaceFormat::SwapBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurfaceFormat_SwapBehavior_CppToPython_QSurfaceFormat_SwapBehavior);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurfaceFormat_SwapBehavior_PythonToCpp_QSurfaceFormat_SwapBehavior,
            is_QSurfaceFormat_SwapBehavior_PythonToCpp_QSurfaceFormat_SwapBehavior_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::SwapBehavior");
        Shiboken::Conversions::registerConverterName(converter, "SwapBehavior");
    }
    // End of 'SwapBehavior' enum.

    // Initialization of enum 'RenderableType'.
    const char *RenderableType_Initializer[] = {
        "DefaultRenderableType",
        "OpenGL",
        "OpenGLES",
        "OpenVG",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderableType_InitializerValues[] = {
        uint8_t(QSurfaceFormat::RenderableType::DefaultRenderableType), //  0x00  0
        uint8_t(QSurfaceFormat::RenderableType::OpenGL),                //  0x01  1
        uint8_t(QSurfaceFormat::RenderableType::OpenGLES),              //  0x02  2
        uint8_t(QSurfaceFormat::RenderableType::OpenVG)                 //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurfaceFormat_TypeF(),
        "2:PySide6.QtGui.QSurfaceFormat.RenderableType",
        RenderableType_Initializer, RenderableType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_RenderableType_IDX].type = EType;
    // Register converter for enum 'QSurfaceFormat::RenderableType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurfaceFormat_RenderableType_CppToPython_QSurfaceFormat_RenderableType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurfaceFormat_RenderableType_PythonToCpp_QSurfaceFormat_RenderableType,
            is_QSurfaceFormat_RenderableType_PythonToCpp_QSurfaceFormat_RenderableType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::RenderableType");
        Shiboken::Conversions::registerConverterName(converter, "RenderableType");
    }
    // End of 'RenderableType' enum.

    // Initialization of enum 'OpenGLContextProfile'.
    const char *OpenGLContextProfile_Initializer[] = {
        "NoProfile",
        "CoreProfile",
        "CompatibilityProfile",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OpenGLContextProfile_InitializerValues[] = {
        uint8_t(QSurfaceFormat::OpenGLContextProfile::NoProfile),           //  0x00  0
        uint8_t(QSurfaceFormat::OpenGLContextProfile::CoreProfile),         //  0x01  1
        uint8_t(QSurfaceFormat::OpenGLContextProfile::CompatibilityProfile) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurfaceFormat_TypeF(),
        "2:PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile",
        OpenGLContextProfile_Initializer, OpenGLContextProfile_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_OpenGLContextProfile_IDX].type = EType;
    // Register converter for enum 'QSurfaceFormat::OpenGLContextProfile'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurfaceFormat_OpenGLContextProfile_CppToPython_QSurfaceFormat_OpenGLContextProfile);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurfaceFormat_OpenGLContextProfile_PythonToCpp_QSurfaceFormat_OpenGLContextProfile,
            is_QSurfaceFormat_OpenGLContextProfile_PythonToCpp_QSurfaceFormat_OpenGLContextProfile_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::OpenGLContextProfile");
        Shiboken::Conversions::registerConverterName(converter, "OpenGLContextProfile");
    }
    // End of 'OpenGLContextProfile' enum.

    // Initialization of enum 'ColorSpace'.
    const char *ColorSpace_Initializer[] = {
        "DefaultColorSpace",
        "sRGBColorSpace",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ColorSpace_InitializerValues[] = {
        uint8_t(QSurfaceFormat::ColorSpace::DefaultColorSpace), //  0x00  0
        uint8_t(QSurfaceFormat::ColorSpace::sRGBColorSpace)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurfaceFormat_TypeF(),
        "2:PySide6.QtGui.QSurfaceFormat.ColorSpace",
        ColorSpace_Initializer, ColorSpace_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_ColorSpace_IDX].type = EType;
    // Register converter for enum 'QSurfaceFormat::ColorSpace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurfaceFormat_ColorSpace_CppToPython_QSurfaceFormat_ColorSpace);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurfaceFormat_ColorSpace_PythonToCpp_QSurfaceFormat_ColorSpace,
            is_QSurfaceFormat_ColorSpace_PythonToCpp_QSurfaceFormat_ColorSpace_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurfaceFormat::ColorSpace");
        Shiboken::Conversions::registerConverterName(converter, "ColorSpace");
    }
    // End of 'ColorSpace' enum.

    qRegisterMetaType< ::QSurfaceFormat >("QSurfaceFormat");
    qRegisterMetaType< ::QSurfaceFormat::FormatOption >("QSurfaceFormat::FormatOption");
    qRegisterMetaType< ::QSurfaceFormat::SwapBehavior >("QSurfaceFormat::SwapBehavior");
    qRegisterMetaType< ::QSurfaceFormat::RenderableType >("QSurfaceFormat::RenderableType");
    qRegisterMetaType< ::QSurfaceFormat::OpenGLContextProfile >("QSurfaceFormat::OpenGLContextProfile");
    qRegisterMetaType< ::QSurfaceFormat::ColorSpace >("QSurfaceFormat::ColorSpace");

    return pyType;
}
