// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"

// main header
#include "qtextcharformat_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtGui/qtextformat.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextCharFormat_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextCharFormat >()))
        return -1;

    ::QTextCharFormat *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextCharFormat", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextCharFormat::QTextCharFormat()
    // 1: QTextCharFormat::QTextCharFormat(QTextCharFormat)
    // 2: QTextCharFormat::QTextCharFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextCharFormat()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QTextCharFormat(QTextCharFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextCharFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextCharFormat()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCharFormat()
                cptr = new ::QTextCharFormat();
            }
            break;
        }
        case 1: // QTextCharFormat(const QTextCharFormat & QTextCharFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextCharFormat cppArg0_local;
            ::QTextCharFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCharFormat(QTextCharFormat)
                cptr = new ::QTextCharFormat(*cppArg0);
            }
            break;
        }
        case 2: // QTextCharFormat(const QTextFormat & fmt)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0_local;
            ::QTextFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextCharFormat(QTextFormat)
                cptr = new ::QTextCharFormat(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextCharFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextCharFormatFunc_anchorHref(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.anchorHref";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // anchorHref()const
            QString cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->anchorHref();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_anchorNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.anchorNames";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // anchorNames()const
            QStringList cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->anchorNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_baselineOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.baselineOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // baselineOffset()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->baselineOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.font";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // font()const
            QFont cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->font();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontCapitalization(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontCapitalization";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontCapitalization()const
            QFont::Capitalization cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontCapitalization();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontFamilies(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontFamilies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontFamilies()const
            QVariant cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontFamilies();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontFamily(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontFamily";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QTextCharFormat", "fontFamily() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontFamily()const
            QString cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontFamily();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontFixedPitch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontFixedPitch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontFixedPitch()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontFixedPitch();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontHintingPreference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontHintingPreference";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontHintingPreference()const
            QFont::HintingPreference cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontHintingPreference();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontItalic(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontItalic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontItalic()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontItalic();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontKerning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontKerning";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontKerning()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontKerning();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontLetterSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontLetterSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontLetterSpacing()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontLetterSpacing();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontLetterSpacingType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontLetterSpacingType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontLetterSpacingType()const
            QFont::SpacingType cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontLetterSpacingType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontOverline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontOverline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontOverline()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontOverline();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontPointSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontPointSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontPointSize()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontPointSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontStretch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontStretch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontStretch()const
            int cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontStretch();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontStrikeOut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontStrikeOut";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontStrikeOut()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontStrikeOut();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontStyleHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontStyleHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontStyleHint()const
            QFont::StyleHint cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontStyleHint();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontStyleName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontStyleName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontStyleName()const
            QVariant cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontStyleName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontStyleStrategy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontStyleStrategy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontStyleStrategy()const
            QFont::StyleStrategy cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontStyleStrategy();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontUnderline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontUnderline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontUnderline()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontUnderline();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontWeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontWeight";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontWeight()const
            int cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontWeight();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_fontWordSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.fontWordSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontWordSpacing()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->fontWordSpacing();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_isAnchor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.isAnchor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAnchor()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->isAnchor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_setAnchor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setAnchor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setAnchor(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAnchor(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnchor(bool)
            cppSelf->setAnchor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setAnchorHref(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setAnchorHref";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setAnchorHref(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setAnchorHref(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnchorHref(QString)
            cppSelf->setAnchorHref(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setAnchorNames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setAnchorNames";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setAnchorNames(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setAnchorNames(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnchorNames(QStringList)
            cppSelf->setAnchorNames(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setBaselineOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setBaselineOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setBaselineOffset(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBaselineOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaselineOffset(qreal)
            cppSelf->setBaselineOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFont(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFont";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setFont", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCharFormat::setFont(QFont,QTextCharFormat::FontPropertiesInheritanceBehavior=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFont(QFont,QTextCharFormat::FontPropertiesInheritanceBehavior)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_FontPropertiesInheritanceBehavior_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setFont(QFont,QTextCharFormat::FontPropertiesInheritanceBehavior)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_behavior = Shiboken::String::createStaticString("behavior");
            if (PyDict_Contains(kwds, key_behavior) != 0) {
                value = PyDict_GetItem(kwds, key_behavior);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_behavior);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_FontPropertiesInheritanceBehavior_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_behavior);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QTextCharFormat::FontPropertiesInheritanceBehavior cppArg1(QTextCharFormat::FontPropertiesInheritanceBehavior::FontPropertiesAll);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont,QTextCharFormat::FontPropertiesInheritanceBehavior)
            cppSelf->setFont(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontCapitalization(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontCapitalization";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontCapitalization(QFont::Capitalization)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFontCapitalization(QFont::Capitalization)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFont::Capitalization cppArg0{QFont::MixedCase};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontCapitalization(QFont::Capitalization)
            cppSelf->setFontCapitalization(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontFamilies(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontFamilies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontFamilies(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setFontFamilies(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontFamilies(QStringList)
            cppSelf->setFontFamilies(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontFamily(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontFamily";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontFamily(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFontFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QTextCharFormat", "setFontFamily(const QString & family)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontFamily(QString)
            cppSelf->setFontFamily(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontFixedPitch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontFixedPitch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontFixedPitch(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontFixedPitch(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontFixedPitch(bool)
            cppSelf->setFontFixedPitch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontHintingPreference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontHintingPreference";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontHintingPreference(QFont::HintingPreference)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFontHintingPreference(QFont::HintingPreference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFont::HintingPreference cppArg0{QFont::PreferDefaultHinting};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontHintingPreference(QFont::HintingPreference)
            cppSelf->setFontHintingPreference(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontItalic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontItalic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontItalic(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontItalic(bool)
            cppSelf->setFontItalic(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontKerning(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontKerning";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontKerning(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontKerning(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontKerning(bool)
            cppSelf->setFontKerning(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontLetterSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontLetterSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontLetterSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setFontLetterSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontLetterSpacing(qreal)
            cppSelf->setFontLetterSpacing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontLetterSpacingType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontLetterSpacingType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontLetterSpacingType(QFont::SpacingType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFontLetterSpacingType(QFont::SpacingType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFont::SpacingType cppArg0{QFont::PercentageSpacing};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontLetterSpacingType(QFont::SpacingType)
            cppSelf->setFontLetterSpacingType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontOverline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontOverline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontOverline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontOverline(bool)
            cppSelf->setFontOverline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontPointSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontPointSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontPointSize(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setFontPointSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontPointSize(qreal)
            cppSelf->setFontPointSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontStretch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontStretch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontStretch(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFontStretch(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontStretch(int)
            cppSelf->setFontStretch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontStrikeOut(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontStrikeOut";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontStrikeOut(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontStrikeOut(bool)
            cppSelf->setFontStrikeOut(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontStyleHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontStyleHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setFontStyleHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextCharFormat::setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_strategy = Shiboken::String::createStaticString("strategy");
            if (PyDict_Contains(kwds, key_strategy) != 0) {
                value = PyDict_GetItem(kwds, key_strategy);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_strategy);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_strategy);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFont::StyleHint cppArg0{QFont::SansSerif};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFont::StyleStrategy cppArg1(QFont::PreferDefault);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
            cppSelf->setFontStyleHint(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontStyleName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontStyleName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontStyleName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFontStyleName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontStyleName(QString)
            cppSelf->setFontStyleName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontStyleStrategy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontStyleStrategy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontStyleStrategy(QFont::StyleStrategy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFontStyleStrategy(QFont::StyleStrategy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFont::StyleStrategy cppArg0 = static_cast< ::QFont::StyleStrategy>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontStyleStrategy(QFont::StyleStrategy)
            cppSelf->setFontStyleStrategy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontUnderline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontUnderline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontUnderline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontUnderline(bool)
            cppSelf->setFontUnderline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontWeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontWeight";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontWeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setFontWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontWeight(int)
            cppSelf->setFontWeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setFontWordSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setFontWordSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setFontWordSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setFontWordSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontWordSpacing(qreal)
            cppSelf->setFontWordSpacing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setSubScriptBaseline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setSubScriptBaseline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setSubScriptBaseline(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSubScriptBaseline(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubScriptBaseline(qreal)
            cppSelf->setSubScriptBaseline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setSuperScriptBaseline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setSuperScriptBaseline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setSuperScriptBaseline(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSuperScriptBaseline(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSuperScriptBaseline(qreal)
            cppSelf->setSuperScriptBaseline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setTableCellColumnSpan(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setTableCellColumnSpan";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setTableCellColumnSpan(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTableCellColumnSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTableCellColumnSpan(int)
            cppSelf->setTableCellColumnSpan(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setTableCellRowSpan(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setTableCellRowSpan";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setTableCellRowSpan(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTableCellRowSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTableCellRowSpan(int)
            cppSelf->setTableCellRowSpan(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setTextOutline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setTextOutline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setTextOutline(QPen)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArg)))) {
        overloadId = 0; // setTextOutline(QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPen cppArg0_local;
        ::QPen *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextOutline(QPen)
            cppSelf->setTextOutline(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setToolTip(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setToolTip";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setToolTip(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setToolTip(QString)
            cppSelf->setToolTip(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setUnderlineColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setUnderlineColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setUnderlineColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setUnderlineColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnderlineColor(QColor)
            cppSelf->setUnderlineColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setUnderlineStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setUnderlineStyle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_UnderlineStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QTextCharFormat::UnderlineStyle cppArg0{QTextCharFormat::NoUnderline};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
            cppSelf->setUnderlineStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_setVerticalAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.setVerticalAlignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextCharFormat::setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_VerticalAlignment_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QTextCharFormat::VerticalAlignment cppArg0{QTextCharFormat::AlignNormal};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
            cppSelf->setVerticalAlignment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextCharFormatFunc_subScriptBaseline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.subScriptBaseline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // subScriptBaseline()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->subScriptBaseline();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_superScriptBaseline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.superScriptBaseline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // superScriptBaseline()const
            qreal cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->superScriptBaseline();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_tableCellColumnSpan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.tableCellColumnSpan";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // tableCellColumnSpan()const
            int cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->tableCellColumnSpan();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_tableCellRowSpan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.tableCellRowSpan";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // tableCellRowSpan()const
            int cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->tableCellRowSpan();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_textOutline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.textOutline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textOutline()const
            QPen cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->textOutline();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_toolTip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.toolTip";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toolTip()const
            QString cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->toolTip();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_underlineColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.underlineColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // underlineColor()const
            QColor cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->underlineColor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_underlineStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.underlineStyle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // underlineStyle()const
            QTextCharFormat::UnderlineStyle cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->underlineStyle();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_UnderlineStyle_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormatFunc_verticalAlignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextCharFormat.verticalAlignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // verticalAlignment()const
            QTextCharFormat::VerticalAlignment cppResult = const_cast<const ::QTextCharFormat *>(cppSelf)->verticalAlignment();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_VerticalAlignment_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextCharFormat__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextCharFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextCharFormat_EnumFlagInfo[] = {
    "FontPropertiesInheritanceBehavior:Enum",
    "UnderlineStyle:Enum",
    "VerticalAlignment:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextCharFormat_methods[] = {
    {"anchorHref", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_anchorHref), METH_NOARGS, nullptr},
    {"anchorNames", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_anchorNames), METH_NOARGS, nullptr},
    {"baselineOffset", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_baselineOffset), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_font), METH_NOARGS, nullptr},
    {"fontCapitalization", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontCapitalization), METH_NOARGS, nullptr},
    {"fontFamilies", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontFamilies), METH_NOARGS, nullptr},
    {"fontFamily", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontFamily), METH_NOARGS, nullptr},
    {"fontFixedPitch", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontFixedPitch), METH_NOARGS, nullptr},
    {"fontHintingPreference", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontHintingPreference), METH_NOARGS, nullptr},
    {"fontItalic", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontItalic), METH_NOARGS, nullptr},
    {"fontKerning", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontKerning), METH_NOARGS, nullptr},
    {"fontLetterSpacing", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontLetterSpacing), METH_NOARGS, nullptr},
    {"fontLetterSpacingType", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontLetterSpacingType), METH_NOARGS, nullptr},
    {"fontOverline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontOverline), METH_NOARGS, nullptr},
    {"fontPointSize", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontPointSize), METH_NOARGS, nullptr},
    {"fontStretch", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontStretch), METH_NOARGS, nullptr},
    {"fontStrikeOut", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontStrikeOut), METH_NOARGS, nullptr},
    {"fontStyleHint", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontStyleHint), METH_NOARGS, nullptr},
    {"fontStyleName", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontStyleName), METH_NOARGS, nullptr},
    {"fontStyleStrategy", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontStyleStrategy), METH_NOARGS, nullptr},
    {"fontUnderline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontUnderline), METH_NOARGS, nullptr},
    {"fontWeight", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontWeight), METH_NOARGS, nullptr},
    {"fontWordSpacing", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_fontWordSpacing), METH_NOARGS, nullptr},
    {"isAnchor", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_isAnchor), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_isValid), METH_NOARGS, nullptr},
    {"setAnchor", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setAnchor), METH_O, nullptr},
    {"setAnchorHref", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setAnchorHref), METH_O, nullptr},
    {"setAnchorNames", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setAnchorNames), METH_O, nullptr},
    {"setBaselineOffset", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setBaselineOffset), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFont), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFontCapitalization", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontCapitalization), METH_O, nullptr},
    {"setFontFamilies", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontFamilies), METH_O, nullptr},
    {"setFontFamily", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontFamily), METH_O, nullptr},
    {"setFontFixedPitch", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontFixedPitch), METH_O, nullptr},
    {"setFontHintingPreference", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontHintingPreference), METH_O, nullptr},
    {"setFontItalic", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontItalic), METH_O, nullptr},
    {"setFontKerning", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontKerning), METH_O, nullptr},
    {"setFontLetterSpacing", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontLetterSpacing), METH_O, nullptr},
    {"setFontLetterSpacingType", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontLetterSpacingType), METH_O, nullptr},
    {"setFontOverline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontOverline), METH_O, nullptr},
    {"setFontPointSize", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontPointSize), METH_O, nullptr},
    {"setFontStretch", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontStretch), METH_O, nullptr},
    {"setFontStrikeOut", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontStrikeOut), METH_O, nullptr},
    {"setFontStyleHint", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontStyleHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFontStyleName", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontStyleName), METH_O, nullptr},
    {"setFontStyleStrategy", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontStyleStrategy), METH_O, nullptr},
    {"setFontUnderline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontUnderline), METH_O, nullptr},
    {"setFontWeight", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontWeight), METH_O, nullptr},
    {"setFontWordSpacing", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setFontWordSpacing), METH_O, nullptr},
    {"setSubScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setSubScriptBaseline), METH_O, nullptr},
    {"setSuperScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setSuperScriptBaseline), METH_O, nullptr},
    {"setTableCellColumnSpan", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setTableCellColumnSpan), METH_O, nullptr},
    {"setTableCellRowSpan", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setTableCellRowSpan), METH_O, nullptr},
    {"setTextOutline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setTextOutline), METH_O, nullptr},
    {"setToolTip", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setToolTip), METH_O, nullptr},
    {"setUnderlineColor", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setUnderlineColor), METH_O, nullptr},
    {"setUnderlineStyle", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setUnderlineStyle), METH_O, nullptr},
    {"setVerticalAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_setVerticalAlignment), METH_O, nullptr},
    {"subScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_subScriptBaseline), METH_NOARGS, nullptr},
    {"superScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_superScriptBaseline), METH_NOARGS, nullptr},
    {"tableCellColumnSpan", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_tableCellColumnSpan), METH_NOARGS, nullptr},
    {"tableCellRowSpan", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_tableCellRowSpan), METH_NOARGS, nullptr},
    {"textOutline", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_textOutline), METH_NOARGS, nullptr},
    {"toolTip", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_toolTip), METH_NOARGS, nullptr},
    {"underlineColor", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_underlineColor), METH_NOARGS, nullptr},
    {"underlineStyle", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_underlineStyle), METH_NOARGS, nullptr},
    {"verticalAlignment", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormatFunc_verticalAlignment), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextCharFormat__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextCharFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextCharFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextCharFormat_Type = nullptr;
static PyTypeObject *Sbk_QTextCharFormat_TypeF(void)
{
    return _Sbk_QTextCharFormat_Type;
}

static PyType_Slot Sbk_QTextCharFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextCharFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextCharFormat_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextCharFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextCharFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextCharFormat_spec = {
    "2:PySide6.QtGui.QTextCharFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextCharFormat_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QTextCharFormat_VerticalAlignment_PythonToCpp_QTextCharFormat_VerticalAlignment(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCharFormat::VerticalAlignment>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCharFormat::VerticalAlignment *>(cppOut) = value;

}
static PythonToCppFunc is_QTextCharFormat_VerticalAlignment_PythonToCpp_QTextCharFormat_VerticalAlignment_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_VerticalAlignment_IDX])))
        return QTextCharFormat_VerticalAlignment_PythonToCpp_QTextCharFormat_VerticalAlignment;
    return {};
}
static PyObject *QTextCharFormat_VerticalAlignment_CppToPython_QTextCharFormat_VerticalAlignment(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QTextCharFormat::VerticalAlignment *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_VerticalAlignment_IDX]), castCppIn);

}

static void QTextCharFormat_UnderlineStyle_PythonToCpp_QTextCharFormat_UnderlineStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCharFormat::UnderlineStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCharFormat::UnderlineStyle *>(cppOut) = value;

}
static PythonToCppFunc is_QTextCharFormat_UnderlineStyle_PythonToCpp_QTextCharFormat_UnderlineStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_UnderlineStyle_IDX])))
        return QTextCharFormat_UnderlineStyle_PythonToCpp_QTextCharFormat_UnderlineStyle;
    return {};
}
static PyObject *QTextCharFormat_UnderlineStyle_CppToPython_QTextCharFormat_UnderlineStyle(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QTextCharFormat::UnderlineStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_UnderlineStyle_IDX]), castCppIn);

}

static void QTextCharFormat_FontPropertiesInheritanceBehavior_PythonToCpp_QTextCharFormat_FontPropertiesInheritanceBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextCharFormat::FontPropertiesInheritanceBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextCharFormat::FontPropertiesInheritanceBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_QTextCharFormat_FontPropertiesInheritanceBehavior_PythonToCpp_QTextCharFormat_FontPropertiesInheritanceBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_FontPropertiesInheritanceBehavior_IDX])))
        return QTextCharFormat_FontPropertiesInheritanceBehavior_PythonToCpp_QTextCharFormat_FontPropertiesInheritanceBehavior;
    return {};
}
static PyObject *QTextCharFormat_FontPropertiesInheritanceBehavior_CppToPython_QTextCharFormat_FontPropertiesInheritanceBehavior(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QTextCharFormat::FontPropertiesInheritanceBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_FontPropertiesInheritanceBehavior_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextCharFormat_PythonToCpp_QTextCharFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextCharFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextCharFormat_PythonToCpp_QTextCharFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextCharFormat_TypeF()))
        return QTextCharFormat_PythonToCpp_QTextCharFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextCharFormat_PTR_CppToPython_QTextCharFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QTextCharFormat *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QTextCharFormat_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QTextCharFormat_COPY_CppToPython_QTextCharFormat(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextCharFormat *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextCharFormat_TypeF(), new ::QTextCharFormat(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextCharFormat_PythonToCpp_QTextCharFormat_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextCharFormat *>(cppOut) = *reinterpret_cast< ::QTextCharFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextCharFormat_PythonToCpp_QTextCharFormat_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextCharFormat_TypeF()))
        return QTextCharFormat_PythonToCpp_QTextCharFormat_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QTextCharFormat_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextCharFormat(self)",
    "1:PySide6.QtGui.QTextCharFormat(self,QTextCharFormat:PySide6.QtGui.QTextCharFormat)",
    "0:PySide6.QtGui.QTextCharFormat(self,fmt:PySide6.QtGui.QTextFormat)",
    "PySide6.QtGui.QTextCharFormat.anchorHref(self)->QString",
    "PySide6.QtGui.QTextCharFormat.anchorNames(self)->QStringList",
    "PySide6.QtGui.QTextCharFormat.baselineOffset(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtGui.QTextCharFormat.fontCapitalization(self)->PySide6.QtGui.QFont.Capitalization",
    "PySide6.QtGui.QTextCharFormat.fontFamilies(self)->QVariant",
    "PySide6.QtGui.QTextCharFormat.fontFamily(self)->QString",
    "PySide6.QtGui.QTextCharFormat.fontFixedPitch(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontHintingPreference(self)->PySide6.QtGui.QFont.HintingPreference",
    "PySide6.QtGui.QTextCharFormat.fontItalic(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontKerning(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontLetterSpacing(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.fontLetterSpacingType(self)->PySide6.QtGui.QFont.SpacingType",
    "PySide6.QtGui.QTextCharFormat.fontOverline(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontPointSize(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.fontStretch(self)->int",
    "PySide6.QtGui.QTextCharFormat.fontStrikeOut(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontStyleHint(self)->PySide6.QtGui.QFont.StyleHint",
    "PySide6.QtGui.QTextCharFormat.fontStyleName(self)->QVariant",
    "PySide6.QtGui.QTextCharFormat.fontStyleStrategy(self)->PySide6.QtGui.QFont.StyleStrategy",
    "PySide6.QtGui.QTextCharFormat.fontUnderline(self)->bool",
    "PySide6.QtGui.QTextCharFormat.fontWeight(self)->int",
    "PySide6.QtGui.QTextCharFormat.fontWordSpacing(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.isAnchor(self)->bool",
    "PySide6.QtGui.QTextCharFormat.isValid(self)->bool",
    "PySide6.QtGui.QTextCharFormat.setAnchor(self,anchor:bool)",
    "PySide6.QtGui.QTextCharFormat.setAnchorHref(self,value:QString)",
    "PySide6.QtGui.QTextCharFormat.setAnchorNames(self,names:QStringList)",
    "PySide6.QtGui.QTextCharFormat.setBaselineOffset(self,baseline:qreal)",
    "PySide6.QtGui.QTextCharFormat.setFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList],behavior:PySide6.QtGui.QTextCharFormat.FontPropertiesInheritanceBehavior=QTextCharFormat.FontPropertiesInheritanceBehavior.FontPropertiesAll)",
    "PySide6.QtGui.QTextCharFormat.setFontCapitalization(self,capitalization:PySide6.QtGui.QFont.Capitalization)",
    "PySide6.QtGui.QTextCharFormat.setFontFamilies(self,families:QStringList)",
    "PySide6.QtGui.QTextCharFormat.setFontFamily(self,family:QString)",
    "PySide6.QtGui.QTextCharFormat.setFontFixedPitch(self,fixedPitch:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontHintingPreference(self,hintingPreference:PySide6.QtGui.QFont.HintingPreference)",
    "PySide6.QtGui.QTextCharFormat.setFontItalic(self,italic:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontKerning(self,enable:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontLetterSpacing(self,spacing:qreal)",
    "PySide6.QtGui.QTextCharFormat.setFontLetterSpacingType(self,letterSpacingType:PySide6.QtGui.QFont.SpacingType)",
    "PySide6.QtGui.QTextCharFormat.setFontOverline(self,overline:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontPointSize(self,size:qreal)",
    "PySide6.QtGui.QTextCharFormat.setFontStretch(self,factor:int)",
    "PySide6.QtGui.QTextCharFormat.setFontStrikeOut(self,strikeOut:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontStyleHint(self,hint:PySide6.QtGui.QFont.StyleHint,strategy:PySide6.QtGui.QFont.StyleStrategy=QFont.PreferDefault)",
    "PySide6.QtGui.QTextCharFormat.setFontStyleName(self,styleName:QString)",
    "PySide6.QtGui.QTextCharFormat.setFontStyleStrategy(self,strategy:PySide6.QtGui.QFont.StyleStrategy)",
    "PySide6.QtGui.QTextCharFormat.setFontUnderline(self,underline:bool)",
    "PySide6.QtGui.QTextCharFormat.setFontWeight(self,weight:int)",
    "PySide6.QtGui.QTextCharFormat.setFontWordSpacing(self,spacing:qreal)",
    "PySide6.QtGui.QTextCharFormat.setSubScriptBaseline(self,baseline:qreal)",
    "PySide6.QtGui.QTextCharFormat.setSuperScriptBaseline(self,baseline:qreal)",
    "PySide6.QtGui.QTextCharFormat.setTableCellColumnSpan(self,tableCellColumnSpan:int)",
    "PySide6.QtGui.QTextCharFormat.setTableCellRowSpan(self,tableCellRowSpan:int)",
    "PySide6.QtGui.QTextCharFormat.setTextOutline(self,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtGui.QTextCharFormat.setToolTip(self,tip:QString)",
    "PySide6.QtGui.QTextCharFormat.setUnderlineColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGui.QTextCharFormat.setUnderlineStyle(self,style:PySide6.QtGui.QTextCharFormat.UnderlineStyle)",
    "PySide6.QtGui.QTextCharFormat.setVerticalAlignment(self,alignment:PySide6.QtGui.QTextCharFormat.VerticalAlignment)",
    "PySide6.QtGui.QTextCharFormat.subScriptBaseline(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.superScriptBaseline(self)->qreal",
    "PySide6.QtGui.QTextCharFormat.tableCellColumnSpan(self)->int",
    "PySide6.QtGui.QTextCharFormat.tableCellRowSpan(self)->int",
    "PySide6.QtGui.QTextCharFormat.textOutline(self)->PySide6.QtGui.QPen",
    "PySide6.QtGui.QTextCharFormat.toolTip(self)->QString",
    "PySide6.QtGui.QTextCharFormat.underlineColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QTextCharFormat.underlineStyle(self)->PySide6.QtGui.QTextCharFormat.UnderlineStyle",
    "PySide6.QtGui.QTextCharFormat.verticalAlignment(self)->PySide6.QtGui.QTextCharFormat.VerticalAlignment",
    "PySide6.QtGui.QTextCharFormat.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QTextCharFormat(PyObject *module)
{
    _Sbk_QTextCharFormat_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextCharFormat",
        "QTextCharFormat",
        &Sbk_QTextCharFormat_spec,
        &Shiboken::callCppDestructor< ::QTextCharFormat >,
        Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextCharFormat_TypeF(); // references _Sbk_QTextCharFormat_Type
    InitSignatureStrings(pyType, QTextCharFormat_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextCharFormat_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextCharFormat_PythonToCpp_QTextCharFormat_PTR,
        is_QTextCharFormat_PythonToCpp_QTextCharFormat_PTR_Convertible,
        QTextCharFormat_PTR_CppToPython_QTextCharFormat,
        QTextCharFormat_COPY_CppToPython_QTextCharFormat);

    Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat");
    Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat*");
    Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextCharFormat).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextCharFormat_PythonToCpp_QTextCharFormat_COPY,
        is_QTextCharFormat_PythonToCpp_QTextCharFormat_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextCharFormat_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'VerticalAlignment'.
    const char *VerticalAlignment_Initializer[] = {
        "AlignNormal",
        "AlignSuperScript",
        "AlignSubScript",
        "AlignMiddle",
        "AlignTop",
        "AlignBottom",
        "AlignBaseline",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t VerticalAlignment_InitializerValues[] = {
        uint8_t(QTextCharFormat::VerticalAlignment::AlignNormal),      //  0x00  0
        uint8_t(QTextCharFormat::VerticalAlignment::AlignSuperScript), //  0x01  1
        uint8_t(QTextCharFormat::VerticalAlignment::AlignSubScript),   //  0x02  2
        uint8_t(QTextCharFormat::VerticalAlignment::AlignMiddle),      //  0x03  3
        uint8_t(QTextCharFormat::VerticalAlignment::AlignTop),         //  0x04  4
        uint8_t(QTextCharFormat::VerticalAlignment::AlignBottom),      //  0x05  5
        uint8_t(QTextCharFormat::VerticalAlignment::AlignBaseline)     //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCharFormat_TypeF(),
        "2:PySide6.QtGui.QTextCharFormat.VerticalAlignment",
        VerticalAlignment_Initializer, VerticalAlignment_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_VerticalAlignment_IDX].type = EType;
    // Register converter for enum 'QTextCharFormat::VerticalAlignment'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCharFormat_VerticalAlignment_CppToPython_QTextCharFormat_VerticalAlignment);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QTextCharFormat_VerticalAlignment_PythonToCpp_QTextCharFormat_VerticalAlignment,
            is_QTextCharFormat_VerticalAlignment_PythonToCpp_QTextCharFormat_VerticalAlignment_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat::VerticalAlignment");
        Shiboken::Conversions::registerConverterName(converter, "VerticalAlignment");
    }
    // End of 'VerticalAlignment' enum.

    // Initialization of enum 'UnderlineStyle'.
    const char *UnderlineStyle_Initializer[] = {
        "NoUnderline",
        "SingleUnderline",
        "DashUnderline",
        "DotLine",
        "DashDotLine",
        "DashDotDotLine",
        "WaveUnderline",
        "SpellCheckUnderline",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UnderlineStyle_InitializerValues[] = {
        uint8_t(QTextCharFormat::UnderlineStyle::NoUnderline),        //  0x00  0
        uint8_t(QTextCharFormat::UnderlineStyle::SingleUnderline),    //  0x01  1
        uint8_t(QTextCharFormat::UnderlineStyle::DashUnderline),      //  0x02  2
        uint8_t(QTextCharFormat::UnderlineStyle::DotLine),            //  0x03  3
        uint8_t(QTextCharFormat::UnderlineStyle::DashDotLine),        //  0x04  4
        uint8_t(QTextCharFormat::UnderlineStyle::DashDotDotLine),     //  0x05  5
        uint8_t(QTextCharFormat::UnderlineStyle::WaveUnderline),      //  0x06  6
        uint8_t(QTextCharFormat::UnderlineStyle::SpellCheckUnderline) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCharFormat_TypeF(),
        "2:PySide6.QtGui.QTextCharFormat.UnderlineStyle",
        UnderlineStyle_Initializer, UnderlineStyle_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_UnderlineStyle_IDX].type = EType;
    // Register converter for enum 'QTextCharFormat::UnderlineStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCharFormat_UnderlineStyle_CppToPython_QTextCharFormat_UnderlineStyle);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QTextCharFormat_UnderlineStyle_PythonToCpp_QTextCharFormat_UnderlineStyle,
            is_QTextCharFormat_UnderlineStyle_PythonToCpp_QTextCharFormat_UnderlineStyle_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat::UnderlineStyle");
        Shiboken::Conversions::registerConverterName(converter, "UnderlineStyle");
    }
    // End of 'UnderlineStyle' enum.

    // Initialization of enum 'FontPropertiesInheritanceBehavior'.
    const char *FontPropertiesInheritanceBehavior_Initializer[] = {
        "FontPropertiesSpecifiedOnly",
        "FontPropertiesAll",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FontPropertiesInheritanceBehavior_InitializerValues[] = {
        uint8_t(QTextCharFormat::FontPropertiesInheritanceBehavior::FontPropertiesSpecifiedOnly), //  0x00  0
        uint8_t(QTextCharFormat::FontPropertiesInheritanceBehavior::FontPropertiesAll)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextCharFormat_TypeF(),
        "2:PySide6.QtGui.QTextCharFormat.FontPropertiesInheritanceBehavior",
        FontPropertiesInheritanceBehavior_Initializer, FontPropertiesInheritanceBehavior_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_FontPropertiesInheritanceBehavior_IDX].type = EType;
    // Register converter for enum 'QTextCharFormat::FontPropertiesInheritanceBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextCharFormat_FontPropertiesInheritanceBehavior_CppToPython_QTextCharFormat_FontPropertiesInheritanceBehavior);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QTextCharFormat_FontPropertiesInheritanceBehavior_PythonToCpp_QTextCharFormat_FontPropertiesInheritanceBehavior,
            is_QTextCharFormat_FontPropertiesInheritanceBehavior_PythonToCpp_QTextCharFormat_FontPropertiesInheritanceBehavior_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QTextCharFormat::FontPropertiesInheritanceBehavior");
        Shiboken::Conversions::registerConverterName(converter, "FontPropertiesInheritanceBehavior");
    }
    // End of 'FontPropertiesInheritanceBehavior' enum.

    qRegisterMetaType< ::QTextCharFormat >("QTextCharFormat");
    qRegisterMetaType< ::QTextCharFormat::VerticalAlignment >("QTextCharFormat::VerticalAlignment");
    qRegisterMetaType< ::QTextCharFormat::UnderlineStyle >("QTextCharFormat::UnderlineStyle");
    qRegisterMetaType< ::QTextCharFormat::FontPropertiesInheritanceBehavior >("QTextCharFormat::FontPropertiesInheritanceBehavior");

    return pyType;
}
