// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverresponder_wrapper.h"

// Argument includes
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qjsondocument.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QHttpServerResponderFunc_sendResponse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerResponder.sendResponse";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerResponder::sendResponse(QHttpServerResponse)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), (pyArg)))) {
        overloadId = 0; // sendResponse(QHttpServerResponse)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpServerResponse *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendResponse(QHttpServerResponse)
            cppSelf->sendResponse(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_write(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerResponder.write";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:write", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::write(QHttpServerResponder::StatusCode=)
    // 1: QHttpServerResponder::write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode=)
    // 2: QHttpServerResponder::write(QByteArray,QByteArray,QHttpServerResponder::StatusCode=)
    // 3: QHttpServerResponder::write(QJsonDocument,QHttpServerResponder::StatusCode=)
    if (numArgs == 0) {
        overloadId = 0; // write(QHttpServerResponder::StatusCode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // write(QJsonDocument,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // write(QJsonDocument,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 2; // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 1; // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // write(QHttpServerResponder::StatusCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // write(QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QHttpServerResponder::StatusCode cppArg0(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QHttpServerResponder::StatusCode)
                cppSelf->write(cppArg0);
            }
            break;
        }
        case 1: // write(QIODevice * data, const QByteArray & mimeType, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QIODevice*,QByteArray,QHttpServerResponder::StatusCode)
                cppSelf->write(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 2: // write(const QByteArray & data, const QByteArray & mimeType, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QHttpServerResponder::StatusCode cppArg2(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QByteArray,QByteArray,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 3: // write(const QJsonDocument & document, QHttpServerResponder::StatusCode status)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_status = Shiboken::String::createStaticString("status");
                if (PyDict_Contains(kwds, key_status) != 0) {
                    value = PyDict_GetItem(kwds, key_status);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_status);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_status);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJsonDocument cppArg0_local;
            ::QJsonDocument *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QHttpServerResponder::StatusCode cppArg1(QHttpServerResponder::StatusCode::Ok);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // write(QJsonDocument,QHttpServerResponder::StatusCode)
                cppSelf->write(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeBody(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerResponder.writeBody";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeBody", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::writeBody(QByteArray)
    // 1: QHttpServerResponder::writeBody(const char*)
    // 2: QHttpServerResponder::writeBody(const char*,qint64)
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // writeBody(const char*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
            overloadId = 2; // writeBody(const char*,qint64)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // writeBody(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeBody(const QByteArray & body)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBody(QByteArray)
                cppSelf->writeBody(*cppArg0);
            }
            break;
        }
        case 1: // writeBody(const char * body)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBody(const char*)
                cppSelf->writeBody(cppArg0);
            }
            break;
        }
        case 2: // writeBody(const char * body, qint64 size)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qint64 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeBody(const char*,qint64)
                cppSelf->writeBody(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeHeader(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerResponder.writeHeader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeHeader", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::writeHeader(QByteArray,QByteArray)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // writeHeader(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // writeHeader(QByteArray,QByteArray)
            cppSelf->writeHeader(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerResponderFunc_writeStatusLine(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerResponder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerResponder.writeStatusLine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:writeStatusLine", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerResponder::writeStatusLine(QHttpServerResponder::StatusCode=)
    if (numArgs == 0) {
        overloadId = 0; // writeStatusLine(QHttpServerResponder::StatusCode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // writeStatusLine(QHttpServerResponder::StatusCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_status = Shiboken::String::createStaticString("status");
            if (PyDict_Contains(kwds, key_status) != 0) {
                value = PyDict_GetItem(kwds, key_status);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_status);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_status);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QHttpServerResponder::StatusCode cppArg0(QHttpServerResponder::StatusCode::Ok);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeStatusLine(QHttpServerResponder::StatusCode)
            cppSelf->writeStatusLine(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHttpServerResponder_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHttpServerResponder_EnumFlagInfo[] = {
    "StatusCode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerResponder_methods[] = {
    {"sendResponse", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_sendResponse), METH_O, nullptr},
    {"write", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_write), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeBody", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeBody), METH_VARARGS, nullptr},
    {"writeHeader", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeHeader), METH_VARARGS, nullptr},
    {"writeStatusLine", reinterpret_cast<PyCFunction>(Sbk_QHttpServerResponderFunc_writeStatusLine), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerResponder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerResponder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerResponder_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerResponder_TypeF(void)
{
    return _Sbk_QHttpServerResponder_Type;
}

static PyType_Slot Sbk_QHttpServerResponder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerResponder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerResponder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerResponder_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerResponder_spec = {
    "2:PySide6.QtHttpServer.QHttpServerResponder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerResponder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QHttpServerResponder_StatusCode_PythonToCpp_QHttpServerResponder_StatusCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHttpServerResponder::StatusCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHttpServerResponder::StatusCode *>(cppOut) = value;

}
static PythonToCppFunc is_QHttpServerResponder_StatusCode_PythonToCpp_QHttpServerResponder_StatusCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX])))
        return QHttpServerResponder_StatusCode_PythonToCpp_QHttpServerResponder_StatusCode;
    return {};
}
static PyObject *QHttpServerResponder_StatusCode_CppToPython_QHttpServerResponder_StatusCode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QHttpServerResponder::StatusCode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerResponder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerResponder_TypeF()))
        return QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerResponder_PTR_CppToPython_QHttpServerResponder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QHttpServerResponder *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QHttpServerResponder_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttpServerResponder_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerResponder.sendResponse(self,response:PySide6.QtHttpServer.QHttpServerResponse)",
    "3:PySide6.QtHttpServer.QHttpServerResponder.write(self,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "2:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:PySide6.QtCore.QIODevice,mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "1:PySide6.QtHttpServer.QHttpServerResponder.write(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],mimeType:typing.Union[PySide6.QtCore.QByteArray, char*],status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "0:PySide6.QtHttpServer.QHttpServerResponder.write(self,document:PySide6.QtCore.QJsonDocument,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    "2:PySide6.QtHttpServer.QHttpServerResponder.writeBody(self,body:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtHttpServer.QHttpServerResponder.writeBody(self,body:char*)",
    "0:PySide6.QtHttpServer.QHttpServerResponder.writeBody(self,body:char*,size:qint64)",
    "PySide6.QtHttpServer.QHttpServerResponder.writeHeader(self,key:typing.Union[PySide6.QtCore.QByteArray, char*],value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtHttpServer.QHttpServerResponder.writeStatusLine(self,status:PySide6.QtHttpServer.QHttpServerResponder.StatusCode=QHttpServerResponder.StatusCode.Ok)",
    nullptr}; // Sentinel

PyTypeObject *init_QHttpServerResponder(PyObject *module)
{
    _Sbk_QHttpServerResponder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerResponder",
        "QHttpServerResponder*",
        &Sbk_QHttpServerResponder_spec,
        &Shiboken::callCppDestructor< ::QHttpServerResponder >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QHttpServerResponder_TypeF(); // references _Sbk_QHttpServerResponder_Type
    InitSignatureStrings(pyType, QHttpServerResponder_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerResponder_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR,
        is_QHttpServerResponder_PythonToCpp_QHttpServerResponder_PTR_Convertible,
        QHttpServerResponder_PTR_CppToPython_QHttpServerResponder);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerResponder).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHttpServerResponder_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StatusCode'.
    const char *StatusCode_Initializer[] = {
        "Continue",
        "SwitchingProtocols",
        "Processing",
        "Ok",
        "Created",
        "Accepted",
        "NonAuthoritativeInformation",
        "NoContent",
        "ResetContent",
        "PartialContent",
        "MultiStatus",
        "AlreadyReported",
        "IMUsed",
        "MultipleChoices",
        "MovedPermanently",
        "Found",
        "SeeOther",
        "NotModified",
        "UseProxy",
        "TemporaryRedirect",
        "PermanentRedirect",
        "BadRequest",
        "Unauthorized",
        "PaymentRequired",
        "Forbidden",
        "NotFound",
        "MethodNotAllowed",
        "NotAcceptable",
        "ProxyAuthenticationRequired",
        "RequestTimeout",
        "Conflict",
        "Gone",
        "LengthRequired",
        "PreconditionFailed",
        "PayloadTooLarge",
        "UriTooLong",
        "UnsupportedMediaType",
        "RequestRangeNotSatisfiable",
        "ExpectationFailed",
        "ImATeapot",
        "MisdirectedRequest",
        "UnprocessableEntity",
        "Locked",
        "FailedDependency",
        "UpgradeRequired",
        "PreconditionRequired",
        "TooManyRequests",
        "RequestHeaderFieldsTooLarge",
        "UnavailableForLegalReasons",
        "InternalServerError",
        "NotImplemented",
        "BadGateway",
        "ServiceUnavailable",
        "GatewayTimeout",
        "HttpVersionNotSupported",
        "VariantAlsoNegotiates",
        "InsufficientStorage",
        "LoopDetected",
        "NotExtended",
        "NetworkAuthenticationRequired",
        "NetworkConnectTimeoutError",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t StatusCode_InitializerValues[] = {
        int16_t(QHttpServerResponder::StatusCode::Continue),                      //  0x0064  100
        int16_t(QHttpServerResponder::StatusCode::SwitchingProtocols),            //  0x0065  101
        int16_t(QHttpServerResponder::StatusCode::Processing),                    //  0x0066  102
        int16_t(QHttpServerResponder::StatusCode::Ok),                            //  0x00c8  200
        int16_t(QHttpServerResponder::StatusCode::Created),                       //  0x00c9  201
        int16_t(QHttpServerResponder::StatusCode::Accepted),                      //  0x00ca  202
        int16_t(QHttpServerResponder::StatusCode::NonAuthoritativeInformation),   //  0x00cb  203
        int16_t(QHttpServerResponder::StatusCode::NoContent),                     //  0x00cc  204
        int16_t(QHttpServerResponder::StatusCode::ResetContent),                  //  0x00cd  205
        int16_t(QHttpServerResponder::StatusCode::PartialContent),                //  0x00ce  206
        int16_t(QHttpServerResponder::StatusCode::MultiStatus),                   //  0x00cf  207
        int16_t(QHttpServerResponder::StatusCode::AlreadyReported),               //  0x00d0  208
        int16_t(QHttpServerResponder::StatusCode::IMUsed),                        //  0x00e2  226
        int16_t(QHttpServerResponder::StatusCode::MultipleChoices),               //  0x012c  300
        int16_t(QHttpServerResponder::StatusCode::MovedPermanently),              //  0x012d  301
        int16_t(QHttpServerResponder::StatusCode::Found),                         //  0x012e  302
        int16_t(QHttpServerResponder::StatusCode::SeeOther),                      //  0x012f  303
        int16_t(QHttpServerResponder::StatusCode::NotModified),                   //  0x0130  304
        int16_t(QHttpServerResponder::StatusCode::UseProxy),                      //  0x0131  305
        int16_t(QHttpServerResponder::StatusCode::TemporaryRedirect),             //  0x0133  307
        int16_t(QHttpServerResponder::StatusCode::PermanentRedirect),             //  0x0134  308
        int16_t(QHttpServerResponder::StatusCode::BadRequest),                    //  0x0190  400
        int16_t(QHttpServerResponder::StatusCode::Unauthorized),                  //  0x0191  401
        int16_t(QHttpServerResponder::StatusCode::PaymentRequired),               //  0x0192  402
        int16_t(QHttpServerResponder::StatusCode::Forbidden),                     //  0x0193  403
        int16_t(QHttpServerResponder::StatusCode::NotFound),                      //  0x0194  404
        int16_t(QHttpServerResponder::StatusCode::MethodNotAllowed),              //  0x0195  405
        int16_t(QHttpServerResponder::StatusCode::NotAcceptable),                 //  0x0196  406
        int16_t(QHttpServerResponder::StatusCode::ProxyAuthenticationRequired),   //  0x0197  407
        int16_t(QHttpServerResponder::StatusCode::RequestTimeout),                //  0x0198  408
        int16_t(QHttpServerResponder::StatusCode::Conflict),                      //  0x0199  409
        int16_t(QHttpServerResponder::StatusCode::Gone),                          //  0x019a  410
        int16_t(QHttpServerResponder::StatusCode::LengthRequired),                //  0x019b  411
        int16_t(QHttpServerResponder::StatusCode::PreconditionFailed),            //  0x019c  412
        int16_t(QHttpServerResponder::StatusCode::PayloadTooLarge),               //  0x019d  413
        int16_t(QHttpServerResponder::StatusCode::UriTooLong),                    //  0x019e  414
        int16_t(QHttpServerResponder::StatusCode::UnsupportedMediaType),          //  0x019f  415
        int16_t(QHttpServerResponder::StatusCode::RequestRangeNotSatisfiable),    //  0x01a0  416
        int16_t(QHttpServerResponder::StatusCode::ExpectationFailed),             //  0x01a1  417
        int16_t(QHttpServerResponder::StatusCode::ImATeapot),                     //  0x01a2  418
        int16_t(QHttpServerResponder::StatusCode::MisdirectedRequest),            //  0x01a5  421
        int16_t(QHttpServerResponder::StatusCode::UnprocessableEntity),           //  0x01a6  422
        int16_t(QHttpServerResponder::StatusCode::Locked),                        //  0x01a7  423
        int16_t(QHttpServerResponder::StatusCode::FailedDependency),              //  0x01a8  424
        int16_t(QHttpServerResponder::StatusCode::UpgradeRequired),               //  0x01aa  426
        int16_t(QHttpServerResponder::StatusCode::PreconditionRequired),          //  0x01ac  428
        int16_t(QHttpServerResponder::StatusCode::TooManyRequests),               //  0x01ad  429
        int16_t(QHttpServerResponder::StatusCode::RequestHeaderFieldsTooLarge),   //  0x01af  431
        int16_t(QHttpServerResponder::StatusCode::UnavailableForLegalReasons),    //  0x01c3  451
        int16_t(QHttpServerResponder::StatusCode::InternalServerError),           //  0x01f4  500
        int16_t(QHttpServerResponder::StatusCode::NotImplemented),                //  0x01f5  501
        int16_t(QHttpServerResponder::StatusCode::BadGateway),                    //  0x01f6  502
        int16_t(QHttpServerResponder::StatusCode::ServiceUnavailable),            //  0x01f7  503
        int16_t(QHttpServerResponder::StatusCode::GatewayTimeout),                //  0x01f8  504
        int16_t(QHttpServerResponder::StatusCode::HttpVersionNotSupported),       //  0x01f9  505
        int16_t(QHttpServerResponder::StatusCode::VariantAlsoNegotiates),         //  0x01fa  506
        int16_t(QHttpServerResponder::StatusCode::InsufficientStorage),           //  0x01fb  507
        int16_t(QHttpServerResponder::StatusCode::LoopDetected),                  //  0x01fc  508
        int16_t(QHttpServerResponder::StatusCode::NotExtended),                   //  0x01fe  510
        int16_t(QHttpServerResponder::StatusCode::NetworkAuthenticationRequired), //  0x01ff  511
        int16_t(QHttpServerResponder::StatusCode::NetworkConnectTimeoutError)     //  0x0257  599
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHttpServerResponder_TypeF(),
        "2:PySide6.QtHttpServer.QHttpServerResponder.StatusCode",
        StatusCode_Initializer, StatusCode_InitializerValues);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_StatusCode_IDX].type = EType;
    // Register converter for enum 'QHttpServerResponder::StatusCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHttpServerResponder_StatusCode_CppToPython_QHttpServerResponder_StatusCode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QHttpServerResponder_StatusCode_PythonToCpp_QHttpServerResponder_StatusCode,
            is_QHttpServerResponder_StatusCode_PythonToCpp_QHttpServerResponder_StatusCode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QHttpServerResponder::StatusCode");
        Shiboken::Conversions::registerConverterName(converter, "StatusCode");
    }
    // End of 'StatusCode' enum.

    qRegisterMetaType< ::QHttpServerResponder *>();
    qRegisterMetaType< ::QHttpServerResponder::StatusCode >("QHttpServerResponder::StatusCode");

    return pyType;
}
