// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserverrouter_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QHash>
#include <QString>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <qmetatype.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpServerRouter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttpServerRouter >()))
        return -1;

    ::QHttpServerRouter *cptr{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QHttpServerRouter()
            cptr = new ::QHttpServerRouter();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttpServerRouter >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttpServerRouterFunc_addConverter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.addConverter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addConverter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouter::addConverter(QMetaType,QAnyStringView)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addConverter(QMetaType,QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addConverter(QMetaType,QAnyStringView)
            cppSelf->addConverter(cppArg0, QAnyStringView(cppArg1));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerRouterFunc_clearConverters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.clearConverters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearConverters()
            cppSelf->clearConverters();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerRouterFunc_converters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.converters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // converters()const
            const QHash<QMetaType,QString> & cppResult = const_cast<const ::QHttpServerRouter *>(cppSelf)->converters();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QHash_QMetaType_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterFunc_handleRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.handleRequest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "handleRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServerRouter::handleRequest(QHttpServerRequest,QHttpServerResponder&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), (pyArgs[1])))) {
        overloadId = 0; // handleRequest(QHttpServerRequest,QHttpServerResponder&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHttpServerRequest *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QHttpServerResponder *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleRequest(QHttpServerRequest,QHttpServerResponder&)const
            bool cppResult = const_cast<const ::QHttpServerRouter *>(cppSelf)->handleRequest(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerRouterFunc_removeConverter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServerRouter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServerRouter.removeConverter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServerRouter::removeConverter(QMetaType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), (pyArg)))) {
        overloadId = 0; // removeConverter(QMetaType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaType cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeConverter(QMetaType)
            cppSelf->removeConverter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QHttpServerRouter_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServerRouter_methods[] = {
    {"addConverter", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_addConverter), METH_VARARGS, nullptr},
    {"clearConverters", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_clearConverters), METH_NOARGS, nullptr},
    {"converters", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_converters), METH_NOARGS, nullptr},
    {"handleRequest", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_handleRequest), METH_VARARGS, nullptr},
    {"removeConverter", reinterpret_cast<PyCFunction>(Sbk_QHttpServerRouterFunc_removeConverter), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpServerRouter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServerRouter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServerRouter_Type = nullptr;
static PyTypeObject *Sbk_QHttpServerRouter_TypeF(void)
{
    return _Sbk_QHttpServerRouter_Type;
}

static PyType_Slot Sbk_QHttpServerRouter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServerRouter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServerRouter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServerRouter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttpServerRouter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServerRouter_spec = {
    "2:PySide6.QtHttpServer.QHttpServerRouter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServerRouter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServerRouter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServerRouter_TypeF()))
        return QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServerRouter_PTR_CppToPython_QHttpServerRouter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QHttpServerRouter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QHttpServerRouter_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttpServerRouter_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServerRouter(self)",
    "PySide6.QtHttpServer.QHttpServerRouter.addConverter(self,metaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type],regexp:QString)",
    "PySide6.QtHttpServer.QHttpServerRouter.clearConverters(self)",
    "PySide6.QtHttpServer.QHttpServerRouter.converters(self)->QHash[PySide6.QtCore.QMetaType, QString]",
    "PySide6.QtHttpServer.QHttpServerRouter.handleRequest(self,request:PySide6.QtHttpServer.QHttpServerRequest,responder:PySide6.QtHttpServer.QHttpServerResponder)->bool",
    "PySide6.QtHttpServer.QHttpServerRouter.removeConverter(self,metaType:typing.Union[PySide6.QtCore.QMetaType, PySide6.QtCore.QMetaType.Type])",
    nullptr}; // Sentinel

PyTypeObject *init_QHttpServerRouter(PyObject *module)
{
    _Sbk_QHttpServerRouter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServerRouter",
        "QHttpServerRouter*",
        &Sbk_QHttpServerRouter_spec,
        &Shiboken::callCppDestructor< ::QHttpServerRouter >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QHttpServerRouter_TypeF(); // references _Sbk_QHttpServerRouter_Type
    InitSignatureStrings(pyType, QHttpServerRouter_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServerRouter_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR,
        is_QHttpServerRouter_PythonToCpp_QHttpServerRouter_PTR_Convertible,
        QHttpServerRouter_PTR_CppToPython_QHttpServerRouter);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServerRouter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServerRouter).name());

    qRegisterMetaType< ::QHttpServerRouter *>();

    return pyType;
}
