// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplacesearchresult_wrapper.h"

// Argument includes
#include <QString>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplacesearchresult.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPlaceSearchResultWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPlaceSearchResultWrapper::QPlaceSearchResultWrapper() : QPlaceSearchResult()
{
    resetPyMethodCache();
    // ... middle
}

QPlaceSearchResultWrapper::~QPlaceSearchResultWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceSearchResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceSearchResult >()))
        return -1;

    ::QPlaceSearchResultWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceSearchResult", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceSearchResult::QPlaceSearchResult()
    // 1: QPlaceSearchResult::QPlaceSearchResult(QPlaceSearchResult)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceSearchResult()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceSearchResult(QPlaceSearchResult)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceSearchResult()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceSearchResult()
                cptr = new ::QPlaceSearchResultWrapper();
            }
            break;
        }
        case 1: // QPlaceSearchResult(const QPlaceSearchResult & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceSearchResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceSearchResult(QPlaceSearchResult)
                cptr = new ::QPlaceSearchResultWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceSearchResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceSearchResultFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.icon";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // icon()const
            QPlaceIcon cppResult = const_cast<const ::QPlaceSearchResult *>(cppSelf)->icon();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchResultFunc_setIcon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.setIcon";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchResult::setIcon(QPlaceIcon)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceIcon_IDX]), (pyArg)))) {
        overloadId = 0; // setIcon(QPlaceIcon)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceIcon cppArg0_local;
        ::QPlaceIcon *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIcon(QPlaceIcon)
            cppSelf->setIcon(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchResultFunc_setTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.setTitle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchResult::setTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTitle(QString)
            cppSelf->setTitle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchResultFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.title";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // title()const
            QString cppResult = const_cast<const ::QPlaceSearchResult *>(cppSelf)->title();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchResultFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchResult.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QPlaceSearchResult::SearchResultType cppResult = const_cast<const ::QPlaceSearchResult *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_SearchResultType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlaceSearchResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPlaceSearchResult_EnumFlagInfo[] = {
    "SearchResultType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceSearchResult_methods[] = {
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchResultFunc_icon), METH_NOARGS, nullptr},
    {"setIcon", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchResultFunc_setIcon), METH_O, nullptr},
    {"setTitle", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchResultFunc_setTitle), METH_O, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchResultFunc_title), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchResultFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPlaceSearchResult_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPlaceSearchResultWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_QPlaceSearchResult_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceSearchResult *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), (pyArg)))) {
                // operator!=(const QPlaceSearchResult & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceSearchResult *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX]), (pyArg)))) {
                // operator==(const QPlaceSearchResult & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceSearchResult *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceSearchResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceSearchResult_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceSearchResult_Type = nullptr;
static PyTypeObject *Sbk_QPlaceSearchResult_TypeF(void)
{
    return _Sbk_QPlaceSearchResult_Type;
}

static PyType_Slot Sbk_QPlaceSearchResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPlaceSearchResult_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceSearchResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceSearchResult_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceSearchResult_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceSearchResult_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceSearchResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceSearchResult_spec = {
    "2:PySide6.QtLocation.QPlaceSearchResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceSearchResult_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QPlaceSearchResult_SearchResultType_PythonToCpp_QPlaceSearchResult_SearchResultType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlaceSearchResult::SearchResultType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlaceSearchResult::SearchResultType *>(cppOut) = value;

}
static PythonToCppFunc is_QPlaceSearchResult_SearchResultType_PythonToCpp_QPlaceSearchResult_SearchResultType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_SearchResultType_IDX])))
        return QPlaceSearchResult_SearchResultType_PythonToCpp_QPlaceSearchResult_SearchResultType;
    return {};
}
static PyObject *QPlaceSearchResult_SearchResultType_CppToPython_QPlaceSearchResult_SearchResultType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPlaceSearchResult::SearchResultType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_SearchResultType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceSearchResult_PythonToCpp_QPlaceSearchResult_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceSearchResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceSearchResult_PythonToCpp_QPlaceSearchResult_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceSearchResult_TypeF()))
        return QPlaceSearchResult_PythonToCpp_QPlaceSearchResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceSearchResult_PTR_CppToPython_QPlaceSearchResult(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QPlaceSearchResult *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QPlaceSearchResult_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPlaceSearchResult_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceSearchResult(self)",
    "0:PySide6.QtLocation.QPlaceSearchResult(self,other:PySide6.QtLocation.QPlaceSearchResult)",
    "PySide6.QtLocation.QPlaceSearchResult.icon(self)->PySide6.QtLocation.QPlaceIcon",
    "PySide6.QtLocation.QPlaceSearchResult.setIcon(self,icon:PySide6.QtLocation.QPlaceIcon)",
    "PySide6.QtLocation.QPlaceSearchResult.setTitle(self,title:QString)",
    "PySide6.QtLocation.QPlaceSearchResult.title(self)->QString",
    "PySide6.QtLocation.QPlaceSearchResult.type(self)->PySide6.QtLocation.QPlaceSearchResult.SearchResultType",
    nullptr}; // Sentinel

PyTypeObject *init_QPlaceSearchResult(PyObject *module)
{
    _Sbk_QPlaceSearchResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceSearchResult",
        "QPlaceSearchResult*",
        &Sbk_QPlaceSearchResult_spec,
        &Shiboken::callCppDestructor< ::QPlaceSearchResult >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QPlaceSearchResult_TypeF(); // references _Sbk_QPlaceSearchResult_Type
    InitSignatureStrings(pyType, QPlaceSearchResult_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceSearchResult_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceSearchResult_PythonToCpp_QPlaceSearchResult_PTR,
        is_QPlaceSearchResult_PythonToCpp_QPlaceSearchResult_PTR_Convertible,
        QPlaceSearchResult_PTR_CppToPython_QPlaceSearchResult);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchResult");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchResult*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceSearchResult).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceSearchResultWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPlaceSearchResult_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SearchResultType'.
    const char *SearchResultType_Initializer[] = {
        "UnknownSearchResult",
        "PlaceResult",
        "ProposedSearchResult",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SearchResultType_InitializerValues[] = {
        uint8_t(QPlaceSearchResult::SearchResultType::UnknownSearchResult), //  0x00  0
        uint8_t(QPlaceSearchResult::SearchResultType::PlaceResult),         //  0x01  1
        uint8_t(QPlaceSearchResult::SearchResultType::ProposedSearchResult) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlaceSearchResult_TypeF(),
        "2:PySide6.QtLocation.QPlaceSearchResult.SearchResultType",
        SearchResultType_Initializer, SearchResultType_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchResult_SearchResultType_IDX].type = EType;
    // Register converter for enum 'QPlaceSearchResult::SearchResultType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlaceSearchResult_SearchResultType_CppToPython_QPlaceSearchResult_SearchResultType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QPlaceSearchResult_SearchResultType_PythonToCpp_QPlaceSearchResult_SearchResultType,
            is_QPlaceSearchResult_SearchResultType_PythonToCpp_QPlaceSearchResult_SearchResultType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchResult::SearchResultType");
        Shiboken::Conversions::registerConverterName(converter, "SearchResultType");
    }
    // End of 'SearchResultType' enum.

    qRegisterMetaType< ::QPlaceSearchResult *>();
    qRegisterMetaType< ::QPlaceSearchResult::SearchResultType >("QPlaceSearchResult::SearchResultType");

    return pyType;
}
