// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qcameradevice_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtMultimedia/qcameradevice.h>
#include <QtMultimedia/qtvideo.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCameraDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCameraDevice >()))
        return -1;

    ::QCameraDevice *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCameraDevice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCameraDevice::QCameraDevice()
    // 1: QCameraDevice::QCameraDevice(QCameraDevice)
    if (numArgs == 0) {
        overloadId = 0; // QCameraDevice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCameraDevice(QCameraDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCameraDevice()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCameraDevice()
                cptr = new ::QCameraDevice();
            }
            break;
        }
        case 1: // QCameraDevice(const QCameraDevice & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCameraDevice cppArg0_local;
            ::QCameraDevice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCameraDevice(QCameraDevice)
                cptr = new ::QCameraDevice(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCameraDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCameraDeviceFunc_correctionAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.correctionAngle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // correctionAngle()const
            QtVideo::Rotation cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->correctionAngle();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtVideo_Rotation_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.id";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // id()const
            QByteArray cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->id();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.isDefault";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDefault()const
            bool cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->isDefault();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_photoResolutions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.photoResolutions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // photoResolutions()const
            QList<QSize> cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->photoResolutions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QSize_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.position";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // position()const
            QCameraDevice::Position cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->position();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDeviceFunc_videoFormats(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCameraDevice.videoFormats";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // videoFormats()const
            QList<QCameraFormat> cppResult = const_cast<const ::QCameraDevice *>(cppSelf)->videoFormats();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QCameraFormat_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraDevice__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCameraDevice_PropertyStrings[] = {
    "correctionAngle:",
    "description:",
    "id:",
    "isDefault:",
    "position:",
    "videoFormats:",
    nullptr // Sentinel
};

static const char *Sbk_QCameraDevice_EnumFlagInfo[] = {
    "Position:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCameraDevice_methods[] = {
    {"correctionAngle", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_correctionAngle), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_description), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_id), METH_NOARGS, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_isDefault), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_isNull), METH_NOARGS, nullptr},
    {"photoResolutions", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_photoResolutions), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_position), METH_NOARGS, nullptr},
    {"videoFormats", reinterpret_cast<PyCFunction>(Sbk_QCameraDeviceFunc_videoFormats), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCameraDevice__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCameraDevice___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QCameraDevice_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArg)))) {
                // operator!=(const QCameraDevice & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraDevice cppArg0_local;
                ::QCameraDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArg)))) {
                // operator==(const QCameraDevice & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCameraDevice cppArg0_local;
                ::QCameraDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QCameraDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCameraDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCameraDevice__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCameraDevice_Type = nullptr;
static PyTypeObject *Sbk_QCameraDevice_TypeF(void)
{
    return _Sbk_QCameraDevice_Type;
}

static PyType_Slot Sbk_QCameraDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCameraDevice__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCameraDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCameraDevice_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCameraDevice_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCameraDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCameraDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QCameraDevice___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCameraDevice_spec = {
    "2:PySide6.QtMultimedia.QCameraDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCameraDevice_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCameraDevice_Position_PythonToCpp_QCameraDevice_Position(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCameraDevice::Position>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCameraDevice::Position *>(cppOut) = value;

}
static PythonToCppFunc is_QCameraDevice_Position_PythonToCpp_QCameraDevice_Position_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX])))
        return QCameraDevice_Position_PythonToCpp_QCameraDevice_Position;
    return {};
}
static PyObject *QCameraDevice_Position_CppToPython_QCameraDevice_Position(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCameraDevice::Position *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCameraDevice_PythonToCpp_QCameraDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCameraDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCameraDevice_PythonToCpp_QCameraDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraDevice_TypeF()))
        return QCameraDevice_PythonToCpp_QCameraDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCameraDevice_PTR_CppToPython_QCameraDevice(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QCameraDevice *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QCameraDevice_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QCameraDevice_COPY_CppToPython_QCameraDevice(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCameraDevice *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCameraDevice_TypeF(), new ::QCameraDevice(*source), true, true);
}

// Python to C++ copy conversion.
static void QCameraDevice_PythonToCpp_QCameraDevice_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCameraDevice *>(cppOut) = *reinterpret_cast< ::QCameraDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCameraDevice_PythonToCpp_QCameraDevice_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCameraDevice_TypeF()))
        return QCameraDevice_PythonToCpp_QCameraDevice_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCameraDevice_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QCameraDevice(self)",
    "0:PySide6.QtMultimedia.QCameraDevice(self,other:PySide6.QtMultimedia.QCameraDevice)",
    "PySide6.QtMultimedia.QCameraDevice.correctionAngle(self)->PySide6.QtMultimedia.QtVideo.Rotation",
    "PySide6.QtMultimedia.QCameraDevice.description(self)->QString",
    "PySide6.QtMultimedia.QCameraDevice.id(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtMultimedia.QCameraDevice.isDefault(self)->bool",
    "PySide6.QtMultimedia.QCameraDevice.isNull(self)->bool",
    "PySide6.QtMultimedia.QCameraDevice.photoResolutions(self)->QList[PySide6.QtCore.QSize]",
    "PySide6.QtMultimedia.QCameraDevice.position(self)->PySide6.QtMultimedia.QCameraDevice.Position",
    "PySide6.QtMultimedia.QCameraDevice.videoFormats(self)->QList[PySide6.QtMultimedia.QCameraFormat]",
    "PySide6.QtMultimedia.QCameraDevice.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QCameraDevice(PyObject *module)
{
    _Sbk_QCameraDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCameraDevice",
        "QCameraDevice",
        &Sbk_QCameraDevice_spec,
        &Shiboken::callCppDestructor< ::QCameraDevice >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCameraDevice_TypeF(); // references _Sbk_QCameraDevice_Type
    InitSignatureStrings(pyType, QCameraDevice_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCameraDevice_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCameraDevice_PythonToCpp_QCameraDevice_PTR,
        is_QCameraDevice_PythonToCpp_QCameraDevice_PTR_Convertible,
        QCameraDevice_PTR_CppToPython_QCameraDevice,
        QCameraDevice_COPY_CppToPython_QCameraDevice);

    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice");
    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QCameraDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCameraDevice).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCameraDevice_PythonToCpp_QCameraDevice_COPY,
        is_QCameraDevice_PythonToCpp_QCameraDevice_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCameraDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Position'.
    const char *Position_Initializer[] = {
        "UnspecifiedPosition",
        "BackFace",
        "FrontFace",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Position_InitializerValues[] = {
        uint8_t(QCameraDevice::Position::UnspecifiedPosition), //  0x00  0
        uint8_t(QCameraDevice::Position::BackFace),            //  0x01  1
        uint8_t(QCameraDevice::Position::FrontFace)            //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCameraDevice_TypeF(),
        "2:PySide6.QtMultimedia.QCameraDevice.Position",
        Position_Initializer, Position_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX].type = EType;
    // Register converter for enum 'QCameraDevice::Position'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCameraDevice_Position_CppToPython_QCameraDevice_Position);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCameraDevice_Position_PythonToCpp_QCameraDevice_Position,
            is_QCameraDevice_Position_PythonToCpp_QCameraDevice_Position_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCameraDevice::Position");
        Shiboken::Conversions::registerConverterName(converter, "Position");
    }
    // End of 'Position' enum.

    qRegisterMetaType< ::QCameraDevice >("QCameraDevice");
    qRegisterMetaType< ::QCameraDevice::Position >("QCameraDevice::Position");

    return pyType;
}
