// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhttp2configuration_wrapper.h"

// Argument includes
#include <QtNetwork/qhttp2configuration.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttp2Configuration_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttp2Configuration >()))
        return -1;

    ::QHttp2Configuration *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHttp2Configuration", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttp2Configuration::QHttp2Configuration()
    // 1: QHttp2Configuration::QHttp2Configuration(QHttp2Configuration)
    if (numArgs == 0) {
        overloadId = 0; // QHttp2Configuration()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHttp2Configuration(QHttp2Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHttp2Configuration()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttp2Configuration()
                cptr = new ::QHttp2Configuration();
            }
            break;
        }
        case 1: // QHttp2Configuration(const QHttp2Configuration & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHttp2Configuration cppArg0_local;
            ::QHttp2Configuration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttp2Configuration(QHttp2Configuration)
                cptr = new ::QHttp2Configuration(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttp2Configuration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_huffmanCompressionEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.huffmanCompressionEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // huffmanCompressionEnabled()const
            bool cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->huffmanCompressionEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_maxFrameSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.maxFrameSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxFrameSize()const
            unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->maxFrameSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_serverPushEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.serverPushEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serverPushEnabled()const
            bool cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->serverPushEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_sessionReceiveWindowSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.sessionReceiveWindowSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sessionReceiveWindowSize()const
            unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->sessionReceiveWindowSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setHuffmanCompressionEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.setHuffmanCompressionEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setHuffmanCompressionEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHuffmanCompressionEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHuffmanCompressionEnabled(bool)
            cppSelf->setHuffmanCompressionEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setMaxFrameSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.setMaxFrameSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setMaxFrameSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setMaxFrameSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxFrameSize(uint)
            bool cppResult = cppSelf->setMaxFrameSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setServerPushEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.setServerPushEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setServerPushEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setServerPushEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setServerPushEnabled(bool)
            cppSelf->setServerPushEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setSessionReceiveWindowSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.setSessionReceiveWindowSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setSessionReceiveWindowSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setSessionReceiveWindowSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSessionReceiveWindowSize(uint)
            bool cppResult = cppSelf->setSessionReceiveWindowSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_setStreamReceiveWindowSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.setStreamReceiveWindowSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::setStreamReceiveWindowSize(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setStreamReceiveWindowSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStreamReceiveWindowSize(uint)
            bool cppResult = cppSelf->setStreamReceiveWindowSize(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_streamReceiveWindowSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.streamReceiveWindowSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // streamReceiveWindowSize()const
            unsigned int cppResult = const_cast<const ::QHttp2Configuration *>(cppSelf)->streamReceiveWindowSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp2ConfigurationFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp2Configuration.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp2Configuration::swap(QHttp2Configuration&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttp2Configuration&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp2Configuration cppArg0_local;
        ::QHttp2Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttp2Configuration&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp2Configuration__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttp2Configuration_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttp2Configuration_methods[] = {
    {"huffmanCompressionEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_huffmanCompressionEnabled), METH_NOARGS, nullptr},
    {"maxFrameSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_maxFrameSize), METH_NOARGS, nullptr},
    {"serverPushEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_serverPushEnabled), METH_NOARGS, nullptr},
    {"sessionReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_sessionReceiveWindowSize), METH_NOARGS, nullptr},
    {"setHuffmanCompressionEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setHuffmanCompressionEnabled), METH_O, nullptr},
    {"setMaxFrameSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setMaxFrameSize), METH_O, nullptr},
    {"setServerPushEnabled", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setServerPushEnabled), METH_O, nullptr},
    {"setSessionReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setSessionReceiveWindowSize), METH_O, nullptr},
    {"setStreamReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_setStreamReceiveWindowSize), METH_O, nullptr},
    {"streamReceiveWindowSize", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_streamReceiveWindowSize), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttp2ConfigurationFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHttp2Configuration__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QHttp2Configuration_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
                // operator!=(const QHttp2Configuration & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp2Configuration cppArg0_local;
                ::QHttp2Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), (pyArg)))) {
                // operator==(const QHttp2Configuration & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp2Configuration cppArg0_local;
                ::QHttp2Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QHttp2Configuration_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttp2Configuration_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttp2Configuration_Type = nullptr;
static PyTypeObject *Sbk_QHttp2Configuration_TypeF(void)
{
    return _Sbk_QHttp2Configuration_Type;
}

static PyType_Slot Sbk_QHttp2Configuration_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttp2Configuration_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttp2Configuration_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHttp2Configuration_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttp2Configuration_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttp2Configuration_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttp2Configuration_spec = {
    "2:PySide6.QtNetwork.QHttp2Configuration",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttp2Configuration_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttp2Configuration_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp2Configuration_TypeF()))
        return QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttp2Configuration_PTR_CppToPython_QHttp2Configuration(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QHttp2Configuration *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QHttp2Configuration_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QHttp2Configuration_COPY_CppToPython_QHttp2Configuration(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHttp2Configuration *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHttp2Configuration_TypeF(), new ::QHttp2Configuration(*source), true, true);
}

// Python to C++ copy conversion.
static void QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHttp2Configuration *>(cppOut) = *reinterpret_cast< ::QHttp2Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp2Configuration_TypeF()))
        return QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttp2Configuration_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QHttp2Configuration(self)",
    "0:PySide6.QtNetwork.QHttp2Configuration(self,other:PySide6.QtNetwork.QHttp2Configuration)",
    "PySide6.QtNetwork.QHttp2Configuration.huffmanCompressionEnabled(self)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.maxFrameSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.serverPushEnabled(self)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.sessionReceiveWindowSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.setHuffmanCompressionEnabled(self,enable:bool)",
    "PySide6.QtNetwork.QHttp2Configuration.setMaxFrameSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.setServerPushEnabled(self,enable:bool)",
    "PySide6.QtNetwork.QHttp2Configuration.setSessionReceiveWindowSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.setStreamReceiveWindowSize(self,size:unsigned int)->bool",
    "PySide6.QtNetwork.QHttp2Configuration.streamReceiveWindowSize(self)->unsigned int",
    "PySide6.QtNetwork.QHttp2Configuration.swap(self,other:PySide6.QtNetwork.QHttp2Configuration)",
    "PySide6.QtNetwork.QHttp2Configuration.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QHttp2Configuration(PyObject *module)
{
    _Sbk_QHttp2Configuration_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttp2Configuration",
        "QHttp2Configuration",
        &Sbk_QHttp2Configuration_spec,
        &Shiboken::callCppDestructor< ::QHttp2Configuration >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHttp2Configuration_TypeF(); // references _Sbk_QHttp2Configuration_Type
    InitSignatureStrings(pyType, QHttp2Configuration_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttp2Configuration_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHttp2Configuration_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR,
        is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_PTR_Convertible,
        QHttp2Configuration_PTR_CppToPython_QHttp2Configuration,
        QHttp2Configuration_COPY_CppToPython_QHttp2Configuration);

    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration");
    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration*");
    Shiboken::Conversions::registerConverterName(converter, "QHttp2Configuration&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttp2Configuration).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY,
        is_QHttp2Configuration_PythonToCpp_QHttp2Configuration_COPY_Convertible);

    qRegisterMetaType< ::QHttp2Configuration >("QHttp2Configuration");

    return pyType;
}
