// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qipv6address_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIPv6Address_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QIPv6Address >()))
        return -1;

    ::QIPv6Address *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QIPv6Address.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QIPv6Address", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QIPv6Address::QIPv6Address()
    // 1: QIPv6Address::QIPv6Address(QIPv6Address)
    if (numArgs == 0) {
        overloadId = 0; // QIPv6Address()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QIPv6Address(QIPv6Address)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QIPv6Address()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QIPv6Address()
                cptr = new ::QIPv6Address();
            }
            break;
        }
        case 1: // QIPv6Address(const QIPv6Address & QIPv6Address)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIPv6Address cppArg0_local;
            ::QIPv6Address *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QIPv6Address(QIPv6Address)
                cptr = new ::QIPv6Address(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QIPv6Address >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QIPv6Address__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QIPv6Address *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QIPv6Address_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QIPv6Address_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QIPv6Address__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

Py_ssize_t Sbk_QIPv6AddressFunc___len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QIPv6Address *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-len)]
    return 16;
    // END of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-len)]
    // ========================================================================
    // End of code injection

}

PyObject* Sbk_QIPv6AddressFunc___getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QIPv6Address *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-getitem)]
    if (_i >= 16) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    if (_i < 0)
        _i = 16 - qAbs(_i);

    uint item = cppSelf->c[_i];
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &item);
    // END of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-getitem)]
    // ========================================================================
    // End of code injection

}

int Sbk_QIPv6AddressFunc___setitem__(PyObject *self, Py_ssize_t _i, PyObject *_value)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QIPv6Address *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-setitem)]
    if (_i >= 16) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return -1;
    }
    if (_i < 0)
        _i = 16 - qAbs(_i);
    quint8 item;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), _value, &(item));
    cppSelf->c[_i] = item;
    return 0;
    // END of custom code block [file: ../glue/qtnetwork.cpp (qipv6address-setitem)]
    // ========================================================================
    // End of code injection

}

} // extern "C"

static int Sbk_QIPv6Address_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QIPv6Address_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QIPv6Address_Type = nullptr;
static PyTypeObject *Sbk_QIPv6Address_TypeF(void)
{
    return _Sbk_QIPv6Address_Type;
}

static PyType_Slot Sbk_QIPv6Address_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QIPv6Address_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QIPv6Address_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QIPv6Address_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QIPv6Address_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(&Sbk_QIPv6AddressFunc___setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(&Sbk_QIPv6AddressFunc___len__)},
    {Py_sq_item,        reinterpret_cast<void *>(&Sbk_QIPv6AddressFunc___getitem__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QIPv6Address_spec = {
    "2:PySide6.QtNetwork.QIPv6Address",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QIPv6Address_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QIPv6Address_PythonToCpp_QIPv6Address_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QIPv6Address_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QIPv6Address_PythonToCpp_QIPv6Address_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QIPv6Address_TypeF()))
        return QIPv6Address_PythonToCpp_QIPv6Address_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QIPv6Address_PTR_CppToPython_QIPv6Address(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QIPv6Address *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QIPv6Address_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QIPv6Address_COPY_CppToPython_QIPv6Address(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QIPv6Address *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QIPv6Address_TypeF(), new ::QIPv6Address(*source), true, true);
}

// Python to C++ copy conversion.
static void QIPv6Address_PythonToCpp_QIPv6Address_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QIPv6Address *>(cppOut) = *reinterpret_cast< ::QIPv6Address *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QIPv6Address_PythonToCpp_QIPv6Address_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QIPv6Address_TypeF()))
        return QIPv6Address_PythonToCpp_QIPv6Address_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QIPv6Address_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QIPv6Address(self)",
    "0:PySide6.QtNetwork.QIPv6Address(self,QIPv6Address:PySide6.QtNetwork.QIPv6Address)",
    "PySide6.QtNetwork.QIPv6Address.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QIPv6Address(PyObject *module)
{
    _Sbk_QIPv6Address_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QIPv6Address",
        "QIPv6Address",
        &Sbk_QIPv6Address_spec,
        &Shiboken::callCppDestructor< ::QIPv6Address >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QIPv6Address_TypeF(); // references _Sbk_QIPv6Address_Type
    InitSignatureStrings(pyType, QIPv6Address_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QIPv6Address_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QIPv6Address_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QIPv6Address_PythonToCpp_QIPv6Address_PTR,
        is_QIPv6Address_PythonToCpp_QIPv6Address_PTR_Convertible,
        QIPv6Address_PTR_CppToPython_QIPv6Address,
        QIPv6Address_COPY_CppToPython_QIPv6Address);

    Shiboken::Conversions::registerConverterName(converter, "QIPv6Address");
    Shiboken::Conversions::registerConverterName(converter, "QIPv6Address*");
    Shiboken::Conversions::registerConverterName(converter, "QIPv6Address&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QIPv6Address).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QIPv6Address_PythonToCpp_QIPv6Address_COPY,
        is_QIPv6Address_PythonToCpp_QIPv6Address_COPY_Convertible);

    qRegisterMetaType< ::QIPv6Address >("QIPv6Address");

    return pyType;
}
