// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qabstractopenglfunctions_wrapper.h"

// Argument includes
#include <QtGui/qopenglcontext.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractOpenGLFunctionsWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractOpenGLFunctionsWrapper::QAbstractOpenGLFunctionsWrapper() : QAbstractOpenGLFunctions()
{
    resetPyMethodCache();
    // ... middle
}

bool QAbstractOpenGLFunctionsWrapper::initializeOpenGLFunctions()
{
    if (m_PyMethodCache[0])
        return this->::QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initializeOpenGLFunctions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractOpenGLFunctions", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAbstractOpenGLFunctionsWrapper::~QAbstractOpenGLFunctionsWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractOpenGLFunctions_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractOpenGLFunctions >()))
        return -1;

    ::QAbstractOpenGLFunctionsWrapper *cptr{};
    static const char fullName[] = "PySide6.QtOpenGL.QAbstractOpenGLFunctions.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractOpenGLFunctions()
            cptr = new ::QAbstractOpenGLFunctionsWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAbstractOpenGLFunctions >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_initializeOpenGLFunctions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QAbstractOpenGLFunctions.initializeOpenGLFunctions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // initializeOpenGLFunctions()
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractOpenGLFunctions::initializeOpenGLFunctions()
                : cppSelf->initializeOpenGLFunctions();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_isInitialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QAbstractOpenGLFunctions.isInitialized";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInitialized()const
            bool cppResult = const_cast<const ::QAbstractOpenGLFunctions *>(cppSelf)->isInitialized();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_owningContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QAbstractOpenGLFunctions.owningContext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // owningContext()const
            QOpenGLContext * cppResult = const_cast<const ::QAbstractOpenGLFunctions *>(cppSelf)->owningContext();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractOpenGLFunctionsFunc_setOwningContext(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QAbstractOpenGLFunctions.setOwningContext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArg)))) {
        overloadId = 0; // setOwningContext(const QOpenGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLContext *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOwningContext(const QOpenGLContext*)
            cppSelf->setOwningContext(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAbstractOpenGLFunctions_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractOpenGLFunctions_methods[] = {
    {"initializeOpenGLFunctions", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_initializeOpenGLFunctions), METH_NOARGS, nullptr},
    {"isInitialized", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_isInitialized), METH_NOARGS, nullptr},
    {"owningContext", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_owningContext), METH_NOARGS, nullptr},
    {"setOwningContext", reinterpret_cast<PyCFunction>(Sbk_QAbstractOpenGLFunctionsFunc_setOwningContext), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractOpenGLFunctions_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractOpenGLFunctions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractOpenGLFunctionsWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractOpenGLFunctions_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractOpenGLFunctions_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractOpenGLFunctions_Type = nullptr;
static PyTypeObject *Sbk_QAbstractOpenGLFunctions_TypeF(void)
{
    return _Sbk_QAbstractOpenGLFunctions_Type;
}

static PyType_Slot Sbk_QAbstractOpenGLFunctions_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractOpenGLFunctions_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractOpenGLFunctions_spec = {
    "2:PySide6.QtOpenGL.QAbstractOpenGLFunctions",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractOpenGLFunctions_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractOpenGLFunctions_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractOpenGLFunctions_TypeF()))
        return QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractOpenGLFunctions_PTR_CppToPython_QAbstractOpenGLFunctions(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QAbstractOpenGLFunctions *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QAbstractOpenGLFunctions_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAbstractOpenGLFunctions_SignatureStrings[] = {
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions(self)",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.initializeOpenGLFunctions(self)->bool",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.isInitialized(self)->bool",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.owningContext(self)->PySide6.QtGui.QOpenGLContext",
    "PySide6.QtOpenGL.QAbstractOpenGLFunctions.setOwningContext(self,context:PySide6.QtGui.QOpenGLContext)",
    nullptr}; // Sentinel

PyTypeObject *init_QAbstractOpenGLFunctions(PyObject *module)
{
    _Sbk_QAbstractOpenGLFunctions_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractOpenGLFunctions",
        "QAbstractOpenGLFunctions*",
        &Sbk_QAbstractOpenGLFunctions_spec,
        &Shiboken::callCppDestructor< ::QAbstractOpenGLFunctions >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QAbstractOpenGLFunctions_TypeF(); // references _Sbk_QAbstractOpenGLFunctions_Type
    InitSignatureStrings(pyType, QAbstractOpenGLFunctions_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractOpenGLFunctions_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR,
        is_QAbstractOpenGLFunctions_PythonToCpp_QAbstractOpenGLFunctions_PTR_Convertible,
        QAbstractOpenGLFunctions_PTR_CppToPython_QAbstractOpenGLFunctions);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractOpenGLFunctions&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractOpenGLFunctions).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractOpenGLFunctionsWrapper).name());

    qRegisterMetaType< ::QAbstractOpenGLFunctions *>();

    return pyType;
}
