// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgmaterialshader_wrapper.h"

// inner classes
#include "qsgmaterialshader_renderstate_wrapper.h"

// Argument includes
#include <QString>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgtexture.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGMaterialShaderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGMaterialShaderWrapper::QSGMaterialShaderWrapper() : QSGMaterialShader()
{
    resetPyMethodCache();
    // ... middle
}

bool QSGMaterialShaderWrapper::updateUniformData(::QSGMaterialShader::RenderState & state, ::QSGMaterial * newMaterial, ::QSGMaterial * oldMaterial)
{
    if (m_PyMethodCache[0])
        return this->::QSGMaterialShader::updateUniformData(state, newMaterial, oldMaterial);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updateUniformData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGMaterialShader::updateUniformData(state, newMaterial, oldMaterial);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), &state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), newMaterial),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), oldMaterial)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGMaterialShader", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGMaterialShaderWrapper::~QSGMaterialShaderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGMaterialShader_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGMaterialShader >()))
        return -1;

    ::QSGMaterialShaderWrapper *cptr{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGMaterialShader()
            cptr = new ::QSGMaterialShaderWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSGMaterialShader >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGMaterialShaderFunc_combinedImageSamplerCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.combinedImageSamplerCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterialShader::combinedImageSamplerCount(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // combinedImageSamplerCount(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // combinedImageSamplerCount(int)const
            int cppResult = const_cast<const ::QSGMaterialShader *>(cppSelf)->combinedImageSamplerCount(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialShaderFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QSGMaterialShader::Flag> cppResult = const_cast<const ::QSGMaterialShader *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.setFlag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::setFlag(QFlags<QSGMaterialShader::Flag>,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QSGMaterialShader::Flag> cppArg0 = QFlags<QSGMaterialShader::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QFlags<QSGMaterialShader::Flag>,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.setFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterialShader::setFlags(QFlags<QSGMaterialShader::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QSGMaterialShader::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QSGMaterialShader::Flag> cppArg0 = QFlags<QSGMaterialShader::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QSGMaterialShader::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_setShaderFileName(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.setShaderFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setShaderFileName", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::setShaderFileName(QSGMaterialShader::Stage,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setShaderFileName(QSGMaterialShader::Stage,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QSGMaterialShader::Stage cppArg0{QSGMaterialShader::VertexStage};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderFileName(QSGMaterialShader::Stage,QString)
            cppSelf->setShaderFileName(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGMaterialShaderFunc_updateUniformData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGMaterialShader.updateUniformData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updateUniformData", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGMaterialShader::updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_RenderState_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArgs[2])))) {
        overloadId = 0; // updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGMaterialShader::RenderState cppArg0_local;
        ::QSGMaterialShader::RenderState *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGMaterial *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSGMaterial *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateUniformData(QSGMaterialShader::RenderState&,QSGMaterial*,QSGMaterial*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGMaterialShader::updateUniformData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->updateUniformData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGMaterialShader_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGMaterialShader_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "Stage:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGMaterialShader_methods[] = {
    {"combinedImageSamplerCount", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_combinedImageSamplerCount), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_flags), METH_NOARGS, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setFlags), METH_O, nullptr},
    {"setShaderFileName", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_setShaderFileName), METH_VARARGS, nullptr},
    {"updateUniformData", reinterpret_cast<PyCFunction>(Sbk_QSGMaterialShaderFunc_updateUniformData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGMaterialShader_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGMaterialShader *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGMaterialShaderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGMaterialShader_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGMaterialShader_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGMaterialShader_Type = nullptr;
static PyTypeObject *Sbk_QSGMaterialShader_TypeF(void)
{
    return _Sbk_QSGMaterialShader_Type;
}

static PyType_Slot Sbk_QSGMaterialShader_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGMaterialShader_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGMaterialShader_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGMaterialShader_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGMaterialShader_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGMaterialShader_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGMaterialShader_spec = {
    "2:PySide6.QtQuick.QSGMaterialShader",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGMaterialShader_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSGMaterialShader_Flag_PythonToCpp_QSGMaterialShader_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGMaterialShader::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGMaterialShader::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_QSGMaterialShader_Flag_PythonToCpp_QSGMaterialShader_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX])))
        return QSGMaterialShader_Flag_PythonToCpp_QSGMaterialShader_Flag;
    return {};
}
static PyObject *QSGMaterialShader_Flag_CppToPython_QSGMaterialShader_Flag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGMaterialShader::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX]), castCppIn);

}

static void QSGMaterialShader_Stage_PythonToCpp_QSGMaterialShader_Stage(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGMaterialShader::Stage>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGMaterialShader::Stage *>(cppOut) = value;

}
static PythonToCppFunc is_QSGMaterialShader_Stage_PythonToCpp_QSGMaterialShader_Stage_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX])))
        return QSGMaterialShader_Stage_PythonToCpp_QSGMaterialShader_Stage;
    return {};
}
static PyObject *QSGMaterialShader_Stage_CppToPython_QSGMaterialShader_Stage(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGMaterialShader::Stage *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGMaterialShader_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGMaterialShader_TypeF()))
        return QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGMaterialShader_PTR_CppToPython_QSGMaterialShader(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QSGMaterialShader *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QSGMaterialShader_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGMaterialShader_SignatureStrings[] = {
    "PySide6.QtQuick.QSGMaterialShader(self)",
    "PySide6.QtQuick.QSGMaterialShader.combinedImageSamplerCount(self,binding:int)->int",
    "PySide6.QtQuick.QSGMaterialShader.flags(self)->PySide6.QtQuick.QSGMaterialShader.Flag",
    "PySide6.QtQuick.QSGMaterialShader.setFlag(self,flags:PySide6.QtQuick.QSGMaterialShader.Flag,on:bool=true)",
    "PySide6.QtQuick.QSGMaterialShader.setFlags(self,flags:PySide6.QtQuick.QSGMaterialShader.Flag)",
    "PySide6.QtQuick.QSGMaterialShader.setShaderFileName(self,stage:PySide6.QtQuick.QSGMaterialShader.Stage,filename:QString)",
    "PySide6.QtQuick.QSGMaterialShader.updateUniformData(self,state:PySide6.QtQuick.QSGMaterialShader.RenderState,newMaterial:PySide6.QtQuick.QSGMaterial,oldMaterial:PySide6.QtQuick.QSGMaterial)->bool",
    nullptr}; // Sentinel

PyTypeObject *init_QSGMaterialShader(PyObject *module)
{
    _Sbk_QSGMaterialShader_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGMaterialShader",
        "QSGMaterialShader*",
        &Sbk_QSGMaterialShader_spec,
        &Shiboken::callCppDestructor< ::QSGMaterialShader >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QSGMaterialShader_TypeF(); // references _Sbk_QSGMaterialShader_Type
    InitSignatureStrings(pyType, QSGMaterialShader_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGMaterialShader_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR,
        is_QSGMaterialShader_PythonToCpp_QSGMaterialShader_PTR_Convertible,
        QSGMaterialShader_PTR_CppToPython_QSGMaterialShader);

    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader*");
    Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGMaterialShader).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGMaterialShaderWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGMaterialShader_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "UpdatesGraphicsPipelineState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QSGMaterialShader::Flag::UpdatesGraphicsPipelineState) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGMaterialShader_TypeF(),
        "2:PySide6.QtQuick.QSGMaterialShader.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_Flag_IDX].type =
        EType;
    // Register converter for enum 'QSGMaterialShader::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGMaterialShader_Flag_CppToPython_QSGMaterialShader_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGMaterialShader_Flag_PythonToCpp_QSGMaterialShader_Flag,
            is_QSGMaterialShader_Flag_PythonToCpp_QSGMaterialShader_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
        // Register converter for flag 'QFlags<QSGMaterialShader::Flag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGMaterialShader::Flag>");
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader::Flags");
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Stage'.
    const char *Stage_Initializer[] = {
        "VertexStage",
        "FragmentStage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Stage_InitializerValues[] = {
        uint8_t(QSGMaterialShader::Stage::VertexStage),  //  0x00  0
        uint8_t(QSGMaterialShader::Stage::FragmentStage) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGMaterialShader_TypeF(),
        "2:PySide6.QtQuick.QSGMaterialShader.Stage",
        Stage_Initializer, Stage_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX].type = EType;
    // Register converter for enum 'QSGMaterialShader::Stage'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGMaterialShader_Stage_CppToPython_QSGMaterialShader_Stage);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGMaterialShader_Stage_PythonToCpp_QSGMaterialShader_Stage,
            is_QSGMaterialShader_Stage_PythonToCpp_QSGMaterialShader_Stage_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGMaterialShader::Stage");
        Shiboken::Conversions::registerConverterName(converter, "Stage");
    }
    // End of 'Stage' enum.

    qRegisterMetaType< ::QSGMaterialShader *>();
    qRegisterMetaType< ::QSGMaterialShader::Flag >("QSGMaterialShader::Flag");
    qRegisterMetaType< ::QSGMaterialShader::Stage >("QSGMaterialShader::Stage");

    return pyType;
}
