// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgrendernode_wrapper.h"

// inner classes
#include "qsgrendernode_renderstate_wrapper.h"

// Argument includes
#include <QtGui/qmatrix4x4.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgrendernode.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGRenderNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGRenderNodeWrapper::QSGRenderNodeWrapper() : QSGRenderNode()
{
    resetPyMethodCache();
    // ... middle
}

::QFlags<QSGRenderNode::StateFlag> QSGRenderNodeWrapper::changedStates() const
{
    if (m_PyMethodCache[0])
        return this->::QSGRenderNode::changedStates();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRenderNode::StateFlag>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changedStates";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGRenderNode::changedStates();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QSGRenderNode::StateFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QFlags<QSGRenderNode::StateFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRenderNode::StateFlag>(0);
    }
    ::QFlags<QSGRenderNode::StateFlag> cppResult = QFlags<QSGRenderNode::StateFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QSGRenderNode::RenderingFlag> QSGRenderNodeWrapper::flags() const
{
    if (m_PyMethodCache[1])
        return this->::QSGRenderNode::flags();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "flags";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGRenderNode::flags();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QFlags<QSGRenderNode::RenderingFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRenderNode::RenderingFlag>(0);
    }
    ::QFlags<QSGRenderNode::RenderingFlag> cppResult = QFlags<QSGRenderNode::RenderingFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSGRenderNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[2])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGRenderNodeWrapper::prepare()
{
    if (m_PyMethodCache[3]) {
        return this->::QSGRenderNode::prepare();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "prepare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QSGRenderNode::prepare();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QSGRenderNodeWrapper::preprocess()
{
    if (m_PyMethodCache[4]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QRectF QSGRenderNodeWrapper::rect() const
{
    if (m_PyMethodCache[5])
        return this->::QSGRenderNode::rect();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "rect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QSGRenderNode::rect();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRenderNode", funcName, Shiboken::SbkType< QRectF >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRectF cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGRenderNodeWrapper::releaseResources()
{
    if (m_PyMethodCache[6]) {
        return this->::QSGRenderNode::releaseResources();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "releaseResources";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QSGRenderNode::releaseResources();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QSGRenderNodeWrapper::render(const ::QSGRenderNode::RenderState * state)
{
    if (m_PyMethodCache[7]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "render";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), state)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), state)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QSGRenderNodeWrapper::~QSGRenderNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGRenderNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGRenderNode");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGRenderNode >()))
        return -1;

    ::QSGRenderNodeWrapper *cptr{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGRenderNode()
            cptr = new ::QSGRenderNodeWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSGRenderNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGRenderNodeFunc_changedStates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.changedStates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // changedStates()const
            QFlags<QSGRenderNode::StateFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::changedStates()
                : const_cast<const ::QSGRenderNode *>(cppSelf)->changedStates();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_clipList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.clipList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clipList()const
            const QSGClipNode * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->clipList();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGClipNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_commandBuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.commandBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // commandBuffer()const
            QRhiCommandBuffer * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->commandBuffer();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QSGRenderNode::RenderingFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::flags()
                : const_cast<const ::QSGRenderNode *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_inheritedOpacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.inheritedOpacity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // inheritedOpacity()const
            qreal cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->inheritedOpacity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_matrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.matrix";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // matrix()const
            const QMatrix4x4 * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->matrix();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_prepare(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.prepare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepare()
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGRenderNode::prepare()
                : cppSelf->prepare();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_projectionMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.projectionMatrix";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // projectionMatrix()const
            const QMatrix4x4 * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->projectionMatrix();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_rect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.rect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rect()const
            QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGRenderNode *>(cppSelf)->::QSGRenderNode::rect()
                : const_cast<const ::QSGRenderNode *>(cppSelf)->rect();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRenderNodeFunc_releaseResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.releaseResources";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseResources()
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGRenderNode::releaseResources()
                : cppSelf->releaseResources();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_render(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.render";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGRenderNode::render(const QSGRenderNode::RenderState*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderState_IDX]), (pyArg)))) {
        overloadId = 0; // render(const QSGRenderNode::RenderState*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGRenderNode::RenderState *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // render(const QSGRenderNode::RenderState*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRenderNode.render");
                return {};
            }
            cppSelf->render(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGRenderNodeFunc_renderTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRenderNode.renderTarget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderTarget()const
            QRhiRenderTarget * cppResult = const_cast<const ::QSGRenderNode *>(cppSelf)->renderTarget();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGRenderNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGRenderNode_EnumFlagInfo[] = {
    "RenderingFlag:Flag:RenderingFlags",
    "StateFlag:Flag:StateFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGRenderNode_methods[] = {
    {"changedStates", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_changedStates), METH_NOARGS, nullptr},
    {"clipList", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_clipList), METH_NOARGS, nullptr},
    {"commandBuffer", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_commandBuffer), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_flags), METH_NOARGS, nullptr},
    {"inheritedOpacity", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_inheritedOpacity), METH_NOARGS, nullptr},
    {"matrix", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_matrix), METH_NOARGS, nullptr},
    {"prepare", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_prepare), METH_NOARGS, nullptr},
    {"projectionMatrix", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_projectionMatrix), METH_NOARGS, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_rect), METH_NOARGS, nullptr},
    {"releaseResources", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_releaseResources), METH_NOARGS, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_render), METH_O, nullptr},
    {"renderTarget", reinterpret_cast<PyCFunction>(Sbk_QSGRenderNodeFunc_renderTarget), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGRenderNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGRenderNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGRenderNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGRenderNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGRenderNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGRenderNode_Type = nullptr;
static PyTypeObject *Sbk_QSGRenderNode_TypeF(void)
{
    return _Sbk_QSGRenderNode_Type;
}

static PyType_Slot Sbk_QSGRenderNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGRenderNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGRenderNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGRenderNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGRenderNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGRenderNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGRenderNode_spec = {
    "2:PySide6.QtQuick.QSGRenderNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGRenderNode_slots
};

} //extern "C"

static void *Sbk_QSGRenderNode_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGNode >())
        return dynamic_cast< ::QSGRenderNode *>(reinterpret_cast< ::QSGNode *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QSGRenderNode_StateFlag_PythonToCpp_QSGRenderNode_StateFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRenderNode::StateFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRenderNode::StateFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRenderNode_StateFlag_PythonToCpp_QSGRenderNode_StateFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX])))
        return QSGRenderNode_StateFlag_PythonToCpp_QSGRenderNode_StateFlag;
    return {};
}
static PyObject *QSGRenderNode_StateFlag_CppToPython_QSGRenderNode_StateFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRenderNode::StateFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX]), castCppIn);

}

static void QSGRenderNode_RenderingFlag_PythonToCpp_QSGRenderNode_RenderingFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRenderNode::RenderingFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRenderNode::RenderingFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRenderNode_RenderingFlag_PythonToCpp_QSGRenderNode_RenderingFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX])))
        return QSGRenderNode_RenderingFlag_PythonToCpp_QSGRenderNode_RenderingFlag;
    return {};
}
static PyObject *QSGRenderNode_RenderingFlag_CppToPython_QSGRenderNode_RenderingFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRenderNode::RenderingFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGRenderNode_PythonToCpp_QSGRenderNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGRenderNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGRenderNode_PythonToCpp_QSGRenderNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGRenderNode_TypeF()))
        return QSGRenderNode_PythonToCpp_QSGRenderNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGRenderNode_PTR_CppToPython_QSGRenderNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QSGRenderNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QSGRenderNode_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGRenderNode_SignatureStrings[] = {
    "PySide6.QtQuick.QSGRenderNode(self)",
    "PySide6.QtQuick.QSGRenderNode.changedStates(self)->PySide6.QtQuick.QSGRenderNode.StateFlag",
    "PySide6.QtQuick.QSGRenderNode.clipList(self)->PySide6.QtQuick.QSGClipNode",
    "PySide6.QtQuick.QSGRenderNode.commandBuffer(self)->PySide6.QtGui.QRhiCommandBuffer",
    "PySide6.QtQuick.QSGRenderNode.flags(self)->PySide6.QtQuick.QSGRenderNode.RenderingFlag",
    "PySide6.QtQuick.QSGRenderNode.inheritedOpacity(self)->qreal",
    "PySide6.QtQuick.QSGRenderNode.matrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtQuick.QSGRenderNode.prepare(self)",
    "PySide6.QtQuick.QSGRenderNode.projectionMatrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtQuick.QSGRenderNode.rect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QSGRenderNode.releaseResources(self)",
    "PySide6.QtQuick.QSGRenderNode.render(self,state:PySide6.QtQuick.QSGRenderNode.RenderState)",
    "PySide6.QtQuick.QSGRenderNode.renderTarget(self)->PySide6.QtGui.QRhiRenderTarget",
    nullptr}; // Sentinel

PyTypeObject *init_QSGRenderNode(PyObject *module)
{
    _Sbk_QSGRenderNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGRenderNode",
        "QSGRenderNode*",
        &Sbk_QSGRenderNode_spec,
        &Shiboken::callCppDestructor< ::QSGRenderNode >,
        Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]),
        0,
        0);
    auto *pyType = Sbk_QSGRenderNode_TypeF(); // references _Sbk_QSGRenderNode_Type
    InitSignatureStrings(pyType, QSGRenderNode_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGRenderNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGRenderNode_PythonToCpp_QSGRenderNode_PTR,
        is_QSGRenderNode_PythonToCpp_QSGRenderNode_PTR_Convertible,
        QSGRenderNode_PTR_CppToPython_QSGRenderNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGRenderNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGRenderNodeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGRenderNode_TypeF(), &Sbk_QSGRenderNode_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGRenderNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StateFlag'.
    const char *StateFlag_Initializer[] = {
        "DepthState",
        "StencilState",
        "ScissorState",
        "ColorState",
        "BlendState",
        "CullState",
        "ViewportState",
        "RenderTargetState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StateFlag_InitializerValues[] = {
        uint8_t(QSGRenderNode::StateFlag::DepthState),       //  0x01  1
        uint8_t(QSGRenderNode::StateFlag::StencilState),     //  0x02  2
        uint8_t(QSGRenderNode::StateFlag::ScissorState),     //  0x04  4
        uint8_t(QSGRenderNode::StateFlag::ColorState),       //  0x08  8
        uint8_t(QSGRenderNode::StateFlag::BlendState),       //  0x10  16
        uint8_t(QSGRenderNode::StateFlag::CullState),        //  0x20  32
        uint8_t(QSGRenderNode::StateFlag::ViewportState),    //  0x40  64
        uint8_t(QSGRenderNode::StateFlag::RenderTargetState) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRenderNode_TypeF(),
        "2:PySide6.QtQuick.QSGRenderNode.StateFlag",
        StateFlag_Initializer, StateFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_StateFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_StateFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGRenderNode::StateFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_StateFlag_CppToPython_QSGRenderNode_StateFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRenderNode_StateFlag_PythonToCpp_QSGRenderNode_StateFlag,
            is_QSGRenderNode_StateFlag_PythonToCpp_QSGRenderNode_StateFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::StateFlag");
        Shiboken::Conversions::registerConverterName(converter, "StateFlag");
        // Register converter for flag 'QFlags<QSGRenderNode::StateFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGRenderNode::StateFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::StateFlags");
    }
    // End of 'StateFlag' enum/flags.

    // Initialization of enum 'RenderingFlag'.
    const char *RenderingFlag_Initializer[] = {
        "BoundedRectRendering",
        "DepthAwareRendering",
        "OpaqueRendering",
        "NoExternalRendering",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderingFlag_InitializerValues[] = {
        uint8_t(QSGRenderNode::RenderingFlag::BoundedRectRendering), //  0x01  1
        uint8_t(QSGRenderNode::RenderingFlag::DepthAwareRendering),  //  0x02  2
        uint8_t(QSGRenderNode::RenderingFlag::OpaqueRendering),      //  0x04  4
        uint8_t(QSGRenderNode::RenderingFlag::NoExternalRendering)   //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRenderNode_TypeF(),
        "2:PySide6.QtQuick.QSGRenderNode.RenderingFlag",
        RenderingFlag_Initializer, RenderingFlag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRenderNode_RenderingFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRenderNode_RenderingFlag_IDX].type =
        EType;
    // Register converter for enum 'QSGRenderNode::RenderingFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRenderNode_RenderingFlag_CppToPython_QSGRenderNode_RenderingFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRenderNode_RenderingFlag_PythonToCpp_QSGRenderNode_RenderingFlag,
            is_QSGRenderNode_RenderingFlag_PythonToCpp_QSGRenderNode_RenderingFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::RenderingFlag");
        Shiboken::Conversions::registerConverterName(converter, "RenderingFlag");
        // Register converter for flag 'QFlags<QSGRenderNode::RenderingFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGRenderNode::RenderingFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QSGRenderNode::RenderingFlags");
    }
    // End of 'RenderingFlag' enum/flags.

    qRegisterMetaType< ::QSGRenderNode *>();
    qRegisterMetaType< ::QSGRenderNode::StateFlag >("QSGRenderNode::StateFlag");
    qRegisterMetaType< ::QSGRenderNode::RenderingFlag >("QSGRenderNode::RenderingFlag");

    return pyType;
}
