// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlcompiler_wrapper.h"

// inner classes
#include "qscxmlcompiler_loader_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtScxml/qscxmlcompiler.h>
#include <QtScxml/qscxmlerror.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <qxmlstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlCompiler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlCompiler >()))
        return -1;

    ::QScxmlCompiler *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QScxmlCompiler", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlCompiler::QScxmlCompiler(QXmlStreamReader*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamReader_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QScxmlCompiler(QXmlStreamReader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QXmlStreamReader *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QScxmlCompiler(QXmlStreamReader*)
            cptr = new ::QScxmlCompiler(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScxmlCompiler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlCompilerFunc_compile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.compile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // compile()
            QScxmlStateMachine * cppResult = cppSelf->compile();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlStateMachine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_errors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.errors";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errors()const
            QList<QScxmlError> cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->errors();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtScxmlTypeConverters[SBK_QtScxml_QList_QScxmlError_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.fileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileName()const
            QString cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->fileName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_loader(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.loader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // loader()const
            QScxmlCompiler::Loader * cppResult = const_cast<const ::QScxmlCompiler *>(cppSelf)->loader();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlCompilerFunc_setFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.setFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlCompiler::setFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileName(QString)
            cppSelf->setFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScxmlCompilerFunc_setLoader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlCompiler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlCompiler.setLoader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScxmlCompiler::setLoader(QScxmlCompiler::Loader*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_Loader_IDX]), (pyArg)))) {
        overloadId = 0; // setLoader(QScxmlCompiler::Loader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScxmlCompiler::Loader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLoader(QScxmlCompiler::Loader*)
            cppSelf->setLoader(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QScxmlCompiler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlCompiler_methods[] = {
    {"compile", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_compile), METH_NOARGS, nullptr},
    {"errors", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_errors), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_fileName), METH_NOARGS, nullptr},
    {"loader", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_loader), METH_NOARGS, nullptr},
    {"setFileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_setFileName), METH_O, nullptr},
    {"setLoader", reinterpret_cast<PyCFunction>(Sbk_QScxmlCompilerFunc_setLoader), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QScxmlCompiler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlCompiler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlCompiler_Type = nullptr;
static PyTypeObject *Sbk_QScxmlCompiler_TypeF(void)
{
    return _Sbk_QScxmlCompiler_Type;
}

static PyType_Slot Sbk_QScxmlCompiler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlCompiler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlCompiler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlCompiler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlCompiler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlCompiler_spec = {
    "2:PySide6.QtScxml.QScxmlCompiler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlCompiler_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlCompiler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlCompiler_TypeF()))
        return QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlCompiler_PTR_CppToPython_QScxmlCompiler(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QScxmlCompiler *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QScxmlCompiler_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QScxmlCompiler_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlCompiler(self,xmlReader:PySide6.QtCore.QXmlStreamReader)",
    "PySide6.QtScxml.QScxmlCompiler.compile(self)->PySide6.QtScxml.QScxmlStateMachine",
    "PySide6.QtScxml.QScxmlCompiler.errors(self)->QList[PySide6.QtScxml.QScxmlError]",
    "PySide6.QtScxml.QScxmlCompiler.fileName(self)->QString",
    "PySide6.QtScxml.QScxmlCompiler.loader(self)->PySide6.QtScxml.QScxmlCompiler.Loader",
    "PySide6.QtScxml.QScxmlCompiler.setFileName(self,fileName:QString)",
    "PySide6.QtScxml.QScxmlCompiler.setLoader(self,newLoader:PySide6.QtScxml.QScxmlCompiler.Loader)",
    nullptr}; // Sentinel

PyTypeObject *init_QScxmlCompiler(PyObject *module)
{
    _Sbk_QScxmlCompiler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlCompiler",
        "QScxmlCompiler*",
        &Sbk_QScxmlCompiler_spec,
        &Shiboken::callCppDestructor< ::QScxmlCompiler >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QScxmlCompiler_TypeF(); // references _Sbk_QScxmlCompiler_Type
    InitSignatureStrings(pyType, QScxmlCompiler_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlCompiler_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlCompiler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR,
        is_QScxmlCompiler_PythonToCpp_QScxmlCompiler_PTR_Convertible,
        QScxmlCompiler_PTR_CppToPython_QScxmlCompiler);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlCompiler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlCompiler).name());

    qRegisterMetaType< ::QScxmlCompiler *>();

    return pyType;
}
