// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmldatamodel_foreachloopbody_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void ForeachLoopBodyWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

ForeachLoopBodyWrapper::ForeachLoopBodyWrapper() : QScxmlDataModel::ForeachLoopBody()
{
    resetPyMethodCache();
    // ... middle
}

void ForeachLoopBodyWrapper::run(bool * ok)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("ForeachLoopBody.run");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "run";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("ForeachLoopBody.run");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), ok)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), ok)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

ForeachLoopBodyWrapper::~ForeachLoopBodyWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlDataModel_ForeachLoopBody_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_ForeachLoopBody_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QScxmlDataModel::ForeachLoopBody");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlDataModel::ForeachLoopBody >()))
        return -1;

    ::ForeachLoopBodyWrapper *cptr{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // ForeachLoopBody()
            cptr = new ::ForeachLoopBodyWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScxmlDataModel::ForeachLoopBody >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlDataModel_ForeachLoopBodyFunc_run(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlDataModel::ForeachLoopBody *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_ForeachLoopBody_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody.run";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: ForeachLoopBody::run(bool*)
    if (PyBool_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // run(bool*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // run(bool*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("ForeachLoopBody.run");
                return {};
            }
            cppSelf->run(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QScxmlDataModel_ForeachLoopBody_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlDataModel_ForeachLoopBody_methods[] = {
    {"run", reinterpret_cast<PyCFunction>(Sbk_QScxmlDataModel_ForeachLoopBodyFunc_run), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScxmlDataModel_ForeachLoopBody_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScxmlDataModel::ForeachLoopBody *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_ForeachLoopBody_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<ForeachLoopBodyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QScxmlDataModel_ForeachLoopBody_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlDataModel_ForeachLoopBody_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlDataModel_ForeachLoopBody_Type = nullptr;
static PyTypeObject *Sbk_QScxmlDataModel_ForeachLoopBody_TypeF(void)
{
    return _Sbk_QScxmlDataModel_ForeachLoopBody_Type;
}

static PyType_Slot Sbk_QScxmlDataModel_ForeachLoopBody_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScxmlDataModel_ForeachLoopBody_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlDataModel_ForeachLoopBody_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlDataModel_ForeachLoopBody_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlDataModel_ForeachLoopBody_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlDataModel_ForeachLoopBody_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlDataModel_ForeachLoopBody_spec = {
    "2:PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlDataModel_ForeachLoopBody_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ForeachLoopBody_PythonToCpp_ForeachLoopBody_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlDataModel_ForeachLoopBody_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ForeachLoopBody_PythonToCpp_ForeachLoopBody_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlDataModel_ForeachLoopBody_TypeF()))
        return ForeachLoopBody_PythonToCpp_ForeachLoopBody_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ForeachLoopBody_PTR_CppToPython_ForeachLoopBody(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QScxmlDataModel::ForeachLoopBody *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QScxmlDataModel_ForeachLoopBody_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QScxmlDataModel_ForeachLoopBody_SignatureStrings[] = {
    "PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody(self)",
    "PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody.run(self,ok:bool*)",
    nullptr}; // Sentinel

PyTypeObject *init_QScxmlDataModel_ForeachLoopBody(PyObject *enclosingClass)
{
    _Sbk_QScxmlDataModel_ForeachLoopBody_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ForeachLoopBody",
        "QScxmlDataModel::ForeachLoopBody*",
        &Sbk_QScxmlDataModel_ForeachLoopBody_spec,
        &Shiboken::callCppDestructor< ::QScxmlDataModel::ForeachLoopBody >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_QScxmlDataModel_ForeachLoopBody_TypeF(); // references _Sbk_QScxmlDataModel_ForeachLoopBody_Type
    InitSignatureStrings(pyType, QScxmlDataModel_ForeachLoopBody_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlDataModel_ForeachLoopBody_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlDataModel_ForeachLoopBody_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ForeachLoopBody_PythonToCpp_ForeachLoopBody_PTR,
        is_ForeachLoopBody_PythonToCpp_ForeachLoopBody_PTR_Convertible,
        ForeachLoopBody_PTR_CppToPython_ForeachLoopBody);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlDataModel::ForeachLoopBody");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlDataModel::ForeachLoopBody*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlDataModel::ForeachLoopBody&");
    Shiboken::Conversions::registerConverterName(converter, "ForeachLoopBody");
    Shiboken::Conversions::registerConverterName(converter, "ForeachLoopBody*");
    Shiboken::Conversions::registerConverterName(converter, "ForeachLoopBody&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlDataModel::ForeachLoopBody).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::ForeachLoopBodyWrapper).name());

    qRegisterMetaType< ::QScxmlDataModel::ForeachLoopBody *>();

    return pyType;
}
