// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtscxml_python.h"

// main header
#include "qscxmlerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtScxml/qscxmlerror.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScxmlError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScxmlError >()))
        return -1;

    ::QScxmlError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "QScxmlError", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScxmlError::QScxmlError()
    // 1: QScxmlError::QScxmlError(QScxmlError)
    // 2: QScxmlError::QScxmlError(QString,int,int,QString)
    if (numArgs == 0) {
        overloadId = 0; // QScxmlError()
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 2; // QScxmlError(QString,int,int,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QScxmlError(QScxmlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScxmlError()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScxmlError()
                cptr = new ::QScxmlError();
            }
            break;
        }
        case 1: // QScxmlError(const QScxmlError & arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScxmlError cppArg0_local;
            ::QScxmlError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScxmlError(QScxmlError)
                cptr = new ::QScxmlError(*cppArg0);
            }
            break;
        }
        case 2: // QScxmlError(const QString & fileName, int line, int column, const QString & description)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScxmlError(QString,int,int,QString)
                cptr = new ::QScxmlError(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QScxmlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScxmlErrorFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.column";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // column()const
            int cppResult = const_cast<const ::QScxmlError *>(cppSelf)->column();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_fileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.fileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileName()const
            QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->fileName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QScxmlError *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_line(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.line";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // line()const
            int cppResult = const_cast<const ::QScxmlError *>(cppSelf)->line();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlErrorFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtScxml.QScxmlError.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString()const
            QString cppResult = const_cast<const ::QScxmlError *>(cppSelf)->toString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScxmlError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScxmlError_PropertyStrings[] = {
    "column:",
    "description:",
    "fileName:",
    "line:",
    "valid:isValid",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScxmlError_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_column), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_description), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_fileName), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_isValid), METH_NOARGS, nullptr},
    {"line", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_line), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QScxmlErrorFunc_toString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QScxmlError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QScxmlError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScxmlError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScxmlError_Type = nullptr;
static PyTypeObject *Sbk_QScxmlError_TypeF(void)
{
    return _Sbk_QScxmlError_Type;
}

static PyType_Slot Sbk_QScxmlError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScxmlError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScxmlError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScxmlError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScxmlError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScxmlError_spec = {
    "2:PySide6.QtScxml.QScxmlError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScxmlError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScxmlError_PythonToCpp_QScxmlError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScxmlError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScxmlError_PythonToCpp_QScxmlError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlError_TypeF()))
        return QScxmlError_PythonToCpp_QScxmlError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScxmlError_PTR_CppToPython_QScxmlError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QScxmlError *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QScxmlError_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QScxmlError_COPY_CppToPython_QScxmlError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QScxmlError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QScxmlError_TypeF(), new ::QScxmlError(*source), true, true);
}

// Python to C++ copy conversion.
static void QScxmlError_PythonToCpp_QScxmlError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QScxmlError *>(cppOut) = *reinterpret_cast< ::QScxmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QScxmlError_PythonToCpp_QScxmlError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QScxmlError_TypeF()))
        return QScxmlError_PythonToCpp_QScxmlError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QScxmlError_SignatureStrings[] = {
    "2:PySide6.QtScxml.QScxmlError(self)",
    "1:PySide6.QtScxml.QScxmlError(self,arg__1:PySide6.QtScxml.QScxmlError)",
    "0:PySide6.QtScxml.QScxmlError(self,fileName:QString,line:int,column:int,description:QString)",
    "PySide6.QtScxml.QScxmlError.column(self)->int",
    "PySide6.QtScxml.QScxmlError.description(self)->QString",
    "PySide6.QtScxml.QScxmlError.fileName(self)->QString",
    "PySide6.QtScxml.QScxmlError.isValid(self)->bool",
    "PySide6.QtScxml.QScxmlError.line(self)->int",
    "PySide6.QtScxml.QScxmlError.toString(self)->QString",
    "PySide6.QtScxml.QScxmlError.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QScxmlError(PyObject *module)
{
    _Sbk_QScxmlError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScxmlError",
        "QScxmlError",
        &Sbk_QScxmlError_spec,
        &Shiboken::callCppDestructor< ::QScxmlError >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QScxmlError_TypeF(); // references _Sbk_QScxmlError_Type
    InitSignatureStrings(pyType, QScxmlError_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScxmlError_PropertyStrings);
    SbkPySide6_QtScxmlTypeStructs[SBK_QScxmlError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScxmlError_PythonToCpp_QScxmlError_PTR,
        is_QScxmlError_PythonToCpp_QScxmlError_PTR_Convertible,
        QScxmlError_PTR_CppToPython_QScxmlError,
        QScxmlError_COPY_CppToPython_QScxmlError);

    Shiboken::Conversions::registerConverterName(converter, "QScxmlError");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlError*");
    Shiboken::Conversions::registerConverterName(converter, "QScxmlError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScxmlError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QScxmlError_PythonToCpp_QScxmlError_COPY,
        is_QScxmlError_PythonToCpp_QScxmlError_COPY_Convertible);

    qRegisterMetaType< ::QScxmlError >("QScxmlError");

    return pyType;
}
