// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensor_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtSensors/qsensor.h>
#include <QtSensors/qsensorbackend.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSensorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSensorWrapper::QSensorWrapper(const ::QByteArray & type, ::QObject * parent) : QSensor(type, parent)
{
    resetPyMethodCache();
    // ... middle
}

void QSensorWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QSensorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QSensorWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QSensorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QSensorWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSensor", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QSensorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSensor", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSensorWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QSensorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QSensor::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QSensorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QSensor::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QSensorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QSensorWrapper *>(this));
    return QSensor::qt_metacast(_clname);
}

QSensorWrapper::~QSensorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensor >()))
        return -1;

    ::QSensorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QSensor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSensor::QSensor(QByteArray,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QSensor(QByteArray,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QSensor(QByteArray,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSensor(QByteArray,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) ::QSensorWrapper(*cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new ::QSensorWrapper(*cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSensor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QSensorFunc_addFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.addFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::addFilter(QSensorFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]), (pyArg)))) {
        overloadId = 0; // addFilter(QSensorFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensorFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addFilter(QSensorFilter*)
            cppSelf->addFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_availableDataRates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.availableDataRates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availableDataRates()const
            QList<std::pair< int,int>> cppResult = const_cast<const ::QSensor *>(cppSelf)->availableDataRates();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_std_pair_int_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_axesOrientationMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.axesOrientationMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // axesOrientationMode()const
            QSensor::AxesOrientationMode cppResult = const_cast<const ::QSensor *>(cppSelf)->axesOrientationMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_backend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.backend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backend()const
            QSensorBackend * cppResult = const_cast<const ::QSensor *>(cppSelf)->backend();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorBackend_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_bufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.bufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bufferSize()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->bufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_connectToBackend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.connectToBackend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectToBackend()
            bool cppResult = cppSelf->connectToBackend();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_currentOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.currentOrientation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // currentOrientation()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->currentOrientation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_dataRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.dataRate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dataRate()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->dataRate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_defaultSensorForType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.defaultSensorForType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSensor::defaultSensorForType(QByteArray)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // defaultSensorForType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultSensorForType(QByteArray)
            QByteArray cppResult = ::QSensor::defaultSensorForType(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QSensor *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_efficientBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.efficientBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // efficientBufferSize()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->efficientBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.error";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // error()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->error();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_filters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.filters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // filters()const
            QList<QSensorFilter*> cppResult = const_cast<const ::QSensor *>(cppSelf)->filters();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QSensorFilterPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.identifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // identifier()const
            QByteArray cppResult = const_cast<const ::QSensor *>(cppSelf)->identifier();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.isActive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isActive()const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isActive();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isAlwaysOn(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.isAlwaysOn";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAlwaysOn()const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isAlwaysOn();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isBusy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.isBusy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isBusy()const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isBusy();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isConnectedToBackend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.isConnectedToBackend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isConnectedToBackend()const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isConnectedToBackend();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_isFeatureSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.isFeatureSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::isFeatureSupported(QSensor::Feature)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFeatureSupported(QSensor::Feature)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSensor::Feature cppArg0{QSensor::Buffering};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFeatureSupported(QSensor::Feature)const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->isFeatureSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_maxBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.maxBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxBufferSize()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->maxBufferSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_outputRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.outputRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // outputRange()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->outputRange();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_outputRanges(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.outputRanges";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // outputRanges()const
            QList<qoutputrange> cppResult = const_cast<const ::QSensor *>(cppSelf)->outputRanges();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_qoutputrange_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_reading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.reading";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reading()const
            QSensorReading * cppResult = const_cast<const ::QSensor *>(cppSelf)->reading();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorReading_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_removeFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.removeFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::removeFilter(QSensorFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorFilter_IDX]), (pyArg)))) {
        overloadId = 0; // removeFilter(QSensorFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSensorFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFilter(QSensorFilter*)
            cppSelf->removeFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_sensorTypes(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.sensorTypes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sensorTypes()
            QList<QByteArray> cppResult = ::QSensor::sensorTypes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_sensorsForType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.sensorsForType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSensor::sensorsForType(QByteArray)->QList< QByteArray>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // sensorsForType(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sensorsForType(QByteArray)
            QList<QByteArray> cppResult = ::QSensor::sensorsForType(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSensorsTypeConverters[SBK_QtSensors_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_setActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setActive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            cppSelf->setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setAlwaysOn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setAlwaysOn";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setAlwaysOn(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAlwaysOn(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlwaysOn(bool)
            cppSelf->setAlwaysOn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setAxesOrientationMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setAxesOrientationMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setAxesOrientationMode(QSensor::AxesOrientationMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAxesOrientationMode(QSensor::AxesOrientationMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSensor::AxesOrientationMode cppArg0{QSensor::FixedOrientation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAxesOrientationMode(QSensor::AxesOrientationMode)
            cppSelf->setAxesOrientationMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBufferSize(int)
            cppSelf->setBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setCurrentOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setCurrentOrientation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setCurrentOrientation(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentOrientation(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentOrientation(int)
            cppSelf->setCurrentOrientation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setDataRate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setDataRate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setDataRate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDataRate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDataRate(int)
            cppSelf->setDataRate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setEfficientBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setEfficientBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setEfficientBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setEfficientBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEfficientBufferSize(int)
            cppSelf->setEfficientBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setIdentifier(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setIdentifier(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIdentifier(QByteArray)
            cppSelf->setIdentifier(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setMaxBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setMaxBufferSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setMaxBufferSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaxBufferSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxBufferSize(int)
            cppSelf->setMaxBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setOutputRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setOutputRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setOutputRange(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setOutputRange(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputRange(int)
            cppSelf->setOutputRange(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setSkipDuplicates(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setSkipDuplicates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setSkipDuplicates(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSkipDuplicates(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSkipDuplicates(bool)
            cppSelf->setSkipDuplicates(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_setUserOrientation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.setUserOrientation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSensor::setUserOrientation(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setUserOrientation(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserOrientation(int)
            cppSelf->setUserOrientation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_skipDuplicates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.skipDuplicates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipDuplicates()const
            bool cppResult = const_cast<const ::QSensor *>(cppSelf)->skipDuplicates();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.start";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // start()
            bool cppResult = cppSelf->start();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtSensors.QSensor.stop";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stop()
            cppSelf->stop();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSensorFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QByteArray cppResult = const_cast<const ::QSensor *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSensorFunc_userOrientation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSensors.QSensor.userOrientation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // userOrientation()const
            int cppResult = const_cast<const ::QSensor *>(cppSelf)->userOrientation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSensor_PropertyStrings[] = {
    "active:isActive:",
    "alwaysOn:isAlwaysOn:",
    "availableDataRates:",
    "axesOrientationMode::",
    "bufferSize::",
    "busy:isBusy",
    "connectedToBackend:isConnectedToBackend",
    "currentOrientation:",
    "dataRate::",
    "description:",
    "efficientBufferSize:",
    "error:",
    "identifier::",
    "maxBufferSize:",
    "outputRange::",
    "outputRanges:",
    "reading:",
    "skipDuplicates::",
    "type:",
    "userOrientation::",
    nullptr // Sentinel
};

static const char *Sbk_QSensor_EnumFlagInfo[] = {
    "AxesOrientationMode:Enum",
    "Feature:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensor_methods[] = {
    {"addFilter", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_addFilter), METH_O, nullptr},
    {"availableDataRates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_availableDataRates), METH_NOARGS, nullptr},
    {"axesOrientationMode", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_axesOrientationMode), METH_NOARGS, nullptr},
    {"backend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_backend), METH_NOARGS, nullptr},
    {"bufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_bufferSize), METH_NOARGS, nullptr},
    {"connectToBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_connectToBackend), METH_NOARGS, nullptr},
    {"currentOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_currentOrientation), METH_NOARGS, nullptr},
    {"dataRate", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_dataRate), METH_NOARGS, nullptr},
    {"defaultSensorForType", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_defaultSensorForType), METH_O|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_description), METH_NOARGS, nullptr},
    {"efficientBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_efficientBufferSize), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_error), METH_NOARGS, nullptr},
    {"filters", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_filters), METH_NOARGS, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_identifier), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isActive), METH_NOARGS, nullptr},
    {"isAlwaysOn", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isAlwaysOn), METH_NOARGS, nullptr},
    {"isBusy", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isBusy), METH_NOARGS, nullptr},
    {"isConnectedToBackend", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isConnectedToBackend), METH_NOARGS, nullptr},
    {"isFeatureSupported", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_isFeatureSupported), METH_O, nullptr},
    {"maxBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_maxBufferSize), METH_NOARGS, nullptr},
    {"outputRange", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_outputRange), METH_NOARGS, nullptr},
    {"outputRanges", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_outputRanges), METH_NOARGS, nullptr},
    {"reading", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_reading), METH_NOARGS, nullptr},
    {"removeFilter", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_removeFilter), METH_O, nullptr},
    {"sensorTypes", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_sensorTypes), METH_NOARGS|METH_STATIC, nullptr},
    {"sensorsForType", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_sensorsForType), METH_O|METH_STATIC, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setActive), METH_O, nullptr},
    {"setAlwaysOn", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setAlwaysOn), METH_O, nullptr},
    {"setAxesOrientationMode", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setAxesOrientationMode), METH_O, nullptr},
    {"setBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setBufferSize), METH_O, nullptr},
    {"setCurrentOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setCurrentOrientation), METH_O, nullptr},
    {"setDataRate", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setDataRate), METH_O, nullptr},
    {"setEfficientBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setEfficientBufferSize), METH_O, nullptr},
    {"setIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setIdentifier), METH_O, nullptr},
    {"setMaxBufferSize", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setMaxBufferSize), METH_O, nullptr},
    {"setOutputRange", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setOutputRange), METH_O, nullptr},
    {"setSkipDuplicates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setSkipDuplicates), METH_O, nullptr},
    {"setUserOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_setUserOrientation), METH_O, nullptr},
    {"skipDuplicates", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_skipDuplicates), METH_NOARGS, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_start), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_stop), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_type), METH_NOARGS, nullptr},
    {"userOrientation", reinterpret_cast<PyCFunction>(Sbk_QSensorFunc_userOrientation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSensor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSensor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSensorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSensor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensor_Type = nullptr;
static PyTypeObject *Sbk_QSensor_TypeF(void)
{
    return _Sbk_QSensor_Type;
}

static PyType_Slot Sbk_QSensor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSensor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensor_spec = {
    "2:PySide6.QtSensors.QSensor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensor_slots
};

} //extern "C"

static void *Sbk_QSensor_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QSensor *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QSensor_Feature_PythonToCpp_QSensor_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSensor::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSensor::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QSensor_Feature_PythonToCpp_QSensor_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX])))
        return QSensor_Feature_PythonToCpp_QSensor_Feature;
    return {};
}
static PyObject *QSensor_Feature_CppToPython_QSensor_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSensor::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX]), castCppIn);

}

static void QSensor_AxesOrientationMode_PythonToCpp_QSensor_AxesOrientationMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSensor::AxesOrientationMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSensor::AxesOrientationMode *>(cppOut) = value;

}
static PythonToCppFunc is_QSensor_AxesOrientationMode_PythonToCpp_QSensor_AxesOrientationMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX])))
        return QSensor_AxesOrientationMode_PythonToCpp_QSensor_AxesOrientationMode;
    return {};
}
static PyObject *QSensor_AxesOrientationMode_CppToPython_QSensor_AxesOrientationMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSensor::AxesOrientationMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensor_PythonToCpp_QSensor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensor_PythonToCpp_QSensor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensor_TypeF()))
        return QSensor_PythonToCpp_QSensor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensor_PTR_CppToPython_QSensor(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QSensor *>(const_cast<void *>(cppIn)), Sbk_QSensor_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSensor_SignatureStrings[] = {
    "PySide6.QtSensors.QSensor(self,type:typing.Union[PySide6.QtCore.QByteArray, char*],parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtSensors.QSensor.addFilter(self,filter:PySide6.QtSensors.QSensorFilter)",
    "PySide6.QtSensors.QSensor.availableDataRates(self)->QList[std.pair[int, int]]",
    "PySide6.QtSensors.QSensor.axesOrientationMode(self)->PySide6.QtSensors.QSensor.AxesOrientationMode",
    "PySide6.QtSensors.QSensor.backend(self)->PySide6.QtSensors.QSensorBackend",
    "PySide6.QtSensors.QSensor.bufferSize(self)->int",
    "PySide6.QtSensors.QSensor.connectToBackend(self)->bool",
    "PySide6.QtSensors.QSensor.currentOrientation(self)->int",
    "PySide6.QtSensors.QSensor.dataRate(self)->int",
    "PySide6.QtSensors.QSensor.defaultSensorForType(type:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.description(self)->QString",
    "PySide6.QtSensors.QSensor.efficientBufferSize(self)->int",
    "PySide6.QtSensors.QSensor.error(self)->int",
    "PySide6.QtSensors.QSensor.filters(self)->QList[PySide6.QtSensors.QSensorFilter]",
    "PySide6.QtSensors.QSensor.identifier(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.isActive(self)->bool",
    "PySide6.QtSensors.QSensor.isAlwaysOn(self)->bool",
    "PySide6.QtSensors.QSensor.isBusy(self)->bool",
    "PySide6.QtSensors.QSensor.isConnectedToBackend(self)->bool",
    "PySide6.QtSensors.QSensor.isFeatureSupported(self,feature:PySide6.QtSensors.QSensor.Feature)->bool",
    "PySide6.QtSensors.QSensor.maxBufferSize(self)->int",
    "PySide6.QtSensors.QSensor.outputRange(self)->int",
    "PySide6.QtSensors.QSensor.outputRanges(self)->QList[PySide6.QtSensors.qoutputrange]",
    "PySide6.QtSensors.QSensor.reading(self)->PySide6.QtSensors.QSensorReading",
    "PySide6.QtSensors.QSensor.removeFilter(self,filter:PySide6.QtSensors.QSensorFilter)",
    "PySide6.QtSensors.QSensor.sensorTypes()->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtSensors.QSensor.sensorsForType(type:typing.Union[PySide6.QtCore.QByteArray, char*])->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtSensors.QSensor.setActive(self,active:bool)",
    "PySide6.QtSensors.QSensor.setAlwaysOn(self,alwaysOn:bool)",
    "PySide6.QtSensors.QSensor.setAxesOrientationMode(self,axesOrientationMode:PySide6.QtSensors.QSensor.AxesOrientationMode)",
    "PySide6.QtSensors.QSensor.setBufferSize(self,bufferSize:int)",
    "PySide6.QtSensors.QSensor.setCurrentOrientation(self,currentOrientation:int)",
    "PySide6.QtSensors.QSensor.setDataRate(self,rate:int)",
    "PySide6.QtSensors.QSensor.setEfficientBufferSize(self,efficientBufferSize:int)",
    "PySide6.QtSensors.QSensor.setIdentifier(self,identifier:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtSensors.QSensor.setMaxBufferSize(self,maxBufferSize:int)",
    "PySide6.QtSensors.QSensor.setOutputRange(self,index:int)",
    "PySide6.QtSensors.QSensor.setSkipDuplicates(self,skipDuplicates:bool)",
    "PySide6.QtSensors.QSensor.setUserOrientation(self,userOrientation:int)",
    "PySide6.QtSensors.QSensor.skipDuplicates(self)->bool",
    "PySide6.QtSensors.QSensor.start(self)->bool",
    "PySide6.QtSensors.QSensor.stop(self)",
    "PySide6.QtSensors.QSensor.type(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtSensors.QSensor.userOrientation(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QSensor(PyObject *module)
{
    _Sbk_QSensor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensor",
        "QSensor*",
        &Sbk_QSensor_spec,
        &Shiboken::callCppDestructor< ::QSensor >,
        Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]),
        0,
        0);
    auto *pyType = Sbk_QSensor_TypeF(); // references _Sbk_QSensor_Type
    InitSignatureStrings(pyType, QSensor_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensor_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensor_PythonToCpp_QSensor_PTR,
        is_QSensor_PythonToCpp_QSensor_PTR_Convertible,
        QSensor_PTR_CppToPython_QSensor);

    Shiboken::Conversions::registerConverterName(converter, "QSensor");
    Shiboken::Conversions::registerConverterName(converter, "QSensor*");
    Shiboken::Conversions::registerConverterName(converter, "QSensor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSensor_TypeF(), &Sbk_QSensor_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSensor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "Buffering",
        "AlwaysOn",
        "GeoValues",
        "FieldOfView",
        "AccelerationMode",
        "SkipDuplicates",
        "AxesOrientation",
        "PressureSensorTemperature",
        "Reserved",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Feature_InitializerValues[] = {
        uint16_t(QSensor::Feature::Buffering),                 //  0x0000  0
        uint16_t(QSensor::Feature::AlwaysOn),                  //  0x0001  1
        uint16_t(QSensor::Feature::GeoValues),                 //  0x0002  2
        uint16_t(QSensor::Feature::FieldOfView),               //  0x0003  3
        uint16_t(QSensor::Feature::AccelerationMode),          //  0x0004  4
        uint16_t(QSensor::Feature::SkipDuplicates),            //  0x0005  5
        uint16_t(QSensor::Feature::AxesOrientation),           //  0x0006  6
        uint16_t(QSensor::Feature::PressureSensorTemperature), //  0x0007  7
        uint16_t(QSensor::Feature::Reserved)                   //  0x0101  257
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSensor_TypeF(),
        "2:PySide6.QtSensors.QSensor.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_Feature_IDX].type = EType;
    // Register converter for enum 'QSensor::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSensor_Feature_CppToPython_QSensor_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSensor_Feature_PythonToCpp_QSensor_Feature,
            is_QSensor_Feature_PythonToCpp_QSensor_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSensor::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
    }
    // End of 'Feature' enum.

    // Initialization of enum 'AxesOrientationMode'.
    const char *AxesOrientationMode_Initializer[] = {
        "FixedOrientation",
        "AutomaticOrientation",
        "UserOrientation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AxesOrientationMode_InitializerValues[] = {
        uint8_t(QSensor::AxesOrientationMode::FixedOrientation),     //  0x00  0
        uint8_t(QSensor::AxesOrientationMode::AutomaticOrientation), //  0x01  1
        uint8_t(QSensor::AxesOrientationMode::UserOrientation)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSensor_TypeF(),
        "2:PySide6.QtSensors.QSensor.AxesOrientationMode",
        AxesOrientationMode_Initializer, AxesOrientationMode_InitializerValues);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensor_AxesOrientationMode_IDX].type = EType;
    // Register converter for enum 'QSensor::AxesOrientationMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSensor_AxesOrientationMode_CppToPython_QSensor_AxesOrientationMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSensor_AxesOrientationMode_PythonToCpp_QSensor_AxesOrientationMode,
            is_QSensor_AxesOrientationMode_PythonToCpp_QSensor_AxesOrientationMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSensor::AxesOrientationMode");
        Shiboken::Conversions::registerConverterName(converter, "AxesOrientationMode");
    }
    // End of 'AxesOrientationMode' enum.

    PySide::Signal::registerSignals(pyType, &::QSensor::staticMetaObject);
    qRegisterMetaType< ::QSensor::Feature >("QSensor::Feature");
    qRegisterMetaType< ::QSensor::AxesOrientationMode >("QSensor::AxesOrientationMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QSensor::staticMetaObject, sizeof(QSensorWrapper));

    return pyType;
}
