// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensorchangesinterface_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSensorChangesInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSensorChangesInterfaceWrapper::QSensorChangesInterfaceWrapper() : QSensorChangesInterface()
{
    resetPyMethodCache();
    // ... middle
}

void QSensorChangesInterfaceWrapper::sensorsChanged()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSensorChangesInterface.sensorsChanged");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sensorsChanged";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSensorChangesInterface.sensorsChanged");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QSensorChangesInterfaceWrapper::~QSensorChangesInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensorChangesInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorChangesInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSensorChangesInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensorChangesInterface >()))
        return -1;

    ::QSensorChangesInterfaceWrapper *cptr{};
    static const char fullName[] = "PySide6.QtSensors.QSensorChangesInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSensorChangesInterface()
            cptr = new ::QSensorChangesInterfaceWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSensorChangesInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSensorChangesInterfaceFunc_sensorsChanged(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensorChangesInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorChangesInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtSensors.QSensorChangesInterface.sensorsChanged";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sensorsChanged()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSensorChangesInterface.sensorsChanged");
                return {};
            }
            cppSelf->sensorsChanged();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSensorChangesInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensorChangesInterface_methods[] = {
    {"sensorsChanged", reinterpret_cast<PyCFunction>(Sbk_QSensorChangesInterfaceFunc_sensorsChanged), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSensorChangesInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSensorChangesInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorChangesInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSensorChangesInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSensorChangesInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensorChangesInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensorChangesInterface_Type = nullptr;
static PyTypeObject *Sbk_QSensorChangesInterface_TypeF(void)
{
    return _Sbk_QSensorChangesInterface_Type;
}

static PyType_Slot Sbk_QSensorChangesInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSensorChangesInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensorChangesInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensorChangesInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensorChangesInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensorChangesInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensorChangesInterface_spec = {
    "2:PySide6.QtSensors.QSensorChangesInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensorChangesInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensorChangesInterface_PythonToCpp_QSensorChangesInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensorChangesInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensorChangesInterface_PythonToCpp_QSensorChangesInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensorChangesInterface_TypeF()))
        return QSensorChangesInterface_PythonToCpp_QSensorChangesInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensorChangesInterface_PTR_CppToPython_QSensorChangesInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QSensorChangesInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QSensorChangesInterface_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSensorChangesInterface_SignatureStrings[] = {
    "PySide6.QtSensors.QSensorChangesInterface(self)",
    "PySide6.QtSensors.QSensorChangesInterface.sensorsChanged(self)",
    nullptr}; // Sentinel

PyTypeObject *init_QSensorChangesInterface(PyObject *module)
{
    _Sbk_QSensorChangesInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensorChangesInterface",
        "QSensorChangesInterface*",
        &Sbk_QSensorChangesInterface_spec,
        &Shiboken::callCppDestructor< ::QSensorChangesInterface >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QSensorChangesInterface_TypeF(); // references _Sbk_QSensorChangesInterface_Type
    InitSignatureStrings(pyType, QSensorChangesInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensorChangesInterface_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensorChangesInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensorChangesInterface_PythonToCpp_QSensorChangesInterface_PTR,
        is_QSensorChangesInterface_PythonToCpp_QSensorChangesInterface_PTR_Convertible,
        QSensorChangesInterface_PTR_CppToPython_QSensorChangesInterface);

    Shiboken::Conversions::registerConverterName(converter, "QSensorChangesInterface");
    Shiboken::Conversions::registerConverterName(converter, "QSensorChangesInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QSensorChangesInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorChangesInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorChangesInterfaceWrapper).name());

    qRegisterMetaType< ::QSensorChangesInterface *>();

    return pyType;
}
