// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbustcpconnectionobserver_wrapper.h"

// Argument includes
#include <QtNetwork/qtcpsocket.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusTcpConnectionObserverWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusTcpConnectionObserverWrapper::QModbusTcpConnectionObserverWrapper() : QModbusTcpConnectionObserver()
{
    resetPyMethodCache();
    // ... middle
}

bool QModbusTcpConnectionObserverWrapper::acceptNewConnection(::QTcpSocket * newClient)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QModbusTcpConnectionObserver.acceptNewConnection");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "acceptNewConnection";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QModbusTcpConnectionObserver.acceptNewConnection");
        return false;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), newClient)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), newClient)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QModbusTcpConnectionObserver", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QModbusTcpConnectionObserverWrapper::~QModbusTcpConnectionObserverWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusTcpConnectionObserver_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpConnectionObserver_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QModbusTcpConnectionObserver");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusTcpConnectionObserver >()))
        return -1;

    ::QModbusTcpConnectionObserverWrapper *cptr{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusTcpConnectionObserver.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QModbusTcpConnectionObserver()
            cptr = new ::QModbusTcpConnectionObserverWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QModbusTcpConnectionObserver >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusTcpConnectionObserverFunc_acceptNewConnection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusTcpConnectionObserver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpConnectionObserver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusTcpConnectionObserver.acceptNewConnection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusTcpConnectionObserver::acceptNewConnection(QTcpSocket*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpSocket_IDX]), (pyArg)))) {
        overloadId = 0; // acceptNewConnection(QTcpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTcpSocket *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // acceptNewConnection(QTcpSocket*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QModbusTcpConnectionObserver.acceptNewConnection");
                return {};
            }
            bool cppResult = cppSelf->acceptNewConnection(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusTcpConnectionObserver_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusTcpConnectionObserver_methods[] = {
    {"acceptNewConnection", reinterpret_cast<PyCFunction>(Sbk_QModbusTcpConnectionObserverFunc_acceptNewConnection), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusTcpConnectionObserver_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusTcpConnectionObserver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpConnectionObserver_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusTcpConnectionObserverWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusTcpConnectionObserver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusTcpConnectionObserver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusTcpConnectionObserver_Type = nullptr;
static PyTypeObject *Sbk_QModbusTcpConnectionObserver_TypeF(void)
{
    return _Sbk_QModbusTcpConnectionObserver_Type;
}

static PyType_Slot Sbk_QModbusTcpConnectionObserver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusTcpConnectionObserver_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusTcpConnectionObserver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusTcpConnectionObserver_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusTcpConnectionObserver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusTcpConnectionObserver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusTcpConnectionObserver_spec = {
    "2:PySide6.QtSerialBus.QModbusTcpConnectionObserver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusTcpConnectionObserver_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusTcpConnectionObserver_PythonToCpp_QModbusTcpConnectionObserver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusTcpConnectionObserver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusTcpConnectionObserver_PythonToCpp_QModbusTcpConnectionObserver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusTcpConnectionObserver_TypeF()))
        return QModbusTcpConnectionObserver_PythonToCpp_QModbusTcpConnectionObserver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusTcpConnectionObserver_PTR_CppToPython_QModbusTcpConnectionObserver(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QModbusTcpConnectionObserver *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QModbusTcpConnectionObserver_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QModbusTcpConnectionObserver_SignatureStrings[] = {
    "PySide6.QtSerialBus.QModbusTcpConnectionObserver(self)",
    "PySide6.QtSerialBus.QModbusTcpConnectionObserver.acceptNewConnection(self,newClient:PySide6.QtNetwork.QTcpSocket)->bool",
    nullptr}; // Sentinel

PyTypeObject *init_QModbusTcpConnectionObserver(PyObject *module)
{
    _Sbk_QModbusTcpConnectionObserver_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusTcpConnectionObserver",
        "QModbusTcpConnectionObserver*",
        &Sbk_QModbusTcpConnectionObserver_spec,
        &Shiboken::callCppDestructor< ::QModbusTcpConnectionObserver >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QModbusTcpConnectionObserver_TypeF(); // references _Sbk_QModbusTcpConnectionObserver_Type
    InitSignatureStrings(pyType, QModbusTcpConnectionObserver_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusTcpConnectionObserver_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpConnectionObserver_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusTcpConnectionObserver_PythonToCpp_QModbusTcpConnectionObserver_PTR,
        is_QModbusTcpConnectionObserver_PythonToCpp_QModbusTcpConnectionObserver_PTR_Convertible,
        QModbusTcpConnectionObserver_PTR_CppToPython_QModbusTcpConnectionObserver);

    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpConnectionObserver");
    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpConnectionObserver*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusTcpConnectionObserver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusTcpConnectionObserver).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusTcpConnectionObserverWrapper).name());

    qRegisterMetaType< ::QModbusTcpConnectionObserver *>();

    return pyType;
}
