// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgesturerecognizer_wrapper.h"

// Argument includes
#include <QtWidgets/qgesture.h>
#include <QtWidgets/qgesturerecognizer.h>
#include <qcoreevent.h>
#include <qnamespace.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGestureRecognizerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGestureRecognizerWrapper::QGestureRecognizerWrapper() : QGestureRecognizer()
{
    resetPyMethodCache();
    // ... middle
}

::QGesture * QGestureRecognizerWrapper::create(::QObject * target)
{
    if (m_PyMethodCache[0])
        return this->::QGestureRecognizer::create(target);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QGestureRecognizer::create(target);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), target)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), target)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    bool invalidateArg0 = Py_REFCNT(pyResult) == 1;
    if (invalidateArg0)
        Shiboken::Object::releaseOwnership(pyResult.object());
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGestureRecognizer", funcName, Shiboken::SbkType< QGesture >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QGesture *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QGestureRecognizer::ResultFlag> QGestureRecognizerWrapper::recognize(::QGesture * state, ::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QGestureRecognizer.recognize");
        return QFlags<QGestureRecognizer::ResultFlag>(0);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QGestureRecognizer::ResultFlag>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "recognize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QGestureRecognizer.recognize");
        return QFlags<QGestureRecognizer::ResultFlag>(0);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), state),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QGestureRecognizer::ResultFlag>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGestureRecognizer_ResultFlag_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGestureRecognizer", funcName, Shiboken::SbkType< QFlags<QGestureRecognizer::ResultFlag> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QGestureRecognizer::ResultFlag>(0);
    }
    ::QFlags<QGestureRecognizer::ResultFlag> cppResult = QFlags<QGestureRecognizer::ResultFlag>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGestureRecognizerWrapper::reset(::QGesture * state)
{
    if (m_PyMethodCache[2]) {
        return this->::QGestureRecognizer::reset(state);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "reset";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QGestureRecognizer::reset(state);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), state)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), state)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QGestureRecognizerWrapper::~QGestureRecognizerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGestureRecognizer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QGestureRecognizer");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGestureRecognizer >()))
        return -1;

    ::QGestureRecognizerWrapper *cptr{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGestureRecognizer()
            cptr = new ::QGestureRecognizerWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGestureRecognizer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGestureRecognizerFunc_create(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGestureRecognizer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGestureRecognizer::create(QObject*)->QGesture*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // create(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QObject*)
            QGesture * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGestureRecognizer::create(cppArg0)
                : cppSelf->create(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), cppResult);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGestureRecognizerFunc_recognize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGestureRecognizer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.recognize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recognize", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGestureRecognizer::recognize(QGesture*,QObject*,QEvent*)->QFlags<QGestureRecognizer::ResultFlag>
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[2])))) {
        overloadId = 0; // recognize(QGesture*,QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGesture *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QEvent *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // recognize(QGesture*,QObject*,QEvent*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QGestureRecognizer.recognize");
                return {};
            }
            QFlags<QGestureRecognizer::ResultFlag> cppResult = cppSelf->recognize(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGestureRecognizer_ResultFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGestureRecognizerFunc_registerRecognizer(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.registerRecognizer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGestureRecognizer::registerRecognizer(QGestureRecognizer*)->Qt::GestureType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]), (pyArg)))) {
        overloadId = 0; // registerRecognizer(QGestureRecognizer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGestureRecognizer *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerRecognizer(QGestureRecognizer*)
            Qt::GestureType cppResult = ::QGestureRecognizer::registerRecognizer(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GestureType_IDX])))->converter, &cppResult);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGestureRecognizerFunc_reset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGestureRecognizer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.reset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGestureRecognizer::reset(QGesture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), (pyArg)))) {
        overloadId = 0; // reset(QGesture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGesture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reset(QGesture*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGestureRecognizer::reset(cppArg0)
                : cppSelf->reset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGestureRecognizerFunc_unregisterRecognizer(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGestureRecognizer.unregisterRecognizer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QGestureRecognizer::unregisterRecognizer(Qt::GestureType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GestureType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // unregisterRecognizer(Qt::GestureType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt::GestureType cppArg0 = static_cast< ::Qt::GestureType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterRecognizer(Qt::GestureType)
            ::QGestureRecognizer::unregisterRecognizer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGestureRecognizer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGestureRecognizer_EnumFlagInfo[] = {
    "ResultFlag:Flag:Result",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGestureRecognizer_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QGestureRecognizerFunc_create), METH_O, nullptr},
    {"recognize", reinterpret_cast<PyCFunction>(Sbk_QGestureRecognizerFunc_recognize), METH_VARARGS, nullptr},
    {"registerRecognizer", reinterpret_cast<PyCFunction>(Sbk_QGestureRecognizerFunc_registerRecognizer), METH_O|METH_STATIC, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QGestureRecognizerFunc_reset), METH_O, nullptr},
    {"unregisterRecognizer", reinterpret_cast<PyCFunction>(Sbk_QGestureRecognizerFunc_unregisterRecognizer), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGestureRecognizer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGestureRecognizer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGestureRecognizerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGestureRecognizer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGestureRecognizer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGestureRecognizer_Type = nullptr;
static PyTypeObject *Sbk_QGestureRecognizer_TypeF(void)
{
    return _Sbk_QGestureRecognizer_Type;
}

static PyType_Slot Sbk_QGestureRecognizer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGestureRecognizer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGestureRecognizer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGestureRecognizer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGestureRecognizer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGestureRecognizer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGestureRecognizer_spec = {
    "2:PySide6.QtWidgets.QGestureRecognizer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGestureRecognizer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QGestureRecognizer_ResultFlag_PythonToCpp_QGestureRecognizer_ResultFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGestureRecognizer::ResultFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGestureRecognizer::ResultFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QGestureRecognizer_ResultFlag_PythonToCpp_QGestureRecognizer_ResultFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_ResultFlag_IDX])))
        return QGestureRecognizer_ResultFlag_PythonToCpp_QGestureRecognizer_ResultFlag;
    return {};
}
static PyObject *QGestureRecognizer_ResultFlag_CppToPython_QGestureRecognizer_ResultFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGestureRecognizer::ResultFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_ResultFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGestureRecognizer_PythonToCpp_QGestureRecognizer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGestureRecognizer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGestureRecognizer_PythonToCpp_QGestureRecognizer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGestureRecognizer_TypeF()))
        return QGestureRecognizer_PythonToCpp_QGestureRecognizer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGestureRecognizer_PTR_CppToPython_QGestureRecognizer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QGestureRecognizer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QGestureRecognizer_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QGestureRecognizer_SignatureStrings[] = {
    "PySide6.QtWidgets.QGestureRecognizer(self)",
    "PySide6.QtWidgets.QGestureRecognizer.create(self,target:PySide6.QtCore.QObject)->PySide6.QtWidgets.QGesture",
    "PySide6.QtWidgets.QGestureRecognizer.recognize(self,state:PySide6.QtWidgets.QGesture,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->PySide6.QtWidgets.QGestureRecognizer.ResultFlag",
    "PySide6.QtWidgets.QGestureRecognizer.registerRecognizer(recognizer:PySide6.QtWidgets.QGestureRecognizer)->PySide6.QtCore.Qt.GestureType",
    "PySide6.QtWidgets.QGestureRecognizer.reset(self,state:PySide6.QtWidgets.QGesture)",
    "PySide6.QtWidgets.QGestureRecognizer.unregisterRecognizer(type:PySide6.QtCore.Qt.GestureType)",
    nullptr}; // Sentinel

PyTypeObject *init_QGestureRecognizer(PyObject *module)
{
    _Sbk_QGestureRecognizer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGestureRecognizer",
        "QGestureRecognizer*",
        &Sbk_QGestureRecognizer_spec,
        &Shiboken::callCppDestructor< ::QGestureRecognizer >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QGestureRecognizer_TypeF(); // references _Sbk_QGestureRecognizer_Type
    InitSignatureStrings(pyType, QGestureRecognizer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGestureRecognizer_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGestureRecognizer_PythonToCpp_QGestureRecognizer_PTR,
        is_QGestureRecognizer_PythonToCpp_QGestureRecognizer_PTR_Convertible,
        QGestureRecognizer_PTR_CppToPython_QGestureRecognizer);

    Shiboken::Conversions::registerConverterName(converter, "QGestureRecognizer");
    Shiboken::Conversions::registerConverterName(converter, "QGestureRecognizer*");
    Shiboken::Conversions::registerConverterName(converter, "QGestureRecognizer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGestureRecognizer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGestureRecognizerWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGestureRecognizer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ResultFlag'.
    const char *ResultFlag_Initializer[] = {
        "Ignore",
        "MayBeGesture",
        "TriggerGesture",
        "FinishGesture",
        "CancelGesture",
        "ResultState_Mask",
        "ConsumeEventHint",
        "ResultHint_Mask",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ResultFlag_InitializerValues[] = {
        uint16_t(QGestureRecognizer::ResultFlag::Ignore),           //  0x0001  1
        uint16_t(QGestureRecognizer::ResultFlag::MayBeGesture),     //  0x0002  2
        uint16_t(QGestureRecognizer::ResultFlag::TriggerGesture),   //  0x0004  4
        uint16_t(QGestureRecognizer::ResultFlag::FinishGesture),    //  0x0008  8
        uint16_t(QGestureRecognizer::ResultFlag::CancelGesture),    //  0x0010  16
        uint16_t(QGestureRecognizer::ResultFlag::ResultState_Mask), //  0x00ff  255
        uint16_t(QGestureRecognizer::ResultFlag::ConsumeEventHint), //  0x0100  256
        uint16_t(QGestureRecognizer::ResultFlag::ResultHint_Mask)   //  0xff00  65280
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGestureRecognizer_TypeF(),
        "2:PySide6.QtWidgets.QGestureRecognizer.ResultFlag",
        ResultFlag_Initializer, ResultFlag_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureRecognizer_ResultFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGestureRecognizer_ResultFlag_IDX].type =
        EType;
    // Register converter for enum 'QGestureRecognizer::ResultFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGestureRecognizer_ResultFlag_CppToPython_QGestureRecognizer_ResultFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGestureRecognizer_ResultFlag_PythonToCpp_QGestureRecognizer_ResultFlag,
            is_QGestureRecognizer_ResultFlag_PythonToCpp_QGestureRecognizer_ResultFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGestureRecognizer::ResultFlag");
        Shiboken::Conversions::registerConverterName(converter, "ResultFlag");
        // Register converter for flag 'QFlags<QGestureRecognizer::ResultFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGestureRecognizer::ResultFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QGestureRecognizer::Result");
    }
    // End of 'ResultFlag' enum/flags.

    qRegisterMetaType< ::QGestureRecognizer *>();
    qRegisterMetaType< ::QGestureRecognizer::ResultFlag >("QGestureRecognizer::ResultFlag");

    return pyType;
}
