// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QGraphicsProxyWidgetWrapper_H
#define SBK_QGraphicsProxyWidgetWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qgraphicsproxywidget.h>

namespace PySide { class DynamicQMetaObject; }

// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
class QGraphicsProxyWidgetWrapper : public QGraphicsProxyWidget
{
public:
    QGraphicsProxyWidgetWrapper(const QGraphicsProxyWidgetWrapper &) = delete;
    QGraphicsProxyWidgetWrapper& operator=(const QGraphicsProxyWidgetWrapper &) = delete;
    QGraphicsProxyWidgetWrapper(QGraphicsProxyWidgetWrapper &&) = delete;
    QGraphicsProxyWidgetWrapper& operator=(QGraphicsProxyWidgetWrapper &&) = delete;

    QGraphicsProxyWidgetWrapper(::QGraphicsItem * parent = nullptr, ::QFlags<Qt::WindowType> wFlags = Qt::WindowFlags());
    void advance(int phase) override;
    ::QRectF boundingRect() const override;
    void changeEvent(::QEvent * event) override;
    void childEvent(::QChildEvent * event) override;
    void closeEvent(::QCloseEvent * event) override;
    bool collidesWithItem(const ::QGraphicsItem * other, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    bool collidesWithPath(const ::QPainterPath & path, ::Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const override;
    void connectNotify(const ::QMetaMethod & signal) override;
    bool contains(const ::QPointF & point) const override;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent * event) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent * event) override;
    void dropEvent(::QGraphicsSceneDragDropEvent * event) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    ::QVariant extension(const ::QVariant & variant) const override;
    void focusInEvent(::QFocusEvent * event) override;
    bool focusNextPrevChild(bool next) override;
    void focusOutEvent(::QFocusEvent * event) override;
    void getContentsMargins(qreal * left, qreal * top, qreal * right, qreal * bottom) const override;
    void grabKeyboardEvent(::QEvent * event) override;
    void grabMouseEvent(::QEvent * event) override;
    void hideEvent(::QHideEvent * event) override;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent * event) override;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent * event) override;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent * event) override;
    void initStyleOption(::QStyleOption * option) const override;
    void inputMethodEvent(::QInputMethodEvent * event) override;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    bool isEmpty() const override;
    bool isObscuredBy(const ::QGraphicsItem * item) const override;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange change, const ::QVariant & value) override;
    void keyPressEvent(::QKeyEvent * event) override;
    void keyReleaseEvent(::QKeyEvent * event) override;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event) override;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent * event) override;
    void mousePressEvent(::QGraphicsSceneMouseEvent * event) override;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent * event) override;
    void moveEvent(::QGraphicsSceneMoveEvent * event) override;
    ::QPainterPath opaqueArea() const override;
    void paint(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget) override;
    void paintWindowFrame(::QPainter * painter, const ::QStyleOptionGraphicsItem * option, ::QWidget * widget = nullptr) override;
    void polishEvent() override;
    ::QVariant propertyChange(const ::QString & propertyName, const ::QVariant & value) override;
    void resizeEvent(::QGraphicsSceneResizeEvent * event) override;
    bool sceneEvent(::QEvent * event) override;
    bool sceneEventFilter(::QGraphicsItem * watched, ::QEvent * event) override;
    void setGeometry(const ::QRectF & rect) override;
    ::QPainterPath shape() const override;
    void showEvent(::QShowEvent * event) override;
    ::QSizeF sizeHint(::Qt::SizeHint which, const ::QSizeF & constraint = QSizeF()) const override;
    void timerEvent(::QTimerEvent * event) override;
    int type() const override;
    void ungrabKeyboardEvent(::QEvent * event) override;
    void ungrabMouseEvent(::QEvent * event) override;
    void updateGeometry() override;
    void wheelEvent(::QGraphicsSceneWheelEvent * event) override;
    bool windowFrameEvent(::QEvent * e) override;
    ::Qt::WindowFrameSection windowFrameSectionAt(const ::QPointF & pos) const override;
    ~QGraphicsProxyWidgetWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[62];
};

#endif // SBK_QGraphicsProxyWidgetWrapper_H

