// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoption_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtwidgets.cpp (qstyleoption-typename)]
const char *styleOptionType(const QStyleOption *o)
{
    switch (o->type) {
    case QStyleOption::SO_Default:
        break;
    case QStyleOption::SO_FocusRect:
        return "QStyleOptionFocusRect";
    case QStyleOption::SO_Button:
        return "QStyleOptionButton";
    case QStyleOption::SO_Tab:
        return "QStyleOptionTab";
    case QStyleOption::SO_MenuItem:
        return "QStyleOptionMenuItem";
    case QStyleOption::SO_Frame:
        return "QStyleOptionFrame";
    case QStyleOption::SO_ProgressBar:
        return "QStyleOptionProgressBar";
    case QStyleOption::SO_ToolBox:
        return "QStyleOptionToolBox";
    case QStyleOption::SO_Header:
        return "QStyleOptionHeader";
    case QStyleOption::SO_DockWidget:
        return "QStyleOptionDockWidget";
    case QStyleOption::SO_ViewItem:
        return "QStyleOptionViewItem";
    case QStyleOption::SO_TabWidgetFrame:
        return "QStyleOptionTabWidgetFrame";
    case QStyleOption::SO_TabBarBase:
        return "QStyleOptionTabBarBase";
    case QStyleOption::SO_RubberBand:
        return "QStyleOptionRubberBand";
    case QStyleOption::SO_ToolBar:
        return "QStyleOptionToolBar";
    case QStyleOption::SO_GraphicsItem:
        return "QStyleOptionGraphicsItem";
    case QStyleOption::SO_Slider:
        return "QStyleOptionSlider";
    case QStyleOption::SO_SpinBox:
        return "QStyleOptionSpinBox";
    case QStyleOption::SO_ToolButton:
        return "QStyleOptionToolButton";
    case QStyleOption::SO_ComboBox:
        return "QStyleOptionComboBox";
    case QStyleOption::SO_TitleBar:
        return "QStyleOptionTitleBar";
    case QStyleOption::SO_GroupBox:
        return "QStyleOptionGroupBox";
    case QStyleOption::SO_SizeGrip:
        return "QStyleOptionSizeGrip";
    default:
        break;
    }
    return "QStyleOption";
}
// END of custom code block [file: ../glue/qtwidgets.cpp (qstyleoption-typename)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOption_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOption >()))
        return -1;

    ::QStyleOption *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyleOption.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QStyleOption", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOption::QStyleOption(QStyleOption)
    // 1: QStyleOption::QStyleOption(int=,int=)
    if (numArgs == 0) {
        overloadId = 1; // QStyleOption(int,int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStyleOption(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // QStyleOption(int,int)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QStyleOption(QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOption(const QStyleOption & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOption *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOption(QStyleOption)
                cptr = new ::QStyleOption(*cppArg0);
            }
            break;
        }
        case 1: // QStyleOption(int version, int type)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_version = Shiboken::String::createStaticString("version");
                if (PyDict_Contains(kwds, key_version) != 0) {
                    value = PyDict_GetItem(kwds, key_version);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_version);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_version);
                }
                static PyObject *const key_type = Shiboken::String::createStaticString("type");
                if (PyDict_Contains(kwds, key_type) != 0) {
                    value = PyDict_GetItem(kwds, key_type);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_type);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_type);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            int cppArg0 = QStyleOption::StyleOptionVersion::Version;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = QStyleOption::OptionType::SO_Default;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOption(int,int)
                cptr = new ::QStyleOption(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOption >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStyleOptionFunc_initFrom(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyleOption.initFrom";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyleOption::initFrom(const QWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // initFrom(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // initFrom(const QWidget*)
            cppSelf->initFrom(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QStyleOption_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOption_EnumFlagInfo[] = {
    "OptionType:Enum",
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOption_methods[] = {
    {"initFrom", reinterpret_cast<PyCFunction>(Sbk_QStyleOptionFunc_initFrom), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOption_get_version(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->version;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOption_set_version(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("version");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("version", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->version;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->version = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOption_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOption_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOption_get_state(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_StateFlag_IDX])))->converter, &cppSelf->state);
    return pyOut;
}
static int Sbk_QStyleOption_set_state(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("state");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_StateFlag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("state", "State");
        return -1;
    }

    auto cppOut_local = cppSelf->state;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->state = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOption_get_direction(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::Qt::LayoutDirection cppOut_local = cppSelf->direction;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOption_set_direction(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("direction");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("direction", "LayoutDirection");
        return -1;
    }

    auto cppOut_local = cppSelf->direction;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->direction = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOption_get_rect(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->rect)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->rect))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->rect)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &(cppSelf->rect), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOption_set_rect(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("rect");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("rect", "QRect");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->rect;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOption_get_fontMetrics(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->fontMetrics)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->fontMetrics))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->fontMetrics)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &(cppSelf->fontMetrics), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOption_set_fontMetrics(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("fontMetrics");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("fontMetrics", "QFontMetrics");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->fontMetrics;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOption_get_palette(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->palette)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->palette))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->palette)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &(cppSelf->palette), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOption_set_palette(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("palette");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("palette", "QPalette");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->palette;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOption_get_styleObject(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppSelf->styleObject);
    return pyOut;
}
static int Sbk_QStyleOption_set_styleObject(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("styleObject");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("styleObject", "QObject");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->styleObject;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "styleObject", pyIn);
    return 0;
}

// Getters and Setters for QStyleOption
static PyGetSetDef Sbk_QStyleOption_getsetlist[] = {
    {const_cast<char *>("version"), Sbk_QStyleOption_get_version, Sbk_QStyleOption_set_version, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QStyleOption_get_type, Sbk_QStyleOption_set_type, nullptr, nullptr},
    {const_cast<char *>("state"), Sbk_QStyleOption_get_state, Sbk_QStyleOption_set_state, nullptr, nullptr},
    {const_cast<char *>("direction"), Sbk_QStyleOption_get_direction, Sbk_QStyleOption_set_direction, nullptr, nullptr},
    {const_cast<char *>("rect"), Sbk_QStyleOption_get_rect, Sbk_QStyleOption_set_rect, nullptr, nullptr},
    {const_cast<char *>("fontMetrics"), Sbk_QStyleOption_get_fontMetrics, Sbk_QStyleOption_set_fontMetrics, nullptr, nullptr},
    {const_cast<char *>("palette"), Sbk_QStyleOption_get_palette, Sbk_QStyleOption_set_palette, nullptr, nullptr},
    {const_cast<char *>("styleObject"), Sbk_QStyleOption_get_styleObject, Sbk_QStyleOption_set_styleObject, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOption_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOption_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QStyleOption__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOption *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOption_Type = nullptr;
static PyTypeObject *Sbk_QStyleOption_TypeF(void)
{
    return _Sbk_QStyleOption_Type;
}

static PyType_Slot Sbk_QStyleOption_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QStyleOption__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOption_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOption_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOption_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOption_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOption_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOption_spec = {
    "2:PySide6.QtWidgets.QStyleOption",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOption_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QStyleOption_OptionType_PythonToCpp_QStyleOption_OptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOption::OptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOption::OptionType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOption_OptionType_PythonToCpp_QStyleOption_OptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_OptionType_IDX])))
        return QStyleOption_OptionType_PythonToCpp_QStyleOption_OptionType;
    return {};
}
static PyObject *QStyleOption_OptionType_CppToPython_QStyleOption_OptionType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOption::OptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_OptionType_IDX]), castCppIn);

}

static void QStyleOption_StyleOptionType_PythonToCpp_QStyleOption_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOption::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOption::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOption_StyleOptionType_PythonToCpp_QStyleOption_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionType_IDX])))
        return QStyleOption_StyleOptionType_PythonToCpp_QStyleOption_StyleOptionType;
    return {};
}
static PyObject *QStyleOption_StyleOptionType_CppToPython_QStyleOption_StyleOptionType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOption::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionType_IDX]), castCppIn);

}

static void QStyleOption_StyleOptionVersion_PythonToCpp_QStyleOption_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOption::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOption::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOption_StyleOptionVersion_PythonToCpp_QStyleOption_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionVersion_IDX])))
        return QStyleOption_StyleOptionVersion_PythonToCpp_QStyleOption_StyleOptionVersion;
    return {};
}
static PyObject *QStyleOption_StyleOptionVersion_CppToPython_QStyleOption_StyleOptionVersion(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOption::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOption_PythonToCpp_QStyleOption_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOption_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOption_PythonToCpp_QStyleOption_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOption_TypeF()))
        return QStyleOption_PythonToCpp_QStyleOption_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOption_PTR_CppToPython_QStyleOption(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QStyleOption *>(cppIn);
    const char *typeName = styleOptionType(tCppIn);
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QStyleOption_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStyleOption_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QStyleOption(self,other:PySide6.QtWidgets.QStyleOption)",
    "0:PySide6.QtWidgets.QStyleOption(self,version:int=QStyleOption.StyleOptionVersion.Version,type:int=QStyleOption.OptionType.SO_Default)",
    "PySide6.QtWidgets.QStyleOption.initFrom(self,w:PySide6.QtWidgets.QWidget)",
    nullptr}; // Sentinel

PyTypeObject *init_QStyleOption(PyObject *module)
{
    _Sbk_QStyleOption_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOption",
        "QStyleOption*",
        &Sbk_QStyleOption_spec,
        &Shiboken::callCppDestructor< ::QStyleOption >,
        nullptr,
        0,
        0);
    auto *pyType = Sbk_QStyleOption_TypeF(); // references _Sbk_QStyleOption_Type
    InitSignatureStrings(pyType, QStyleOption_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOption_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOption_PythonToCpp_QStyleOption_PTR,
        is_QStyleOption_PythonToCpp_QStyleOption_PTR_Convertible,
        QStyleOption_PTR_CppToPython_QStyleOption);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOption");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOption*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOption&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOption).name());


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOption_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OptionType'.
    const char *OptionType_Initializer[] = {
        "SO_Default",
        "SO_FocusRect",
        "SO_Button",
        "SO_Tab",
        "SO_MenuItem",
        "SO_Frame",
        "SO_ProgressBar",
        "SO_ToolBox",
        "SO_Header",
        "SO_DockWidget",
        "SO_ViewItem",
        "SO_TabWidgetFrame",
        "SO_TabBarBase",
        "SO_RubberBand",
        "SO_ToolBar",
        "SO_GraphicsItem",
        "SO_Complex",
        "SO_Slider",
        "SO_SpinBox",
        "SO_ToolButton",
        "SO_ComboBox",
        "SO_TitleBar",
        "SO_GroupBox",
        "SO_SizeGrip",
        "SO_CustomBase",
        "SO_ComplexCustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t OptionType_InitializerValues[] = {
        uint32_t(QStyleOption::OptionType::SO_Default),          //  0x00000000  0
        uint32_t(QStyleOption::OptionType::SO_FocusRect),        //  0x00000001  1
        uint32_t(QStyleOption::OptionType::SO_Button),           //  0x00000002  2
        uint32_t(QStyleOption::OptionType::SO_Tab),              //  0x00000003  3
        uint32_t(QStyleOption::OptionType::SO_MenuItem),         //  0x00000004  4
        uint32_t(QStyleOption::OptionType::SO_Frame),            //  0x00000005  5
        uint32_t(QStyleOption::OptionType::SO_ProgressBar),      //  0x00000006  6
        uint32_t(QStyleOption::OptionType::SO_ToolBox),          //  0x00000007  7
        uint32_t(QStyleOption::OptionType::SO_Header),           //  0x00000008  8
        uint32_t(QStyleOption::OptionType::SO_DockWidget),       //  0x00000009  9
        uint32_t(QStyleOption::OptionType::SO_ViewItem),         //  0x0000000a  10
        uint32_t(QStyleOption::OptionType::SO_TabWidgetFrame),   //  0x0000000b  11
        uint32_t(QStyleOption::OptionType::SO_TabBarBase),       //  0x0000000c  12
        uint32_t(QStyleOption::OptionType::SO_RubberBand),       //  0x0000000d  13
        uint32_t(QStyleOption::OptionType::SO_ToolBar),          //  0x0000000e  14
        uint32_t(QStyleOption::OptionType::SO_GraphicsItem),     //  0x0000000f  15
        uint32_t(QStyleOption::OptionType::SO_Complex),          //  0x000f0000  983040
        uint32_t(QStyleOption::OptionType::SO_Slider),           //  0x000f0001  983041
        uint32_t(QStyleOption::OptionType::SO_SpinBox),          //  0x000f0002  983042
        uint32_t(QStyleOption::OptionType::SO_ToolButton),       //  0x000f0003  983043
        uint32_t(QStyleOption::OptionType::SO_ComboBox),         //  0x000f0004  983044
        uint32_t(QStyleOption::OptionType::SO_TitleBar),         //  0x000f0005  983045
        uint32_t(QStyleOption::OptionType::SO_GroupBox),         //  0x000f0006  983046
        uint32_t(QStyleOption::OptionType::SO_SizeGrip),         //  0x000f0007  983047
        uint32_t(QStyleOption::OptionType::SO_CustomBase),       //  0x00000f00  3840
        uint32_t(QStyleOption::OptionType::SO_ComplexCustomBase) //  0x0f000000  251658240
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOption_TypeF(),
        "2:PySide6.QtWidgets.QStyleOption.OptionType",
        OptionType_Initializer, OptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_OptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOption::OptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOption_OptionType_CppToPython_QStyleOption_OptionType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOption_OptionType_PythonToCpp_QStyleOption_OptionType,
            is_QStyleOption_OptionType_PythonToCpp_QStyleOption_OptionType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOption::OptionType");
        Shiboken::Conversions::registerConverterName(converter, "OptionType");
    }
    // End of 'OptionType' enum.

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOption::StyleOptionType::Type) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOption_TypeF(),
        "2:PySide6.QtWidgets.QStyleOption.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOption::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOption_StyleOptionType_CppToPython_QStyleOption_StyleOptionType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOption_StyleOptionType_PythonToCpp_QStyleOption_StyleOptionType,
            is_QStyleOption_StyleOptionType_PythonToCpp_QStyleOption_StyleOptionType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOption::StyleOptionType");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionType");
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOption::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOption_TypeF(),
        "2:PySide6.QtWidgets.QStyleOption.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOption::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOption_StyleOptionVersion_CppToPython_QStyleOption_StyleOptionVersion);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOption_StyleOptionVersion_PythonToCpp_QStyleOption_StyleOptionVersion,
            is_QStyleOption_StyleOptionVersion_PythonToCpp_QStyleOption_StyleOptionVersion_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOption::StyleOptionVersion");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionVersion");
    }
    // End of 'StyleOptionVersion' enum.


    qRegisterMetaType< ::QStyleOption *>();
    qRegisterMetaType< ::QStyleOption::OptionType >("QStyleOption::OptionType");
    qRegisterMetaType< ::QStyleOption::StyleOptionType >("QStyleOption::StyleOptionType");
    qRegisterMetaType< ::QStyleOption::StyleOptionVersion >("QStyleOption::StyleOptionVersion");

    return pyType;
}

