// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptionmenuitem_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionMenuItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionMenuItem >()))
        return -1;

    ::QStyleOptionMenuItem *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyleOptionMenuItem.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionMenuItem", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionMenuItem::QStyleOptionMenuItem()
    // 1: QStyleOptionMenuItem::QStyleOptionMenuItem(QStyleOptionMenuItem)
    // 2: QStyleOptionMenuItem::QStyleOptionMenuItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionMenuItem()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionMenuItem(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionMenuItem(QStyleOptionMenuItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionMenuItem()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionMenuItem()
                cptr = new ::QStyleOptionMenuItem();
            }
            break;
        }
        case 1: // QStyleOptionMenuItem(const QStyleOptionMenuItem & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionMenuItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionMenuItem(QStyleOptionMenuItem)
                cptr = new ::QStyleOptionMenuItem(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionMenuItem(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionMenuItem(int)
                cptr = new ::QStyleOptionMenuItem(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionMenuItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionMenuItem_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionMenuItem_EnumFlagInfo[] = {
    "CheckType:Enum",
    "MenuItemType:Enum",
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionMenuItem_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionMenuItem_get_menuItemType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QStyleOptionMenuItem::MenuItemType cppOut_local = cppSelf->menuItemType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_MenuItemType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_menuItemType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("menuItemType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_MenuItemType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("menuItemType", "MenuItemType");
        return -1;
    }

    auto cppOut_local = cppSelf->menuItemType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->menuItemType = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_checkType(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QStyleOptionMenuItem::CheckType cppOut_local = cppSelf->checkType;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_CheckType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_checkType(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("checkType");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_CheckType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("checkType", "CheckType");
        return -1;
    }

    auto cppOut_local = cppSelf->checkType;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->checkType = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_checked(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->checked;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_checked(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("checked");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("checked", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->checked;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->checked = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->menuHasCheckableItems;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("menuHasCheckableItems");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("menuHasCheckableItems", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->menuHasCheckableItems;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->menuHasCheckableItems = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_menuRect(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->menuRect)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->menuRect))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->menuRect)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &(cppSelf->menuRect), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_menuRect(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("menuRect");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("menuRect", "QRect");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->menuRect;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_text(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->text);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_text(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("text");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("text", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->text;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_icon(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->icon)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->icon))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->icon)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &(cppSelf->icon), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_icon(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("icon");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("icon", "QIcon");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->icon;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_maxIconWidth(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->maxIconWidth;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_maxIconWidth(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("maxIconWidth");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("maxIconWidth", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->maxIconWidth;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->maxIconWidth = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_reservedShortcutWidth(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->reservedShortcutWidth;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_reservedShortcutWidth(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("reservedShortcutWidth");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("reservedShortcutWidth", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->reservedShortcutWidth;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->reservedShortcutWidth = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionMenuItem_get_font(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->font)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->font))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->font)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &(cppSelf->font), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionMenuItem_set_font(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionMenuItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("font");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("font", "QFont");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->font;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for QStyleOptionMenuItem
static PyGetSetDef Sbk_QStyleOptionMenuItem_getsetlist[] = {
    {const_cast<char *>("menuItemType"), Sbk_QStyleOptionMenuItem_get_menuItemType, Sbk_QStyleOptionMenuItem_set_menuItemType, nullptr, nullptr},
    {const_cast<char *>("checkType"), Sbk_QStyleOptionMenuItem_get_checkType, Sbk_QStyleOptionMenuItem_set_checkType, nullptr, nullptr},
    {const_cast<char *>("checked"), Sbk_QStyleOptionMenuItem_get_checked, Sbk_QStyleOptionMenuItem_set_checked, nullptr, nullptr},
    {const_cast<char *>("menuHasCheckableItems"), Sbk_QStyleOptionMenuItem_get_menuHasCheckableItems, Sbk_QStyleOptionMenuItem_set_menuHasCheckableItems, nullptr, nullptr},
    {const_cast<char *>("menuRect"), Sbk_QStyleOptionMenuItem_get_menuRect, Sbk_QStyleOptionMenuItem_set_menuRect, nullptr, nullptr},
    {const_cast<char *>("text"), Sbk_QStyleOptionMenuItem_get_text, Sbk_QStyleOptionMenuItem_set_text, nullptr, nullptr},
    {const_cast<char *>("icon"), Sbk_QStyleOptionMenuItem_get_icon, Sbk_QStyleOptionMenuItem_set_icon, nullptr, nullptr},
    {const_cast<char *>("maxIconWidth"), Sbk_QStyleOptionMenuItem_get_maxIconWidth, Sbk_QStyleOptionMenuItem_set_maxIconWidth, nullptr, nullptr},
    {const_cast<char *>("reservedShortcutWidth"), Sbk_QStyleOptionMenuItem_get_reservedShortcutWidth, Sbk_QStyleOptionMenuItem_set_reservedShortcutWidth, nullptr, nullptr},
    {const_cast<char *>("font"), Sbk_QStyleOptionMenuItem_get_font, Sbk_QStyleOptionMenuItem_set_font, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionMenuItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionMenuItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionMenuItem_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionMenuItem_TypeF(void)
{
    return _Sbk_QStyleOptionMenuItem_Type;
}

static PyType_Slot Sbk_QStyleOptionMenuItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionMenuItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionMenuItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionMenuItem_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionMenuItem_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionMenuItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionMenuItem_spec = {
    "2:PySide6.QtWidgets.QStyleOptionMenuItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionMenuItem_slots
};

} //extern "C"

static void *Sbk_QStyleOptionMenuItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
     if (qstyleoption_cast<const QStyleOptionMenuItem *>( reinterpret_cast< ::QStyleOptionMenuItem *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QStyleOptionMenuItem_StyleOptionType_PythonToCpp_QStyleOptionMenuItem_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionMenuItem::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionMenuItem::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionMenuItem_StyleOptionType_PythonToCpp_QStyleOptionMenuItem_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionType_IDX])))
        return QStyleOptionMenuItem_StyleOptionType_PythonToCpp_QStyleOptionMenuItem_StyleOptionType;
    return {};
}
static PyObject *QStyleOptionMenuItem_StyleOptionType_CppToPython_QStyleOptionMenuItem_StyleOptionType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionMenuItem::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionType_IDX]), castCppIn);

}

static void QStyleOptionMenuItem_StyleOptionVersion_PythonToCpp_QStyleOptionMenuItem_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionMenuItem::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionMenuItem::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionMenuItem_StyleOptionVersion_PythonToCpp_QStyleOptionMenuItem_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionVersion_IDX])))
        return QStyleOptionMenuItem_StyleOptionVersion_PythonToCpp_QStyleOptionMenuItem_StyleOptionVersion;
    return {};
}
static PyObject *QStyleOptionMenuItem_StyleOptionVersion_CppToPython_QStyleOptionMenuItem_StyleOptionVersion(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionMenuItem::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionVersion_IDX]), castCppIn);

}

static void QStyleOptionMenuItem_MenuItemType_PythonToCpp_QStyleOptionMenuItem_MenuItemType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionMenuItem::MenuItemType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionMenuItem::MenuItemType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionMenuItem_MenuItemType_PythonToCpp_QStyleOptionMenuItem_MenuItemType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_MenuItemType_IDX])))
        return QStyleOptionMenuItem_MenuItemType_PythonToCpp_QStyleOptionMenuItem_MenuItemType;
    return {};
}
static PyObject *QStyleOptionMenuItem_MenuItemType_CppToPython_QStyleOptionMenuItem_MenuItemType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionMenuItem::MenuItemType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_MenuItemType_IDX]), castCppIn);

}

static void QStyleOptionMenuItem_CheckType_PythonToCpp_QStyleOptionMenuItem_CheckType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionMenuItem::CheckType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionMenuItem::CheckType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionMenuItem_CheckType_PythonToCpp_QStyleOptionMenuItem_CheckType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_CheckType_IDX])))
        return QStyleOptionMenuItem_CheckType_PythonToCpp_QStyleOptionMenuItem_CheckType;
    return {};
}
static PyObject *QStyleOptionMenuItem_CheckType_CppToPython_QStyleOptionMenuItem_CheckType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionMenuItem::CheckType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_CheckType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionMenuItem_PythonToCpp_QStyleOptionMenuItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionMenuItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionMenuItem_PythonToCpp_QStyleOptionMenuItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionMenuItem_TypeF()))
        return QStyleOptionMenuItem_PythonToCpp_QStyleOptionMenuItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionMenuItem_PTR_CppToPython_QStyleOptionMenuItem(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QStyleOptionMenuItem *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QStyleOptionMenuItem_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStyleOptionMenuItem_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionMenuItem(self)",
    "1:PySide6.QtWidgets.QStyleOptionMenuItem(self,other:PySide6.QtWidgets.QStyleOptionMenuItem)",
    "0:PySide6.QtWidgets.QStyleOptionMenuItem(self,version:int)",
    nullptr}; // Sentinel

PyTypeObject *init_QStyleOptionMenuItem(PyObject *module)
{
    _Sbk_QStyleOptionMenuItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionMenuItem",
        "QStyleOptionMenuItem*",
        &Sbk_QStyleOptionMenuItem_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionMenuItem >,
        Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]),
        0,
        0);
    auto *pyType = Sbk_QStyleOptionMenuItem_TypeF(); // references _Sbk_QStyleOptionMenuItem_Type
    InitSignatureStrings(pyType, QStyleOptionMenuItem_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionMenuItem_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionMenuItem_PythonToCpp_QStyleOptionMenuItem_PTR,
        is_QStyleOptionMenuItem_PythonToCpp_QStyleOptionMenuItem_PTR_Convertible,
        QStyleOptionMenuItem_PTR_CppToPython_QStyleOptionMenuItem);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionMenuItem).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionMenuItem_TypeF(), &Sbk_QStyleOptionMenuItem_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionMenuItem_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionType_InitializerValues[] = {
        uint8_t(QStyleOptionMenuItem::StyleOptionType::Type) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionMenuItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionMenuItem.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionMenuItem::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionMenuItem_StyleOptionType_CppToPython_QStyleOptionMenuItem_StyleOptionType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionMenuItem_StyleOptionType_PythonToCpp_QStyleOptionMenuItem_StyleOptionType,
            is_QStyleOptionMenuItem_StyleOptionType_PythonToCpp_QStyleOptionMenuItem_StyleOptionType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem::StyleOptionType");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionType");
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionMenuItem::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionMenuItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionMenuItem.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionMenuItem::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionMenuItem_StyleOptionVersion_CppToPython_QStyleOptionMenuItem_StyleOptionVersion);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionMenuItem_StyleOptionVersion_PythonToCpp_QStyleOptionMenuItem_StyleOptionVersion,
            is_QStyleOptionMenuItem_StyleOptionVersion_PythonToCpp_QStyleOptionMenuItem_StyleOptionVersion_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem::StyleOptionVersion");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionVersion");
    }
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'MenuItemType'.
    const char *MenuItemType_Initializer[] = {
        "Normal",
        "DefaultItem",
        "Separator",
        "SubMenu",
        "Scroller",
        "TearOff",
        "Margin",
        "EmptyArea",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MenuItemType_InitializerValues[] = {
        uint8_t(QStyleOptionMenuItem::MenuItemType::Normal),      //  0x00  0
        uint8_t(QStyleOptionMenuItem::MenuItemType::DefaultItem), //  0x01  1
        uint8_t(QStyleOptionMenuItem::MenuItemType::Separator),   //  0x02  2
        uint8_t(QStyleOptionMenuItem::MenuItemType::SubMenu),     //  0x03  3
        uint8_t(QStyleOptionMenuItem::MenuItemType::Scroller),    //  0x04  4
        uint8_t(QStyleOptionMenuItem::MenuItemType::TearOff),     //  0x05  5
        uint8_t(QStyleOptionMenuItem::MenuItemType::Margin),      //  0x06  6
        uint8_t(QStyleOptionMenuItem::MenuItemType::EmptyArea)    //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionMenuItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionMenuItem.MenuItemType",
        MenuItemType_Initializer, MenuItemType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_MenuItemType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionMenuItem::MenuItemType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionMenuItem_MenuItemType_CppToPython_QStyleOptionMenuItem_MenuItemType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionMenuItem_MenuItemType_PythonToCpp_QStyleOptionMenuItem_MenuItemType,
            is_QStyleOptionMenuItem_MenuItemType_PythonToCpp_QStyleOptionMenuItem_MenuItemType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem::MenuItemType");
        Shiboken::Conversions::registerConverterName(converter, "MenuItemType");
    }
    // End of 'MenuItemType' enum.

    // Initialization of enum 'CheckType'.
    const char *CheckType_Initializer[] = {
        "NotCheckable",
        "Exclusive",
        "NonExclusive",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CheckType_InitializerValues[] = {
        uint8_t(QStyleOptionMenuItem::CheckType::NotCheckable), //  0x00  0
        uint8_t(QStyleOptionMenuItem::CheckType::Exclusive),    //  0x01  1
        uint8_t(QStyleOptionMenuItem::CheckType::NonExclusive)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionMenuItem_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionMenuItem.CheckType",
        CheckType_Initializer, CheckType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_CheckType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionMenuItem::CheckType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionMenuItem_CheckType_CppToPython_QStyleOptionMenuItem_CheckType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionMenuItem_CheckType_PythonToCpp_QStyleOptionMenuItem_CheckType,
            is_QStyleOptionMenuItem_CheckType_PythonToCpp_QStyleOptionMenuItem_CheckType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionMenuItem::CheckType");
        Shiboken::Conversions::registerConverterName(converter, "CheckType");
    }
    // End of 'CheckType' enum.

    qRegisterMetaType< ::QStyleOptionMenuItem *>();
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionType >("QStyleOptionMenuItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionMenuItem::StyleOptionVersion >("QStyleOptionMenuItem::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionMenuItem::MenuItemType >("QStyleOptionMenuItem::MenuItemType");
    qRegisterMetaType< ::QStyleOptionMenuItem::CheckType >("QStyleOptionMenuItem::CheckType");

    return pyType;
}
