// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptionspinbox_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionSpinBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionSpinBox >()))
        return -1;

    ::QStyleOptionSpinBox *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyleOptionSpinBox.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionSpinBox", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionSpinBox::QStyleOptionSpinBox()
    // 1: QStyleOptionSpinBox::QStyleOptionSpinBox(QStyleOptionSpinBox)
    // 2: QStyleOptionSpinBox::QStyleOptionSpinBox(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionSpinBox()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionSpinBox(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionSpinBox(QStyleOptionSpinBox)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionSpinBox()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionSpinBox()
                cptr = new ::QStyleOptionSpinBox();
            }
            break;
        }
        case 1: // QStyleOptionSpinBox(const QStyleOptionSpinBox & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionSpinBox *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionSpinBox(QStyleOptionSpinBox)
                cptr = new ::QStyleOptionSpinBox(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionSpinBox(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionSpinBox(int)
                cptr = new ::QStyleOptionSpinBox(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionSpinBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionSpinBox_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionSpinBox_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionSpinBox_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionSpinBox_get_buttonSymbols(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QAbstractSpinBox::ButtonSymbols cppOut_local = cppSelf->buttonSymbols;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionSpinBox_set_buttonSymbols(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("buttonSymbols");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_ButtonSymbols_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("buttonSymbols", "ButtonSymbols");
        return -1;
    }

    auto cppOut_local = cppSelf->buttonSymbols;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->buttonSymbols = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionSpinBox_get_stepEnabled(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX])))->converter, &cppSelf->stepEnabled);
    return pyOut;
}
static int Sbk_QStyleOptionSpinBox_set_stepEnabled(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("stepEnabled");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QAbstractSpinBox_StepEnabledFlag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("stepEnabled", "StepEnabled");
        return -1;
    }

    auto cppOut_local = cppSelf->stepEnabled;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->stepEnabled = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionSpinBox_get_frame(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->frame;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionSpinBox_set_frame(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionSpinBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("frame");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("frame", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->frame;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->frame = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleOptionSpinBox
static PyGetSetDef Sbk_QStyleOptionSpinBox_getsetlist[] = {
    {const_cast<char *>("buttonSymbols"), Sbk_QStyleOptionSpinBox_get_buttonSymbols, Sbk_QStyleOptionSpinBox_set_buttonSymbols, nullptr, nullptr},
    {const_cast<char *>("stepEnabled"), Sbk_QStyleOptionSpinBox_get_stepEnabled, Sbk_QStyleOptionSpinBox_set_stepEnabled, nullptr, nullptr},
    {const_cast<char *>("frame"), Sbk_QStyleOptionSpinBox_get_frame, Sbk_QStyleOptionSpinBox_set_frame, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionSpinBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionSpinBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionSpinBox_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionSpinBox_TypeF(void)
{
    return _Sbk_QStyleOptionSpinBox_Type;
}

static PyType_Slot Sbk_QStyleOptionSpinBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionSpinBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionSpinBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionSpinBox_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionSpinBox_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionSpinBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionSpinBox_spec = {
    "2:PySide6.QtWidgets.QStyleOptionSpinBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionSpinBox_slots
};

} //extern "C"

static void *Sbk_QStyleOptionSpinBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
     if (qstyleoption_cast<const QStyleOptionSpinBox *>( reinterpret_cast< ::QStyleOptionSpinBox *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QStyleOptionSpinBox_StyleOptionType_PythonToCpp_QStyleOptionSpinBox_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionSpinBox::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionSpinBox::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionSpinBox_StyleOptionType_PythonToCpp_QStyleOptionSpinBox_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionType_IDX])))
        return QStyleOptionSpinBox_StyleOptionType_PythonToCpp_QStyleOptionSpinBox_StyleOptionType;
    return {};
}
static PyObject *QStyleOptionSpinBox_StyleOptionType_CppToPython_QStyleOptionSpinBox_StyleOptionType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionSpinBox::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionType_IDX]), castCppIn);

}

static void QStyleOptionSpinBox_StyleOptionVersion_PythonToCpp_QStyleOptionSpinBox_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionSpinBox::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionSpinBox::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionSpinBox_StyleOptionVersion_PythonToCpp_QStyleOptionSpinBox_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionVersion_IDX])))
        return QStyleOptionSpinBox_StyleOptionVersion_PythonToCpp_QStyleOptionSpinBox_StyleOptionVersion;
    return {};
}
static PyObject *QStyleOptionSpinBox_StyleOptionVersion_CppToPython_QStyleOptionSpinBox_StyleOptionVersion(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionSpinBox::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionSpinBox_PythonToCpp_QStyleOptionSpinBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionSpinBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionSpinBox_PythonToCpp_QStyleOptionSpinBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionSpinBox_TypeF()))
        return QStyleOptionSpinBox_PythonToCpp_QStyleOptionSpinBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionSpinBox_PTR_CppToPython_QStyleOptionSpinBox(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QStyleOptionSpinBox *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QStyleOptionSpinBox_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStyleOptionSpinBox_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionSpinBox(self)",
    "1:PySide6.QtWidgets.QStyleOptionSpinBox(self,other:PySide6.QtWidgets.QStyleOptionSpinBox)",
    "0:PySide6.QtWidgets.QStyleOptionSpinBox(self,version:int)",
    nullptr}; // Sentinel

PyTypeObject *init_QStyleOptionSpinBox(PyObject *module)
{
    _Sbk_QStyleOptionSpinBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionSpinBox",
        "QStyleOptionSpinBox*",
        &Sbk_QStyleOptionSpinBox_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionSpinBox >,
        Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]),
        0,
        0);
    auto *pyType = Sbk_QStyleOptionSpinBox_TypeF(); // references _Sbk_QStyleOptionSpinBox_Type
    InitSignatureStrings(pyType, QStyleOptionSpinBox_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionSpinBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionSpinBox_PythonToCpp_QStyleOptionSpinBox_PTR,
        is_QStyleOptionSpinBox_PythonToCpp_QStyleOptionSpinBox_PTR_Convertible,
        QStyleOptionSpinBox_PTR_CppToPython_QStyleOptionSpinBox);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionSpinBox");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionSpinBox*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionSpinBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionSpinBox).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionSpinBox_TypeF(), &Sbk_QStyleOptionSpinBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionSpinBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StyleOptionType_InitializerValues[] = {
        uint32_t(QStyleOptionSpinBox::StyleOptionType::Type) //  0x000f0002  983042
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionSpinBox.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionSpinBox::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionSpinBox_StyleOptionType_CppToPython_QStyleOptionSpinBox_StyleOptionType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionSpinBox_StyleOptionType_PythonToCpp_QStyleOptionSpinBox_StyleOptionType,
            is_QStyleOptionSpinBox_StyleOptionType_PythonToCpp_QStyleOptionSpinBox_StyleOptionType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionSpinBox::StyleOptionType");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionType");
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionSpinBox::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionSpinBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionSpinBox.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionSpinBox::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionSpinBox_StyleOptionVersion_CppToPython_QStyleOptionSpinBox_StyleOptionVersion);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionSpinBox_StyleOptionVersion_PythonToCpp_QStyleOptionSpinBox_StyleOptionVersion,
            is_QStyleOptionSpinBox_StyleOptionVersion_PythonToCpp_QStyleOptionSpinBox_StyleOptionVersion_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionSpinBox::StyleOptionVersion");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionVersion");
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleOptionSpinBox *>();
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionType >("QStyleOptionSpinBox::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionSpinBox::StyleOptionVersion >("QStyleOptionSpinBox::StyleOptionVersion");

    return pyType;
}
