// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcborvalue_wrapper.h"

// Argument includes
#include <QString>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qbytearray.h>
#include <qcborarray.h>
#include <qcborcommon.h>
#include <qcbormap.h>
#include <qcborstream.h>
#include <qcborvalue.h>
#include <qdatetime.h>
#include <qjsonvalue.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregularexpression.h>
#include <qurl.h>
#include <quuid.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCborValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCborValue >()))
        return -1;

    ::QCborValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QCborValue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCborValue::QCborValue()
    // 1: QCborValue::QCborValue(QCborKnownTags,const QCborValue&=)
    // 2: QCborValue::QCborValue(QCborSimpleType)
    // 3: QCborValue::QCborValue(QCborTag,const QCborValue&=)
    // 4: QCborValue::QCborValue(QCborValue::Type)
    // 5: QCborValue::QCborValue(QLatin1String)
    // 6: QCborValue::QCborValue(QStringView)
    // 7: QCborValue::QCborValue(bool)
    // 8: QCborValue::QCborValue(QByteArray)
    // 9: QCborValue::QCborValue(QCborArray)
    // 10: QCborValue::QCborValue(QCborMap)
    // 11: QCborValue::QCborValue(QCborValue)
    // 12: QCborValue::QCborValue(QDateTime)
    // 13: QCborValue::QCborValue(QRegularExpression)
    // 14: QCborValue::QCborValue(QString)
    // 15: QCborValue::QCborValue(QUrl)
    // 16: QCborValue::QCborValue(QUuid)
    // 17: QCborValue::QCborValue(const char*)
    // 18: QCborValue::QCborValue(double)
    // 19: QCborValue::QCborValue(int)
    // 20: QCborValue::QCborValue(qint64)
    // 21: QCborValue::QCborValue(uint)
    if (numArgs == 0) {
        overloadId = 0; // QCborValue()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))) {
        overloadId = 16; // QCborValue(QUuid)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        overloadId = 12; // QCborValue(QDateTime)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), (pyArgs[0])))) {
        overloadId = 10; // QCborValue(QCborMap)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArgs[0])))) {
        overloadId = 9; // QCborValue(QCborArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 6; // QCborValue(QStringView)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 5; // QCborValue(QLatin1String)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 4; // QCborValue(QCborValue::Type)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QCborValue(QCborTag,QCborValue)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[1])))) {
            overloadId = 3; // QCborValue(QCborTag,QCborValue)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 2; // QCborValue(QCborSimpleType)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QCborValue(QCborKnownTags,QCborValue)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QCborValue(QCborKnownTags,QCborValue)
        }
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 18; // QCborValue(double)
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 17; // QCborValue(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 14; // QCborValue(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 15; // QCborValue(QUrl)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        overloadId = 13; // QCborValue(QRegularExpression)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 8; // QCborValue(QByteArray)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 7; // QCborValue(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 20; // QCborValue(qint64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 21; // QCborValue(uint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 19; // QCborValue(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[0])))) {
        overloadId = 11; // QCborValue(QCborValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCborValue()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue()
                cptr = new ::QCborValue();
            }
            break;
        }
        case 1: // QCborValue(QCborKnownTags t_, const QCborValue & tv)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_tv = Shiboken::String::createStaticString("tv");
                if (PyDict_Contains(kwds, key_tv) != 0) {
                    value = PyDict_GetItem(kwds, key_tv);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_tv);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_tv);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QCborKnownTags cppArg0{QCborKnownTags::DateTimeString};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QCborValue cppArg1_local = QCborValue();
            ::QCborValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborKnownTags,QCborValue)
                cptr = new ::QCborValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QCborValue(QCborSimpleType st)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborSimpleType)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 3: // QCborValue(QCborTag tag, const QCborValue & taggedValue)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_taggedValue = Shiboken::String::createStaticString("taggedValue");
                if (PyDict_Contains(kwds, key_taggedValue) != 0) {
                    value = PyDict_GetItem(kwds, key_taggedValue);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_taggedValue);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_taggedValue);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QCborTag cppArg0 = static_cast< ::QCborTag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QCborValue cppArg1_local = QCborValue();
            ::QCborValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborTag,QCborValue)
                cptr = new ::QCborValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 4: // QCborValue(QCborValue::Type t_)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QCborValue::Type cppArg0{QCborValue::Integer};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborValue::Type)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 5: // QCborValue(QLatin1String s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QLatin1String)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 6: // QCborValue(QStringView s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QStringView)
                cptr = new ::QCborValue(QStringView(cppArg0));
            }
            break;
        }
        case 7: // QCborValue(bool b_)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(bool)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 8: // QCborValue(const QByteArray & ba)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QByteArray)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 9: // QCborValue(const QCborArray & a)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCborArray cppArg0_local;
            ::QCborArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborArray)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 10: // QCborValue(const QCborMap & m)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCborMap cppArg0_local;
            ::QCborMap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborMap)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 11: // QCborValue(const QCborValue & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCborValue cppArg0_local;
            ::QCborValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QCborValue)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 12: // QCborValue(const QDateTime & dt)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QDateTime)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 13: // QCborValue(const QRegularExpression & rx)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QRegularExpression)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 14: // QCborValue(const QString & s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QString)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 15: // QCborValue(const QUrl & url)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QUrl)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 16: // QCborValue(const QUuid & uuid)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUuid cppArg0_local;
            ::QUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(QUuid)
                cptr = new ::QCborValue(*cppArg0);
            }
            break;
        }
        case 17: // QCborValue(const char * s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(const char*)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 18: // QCborValue(double v)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(double)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 19: // QCborValue(int i)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(int)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 20: // QCborValue(qint64 i)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            qint64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(qint64)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
        case 21: // QCborValue(unsigned int u)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborValue(uint)
                cptr = new ::QCborValue(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCborValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCborValueFunc_compare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.compare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborValue::compare(QCborValue)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // compare(QCborValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QCborValue)const
            int cppResult = const_cast<const ::QCborValue *>(cppSelf)->compare(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_fromCbor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.fromCbor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:fromCbor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCborValue::fromCbor(QCborStreamReader&)->QCborValue
    // 1: static QCborValue::fromCbor(QByteArray,QCborParserError*=)->QCborValue
    // 2: static QCborValue::fromCbor(const char*,qsizetype,QCborParserError*=)->QCborValue
    // 3: static QCborValue::fromCbor(const quint8*,qsizetype,QCborParserError*=)->QCborValue
    if (numArgs >= 2
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 3; // fromCbor(const quint8*,qsizetype,QCborParserError*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[2])))) {
            overloadId = 3; // fromCbor(const quint8*,qsizetype,QCborParserError*)
        }
    } else if (numArgs >= 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // fromCbor(const char*,qsizetype,QCborParserError*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[2])))) {
            overloadId = 2; // fromCbor(const char*,qsizetype,QCborParserError*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // fromCbor(QByteArray,QCborParserError*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[1])))) {
            overloadId = 1; // fromCbor(QByteArray,QCborParserError*)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamReader_IDX]), (pyArgs[0])))) {
        overloadId = 0; // fromCbor(QCborStreamReader&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // fromCbor(QCborStreamReader & reader)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCborStreamReader *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromCbor(QCborStreamReader&)
                QCborValue cppResult = ::QCborValue::fromCbor(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromCbor(const QByteArray & ba, QCborParserError * error)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_error = Shiboken::String::createStaticString("error");
                if (PyDict_Contains(kwds, key_error) != 0) {
                    value = PyDict_GetItem(kwds, key_error);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_error);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_error);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QCborParserError *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromCbor(QByteArray,QCborParserError*)
                QCborValue cppResult = ::QCborValue::fromCbor(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
            }
            break;
        }
        case 2: // fromCbor(const char * data, qsizetype len, QCborParserError * error)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_error = Shiboken::String::createStaticString("error");
                if (PyDict_Contains(kwds, key_error) != 0) {
                    value = PyDict_GetItem(kwds, key_error);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_error);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_error);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCborParserError *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromCbor(const char*,qsizetype,QCborParserError*)
                QCborValue cppResult = ::QCborValue::fromCbor(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
            }
            break;
        }
        case 3: // fromCbor(const quint8 * data, qsizetype len, QCborParserError * error)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_error = Shiboken::String::createStaticString("error");
                if (PyDict_Contains(kwds, key_error) != 0) {
                    value = PyDict_GetItem(kwds, key_error);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_error);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborParserError_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_error);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            quint8 *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCborParserError *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromCbor(const quint8*,qsizetype,QCborParserError*)
                QCborValue cppResult = ::QCborValue::fromCbor(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_fromJsonValue(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.fromJsonValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCborValue::fromJsonValue(QJsonValue)->QCborValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
        overloadId = 0; // fromJsonValue(QJsonValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJsonValue cppArg0_local;
        ::QJsonValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromJsonValue(QJsonValue)
            QCborValue cppResult = ::QCborValue::fromJsonValue(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_fromVariant(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.fromVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCborValue::fromVariant(QVariant)->QCborValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // fromVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVariant(QVariant)
            QCborValue cppResult = ::QCborValue::fromVariant(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isArray()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isBool()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isBool();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isByteArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isByteArray()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isByteArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isContainer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isContainer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isContainer()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isContainer();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isDateTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDateTime()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isDateTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDouble()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isDouble();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isFalse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isFalse";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFalse()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isFalse();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isInteger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isInteger";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInteger()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isInteger();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isInvalid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isInvalid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInvalid()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isInvalid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isMap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isMap()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isMap();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isRegularExpression(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isRegularExpression";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRegularExpression()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isRegularExpression();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isSimpleType(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isSimpleType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isSimpleType", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::isSimpleType()const->bool
    // 1: QCborValue::isSimpleType(QCborSimpleType)const->bool
    if (numArgs == 0) {
        overloadId = 0; // isSimpleType()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // isSimpleType(QCborSimpleType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // isSimpleType() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSimpleType()const
                bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isSimpleType();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isSimpleType(QCborSimpleType st) const
        {
            ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSimpleType(QCborSimpleType)const
                bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isSimpleType(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isString()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isString();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isTag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isTag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTag()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isTag();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isTrue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isTrue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTrue()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isTrue();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isUndefined";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUndefined()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isUndefined();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUrl()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_isUuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.isUuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUuid()const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->isUuid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCborValue::swap(QCborValue&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCborValue&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCborValue cppArg0_local;
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCborValue&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCborValueFunc_tag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.tag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:tag", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::tag(QCborTag=)const->QCborTag
    if (numArgs == 0) {
        overloadId = 0; // tag(QCborTag)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // tag(QCborTag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QCborTag cppArg0 = QCborTag(-1);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // tag(QCborTag)const
            QCborTag cppResult = const_cast<const ::QCborValue *>(cppSelf)->tag(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_taggedValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.taggedValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:taggedValue", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::taggedValue(const QCborValue&=)const->QCborValue
    if (numArgs == 0) {
        overloadId = 0; // taggedValue(QCborValue)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[0])))) {
        overloadId = 0; // taggedValue(QCborValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QCborValue cppArg0_local = QCborValue();
        ::QCborValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // taggedValue(QCborValue)const
            QCborValue cppResult = const_cast<const ::QCborValue *>(cppSelf)->taggedValue(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toArray", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toArray()const->QCborArray
    // 1: QCborValue::toArray(QCborArray)const->QCborArray
    if (numArgs == 0) {
        overloadId = 0; // toArray()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // toArray(QCborArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toArray() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toArray()const
                QCborArray cppResult = const_cast<const ::QCborValue *>(cppSelf)->toArray();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toArray(const QCborArray & defaultValue) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCborArray cppArg0_local;
            ::QCborArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // toArray(QCborArray)const
                QCborArray cppResult = const_cast<const ::QCborValue *>(cppSelf)->toArray(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toBool(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toBool", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toBool(bool=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // toBool(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // toBool(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toBool(bool)const
            bool cppResult = const_cast<const ::QCborValue *>(cppSelf)->toBool(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toByteArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toByteArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toByteArray", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toByteArray(const QByteArray&=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toByteArray(QByteArray)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // toByteArray(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local{};
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toByteArray(QByteArray)const
            QByteArray cppResult = const_cast<const ::QCborValue *>(cppSelf)->toByteArray(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toCbor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toCbor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:toCbor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toCbor(QCborStreamWriter&,QFlags<QCborValue::EncodingOption>=)const
    // 1: QCborValue::toCbor(QFlags<QCborValue::EncodingOption>=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 1; // toCbor(QFlags<QCborValue::EncodingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_EncodingOption_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // toCbor(QFlags<QCborValue::EncodingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborStreamWriter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toCbor(QCborStreamWriter&,QFlags<QCborValue::EncodingOption>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_EncodingOption_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // toCbor(QCborStreamWriter&,QFlags<QCborValue::EncodingOption>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toCbor(QCborStreamWriter & writer, QFlags<QCborValue::EncodingOption> opt) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_opt = Shiboken::String::createStaticString("opt");
                if (PyDict_Contains(kwds, key_opt) != 0) {
                    value = PyDict_GetItem(kwds, key_opt);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_opt);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_EncodingOption_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_opt);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCborStreamWriter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QCborValue::EncodingOption> cppArg1(QCborValue::EncodingOption::NoTransformation);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCbor(QCborStreamWriter&,QFlags<QCborValue::EncodingOption>)const
                const_cast<const ::QCborValue *>(cppSelf)->toCbor(*cppArg0, cppArg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // toCbor(QFlags<QCborValue::EncodingOption> opt) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_opt = Shiboken::String::createStaticString("opt");
                if (PyDict_Contains(kwds, key_opt) != 0) {
                    value = PyDict_GetItem(kwds, key_opt);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_opt);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_EncodingOption_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_opt);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QFlags<QCborValue::EncodingOption> cppArg0(QCborValue::EncodingOption::NoTransformation);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCbor(QFlags<QCborValue::EncodingOption>)const
                QByteArray cppResult = const_cast<const ::QCborValue *>(cppSelf)->toCbor(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toDateTime(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toDateTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toDateTime", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toDateTime(const QDateTime&=)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // toDateTime(QDateTime)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        overloadId = 0; // toDateTime(QDateTime)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local{};
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDateTime(QDateTime)const
            QDateTime cppResult = const_cast<const ::QCborValue *>(cppSelf)->toDateTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toDiagnosticNotation(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toDiagnosticNotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toDiagnosticNotation", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toDiagnosticNotation(QFlags<QCborValue::DiagnosticNotationOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toDiagnosticNotation(QFlags<QCborValue::DiagnosticNotationOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_DiagnosticNotationOption_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toDiagnosticNotation(QFlags<QCborValue::DiagnosticNotationOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_opts = Shiboken::String::createStaticString("opts");
            if (PyDict_Contains(kwds, key_opts) != 0) {
                value = PyDict_GetItem(kwds, key_opts);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_opts);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_DiagnosticNotationOption_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_opts);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QCborValue::DiagnosticNotationOption> cppArg0(QCborValue::DiagnosticNotationOption::Compact);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDiagnosticNotation(QFlags<QCborValue::DiagnosticNotationOption>)const
            QString cppResult = const_cast<const ::QCborValue *>(cppSelf)->toDiagnosticNotation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toDouble(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toDouble", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toDouble(double=)const->double
    if (numArgs == 0) {
        overloadId = 0; // toDouble(double)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 0; // toDouble(double)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        double cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDouble(double)const
            double cppResult = const_cast<const ::QCborValue *>(cppSelf)->toDouble(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toInteger(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toInteger";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toInteger", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toInteger(qint64=)const->qint64
    if (numArgs == 0) {
        overloadId = 0; // toInteger(qint64)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        overloadId = 0; // toInteger(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qint64 cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInteger(qint64)const
            qint64 cppResult = const_cast<const ::QCborValue *>(cppSelf)->toInteger(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toJsonValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toJsonValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toJsonValue()const
            QJsonValue cppResult = const_cast<const ::QCborValue *>(cppSelf)->toJsonValue();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toMap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toMap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toMap", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toMap()const->QCborMap
    // 1: QCborValue::toMap(QCborMap)const->QCborMap
    if (numArgs == 0) {
        overloadId = 0; // toMap()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), (pyArgs[0])))) {
        overloadId = 1; // toMap(QCborMap)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toMap() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toMap()const
                QCborMap cppResult = const_cast<const ::QCborValue *>(cppSelf)->toMap();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toMap(const QCborMap & defaultValue) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCborMap cppArg0_local;
            ::QCborMap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // toMap(QCborMap)const
                QCborMap cppResult = const_cast<const ::QCborValue *>(cppSelf)->toMap(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toRegularExpression(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toRegularExpression";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toRegularExpression", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toRegularExpression(const QRegularExpression&=)const->QRegularExpression
    if (numArgs == 0) {
        overloadId = 0; // toRegularExpression(QRegularExpression)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        overloadId = 0; // toRegularExpression(QRegularExpression)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRegularExpression cppArg0_local{};
        ::QRegularExpression *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toRegularExpression(QRegularExpression)const
            QRegularExpression cppResult = const_cast<const ::QCborValue *>(cppSelf)->toRegularExpression(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toSimpleType(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toSimpleType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toSimpleType", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toSimpleType(QCborSimpleType=)const->QCborSimpleType
    if (numArgs == 0) {
        overloadId = 0; // toSimpleType(QCborSimpleType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toSimpleType(QCborSimpleType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QCborSimpleType cppArg0(QCborSimpleType::Undefined);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toSimpleType(QCborSimpleType)const
            QCborSimpleType cppResult = const_cast<const ::QCborValue *>(cppSelf)->toSimpleType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toString(const QString&=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // toString(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QString)const
            QString cppResult = const_cast<const ::QCborValue *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toUrl", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toUrl(const QUrl&=)const->QUrl
    if (numArgs == 0) {
        overloadId = 0; // toUrl(QUrl)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 0; // toUrl(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local{};
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUrl(QUrl)const
            QUrl cppResult = const_cast<const ::QCborValue *>(cppSelf)->toUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toUuid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toUuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toUuid", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCborValue::toUuid(const QUuid&=)const->QUuid
    if (numArgs == 0) {
        overloadId = 0; // toUuid(QUuid)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0])))) {
        overloadId = 0; // toUuid(QUuid)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUuid cppArg0_local{};
        ::QUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUuid(QUuid)const
            QUuid cppResult = const_cast<const ::QCborValue *>(cppSelf)->toUuid(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_toVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.toVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toVariant()const
            QVariant cppResult = const_cast<const ::QCborValue *>(cppSelf)->toVariant();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValueFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborValue.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QCborValue::Type cppResult = const_cast<const ::QCborValue *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborValue__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCborValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCborValue_EnumFlagInfo[] = {
    "DiagnosticNotationOption:Flag:DiagnosticNotationOptions",
    "EncodingOption:Flag:EncodingOptions",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCborValue_methods[] = {
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_compare), METH_O, nullptr},
    {"fromCbor", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_fromCbor), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromJsonValue", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_fromJsonValue), METH_O|METH_STATIC, nullptr},
    {"fromVariant", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_fromVariant), METH_O|METH_STATIC, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isArray), METH_NOARGS, nullptr},
    {"isBool", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isBool), METH_NOARGS, nullptr},
    {"isByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isByteArray), METH_NOARGS, nullptr},
    {"isContainer", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isContainer), METH_NOARGS, nullptr},
    {"isDateTime", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isDateTime), METH_NOARGS, nullptr},
    {"isDouble", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isDouble), METH_NOARGS, nullptr},
    {"isFalse", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isFalse), METH_NOARGS, nullptr},
    {"isInteger", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isInteger), METH_NOARGS, nullptr},
    {"isInvalid", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isInvalid), METH_NOARGS, nullptr},
    {"isMap", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isMap), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isNull), METH_NOARGS, nullptr},
    {"isRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isRegularExpression), METH_NOARGS, nullptr},
    {"isSimpleType", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isSimpleType), METH_VARARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isString), METH_NOARGS, nullptr},
    {"isTag", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isTag), METH_NOARGS, nullptr},
    {"isTrue", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isTrue), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isUndefined), METH_NOARGS, nullptr},
    {"isUrl", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isUrl), METH_NOARGS, nullptr},
    {"isUuid", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_isUuid), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_swap), METH_O, nullptr},
    {"tag", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_tag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"taggedValue", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_taggedValue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toArray", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toArray), METH_VARARGS, nullptr},
    {"toBool", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toBool), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toByteArray", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toByteArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toCbor", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toCbor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDateTime", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toDateTime), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDiagnosticNotation", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toDiagnosticNotation), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toDouble), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInteger", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toInteger), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toJsonValue", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toJsonValue), METH_NOARGS, nullptr},
    {"toMap", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toMap), METH_VARARGS, nullptr},
    {"toRegularExpression", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toRegularExpression), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toSimpleType", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toSimpleType), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toUrl", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toUrl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toUuid", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toUuid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_toVariant), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QCborValueFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCborValue__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCborValue___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QCborValue_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator!=(const QCborValue & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator<(const QCborValue & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
                // operator==(const QCborValue & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QCborValue_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QCborValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCborValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QCborValue__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCborValue_Type = nullptr;
static PyTypeObject *Sbk_QCborValue_TypeF(void)
{
    return _Sbk_QCborValue_Type;
}

static PyType_Slot Sbk_QCborValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QCborValue__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QCborValue_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCborValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCborValue_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCborValue_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCborValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCborValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QCborValue___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCborValue_spec = {
    "2:PySide6.QtCore.QCborValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCborValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCborValue_EncodingOption_PythonToCpp_QCborValue_EncodingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborValue::EncodingOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborValue::EncodingOption *>(cppOut) = value;

}
static PythonToCppFunc is_QCborValue_EncodingOption_PythonToCpp_QCborValue_EncodingOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_EncodingOption_IDX])))
        return QCborValue_EncodingOption_PythonToCpp_QCborValue_EncodingOption;
    return {};
}
static PyObject *QCborValue_EncodingOption_CppToPython_QCborValue_EncodingOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborValue::EncodingOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_EncodingOption_IDX]), castCppIn);

}

static void QCborValue_DiagnosticNotationOption_PythonToCpp_QCborValue_DiagnosticNotationOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborValue::DiagnosticNotationOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborValue::DiagnosticNotationOption *>(cppOut) = value;

}
static PythonToCppFunc is_QCborValue_DiagnosticNotationOption_PythonToCpp_QCborValue_DiagnosticNotationOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_DiagnosticNotationOption_IDX])))
        return QCborValue_DiagnosticNotationOption_PythonToCpp_QCborValue_DiagnosticNotationOption;
    return {};
}
static PyObject *QCborValue_DiagnosticNotationOption_CppToPython_QCborValue_DiagnosticNotationOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborValue::DiagnosticNotationOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_DiagnosticNotationOption_IDX]), castCppIn);

}

static void QCborValue_Type_PythonToCpp_QCborValue_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborValue::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborValue::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QCborValue_Type_PythonToCpp_QCborValue_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX])))
        return QCborValue_Type_PythonToCpp_QCborValue_Type;
    return {};
}
static PyObject *QCborValue_Type_CppToPython_QCborValue_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborValue::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCborValue_PythonToCpp_QCborValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCborValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCborValue_PythonToCpp_QCborValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCborValue_TypeF()))
        return QCborValue_PythonToCpp_QCborValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCborValue_PTR_CppToPython_QCborValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QCborValue *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QCborValue_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// C++ to Python copy conversion.
static PyObject *QCborValue_COPY_CppToPython_QCborValue(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCborValue *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCborValue_TypeF(), new ::QCborValue(*source), true, true);
}

// Python to C++ copy conversion.
static void QCborValue_PythonToCpp_QCborValue_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborValue *>(cppOut) = *reinterpret_cast< ::QCborValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCborValue_PythonToCpp_QCborValue_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCborValue_TypeF()))
        return QCborValue_PythonToCpp_QCborValue_COPY;
    return {};
}

// Implicit conversions.
static void QCborKnownTags_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QCborKnownTags cppIn{QCborKnownTags::DateTimeString};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QCborKnownTags_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX]), pyIn))
        return QCborKnownTags_PythonToCpp_QCborValue;
    return {};
}

static void QCborSimpleType_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QCborSimpleType cppIn = static_cast< ::QCborSimpleType>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QCborSimpleType_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX]), pyIn))
        return QCborSimpleType_PythonToCpp_QCborValue;
    return {};
}

static void QCborTag_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QCborTag cppIn = static_cast< ::QCborTag>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QCborTag_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX]), pyIn))
        return QCborTag_PythonToCpp_QCborValue;
    return {};
}

static void QCborValue_Type_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QCborValue::Type cppIn{QCborValue::Integer};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QCborValue_Type_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX]), pyIn))
        return QCborValue_Type_PythonToCpp_QCborValue;
    return {};
}

static void QLatin1String_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QLatin1String cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QLatin1String_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return QLatin1String_PythonToCpp_QCborValue;
    return {};
}

static void QStringView_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QStringView cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_QStringView_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return QStringView_PythonToCpp_QCborValue;
    return {};
}

static void bool_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    bool cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_bool_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return bool_PythonToCpp_QCborValue;
    return {};
}

static void constQByteArrayREF_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue( *reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQByteArrayREF_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return constQByteArrayREF_PythonToCpp_QCborValue;
    return {};
}

static void constQCborArrayREF_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue( *reinterpret_cast< ::QCborArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQCborArrayREF_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), pyIn))
        return constQCborArrayREF_PythonToCpp_QCborValue;
    return {};
}

static void constQCborMapREF_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue( *reinterpret_cast< ::QCborMap *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQCborMapREF_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), pyIn))
        return constQCborMapREF_PythonToCpp_QCborValue;
    return {};
}

static void constQStringREF_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QCborValue;
    return {};
}

static void constcharPTR_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    const char* cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_constcharPTR_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return constcharPTR_PythonToCpp_QCborValue;
    return {};
}

static void double_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    double cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_double_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return double_PythonToCpp_QCborValue;
    return {};
}

static void int_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QCborValue;
    return {};
}

static void qint64_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    qint64 cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_qint64_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return qint64_PythonToCpp_QCborValue;
    return {};
}

static void unsignedint_PythonToCpp_QCborValue(PyObject *pyIn, void *cppOut)
{
    unsigned int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyIn, &cppIn);
    *reinterpret_cast<::QCborValue *>(cppOut) = ::QCborValue(cppIn);
}
static PythonToCppFunc is_unsignedint_PythonToCpp_QCborValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return unsignedint_PythonToCpp_QCborValue;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCborValue_SignatureStrings[] = {
    "21:PySide6.QtCore.QCborValue(self)",
    "20:PySide6.QtCore.QCborValue(self,t_:PySide6.QtCore.QCborKnownTags,tv:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int]=QCborValue())",
    "19:PySide6.QtCore.QCborValue(self,st:PySide6.QtCore.QCborSimpleType)",
    "18:PySide6.QtCore.QCborValue(self,tag:PySide6.QtCore.QCborTag,taggedValue:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int]=QCborValue())",
    "17:PySide6.QtCore.QCborValue(self,t_:PySide6.QtCore.QCborValue.Type)",
    "16:PySide6.QtCore.QCborValue(self,s:QLatin1String)",
    "15:PySide6.QtCore.QCborValue(self,s:QString)",
    "14:PySide6.QtCore.QCborValue(self,b_:bool)",
    "13:PySide6.QtCore.QCborValue(self,ba:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "12:PySide6.QtCore.QCborValue(self,a:PySide6.QtCore.QCborArray)",
    "11:PySide6.QtCore.QCborValue(self,m:PySide6.QtCore.QCborMap)",
    "10:PySide6.QtCore.QCborValue(self,other:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "9:PySide6.QtCore.QCborValue(self,dt:PySide6.QtCore.QDateTime)",
    "8:PySide6.QtCore.QCborValue(self,rx:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "7:PySide6.QtCore.QCborValue(self,s:QString)",
    "6:PySide6.QtCore.QCborValue(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "5:PySide6.QtCore.QCborValue(self,uuid:PySide6.QtCore.QUuid)",
    "4:PySide6.QtCore.QCborValue(self,s:char*)",
    "3:PySide6.QtCore.QCborValue(self,v:double)",
    "2:PySide6.QtCore.QCborValue(self,i:int)",
    "1:PySide6.QtCore.QCborValue(self,i:qint64)",
    "0:PySide6.QtCore.QCborValue(self,u:unsigned int)",
    "PySide6.QtCore.QCborValue.compare(self,other:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->int",
    "3:PySide6.QtCore.QCborValue.fromCbor(reader:PySide6.QtCore.QCborStreamReader)->PySide6.QtCore.QCborValue",
    "2:PySide6.QtCore.QCborValue.fromCbor(ba:typing.Union[PySide6.QtCore.QByteArray, char*],error:PySide6.QtCore.QCborParserError=nullptr)->PySide6.QtCore.QCborValue",
    "1:PySide6.QtCore.QCborValue.fromCbor(data:char*,len:qsizetype,error:PySide6.QtCore.QCborParserError=nullptr)->PySide6.QtCore.QCborValue",
    "0:PySide6.QtCore.QCborValue.fromCbor(data:quint8*,len:qsizetype,error:PySide6.QtCore.QCborParserError=nullptr)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborValue.fromJsonValue(v:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborValue.fromVariant(variant:QVariant)->PySide6.QtCore.QCborValue",
    "PySide6.QtCore.QCborValue.isArray(self)->bool",
    "PySide6.QtCore.QCborValue.isBool(self)->bool",
    "PySide6.QtCore.QCborValue.isByteArray(self)->bool",
    "PySide6.QtCore.QCborValue.isContainer(self)->bool",
    "PySide6.QtCore.QCborValue.isDateTime(self)->bool",
    "PySide6.QtCore.QCborValue.isDouble(self)->bool",
    "PySide6.QtCore.QCborValue.isFalse(self)->bool",
    "PySide6.QtCore.QCborValue.isInteger(self)->bool",
    "PySide6.QtCore.QCborValue.isInvalid(self)->bool",
    "PySide6.QtCore.QCborValue.isMap(self)->bool",
    "PySide6.QtCore.QCborValue.isNull(self)->bool",
    "PySide6.QtCore.QCborValue.isRegularExpression(self)->bool",
    "1:PySide6.QtCore.QCborValue.isSimpleType(self)->bool",
    "0:PySide6.QtCore.QCborValue.isSimpleType(self,st:PySide6.QtCore.QCborSimpleType)->bool",
    "PySide6.QtCore.QCborValue.isString(self)->bool",
    "PySide6.QtCore.QCborValue.isTag(self)->bool",
    "PySide6.QtCore.QCborValue.isTrue(self)->bool",
    "PySide6.QtCore.QCborValue.isUndefined(self)->bool",
    "PySide6.QtCore.QCborValue.isUrl(self)->bool",
    "PySide6.QtCore.QCborValue.isUuid(self)->bool",
    "PySide6.QtCore.QCborValue.swap(self,other:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])",
    "PySide6.QtCore.QCborValue.tag(self,defaultValue:PySide6.QtCore.QCborTag=QCborTag(-1))->PySide6.QtCore.QCborTag",
    "PySide6.QtCore.QCborValue.taggedValue(self,defaultValue:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int]=QCborValue())->PySide6.QtCore.QCborValue",
    "1:PySide6.QtCore.QCborValue.toArray(self)->PySide6.QtCore.QCborArray",
    "0:PySide6.QtCore.QCborValue.toArray(self,defaultValue:PySide6.QtCore.QCborArray)->PySide6.QtCore.QCborArray",
    "PySide6.QtCore.QCborValue.toBool(self,defaultValue:bool=false)->bool",
    "PySide6.QtCore.QCborValue.toByteArray(self,defaultValue:typing.Union[PySide6.QtCore.QByteArray, char*]={})->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QCborValue.toCbor(self,writer:PySide6.QtCore.QCborStreamWriter,opt:PySide6.QtCore.QCborValue.EncodingOption=QCborValue.EncodingOption.NoTransformation)",
    "0:PySide6.QtCore.QCborValue.toCbor(self,opt:PySide6.QtCore.QCborValue.EncodingOption=QCborValue.EncodingOption.NoTransformation)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QCborValue.toDateTime(self,defaultValue:PySide6.QtCore.QDateTime={})->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QCborValue.toDiagnosticNotation(self,opts:PySide6.QtCore.QCborValue.DiagnosticNotationOption=QCborValue.DiagnosticNotationOption.Compact)->QString",
    "PySide6.QtCore.QCborValue.toDouble(self,defaultValue:double=0)->double",
    "PySide6.QtCore.QCborValue.toInteger(self,defaultValue:qint64=0)->qint64",
    "PySide6.QtCore.QCborValue.toJsonValue(self)->PySide6.QtCore.QJsonValue",
    "1:PySide6.QtCore.QCborValue.toMap(self)->PySide6.QtCore.QCborMap",
    "0:PySide6.QtCore.QCborValue.toMap(self,defaultValue:PySide6.QtCore.QCborMap)->PySide6.QtCore.QCborMap",
    "PySide6.QtCore.QCborValue.toRegularExpression(self,defaultValue:typing.Union[PySide6.QtCore.QRegularExpression, QString]={})->PySide6.QtCore.QRegularExpression",
    "PySide6.QtCore.QCborValue.toSimpleType(self,defaultValue:PySide6.QtCore.QCborSimpleType=QCborSimpleType.Undefined)->PySide6.QtCore.QCborSimpleType",
    "PySide6.QtCore.QCborValue.toString(self,defaultValue:QString={})->QString",
    "PySide6.QtCore.QCborValue.toUrl(self,defaultValue:typing.Union[PySide6.QtCore.QUrl, QString]={})->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QCborValue.toUuid(self,defaultValue:PySide6.QtCore.QUuid={})->PySide6.QtCore.QUuid",
    "PySide6.QtCore.QCborValue.toVariant(self)->QVariant",
    "PySide6.QtCore.QCborValue.type(self)->PySide6.QtCore.QCborValue.Type",
    "PySide6.QtCore.QCborValue.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QCborValue(PyObject *module)
{
    _Sbk_QCborValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCborValue",
        "QCborValue",
        &Sbk_QCborValue_spec,
        &Shiboken::callCppDestructor< ::QCborValue >,
        nullptr,
        0,
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCborValue_TypeF(); // references _Sbk_QCborValue_Type
    InitSignatureStrings(pyType, QCborValue_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCborValue_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCborValue_PythonToCpp_QCborValue_PTR,
        is_QCborValue_PythonToCpp_QCborValue_PTR_Convertible,
        QCborValue_PTR_CppToPython_QCborValue,
        QCborValue_COPY_CppToPython_QCborValue);

    Shiboken::Conversions::registerConverterName(converter, "QCborValue");
    Shiboken::Conversions::registerConverterName(converter, "QCborValue*");
    Shiboken::Conversions::registerConverterName(converter, "QCborValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCborValue).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborValue_PythonToCpp_QCborValue_COPY,
        is_QCborValue_PythonToCpp_QCborValue_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborKnownTags_PythonToCpp_QCborValue,
        is_QCborKnownTags_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborSimpleType_PythonToCpp_QCborValue,
        is_QCborSimpleType_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborTag_PythonToCpp_QCborValue,
        is_QCborTag_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborValue_Type_PythonToCpp_QCborValue,
        is_QCborValue_Type_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLatin1String_PythonToCpp_QCborValue,
        is_QLatin1String_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QStringView_PythonToCpp_QCborValue,
        is_QStringView_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        bool_PythonToCpp_QCborValue,
        is_bool_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQByteArrayREF_PythonToCpp_QCborValue,
        is_constQByteArrayREF_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQCborArrayREF_PythonToCpp_QCborValue,
        is_constQCborArrayREF_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQCborMapREF_PythonToCpp_QCborValue,
        is_constQCborMapREF_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QCborValue,
        is_constQStringREF_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constcharPTR_PythonToCpp_QCborValue,
        is_constcharPTR_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        double_PythonToCpp_QCborValue,
        is_double_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QCborValue,
        is_int_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        qint64_PythonToCpp_QCborValue,
        is_qint64_PythonToCpp_QCborValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        unsignedint_PythonToCpp_QCborValue,
        is_unsignedint_PythonToCpp_QCborValue_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCborValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'EncodingOption'.
    const char *EncodingOption_Initializer[] = {
        "SortKeysInMaps",
        "UseFloat",
        "UseFloat16",
        "UseIntegers",
        "NoTransformation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EncodingOption_InitializerValues[] = {
        uint8_t(QCborValue::EncodingOption::SortKeysInMaps),  //  0x01  1
        uint8_t(QCborValue::EncodingOption::UseFloat),        //  0x02  2
        uint8_t(QCborValue::EncodingOption::UseFloat16),      //  0x06  6
        uint8_t(QCborValue::EncodingOption::UseIntegers),     //  0x08  8
        uint8_t(QCborValue::EncodingOption::NoTransformation) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborValue_TypeF(),
        "2:PySide6.QtCore.QCborValue.EncodingOption",
        EncodingOption_Initializer, EncodingOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_EncodingOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_EncodingOption_IDX].type =
        EType;
    // Register converter for enum 'QCborValue::EncodingOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborValue_EncodingOption_CppToPython_QCborValue_EncodingOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborValue_EncodingOption_PythonToCpp_QCborValue_EncodingOption,
            is_QCborValue_EncodingOption_PythonToCpp_QCborValue_EncodingOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborValue::EncodingOption");
        Shiboken::Conversions::registerConverterName(converter, "EncodingOption");
        // Register converter for flag 'QFlags<QCborValue::EncodingOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QCborValue::EncodingOption>");
        Shiboken::Conversions::registerConverterName(converter, "QCborValue::EncodingOptions");
    }
    // End of 'EncodingOption' enum/flags.

    // Initialization of enum 'DiagnosticNotationOption'.
    const char *DiagnosticNotationOption_Initializer[] = {
        "Compact",
        "LineWrapped",
        "ExtendedFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DiagnosticNotationOption_InitializerValues[] = {
        uint8_t(QCborValue::DiagnosticNotationOption::Compact),       //  0x00  0
        uint8_t(QCborValue::DiagnosticNotationOption::LineWrapped),   //  0x01  1
        uint8_t(QCborValue::DiagnosticNotationOption::ExtendedFormat) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborValue_TypeF(),
        "2:PySide6.QtCore.QCborValue.DiagnosticNotationOption",
        DiagnosticNotationOption_Initializer, DiagnosticNotationOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_DiagnosticNotationOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QCborValue_DiagnosticNotationOption_IDX].type =
        EType;
    // Register converter for enum 'QCborValue::DiagnosticNotationOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborValue_DiagnosticNotationOption_CppToPython_QCborValue_DiagnosticNotationOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborValue_DiagnosticNotationOption_PythonToCpp_QCborValue_DiagnosticNotationOption,
            is_QCborValue_DiagnosticNotationOption_PythonToCpp_QCborValue_DiagnosticNotationOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborValue::DiagnosticNotationOption");
        Shiboken::Conversions::registerConverterName(converter, "DiagnosticNotationOption");
        // Register converter for flag 'QFlags<QCborValue::DiagnosticNotationOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QCborValue::DiagnosticNotationOption>");
        Shiboken::Conversions::registerConverterName(converter, "QCborValue::DiagnosticNotationOptions");
    }
    // End of 'DiagnosticNotationOption' enum/flags.

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Integer",
        "ByteArray",
        "String",
        "Array",
        "Map",
        "Tag",
        "SimpleType",
        "False_",
        "True_",
        "Null",
        "Undefined",
        "Double",
        "DateTime",
        "Url",
        "RegularExpression",
        "Uuid",
        "Invalid",
        nullptr};
    // "int32_t" used instead of "int"
    constexpr int32_t Type_InitializerValues[] = {
        int32_t(QCborValue::Type::Integer),           //  0x00000000  0
        int32_t(QCborValue::Type::ByteArray),         //  0x00000040  64
        int32_t(QCborValue::Type::String),            //  0x00000060  96
        int32_t(QCborValue::Type::Array),             //  0x00000080  128
        int32_t(QCborValue::Type::Map),               //  0x000000a0  160
        int32_t(QCborValue::Type::Tag),               //  0x000000c0  192
        int32_t(QCborValue::Type::SimpleType),        //  0x00000100  256
        int32_t(QCborValue::Type::False),             //  0x00000114  276
        int32_t(QCborValue::Type::True),              //  0x00000115  277
        int32_t(QCborValue::Type::Null),              //  0x00000116  278
        int32_t(QCborValue::Type::Undefined),         //  0x00000117  279
        int32_t(QCborValue::Type::Double),            //  0x00000202  514
        int32_t(QCborValue::Type::DateTime),          //  0x00010000  65536
        int32_t(QCborValue::Type::Url),               //  0x00010020  65568
        int32_t(QCborValue::Type::RegularExpression), //  0x00010023  65571
        int32_t(QCborValue::Type::Uuid),              //  0x00010025  65573
        int32_t(QCborValue::Type::Invalid)            // -0x00000001 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborValue_TypeF(),
        "2:PySide6.QtCore.QCborValue.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_Type_IDX].type = EType;
    // Register converter for enum 'QCborValue::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborValue_Type_CppToPython_QCborValue_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborValue_Type_PythonToCpp_QCborValue_Type,
            is_QCborValue_Type_PythonToCpp_QCborValue_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborValue::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QCborValue >("QCborValue");
    qRegisterMetaType< ::QCborValue::EncodingOption >("QCborValue::EncodingOption");
    qRegisterMetaType< ::QCborValue::DiagnosticNotationOption >("QCborValue::DiagnosticNotationOption");
    qRegisterMetaType< ::QCborValue::Type >("QCborValue::Type");

    return pyType;
}
