// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdatastream_wrapper.h"

// Extra includes
#include <QtCore/QtCore>

// Argument includes
#include <QString>
#include <QStringList>
#include <qbitarray.h>
#include <qbytearray.h>
#include <qcborarray.h>
#include <qcborcommon.h>
#include <qcbormap.h>
#include <qcborvalue.h>
#include <qchar.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qeasingcurve.h>
#include <qiodevice.h>
#include <qjsonarray.h>
#include <qjsondocument.h>
#include <qjsonobject.h>
#include <qjsonvalue.h>
#include <qline.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qnamespace.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregularexpression.h>
#include <qsize.h>
#include <qtimezone.h>
#include <qurl.h>
#include <quuid.h>
#include <qvariant.h>
#include <qversionnumber.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDataStream_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDataStream >()))
        return -1;

    ::QDataStream *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDataStream", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDataStream::QDataStream()
    // 1: QDataStream::QDataStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
    // 2: QDataStream::QDataStream(QIODevice*)
    // 3: QDataStream::QDataStream(QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QDataStream()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QDataStream(QIODevice*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QDataStream(QByteArray)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QDataStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDataStream()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDataStream()
                cptr = new ::QDataStream();
            }
            break;
        }
        case 1: // QDataStream(QByteArray * arg__1, QFlags<QIODeviceBase::OpenModeFlag> flags)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1 = QFlags<QIODeviceBase::OpenModeFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDataStream(QByteArray*,QFlags<QIODeviceBase::OpenModeFlag>)
                cptr = new ::QDataStream(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QDataStream(QIODevice * arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDataStream(QIODevice*)
                cptr = new ::QDataStream(cppArg0);
            }
            break;
        }
        case 3: // QDataStream(const QByteArray & arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDataStream(QByteArray)
                cptr = new ::QDataStream(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDataStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDataStreamFunc_abortTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QDataStream.abortTransaction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // abortTransaction()
            cppSelf->abortTransaction();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_atEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.atEnd";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // atEnd()const
            bool cppResult = const_cast<const ::QDataStream *>(cppSelf)->atEnd();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_byteOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.byteOrder";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // byteOrder()const
            QDataStream::ByteOrder cppResult = const_cast<const ::QDataStream *>(cppSelf)->byteOrder();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_ByteOrder_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_commitTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.commitTransaction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // commitTransaction()
            bool cppResult = cppSelf->commitTransaction();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.device";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // device()const
            QIODevice * cppResult = const_cast<const ::QDataStream *>(cppSelf)->device();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_floatingPointPrecision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.floatingPointPrecision";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // floatingPointPrecision()const
            QDataStream::FloatingPointPrecision cppResult = const_cast<const ::QDataStream *>(cppSelf)->floatingPointPrecision();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_FloatingPointPrecision_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_isDeviceTransactionStarted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.isDeviceTransactionStarted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDeviceTransactionStarted()const
            bool cppResult = const_cast<const ::QDataStream *>(cppSelf)->isDeviceTransactionStarted();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readBool()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            bool _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readBytes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readBytes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::readBytes(char*&,qint64&)->PyTuple
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readBytes(char*&,qint64&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readBytes(char*&,qint64&)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qdatastream-read-bytes)]
            QByteArray data;
            data.resize(cppArg0);
            auto dataChar = data.data();
            cppSelf->readBytes(dataChar, cppArg0);
            const char *constDataChar = dataChar;
            if (dataChar == nullptr) {
                Py_INCREF(Py_None);
                pyResult = Py_None;
            } else {
                pyResult = PyBytes_FromStringAndSize(constDataChar, cppArg0);
            }
            // END of custom code block [file: ../glue/qtcore.cpp (qdatastream-read-bytes)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readDouble()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            qreal _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readFloat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readFloat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readFloat()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            float _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readInt16(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readInt16";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readInt16()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            qint16 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readInt32(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readInt32";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readInt32()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            qint32 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readInt64(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readInt64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readInt64()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            qint64 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readInt8(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readInt8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readInt8()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            qint8 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint8>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readQChar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readQChar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readQChar()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            ::QChar _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readQString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readQString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readQString()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            ::QString _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readQStringList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readQStringList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readQStringList()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            ::QStringList _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readQVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readQVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readQVariant()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            ::QVariant _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readRawData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readRawData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::readRawData(char*,qint64)->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readRawData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readRawData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qdatastream-readrawdata)]
            QByteArray data;
            data.resize(cppArg0);
            int result = 0;
            Py_BEGIN_ALLOW_THREADS
            result = cppSelf->readRawData(data.data(), data.size());
            Py_END_ALLOW_THREADS
            if (result == -1) {
                Py_INCREF(Py_None);
                pyResult = Py_None;
            } else {
                pyResult = PyBytes_FromStringAndSize(data.constData(), result);
            }
            // END of custom code block [file: ../glue/qtcore.cpp (qdatastream-readrawdata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readString()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            ::QString _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readUInt16(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readUInt16";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readUInt16()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            quint16 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readUInt32(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readUInt32";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readUInt32()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            quint32 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readUInt64(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readUInt64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readUInt64()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            quint64 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_readUInt8(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.readUInt8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readUInt8()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            quint8 _cpp_result;
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) >> _cpp_result;
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), &_cpp_result);
            // END of custom code block [file: ../glue/qtcore.cpp (stream-read-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_resetStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QDataStream.resetStatus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetStatus()
            cppSelf->resetStatus();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_rollbackTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QDataStream.rollbackTransaction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rollbackTransaction()
            cppSelf->rollbackTransaction();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_setByteOrder(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.setByteOrder";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::setByteOrder(QDataStream::ByteOrder)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_ByteOrder_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setByteOrder(QDataStream::ByteOrder)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QDataStream::ByteOrder cppArg0{QDataStream::BigEndian};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setByteOrder(QDataStream::ByteOrder)
            cppSelf->setByteOrder(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_setDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.setDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::setDevice(QIODevice*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIODevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevice(QIODevice*)
            cppSelf->setDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_setFloatingPointPrecision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.setFloatingPointPrecision";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_FloatingPointPrecision_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QDataStream::FloatingPointPrecision cppArg0{QDataStream::SinglePrecision};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
            cppSelf->setFloatingPointPrecision(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.setStatus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::setStatus(QDataStream::Status)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Status_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStatus(QDataStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QDataStream::Status cppArg0{QDataStream::Ok};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStatus(QDataStream::Status)
            cppSelf->setStatus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_setVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.setVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::setVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVersion(int)
            cppSelf->setVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_skipRawData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.skipRawData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::skipRawData(qint64)->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // skipRawData(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipRawData(qint64)
            qint64 cppResult = cppSelf->skipRawData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_startTransaction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QDataStream.startTransaction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // startTransaction()
            cppSelf->startTransaction();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.status";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // status()const
            QDataStream::Status cppResult = const_cast<const ::QDataStream *>(cppSelf)->status();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Status_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.version";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // version()const
            int cppResult = const_cast<const ::QDataStream *>(cppSelf)->version();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_writeBool(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeBool(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // writeBool(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeBool(bool)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeBytes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeBytes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeBytes(PyBuffer,qint64)->QDataStream&
    if (Shiboken::Buffer::checkType(pyArg)) {
        overloadId = 0; // writeBytes(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeBytes(const char*,qint64)
            // Begin code injection
            // TEMPLATE - pybuffer_const_char - START
            Py_ssize_t bufferLen;
            char *arg__1_out = reinterpret_cast<char*>(Shiboken::Buffer::getPointer(pyArg, &bufferLen));
            // TEMPLATE - pybuffer_const_char - END
            // TEMPLATE - uint_remove - START
            uint len_out = bufferLen;
            // TEMPLATE - uint_remove - END
            // End of code injection

            QDataStream & cppResult = cppSelf->writeBytes(arg__1_out, len_out);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_writeDouble(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeDouble(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // writeDouble(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeDouble(qreal)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeFloat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeFloat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeFloat(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // writeFloat(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeFloat(float)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeInt16(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeInt16";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeInt16(qint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), (pyArg)))) {
        overloadId = 0; // writeInt16(qint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeInt16(qint16)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeInt32(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeInt32";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeInt32(qint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), (pyArg)))) {
        overloadId = 0; // writeInt32(qint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeInt32(qint32)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeInt64(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeInt64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeInt64(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // writeInt64(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeInt64(qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeInt8(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeInt8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeInt8(qint8)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint8>(), (pyArg)))) {
        overloadId = 0; // writeInt8(qint8)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint8 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeInt8(qint8)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeQChar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeQChar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeQChar(QChar)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
        overloadId = 0; // writeQChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QChar cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeQChar(QChar)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeQString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeQString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeQString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeQString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeQString(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeQStringList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeQStringList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeQStringList(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // writeQStringList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeQStringList(QStringList)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeQVariant(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeQVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeQVariant(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // writeQVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeQVariant(QVariant)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeRawData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeRawData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeRawData(PyBuffer)
    // 1: QDataStream::writeRawData(const char*,qint64)->qint64
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 1; // writeRawData(const char*,qint64)
    } else if (Shiboken::Buffer::checkType(pyArg)) {
        overloadId = 0; // writeRawData(PyBuffer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // writeRawData(PyBuffer arg__1)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeRawData(PyBuffer)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qdatastream-writerawdata-pybuffer)]
                int r = 0;
                Py_ssize_t bufferLen;
                auto *data = reinterpret_cast<const char*>(Shiboken::Buffer::getPointer(pyArg, &bufferLen));
                Py_BEGIN_ALLOW_THREADS
                r = cppSelf->writeRawData(data, bufferLen);
                Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &r);
                // END of custom code block [file: ../glue/qtcore.cpp (qdatastream-writerawdata-pybuffer)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // writeRawData(const char * arg__1, qint64 len)
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // writeRawData(const char*,qint64)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qdatastream-writerawdata)]
                int r = 0;
                Py_BEGIN_ALLOW_THREADS
                r = cppSelf->writeRawData(cppArg0, Shiboken::String::len(pyArg));
                Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &r);
                // END of custom code block [file: ../glue/qtcore.cpp (qdatastream-writerawdata)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc_writeString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // writeString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeString(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeUInt16(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeUInt16";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeUInt16(quint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArg)))) {
        overloadId = 0; // writeUInt16(quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeUInt16(quint16)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeUInt32(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeUInt32";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeUInt32(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // writeUInt32(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeUInt32(quint32)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeUInt64(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeUInt64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeUInt64(quint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint64>(), (pyArg)))) {
        overloadId = 0; // writeUInt64(quint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeUInt64(quint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDataStreamFunc_writeUInt8(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.writeUInt8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDataStream::writeUInt8(quint8)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), (pyArg)))) {
        overloadId = 0; // writeUInt8(quint8)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint8 cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeUInt8(quint8)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            Py_BEGIN_ALLOW_THREADS
            (*cppSelf) << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDataStream_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDataStream_EnumFlagInfo[] = {
    "ByteOrder:Enum",
    "FloatingPointPrecision:Enum",
    "Status:Enum",
    "Version:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDataStream_methods[] = {
    {"abortTransaction", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_abortTransaction), METH_NOARGS, nullptr},
    {"atEnd", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_atEnd), METH_NOARGS, nullptr},
    {"byteOrder", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_byteOrder), METH_NOARGS, nullptr},
    {"commitTransaction", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_commitTransaction), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_device), METH_NOARGS, nullptr},
    {"floatingPointPrecision", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_floatingPointPrecision), METH_NOARGS, nullptr},
    {"isDeviceTransactionStarted", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_isDeviceTransactionStarted), METH_NOARGS, nullptr},
    {"readBool", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readBool), METH_NOARGS, nullptr},
    {"readBytes", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readBytes), METH_O, nullptr},
    {"readDouble", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readDouble), METH_NOARGS, nullptr},
    {"readFloat", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readFloat), METH_NOARGS, nullptr},
    {"readInt16", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readInt16), METH_NOARGS, nullptr},
    {"readInt32", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readInt32), METH_NOARGS, nullptr},
    {"readInt64", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readInt64), METH_NOARGS, nullptr},
    {"readInt8", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readInt8), METH_NOARGS, nullptr},
    {"readQChar", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readQChar), METH_NOARGS, nullptr},
    {"readQString", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readQString), METH_NOARGS, nullptr},
    {"readQStringList", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readQStringList), METH_NOARGS, nullptr},
    {"readQVariant", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readQVariant), METH_NOARGS, nullptr},
    {"readRawData", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readRawData), METH_O, nullptr},
    {"readString", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readString), METH_NOARGS, nullptr},
    {"readUInt16", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readUInt16), METH_NOARGS, nullptr},
    {"readUInt32", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readUInt32), METH_NOARGS, nullptr},
    {"readUInt64", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readUInt64), METH_NOARGS, nullptr},
    {"readUInt8", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_readUInt8), METH_NOARGS, nullptr},
    {"resetStatus", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_resetStatus), METH_NOARGS, nullptr},
    {"rollbackTransaction", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_rollbackTransaction), METH_NOARGS, nullptr},
    {"setByteOrder", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_setByteOrder), METH_O, nullptr},
    {"setDevice", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_setDevice), METH_O, nullptr},
    {"setFloatingPointPrecision", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_setFloatingPointPrecision), METH_O, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_setStatus), METH_O, nullptr},
    {"setVersion", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_setVersion), METH_O, nullptr},
    {"skipRawData", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_skipRawData), METH_O, nullptr},
    {"startTransaction", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_startTransaction), METH_NOARGS, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_status), METH_NOARGS, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_version), METH_NOARGS, nullptr},
    {"writeBool", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeBool), METH_O, nullptr},
    {"writeBytes", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeBytes), METH_O, nullptr},
    {"writeDouble", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeDouble), METH_O, nullptr},
    {"writeFloat", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeFloat), METH_O, nullptr},
    {"writeInt16", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeInt16), METH_O, nullptr},
    {"writeInt32", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeInt32), METH_O, nullptr},
    {"writeInt64", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeInt64), METH_O, nullptr},
    {"writeInt8", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeInt8), METH_O, nullptr},
    {"writeQChar", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeQChar), METH_O, nullptr},
    {"writeQString", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeQString), METH_O, nullptr},
    {"writeQStringList", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeQStringList), METH_O, nullptr},
    {"writeQVariant", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeQVariant), METH_O, nullptr},
    {"writeRawData", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeRawData), METH_O, nullptr},
    {"writeString", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeString), METH_O, nullptr},
    {"writeUInt16", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeUInt16), METH_O, nullptr},
    {"writeUInt32", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeUInt32), METH_O, nullptr},
    {"writeUInt64", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeUInt64), METH_O, nullptr},
    {"writeUInt8", reinterpret_cast<PyCFunction>(Sbk_QDataStreamFunc_writeUInt8), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QDataStreamFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.__lshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDataStream::operator<<(QCborSimpleType)->QDataStream&
        // 1: QDataStream::operator<<(QChar)->QDataStream&
        // 2: QDataStream::operator<<(QDate)->QDataStream&
        // 3: QDataStream::operator<<(QKeyCombination)->QDataStream&
        // 4: QDataStream::operator<<(QTime)->QDataStream&
        // 5: QDataStream::operator<<(char)->QDataStream&
        // 6: QDataStream::operator<<(QBitArray)->QDataStream&
        // 7: QDataStream::operator<<(QByteArray)->QDataStream&
        // 8: QDataStream::operator<<(QCborArray)->QDataStream&
        // 9: QDataStream::operator<<(QCborMap)->QDataStream&
        // 10: QDataStream::operator<<(QCborValue)->QDataStream&
        // 11: QDataStream::operator<<(QDateTime)->QDataStream&
        // 12: QDataStream::operator<<(QEasingCurve)->QDataStream&
        // 13: QDataStream::operator<<(QJsonArray)->QDataStream&
        // 14: QDataStream::operator<<(QJsonDocument)->QDataStream&
        // 15: QDataStream::operator<<(QJsonObject)->QDataStream&
        // 16: QDataStream::operator<<(QJsonValue)->QDataStream&
        // 17: QDataStream::operator<<(QLine)->QDataStream&
        // 18: QDataStream::operator<<(QLineF)->QDataStream&
        // 19: QDataStream::operator<<(QLocale)->QDataStream&
        // 20: QDataStream::operator<<(QMargins)->QDataStream&
        // 21: QDataStream::operator<<(QMarginsF)->QDataStream&
        // 22: QDataStream::operator<<(QPoint)->QDataStream&
        // 23: QDataStream::operator<<(QPointF)->QDataStream&
        // 24: QDataStream::operator<<(QRect)->QDataStream&
        // 25: QDataStream::operator<<(QRectF)->QDataStream&
        // 26: QDataStream::operator<<(QRegularExpression)->QDataStream&
        // 27: QDataStream::operator<<(QSize)->QDataStream&
        // 28: QDataStream::operator<<(QSizeF)->QDataStream&
        // 29: QDataStream::operator<<(QString)
        // 30: QDataStream::operator<<(QString)->QDataStream&
        // 31: QDataStream::operator<<(QTimeZone)->QDataStream&
        // 32: QDataStream::operator<<(QUrl)->QDataStream&
        // 33: QDataStream::operator<<(QUuid)->QDataStream&
        // 34: QDataStream::operator<<(QVariant)->QDataStream&
        // 35: QDataStream::operator<<(QVersionNumber)->QDataStream&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
            overloadId = 35; // operator<<(QDataStream&,QVersionNumber)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
            overloadId = 33; // operator<<(QDataStream&,QUuid)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
            overloadId = 31; // operator<<(QDataStream&,QTimeZone)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 30; // operator<<(QDataStream&,QString)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 29; // operator<<(QString)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
            overloadId = 32; // operator<<(QDataStream&,QUrl)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
            overloadId = 27; // operator<<(QDataStream&,QSize)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
            overloadId = 28; // operator<<(QDataStream&,QSizeF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
            overloadId = 26; // operator<<(QDataStream&,QRegularExpression)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
            overloadId = 24; // operator<<(QDataStream&,QRect)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
            overloadId = 25; // operator<<(QDataStream&,QRectF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
            overloadId = 22; // operator<<(QDataStream&,QPoint)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
            overloadId = 23; // operator<<(QDataStream&,QPointF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMargins_IDX]), (pyArg)))) {
            overloadId = 20; // operator<<(QDataStream&,QMargins)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArg)))) {
            overloadId = 21; // operator<<(QDataStream&,QMarginsF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
            overloadId = 19; // operator<<(QDataStream&,QLocale)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
            overloadId = 17; // operator<<(QDataStream&,QLine)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
            overloadId = 18; // operator<<(QDataStream&,QLineF)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
            overloadId = 15; // operator<<(QDataStream&,QJsonObject)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArg)))) {
            overloadId = 14; // operator<<(QDataStream&,QJsonDocument)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
            overloadId = 13; // operator<<(QDataStream&,QJsonArray)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
            overloadId = 12; // operator<<(QDataStream&,QEasingCurve)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
            overloadId = 11; // operator<<(QDataStream&,QDateTime)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), (pyArg)))) {
            overloadId = 9; // operator<<(QDataStream&,QCborMap)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
            overloadId = 8; // operator<<(QDataStream&,QCborArray)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArg)))) {
            overloadId = 6; // operator<<(QDataStream&,QBitArray)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
            overloadId = 4; // operator<<(QDataStream&,QTime)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArg)))) {
            overloadId = 3; // operator<<(QDataStream&,QKeyCombination)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
            overloadId = 2; // operator<<(QDataStream&,QDate)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
            overloadId = 1; // operator<<(QDataStream&,QChar)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QCborSimpleType)
        } else if (!isReverse
            && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
            overloadId = 5; // operator<<(char)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
            overloadId = 16; // operator<<(QDataStream&,QJsonValue)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 7; // operator<<(QDataStream&,QByteArray)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
            overloadId = 10; // operator<<(QDataStream&,QCborValue)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
            overloadId = 34; // operator<<(QDataStream&,QVariant)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        switch (overloadId) {
            case 0: // operator<<(QCborSimpleType st)
            {
                ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QCborSimpleType)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 1: // operator<<(QChar arg__2)
            {
                ::QChar cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QChar)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 2: // operator<<(QDate arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QDate)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 3: // operator<<(QKeyCombination combination)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeyCombination cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QKeyCombination)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 4: // operator<<(QTime arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QTime)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 5: // operator<<(char i)
            {
                char cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(char)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 6: // operator<<(const QBitArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBitArray cppArg0_local;
                ::QBitArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QBitArray)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 7: // operator<<(const QByteArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QByteArray)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 8: // operator<<(const QCborArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QCborArray)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 9: // operator<<(const QCborMap & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborMap cppArg0_local;
                ::QCborMap *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QCborMap)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 10: // operator<<(const QCborValue & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QCborValue)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 11: // operator<<(const QDateTime & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDateTime cppArg0_local;
                ::QDateTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QDateTime)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 12: // operator<<(const QEasingCurve & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEasingCurve cppArg0_local;
                ::QEasingCurve *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QEasingCurve)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 13: // operator<<(const QJsonArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonArray cppArg0_local;
                ::QJsonArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QJsonArray)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 14: // operator<<(const QJsonDocument & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonDocument cppArg0_local;
                ::QJsonDocument *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QJsonDocument)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 15: // operator<<(const QJsonObject & arg__2)
            {
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QJsonObject)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 16: // operator<<(const QJsonValue & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QJsonValue)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 17: // operator<<(const QLine & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QLine)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 18: // operator<<(const QLineF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QLineF)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 19: // operator<<(const QLocale & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLocale cppArg0_local;
                ::QLocale *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QLocale)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 20: // operator<<(const QMargins & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMargins cppArg0_local;
                ::QMargins *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QMargins)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 21: // operator<<(const QMarginsF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMarginsF cppArg0_local;
                ::QMarginsF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QMarginsF)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 22: // operator<<(const QPoint & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPoint cppArg0_local;
                ::QPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QPoint)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 23: // operator<<(const QPointF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPointF cppArg0_local;
                ::QPointF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QPointF)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 24: // operator<<(const QRect & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRect cppArg0_local;
                ::QRect *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QRect)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 25: // operator<<(const QRectF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRectF cppArg0_local;
                ::QRectF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QRectF)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 26: // operator<<(const QRegularExpression & re)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QRegularExpression)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 27: // operator<<(const QSize & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QSize)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 28: // operator<<(const QSizeF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QSizeF)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 29: // operator<<(const QString & arg__1)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                SBK_UNUSED(cppArg0)

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QString)
                    // Begin code injection
                    // ========================================================================
                    // START of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
                    Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) << cppArg0;
                    Py_END_ALLOW_THREADS
                    // END of custom code block [file: ../glue/qtcore.cpp (stream-write-method)]
                    // ========================================================================
                    // End of code injection

                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 30: // operator<<(const QString & arg__2)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QString)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 31: // operator<<(const QTimeZone & tz)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTimeZone cppArg0_local;
                ::QTimeZone *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QTimeZone)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 32: // operator<<(const QUrl & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QUrl)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 33: // operator<<(const QUuid & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QUuid)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 34: // operator<<(const QVariant & p)
            {
                ::QVariant cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QVariant)
                    QDataStream & cppResult = (*cppSelf) << cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 35: // operator<<(const QVersionNumber & version)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator<<(QDataStream&,QVersionNumber)
                    QDataStream & cppResult = (*cppSelf) << (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDataStreamFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDataStream *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDataStream.__rshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDataStream::operator>>(QBitArray&)->QDataStream&
        // 1: QDataStream::operator>>(QByteArray&)->QDataStream&
        // 2: QDataStream::operator>>(QCborArray&)->QDataStream&
        // 3: QDataStream::operator>>(QCborMap&)->QDataStream&
        // 4: QDataStream::operator>>(QCborSimpleType&)->QDataStream&
        // 5: QDataStream::operator>>(QCborValue&)->QDataStream&
        // 6: QDataStream::operator>>(QChar&)->QDataStream&
        // 7: QDataStream::operator>>(QDate&)->QDataStream&
        // 8: QDataStream::operator>>(QDateTime&)->QDataStream&
        // 9: QDataStream::operator>>(QEasingCurve&)->QDataStream&
        // 10: QDataStream::operator>>(QJsonArray&)->QDataStream&
        // 11: QDataStream::operator>>(QJsonDocument&)->QDataStream&
        // 12: QDataStream::operator>>(QJsonObject&)->QDataStream&
        // 13: QDataStream::operator>>(QJsonValue&)->QDataStream&
        // 14: QDataStream::operator>>(QKeyCombination&)->QDataStream&
        // 15: QDataStream::operator>>(QLine&)->QDataStream&
        // 16: QDataStream::operator>>(QLineF&)->QDataStream&
        // 17: QDataStream::operator>>(QLocale&)->QDataStream&
        // 18: QDataStream::operator>>(QMargins&)->QDataStream&
        // 19: QDataStream::operator>>(QMarginsF&)->QDataStream&
        // 20: QDataStream::operator>>(QPoint&)->QDataStream&
        // 21: QDataStream::operator>>(QPointF&)->QDataStream&
        // 22: QDataStream::operator>>(QRect&)->QDataStream&
        // 23: QDataStream::operator>>(QRectF&)->QDataStream&
        // 24: QDataStream::operator>>(QRegularExpression&)->QDataStream&
        // 25: QDataStream::operator>>(QSize&)->QDataStream&
        // 26: QDataStream::operator>>(QSizeF&)->QDataStream&
        // 27: QDataStream::operator>>(QString&)->QDataStream&
        // 28: QDataStream::operator>>(QTime&)->QDataStream&
        // 29: QDataStream::operator>>(QTimeZone&)->QDataStream&
        // 30: QDataStream::operator>>(QUrl&)->QDataStream&
        // 31: QDataStream::operator>>(QUuid&)->QDataStream&
        // 32: QDataStream::operator>>(QVariant&)->QDataStream&
        // 33: QDataStream::operator>>(QVersionNumber&)->QDataStream&
        // 34: QDataStream::operator>>(char&)->QDataStream&
        if (!isReverse
            && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
            overloadId = 34; // operator>>(char&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QVersionNumber_IDX]), (pyArg)))) {
            overloadId = 33; // operator>>(QDataStream&,QVersionNumber&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX]), (pyArg)))) {
            overloadId = 31; // operator>>(QDataStream&,QUuid&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
            overloadId = 29; // operator>>(QDataStream&,QTimeZone&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArg)))) {
            overloadId = 28; // operator>>(QDataStream&,QTime&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
            overloadId = 27; // operator>>(QDataStream&,QString&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
            overloadId = 30; // operator>>(QDataStream&,QUrl&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
            overloadId = 25; // operator>>(QDataStream&,QSize&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
            overloadId = 26; // operator>>(QDataStream&,QSizeF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArg)))) {
            overloadId = 24; // operator>>(QDataStream&,QRegularExpression&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArg)))) {
            overloadId = 22; // operator>>(QDataStream&,QRect&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
            overloadId = 23; // operator>>(QDataStream&,QRectF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
            overloadId = 20; // operator>>(QDataStream&,QPoint&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
            overloadId = 21; // operator>>(QDataStream&,QPointF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMargins_IDX]), (pyArg)))) {
            overloadId = 18; // operator>>(QDataStream&,QMargins&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), (pyArg)))) {
            overloadId = 19; // operator>>(QDataStream&,QMarginsF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
            overloadId = 17; // operator>>(QDataStream&,QLocale&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArg)))) {
            overloadId = 15; // operator>>(QDataStream&,QLine&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArg)))) {
            overloadId = 16; // operator>>(QDataStream&,QLineF&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), (pyArg)))) {
            overloadId = 14; // operator>>(QDataStream&,QKeyCombination&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], (pyArg)))) {
            overloadId = 12; // operator>>(QDataStream&,QJsonObject&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonDocument_IDX]), (pyArg)))) {
            overloadId = 11; // operator>>(QDataStream&,QJsonDocument&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonArray_IDX]), (pyArg)))) {
            overloadId = 10; // operator>>(QDataStream&,QJsonArray&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QJsonValue_IDX]), (pyArg)))) {
            overloadId = 13; // operator>>(QDataStream&,QJsonValue&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEasingCurve_IDX]), (pyArg)))) {
            overloadId = 9; // operator>>(QDataStream&,QEasingCurve&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
            overloadId = 8; // operator>>(QDataStream&,QDateTime&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
            overloadId = 7; // operator>>(QDataStream&,QDate&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArg)))) {
            overloadId = 6; // operator>>(QDataStream&,QChar&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))->converter, (pyArg)))) {
            overloadId = 4; // operator>>(QDataStream&,QCborSimpleType&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborMap_IDX]), (pyArg)))) {
            overloadId = 3; // operator>>(QDataStream&,QCborMap&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborArray_IDX]), (pyArg)))) {
            overloadId = 2; // operator>>(QDataStream&,QCborArray&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
            overloadId = 1; // operator>>(QDataStream&,QByteArray&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), (pyArg)))) {
            overloadId = 5; // operator>>(QDataStream&,QCborValue&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QBitArray&)
        } else if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
            overloadId = 32; // operator>>(QDataStream&,QVariant&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        switch (overloadId) {
            case 0: // operator>>(QBitArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBitArray cppArg0_local;
                ::QBitArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QBitArray&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 1: // operator>>(QByteArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QByteArray&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 2: // operator>>(QCborArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborArray cppArg0_local;
                ::QCborArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QCborArray&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 3: // operator>>(QCborMap & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborMap cppArg0_local;
                ::QCborMap *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QCborMap&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 4: // operator>>(QCborSimpleType & st)
            {
                ::QCborSimpleType cppArg0 = static_cast< ::QCborSimpleType>(0);
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QCborSimpleType&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 5: // operator>>(QCborValue & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCborValue cppArg0_local;
                ::QCborValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QCborValue&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 6: // operator>>(QChar & arg__2)
            {
                ::QChar cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QChar&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 7: // operator>>(QDate & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDate cppArg0_local;
                ::QDate *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QDate&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 8: // operator>>(QDateTime & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDateTime cppArg0_local;
                ::QDateTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QDateTime&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 9: // operator>>(QEasingCurve & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QEasingCurve cppArg0_local;
                ::QEasingCurve *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QEasingCurve&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 10: // operator>>(QJsonArray & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonArray cppArg0_local;
                ::QJsonArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QJsonArray&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 11: // operator>>(QJsonDocument & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonDocument cppArg0_local;
                ::QJsonDocument *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QJsonDocument&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 12: // operator>>(QJsonObject & arg__2)
            {
                ::QJsonObject cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QJsonObject&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 13: // operator>>(QJsonValue & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QJsonValue cppArg0_local;
                ::QJsonValue *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QJsonValue&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 14: // operator>>(QKeyCombination & combination)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QKeyCombination cppArg0_local;
                ::QKeyCombination *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QKeyCombination&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 15: // operator>>(QLine & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLine cppArg0_local;
                ::QLine *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QLine&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 16: // operator>>(QLineF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLineF cppArg0_local;
                ::QLineF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QLineF&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 17: // operator>>(QLocale & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLocale cppArg0_local;
                ::QLocale *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QLocale&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 18: // operator>>(QMargins & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMargins cppArg0_local;
                ::QMargins *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QMargins&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 19: // operator>>(QMarginsF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QMarginsF cppArg0_local;
                ::QMarginsF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QMarginsF&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 20: // operator>>(QPoint & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPoint cppArg0_local;
                ::QPoint *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QPoint&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 21: // operator>>(QPointF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPointF cppArg0_local;
                ::QPointF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QPointF&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 22: // operator>>(QRect & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRect cppArg0_local;
                ::QRect *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QRect&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 23: // operator>>(QRectF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRectF cppArg0_local;
                ::QRectF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QRectF&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 24: // operator>>(QRegularExpression & re)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QRegularExpression cppArg0_local;
                ::QRegularExpression *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QRegularExpression&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 25: // operator>>(QSize & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSize cppArg0_local;
                ::QSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QSize&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 26: // operator>>(QSizeF & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QSizeF cppArg0_local;
                ::QSizeF *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QSizeF&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 27: // operator>>(QString & arg__2)
            {
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QString&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 28: // operator>>(QTime & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTime cppArg0_local;
                ::QTime *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QTime&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 29: // operator>>(QTimeZone & tz)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTimeZone cppArg0_local;
                ::QTimeZone *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QTimeZone&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 30: // operator>>(QUrl & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QUrl&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 31: // operator>>(QUuid & arg__2)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUuid cppArg0_local;
                ::QUuid *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QUuid&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 32: // operator>>(QVariant & p)
            {
                ::QVariant cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QVariant&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 33: // operator>>(QVersionNumber & version)
            {
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVersionNumber cppArg0_local;
                ::QVersionNumber *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);


                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(QDataStream&,QVersionNumber&)
                    QDataStream & cppResult = (*cppSelf) >> (*cppArg0);
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
            case 34: // operator>>(char & i)
            {
                char cppArg0;
                pythonToCpp(pyArg, &cppArg0);

                if (Shiboken::Errors::occurred() == nullptr) {
                    // operator>>(char&)
                    QDataStream & cppResult = (*cppSelf) >> cppArg0;
                    pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
                }
                break;
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QDataStream_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDataStream_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDataStream_Type = nullptr;
static PyTypeObject *Sbk_QDataStream_TypeF(void)
{
    return _Sbk_QDataStream_Type;
}

static PyType_Slot Sbk_QDataStream_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDataStream_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDataStream_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDataStream_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDataStream_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QDataStreamFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QDataStreamFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDataStream_spec = {
    "2:PySide6.QtCore.QDataStream",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDataStream_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QDataStream_Version_PythonToCpp_QDataStream_Version(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDataStream::Version>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDataStream::Version *>(cppOut) = value;

}
static PythonToCppFunc is_QDataStream_Version_PythonToCpp_QDataStream_Version_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Version_IDX])))
        return QDataStream_Version_PythonToCpp_QDataStream_Version;
    return {};
}
static PyObject *QDataStream_Version_CppToPython_QDataStream_Version(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDataStream::Version *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Version_IDX]), castCppIn);

}

static void QDataStream_ByteOrder_PythonToCpp_QDataStream_ByteOrder(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDataStream::ByteOrder>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDataStream::ByteOrder *>(cppOut) = value;

}
static PythonToCppFunc is_QDataStream_ByteOrder_PythonToCpp_QDataStream_ByteOrder_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_ByteOrder_IDX])))
        return QDataStream_ByteOrder_PythonToCpp_QDataStream_ByteOrder;
    return {};
}
static PyObject *QDataStream_ByteOrder_CppToPython_QDataStream_ByteOrder(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDataStream::ByteOrder *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_ByteOrder_IDX]), castCppIn);

}

static void QDataStream_Status_PythonToCpp_QDataStream_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDataStream::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDataStream::Status *>(cppOut) = value;

}
static PythonToCppFunc is_QDataStream_Status_PythonToCpp_QDataStream_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Status_IDX])))
        return QDataStream_Status_PythonToCpp_QDataStream_Status;
    return {};
}
static PyObject *QDataStream_Status_CppToPython_QDataStream_Status(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDataStream::Status *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Status_IDX]), castCppIn);

}

static void QDataStream_FloatingPointPrecision_PythonToCpp_QDataStream_FloatingPointPrecision(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDataStream::FloatingPointPrecision>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDataStream::FloatingPointPrecision *>(cppOut) = value;

}
static PythonToCppFunc is_QDataStream_FloatingPointPrecision_PythonToCpp_QDataStream_FloatingPointPrecision_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_FloatingPointPrecision_IDX])))
        return QDataStream_FloatingPointPrecision_PythonToCpp_QDataStream_FloatingPointPrecision;
    return {};
}
static PyObject *QDataStream_FloatingPointPrecision_CppToPython_QDataStream_FloatingPointPrecision(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDataStream::FloatingPointPrecision *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_FloatingPointPrecision_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDataStream_PythonToCpp_QDataStream_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDataStream_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDataStream_PythonToCpp_QDataStream_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDataStream_TypeF()))
        return QDataStream_PythonToCpp_QDataStream_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDataStream_PTR_CppToPython_QDataStream(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto *tCppIn = reinterpret_cast<const ::QDataStream *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = Shiboken::typeNameOf(typeid(*tCppIn).name());
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QDataStream_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDataStream_SignatureStrings[] = {
    "3:PySide6.QtCore.QDataStream(self)",
    "2:PySide6.QtCore.QDataStream(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*],flags:PySide6.QtCore.QIODeviceBase.OpenModeFlag)",
    "1:PySide6.QtCore.QDataStream(self,arg__1:PySide6.QtCore.QIODevice)",
    "0:PySide6.QtCore.QDataStream(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QDataStream.abortTransaction(self)",
    "PySide6.QtCore.QDataStream.atEnd(self)->bool",
    "PySide6.QtCore.QDataStream.byteOrder(self)->PySide6.QtCore.QDataStream.ByteOrder",
    "PySide6.QtCore.QDataStream.commitTransaction(self)->bool",
    "PySide6.QtCore.QDataStream.device(self)->PySide6.QtCore.QIODevice",
    "PySide6.QtCore.QDataStream.floatingPointPrecision(self)->PySide6.QtCore.QDataStream.FloatingPointPrecision",
    "PySide6.QtCore.QDataStream.isDeviceTransactionStarted(self)->bool",
    "PySide6.QtCore.QDataStream.readBool(self)->bool",
    "PySide6.QtCore.QDataStream.readBytes(self,len:qint64)->PyTuple",
    "PySide6.QtCore.QDataStream.readDouble(self)->qreal",
    "PySide6.QtCore.QDataStream.readFloat(self)->float",
    "PySide6.QtCore.QDataStream.readInt16(self)->qint16",
    "PySide6.QtCore.QDataStream.readInt32(self)->qint32",
    "PySide6.QtCore.QDataStream.readInt64(self)->qint64",
    "PySide6.QtCore.QDataStream.readInt8(self)->qint8",
    "PySide6.QtCore.QDataStream.readQChar(self)->QChar",
    "PySide6.QtCore.QDataStream.readQString(self)->QString",
    "PySide6.QtCore.QDataStream.readQStringList(self)->QStringList",
    "PySide6.QtCore.QDataStream.readQVariant(self)->QVariant",
    "PySide6.QtCore.QDataStream.readRawData(self,len:qint64)->bytes",
    "PySide6.QtCore.QDataStream.readString(self)->QString",
    "PySide6.QtCore.QDataStream.readUInt16(self)->quint16",
    "PySide6.QtCore.QDataStream.readUInt32(self)->quint32",
    "PySide6.QtCore.QDataStream.readUInt64(self)->quint64",
    "PySide6.QtCore.QDataStream.readUInt8(self)->quint8",
    "PySide6.QtCore.QDataStream.resetStatus(self)",
    "PySide6.QtCore.QDataStream.rollbackTransaction(self)",
    "PySide6.QtCore.QDataStream.setByteOrder(self,arg__1:PySide6.QtCore.QDataStream.ByteOrder)",
    "PySide6.QtCore.QDataStream.setDevice(self,arg__1:PySide6.QtCore.QIODevice)",
    "PySide6.QtCore.QDataStream.setFloatingPointPrecision(self,precision:PySide6.QtCore.QDataStream.FloatingPointPrecision)",
    "PySide6.QtCore.QDataStream.setStatus(self,status:PySide6.QtCore.QDataStream.Status)",
    "PySide6.QtCore.QDataStream.setVersion(self,arg__1:int)",
    "PySide6.QtCore.QDataStream.skipRawData(self,len:qint64)->qint64",
    "PySide6.QtCore.QDataStream.startTransaction(self)",
    "PySide6.QtCore.QDataStream.status(self)->PySide6.QtCore.QDataStream.Status",
    "PySide6.QtCore.QDataStream.version(self)->int",
    "PySide6.QtCore.QDataStream.writeBool(self,arg__1:bool)",
    "PySide6.QtCore.QDataStream.writeBytes(self,arg__1:PyBuffer)->PySide6.QtCore.QDataStream",
    "PySide6.QtCore.QDataStream.writeDouble(self,arg__1:qreal)",
    "PySide6.QtCore.QDataStream.writeFloat(self,arg__1:float)",
    "PySide6.QtCore.QDataStream.writeInt16(self,arg__1:qint16)",
    "PySide6.QtCore.QDataStream.writeInt32(self,arg__1:qint32)",
    "PySide6.QtCore.QDataStream.writeInt64(self,arg__1:qint64)",
    "PySide6.QtCore.QDataStream.writeInt8(self,arg__1:qint8)",
    "PySide6.QtCore.QDataStream.writeQChar(self,arg__1:QChar)",
    "PySide6.QtCore.QDataStream.writeQString(self,arg__1:QString)",
    "PySide6.QtCore.QDataStream.writeQStringList(self,arg__1:QStringList)",
    "PySide6.QtCore.QDataStream.writeQVariant(self,arg__1:QVariant)",
    "1:PySide6.QtCore.QDataStream.writeRawData(self,arg__1:PyBuffer)",
    "0:PySide6.QtCore.QDataStream.writeRawData(self,arg__1:str)->qint64",
    "PySide6.QtCore.QDataStream.writeString(self,arg__1:QString)",
    "PySide6.QtCore.QDataStream.writeUInt16(self,arg__1:quint16)",
    "PySide6.QtCore.QDataStream.writeUInt32(self,arg__1:quint32)",
    "PySide6.QtCore.QDataStream.writeUInt64(self,arg__1:quint64)",
    "PySide6.QtCore.QDataStream.writeUInt8(self,arg__1:quint8)",
    "35:PySide6.QtCore.QDataStream.__lshift__(self,st:PySide6.QtCore.QCborSimpleType)->PySide6.QtCore.QDataStream",
    "34:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:QChar)->PySide6.QtCore.QDataStream",
    "33:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QDate)->PySide6.QtCore.QDataStream",
    "32:PySide6.QtCore.QDataStream.__lshift__(self,combination:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key])->PySide6.QtCore.QDataStream",
    "31:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QTime)->PySide6.QtCore.QDataStream",
    "30:PySide6.QtCore.QDataStream.__lshift__(self,i:char)->PySide6.QtCore.QDataStream",
    "29:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QBitArray, qsizetype])->PySide6.QtCore.QDataStream",
    "28:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QDataStream",
    "27:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QCborArray)->PySide6.QtCore.QDataStream",
    "26:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QCborMap)->PySide6.QtCore.QDataStream",
    "25:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->PySide6.QtCore.QDataStream",
    "24:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDataStream",
    "23:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])->PySide6.QtCore.QDataStream",
    "22:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QJsonArray)->PySide6.QtCore.QDataStream",
    "21:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QJsonDocument)->PySide6.QtCore.QDataStream",
    "20:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:QJsonObject)->PySide6.QtCore.QDataStream",
    "19:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])->PySide6.QtCore.QDataStream",
    "18:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QLine)->PySide6.QtCore.QDataStream",
    "17:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtCore.QDataStream",
    "16:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])->PySide6.QtCore.QDataStream",
    "15:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QMargins)->PySide6.QtCore.QDataStream",
    "14:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])->PySide6.QtCore.QDataStream",
    "13:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QPoint)->PySide6.QtCore.QDataStream",
    "12:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])->PySide6.QtCore.QDataStream",
    "11:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QRect)->PySide6.QtCore.QDataStream",
    "10:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QDataStream",
    "9:PySide6.QtCore.QDataStream.__lshift__(self,re:typing.Union[PySide6.QtCore.QRegularExpression, QString])->PySide6.QtCore.QDataStream",
    "8:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QSize)->PySide6.QtCore.QDataStream",
    "7:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QDataStream",
    "6:PySide6.QtCore.QDataStream.__lshift__(self,arg__1:QString)",
    "5:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:QString)->PySide6.QtCore.QDataStream",
    "4:PySide6.QtCore.QDataStream.__lshift__(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDataStream",
    "3:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QDataStream",
    "2:PySide6.QtCore.QDataStream.__lshift__(self,arg__2:PySide6.QtCore.QUuid)->PySide6.QtCore.QDataStream",
    "1:PySide6.QtCore.QDataStream.__lshift__(self,p:QVariant)->PySide6.QtCore.QDataStream",
    "0:PySide6.QtCore.QDataStream.__lshift__(self,version:PySide6.QtCore.QVersionNumber)->PySide6.QtCore.QDataStream",
    "34:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QBitArray, qsizetype])->PySide6.QtCore.QDataStream",
    "33:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QDataStream",
    "32:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QCborArray)->PySide6.QtCore.QDataStream",
    "31:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QCborMap)->PySide6.QtCore.QDataStream",
    "30:PySide6.QtCore.QDataStream.__rshift__(self,st:PySide6.QtCore.QCborSimpleType)->PySide6.QtCore.QDataStream",
    "29:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QCborValue, PySide6.QtCore.QCborKnownTags, PySide6.QtCore.QCborSimpleType, PySide6.QtCore.QCborTag, PySide6.QtCore.QCborValue.Type, QLatin1String, QStringView, bool, PySide6.QtCore.QByteArray, PySide6.QtCore.QCborArray, PySide6.QtCore.QCborMap, QString, char*, double, int, qint64, unsigned int])->PySide6.QtCore.QDataStream",
    "28:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:QChar)->PySide6.QtCore.QDataStream",
    "27:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QDate)->PySide6.QtCore.QDataStream",
    "26:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDataStream",
    "25:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QEasingCurve, PySide6.QtCore.QEasingCurve.Type])->PySide6.QtCore.QDataStream",
    "24:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QJsonArray)->PySide6.QtCore.QDataStream",
    "23:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QJsonDocument)->PySide6.QtCore.QDataStream",
    "22:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:QJsonObject)->PySide6.QtCore.QDataStream",
    "21:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QJsonValue, PySide6.QtCore.QJsonValue.Type, QLatin1String, bool, PySide6.QtCore.QJsonArray, QJsonObject, QString, char*, double, int, qint64])->PySide6.QtCore.QDataStream",
    "20:PySide6.QtCore.QDataStream.__rshift__(self,combination:typing.Union[PySide6.QtCore.QKeyCombination, PySide6.QtCore.Qt.KeyboardModifier, PySide6.QtCore.Qt.Key])->PySide6.QtCore.QDataStream",
    "19:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QLine)->PySide6.QtCore.QDataStream",
    "18:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])->PySide6.QtCore.QDataStream",
    "17:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])->PySide6.QtCore.QDataStream",
    "16:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QMargins)->PySide6.QtCore.QDataStream",
    "15:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QMarginsF, PySide6.QtCore.QMargins])->PySide6.QtCore.QDataStream",
    "14:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QPoint)->PySide6.QtCore.QDataStream",
    "13:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint])->PySide6.QtCore.QDataStream",
    "12:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QRect)->PySide6.QtCore.QDataStream",
    "11:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QDataStream",
    "10:PySide6.QtCore.QDataStream.__rshift__(self,re:typing.Union[PySide6.QtCore.QRegularExpression, QString])->PySide6.QtCore.QDataStream",
    "9:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QSize)->PySide6.QtCore.QDataStream",
    "8:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])->PySide6.QtCore.QDataStream",
    "7:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:QString)->PySide6.QtCore.QDataStream",
    "6:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QTime)->PySide6.QtCore.QDataStream",
    "5:PySide6.QtCore.QDataStream.__rshift__(self,tz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->PySide6.QtCore.QDataStream",
    "4:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QDataStream",
    "3:PySide6.QtCore.QDataStream.__rshift__(self,arg__2:PySide6.QtCore.QUuid)->PySide6.QtCore.QDataStream",
    "2:PySide6.QtCore.QDataStream.__rshift__(self,p:QVariant)->PySide6.QtCore.QDataStream",
    "1:PySide6.QtCore.QDataStream.__rshift__(self,version:PySide6.QtCore.QVersionNumber)->PySide6.QtCore.QDataStream",
    "0:PySide6.QtCore.QDataStream.__rshift__(self,i:char)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel

PyTypeObject *init_QDataStream(PyObject *module)
{
    _Sbk_QDataStream_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDataStream",
        "QDataStream*",
        &Sbk_QDataStream_spec,
        &Shiboken::callCppDestructor< ::QDataStream >,
        Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]),
        0,
        0);
    auto *pyType = Sbk_QDataStream_TypeF(); // references _Sbk_QDataStream_Type
    InitSignatureStrings(pyType, QDataStream_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDataStream_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDataStream_PythonToCpp_QDataStream_PTR,
        is_QDataStream_PythonToCpp_QDataStream_PTR_Convertible,
        QDataStream_PTR_CppToPython_QDataStream);

    Shiboken::Conversions::registerConverterName(converter, "QDataStream");
    Shiboken::Conversions::registerConverterName(converter, "QDataStream*");
    Shiboken::Conversions::registerConverterName(converter, "QDataStream&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDataStream).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDataStream_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Version'.
    const char *Version_Initializer[] = {
        "Qt_1_0",
        "Qt_2_0",
        "Qt_2_1",
        "Qt_3_0",
        "Qt_3_1",
        "Qt_3_3",
        "Qt_4_0",
        "Qt_4_1",
        "Qt_4_2",
        "Qt_4_3",
        "Qt_4_4",
        "Qt_4_5",
        "Qt_4_6",
        "Qt_4_7",
        "Qt_4_8",
        "Qt_4_9",
        "Qt_5_0",
        "Qt_5_1",
        "Qt_5_2",
        "Qt_5_3",
        "Qt_5_4",
        "Qt_5_5",
        "Qt_5_6",
        "Qt_5_7",
        "Qt_5_8",
        "Qt_5_9",
        "Qt_5_10",
        "Qt_5_11",
        "Qt_5_12",
        "Qt_5_13",
        "Qt_5_14",
        "Qt_5_15",
        "Qt_6_0",
        "Qt_6_1",
        "Qt_6_2",
        "Qt_6_3",
        "Qt_6_4",
        "Qt_6_5",
        "Qt_6_6",
        "Qt_6_7",
        "Qt_DefaultCompiledVersion",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Version_InitializerValues[] = {
        uint8_t(QDataStream::Version::Qt_1_0),                   //  0x01  1
        uint8_t(QDataStream::Version::Qt_2_0),                   //  0x02  2
        uint8_t(QDataStream::Version::Qt_2_1),                   //  0x03  3
        uint8_t(QDataStream::Version::Qt_3_0),                   //  0x04  4
        uint8_t(QDataStream::Version::Qt_3_1),                   //  0x05  5
        uint8_t(QDataStream::Version::Qt_3_3),                   //  0x06  6
        uint8_t(QDataStream::Version::Qt_4_0),                   //  0x07  7
        uint8_t(QDataStream::Version::Qt_4_1),                   //  0x07  7
        uint8_t(QDataStream::Version::Qt_4_2),                   //  0x08  8
        uint8_t(QDataStream::Version::Qt_4_3),                   //  0x09  9
        uint8_t(QDataStream::Version::Qt_4_4),                   //  0x0a  10
        uint8_t(QDataStream::Version::Qt_4_5),                   //  0x0b  11
        uint8_t(QDataStream::Version::Qt_4_6),                   //  0x0c  12
        uint8_t(QDataStream::Version::Qt_4_7),                   //  0x0c  12
        uint8_t(QDataStream::Version::Qt_4_8),                   //  0x0c  12
        uint8_t(QDataStream::Version::Qt_4_9),                   //  0x0c  12
        uint8_t(QDataStream::Version::Qt_5_0),                   //  0x0d  13
        uint8_t(QDataStream::Version::Qt_5_1),                   //  0x0e  14
        uint8_t(QDataStream::Version::Qt_5_2),                   //  0x0f  15
        uint8_t(QDataStream::Version::Qt_5_3),                   //  0x0f  15
        uint8_t(QDataStream::Version::Qt_5_4),                   //  0x10  16
        uint8_t(QDataStream::Version::Qt_5_5),                   //  0x10  16
        uint8_t(QDataStream::Version::Qt_5_6),                   //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_7),                   //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_8),                   //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_9),                   //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_10),                  //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_11),                  //  0x11  17
        uint8_t(QDataStream::Version::Qt_5_12),                  //  0x12  18
        uint8_t(QDataStream::Version::Qt_5_13),                  //  0x13  19
        uint8_t(QDataStream::Version::Qt_5_14),                  //  0x13  19
        uint8_t(QDataStream::Version::Qt_5_15),                  //  0x13  19
        uint8_t(QDataStream::Version::Qt_6_0),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_1),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_2),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_3),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_4),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_5),                   //  0x14  20
        uint8_t(QDataStream::Version::Qt_6_6),                   //  0x15  21
        uint8_t(QDataStream::Version::Qt_6_7),                   //  0x16  22
        uint8_t(QDataStream::Version::Qt_DefaultCompiledVersion) //  0x16  22
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDataStream_TypeF(),
        "2:PySide6.QtCore.QDataStream.Version",
        Version_Initializer, Version_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Version_IDX].type = EType;
    // Register converter for enum 'QDataStream::Version'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDataStream_Version_CppToPython_QDataStream_Version);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDataStream_Version_PythonToCpp_QDataStream_Version,
            is_QDataStream_Version_PythonToCpp_QDataStream_Version_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDataStream::Version");
        Shiboken::Conversions::registerConverterName(converter, "Version");
    }
    // End of 'Version' enum.

    // Initialization of enum 'ByteOrder'.
    const char *ByteOrder_Initializer[] = {
        "BigEndian",
        "LittleEndian",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ByteOrder_InitializerValues[] = {
        uint8_t(QDataStream::ByteOrder::BigEndian),   //  0x00  0
        uint8_t(QDataStream::ByteOrder::LittleEndian) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDataStream_TypeF(),
        "2:PySide6.QtCore.QDataStream.ByteOrder",
        ByteOrder_Initializer, ByteOrder_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_ByteOrder_IDX].type = EType;
    // Register converter for enum 'QDataStream::ByteOrder'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDataStream_ByteOrder_CppToPython_QDataStream_ByteOrder);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDataStream_ByteOrder_PythonToCpp_QDataStream_ByteOrder,
            is_QDataStream_ByteOrder_PythonToCpp_QDataStream_ByteOrder_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDataStream::ByteOrder");
        Shiboken::Conversions::registerConverterName(converter, "ByteOrder");
    }
    // End of 'ByteOrder' enum.

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "Ok",
        "ReadPastEnd",
        "ReadCorruptData",
        "WriteFailed",
        "SizeLimitExceeded",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(QDataStream::Status::Ok),               //  0x00  0
        uint8_t(QDataStream::Status::ReadPastEnd),      //  0x01  1
        uint8_t(QDataStream::Status::ReadCorruptData),  //  0x02  2
        uint8_t(QDataStream::Status::WriteFailed),      //  0x03  3
        uint8_t(QDataStream::Status::SizeLimitExceeded) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDataStream_TypeF(),
        "2:PySide6.QtCore.QDataStream.Status",
        Status_Initializer, Status_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_Status_IDX].type = EType;
    // Register converter for enum 'QDataStream::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDataStream_Status_CppToPython_QDataStream_Status);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDataStream_Status_PythonToCpp_QDataStream_Status,
            is_QDataStream_Status_PythonToCpp_QDataStream_Status_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDataStream::Status");
        Shiboken::Conversions::registerConverterName(converter, "Status");
    }
    // End of 'Status' enum.

    // Initialization of enum 'FloatingPointPrecision'.
    const char *FloatingPointPrecision_Initializer[] = {
        "SinglePrecision",
        "DoublePrecision",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FloatingPointPrecision_InitializerValues[] = {
        uint8_t(QDataStream::FloatingPointPrecision::SinglePrecision), //  0x00  0
        uint8_t(QDataStream::FloatingPointPrecision::DoublePrecision)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDataStream_TypeF(),
        "2:PySide6.QtCore.QDataStream.FloatingPointPrecision",
        FloatingPointPrecision_Initializer, FloatingPointPrecision_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_FloatingPointPrecision_IDX].type = EType;
    // Register converter for enum 'QDataStream::FloatingPointPrecision'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDataStream_FloatingPointPrecision_CppToPython_QDataStream_FloatingPointPrecision);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QDataStream_FloatingPointPrecision_PythonToCpp_QDataStream_FloatingPointPrecision,
            is_QDataStream_FloatingPointPrecision_PythonToCpp_QDataStream_FloatingPointPrecision_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDataStream::FloatingPointPrecision");
        Shiboken::Conversions::registerConverterName(converter, "FloatingPointPrecision");
    }
    // End of 'FloatingPointPrecision' enum.

    qRegisterMetaType< ::QDataStream *>();
    qRegisterMetaType< ::QDataStream::Version >("QDataStream::Version");
    qRegisterMetaType< ::QDataStream::ByteOrder >("QDataStream::ByteOrder");
    qRegisterMetaType< ::QDataStream::Status >("QDataStream::Status");
    qRegisterMetaType< ::QDataStream::FloatingPointPrecision >("QDataStream::FloatingPointPrecision");

    return pyType;
}
