// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtgui_python.h"

#include <QHash>
#include <QInputMethodEvent>
#include <QList>
#include <QMap>
#include <QPainterPath>
#include <QSet>
#include <QString>
#include <QTextLayout>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaction.h>
#include <QtGui/qcolor.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontdatabase.h>
#include <QtGui/qglyphrun.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpixelformat.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qrgb.h>
#include <QtGui/qscreen.h>
#include <QtGui/qstandarditemmodel.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qundostack.h>
#include <QtGui/qvectornd.h>
#include <QtGui/qwindow.h>
#include <array>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qline.h>
#include <qobject.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>
#include <rhi/qrhi.h>
#include <rhi/qshader.h>
#include <utility>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtGuiTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtGuiTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtGuiModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtGuiTypeConverters = nullptr;

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtgui.cpp (gui-declarations)]
QT_BEGIN_NAMESPACE
void qt_set_sequence_auto_mnemonic(bool);
QT_END_NAMESPACE
// END of custom code block [file: ../glue/qtgui.cpp (gui-declarations)]
// ========================================================================
// End of code injection

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtGui_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtGuiTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtGuiTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------
static PyObject *SbkQtGuiModule_qAlpha(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qAlpha";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qAlpha(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qAlpha(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qAlpha(uint)
            int cppResult = qAlpha(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qBlue(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qBlue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qBlue(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qBlue(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qBlue(uint)
            int cppResult = qBlue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qFuzzyCompare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qFuzzyCompare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qFuzzyCompare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qFuzzyCompare(QTransform,QTransform)->bool
    // 1: qFuzzyCompare(QQuaternion,QQuaternion)->bool
    // 2: qFuzzyCompare(QMatrix4x4,QMatrix4x4)->bool
    // 3: qFuzzyCompare(QVector2D,QVector2D)->bool
    // 4: qFuzzyCompare(QVector3D,QVector3D)->bool
    // 5: qFuzzyCompare(QVector4D,QVector4D)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
        overloadId = 5; // qFuzzyCompare(QVector4D,QVector4D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
        overloadId = 4; // qFuzzyCompare(QVector3D,QVector3D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))) {
        overloadId = 3; // qFuzzyCompare(QVector2D,QVector2D)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArgs[1])))) {
        overloadId = 1; // qFuzzyCompare(QQuaternion,QQuaternion)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
        overloadId = 0; // qFuzzyCompare(QTransform,QTransform)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[1])))) {
        overloadId = 2; // qFuzzyCompare(QMatrix4x4,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qFuzzyCompare(QTransform arg__1, QTransform arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTransform cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QTransform,QTransform)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // qFuzzyCompare(QQuaternion arg__1, QQuaternion arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuaternion cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QQuaternion cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QQuaternion,QQuaternion)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // qFuzzyCompare(QMatrix4x4 arg__1, QMatrix4x4 arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMatrix4x4 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QMatrix4x4,QMatrix4x4)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // qFuzzyCompare(QVector2D arg__1, QVector2D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector2D,QVector2D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 4: // qFuzzyCompare(QVector3D arg__1, QVector3D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector3D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector3D,QVector3D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 5: // qFuzzyCompare(QVector4D arg__1, QVector4D arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QVector4D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFuzzyCompare(QVector4D,QVector4D)
                bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qGray(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qGray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "qGray", 1, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qGray(uint)->int
    // 1: qGray(int,int,int)->int
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // qGray(int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 0; // qGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qGray(unsigned int rgb)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qGray(uint)
                int cppResult = qGray(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // qGray(int r, int g, int b)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qGray(int,int,int)
                int cppResult = qGray(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qGreen(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qGreen";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qGreen(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qGreen(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qGreen(uint)
            int cppResult = qGreen(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qIsGray(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qIsGray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsGray(uint)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qIsGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsGray(uint)
            bool cppResult = qIsGray(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatAlpha(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatAlpha";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:qPixelFormatAlpha", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPixelFormat::TypeInterpretation cppArg1(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatAlpha(uchar,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatAlpha(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatCmyk(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatCmyk";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatCmyk", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatCmyk(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatCmyk(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatGrayscale(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatGrayscale";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:qPixelFormatGrayscale", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QPixelFormat::TypeInterpretation cppArg1(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatGrayscale(uchar,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatGrayscale(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatHsl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatHsl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatHsl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatHsl(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::FloatingPoint);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatHsl(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatHsl(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatHsv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatHsv";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:qPixelFormatHsv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatHsv(uchar,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4])))) {
                        overloadId = 0; // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::TypeInterpretation cppArg4(QPixelFormat::FloatingPoint);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatHsv(uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatHsv(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatRgba(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatRgba";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 6, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qPixelFormatRgba", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied=,QPixelFormat::TypeInterpretation=)->QPixelFormat
    if (numArgs >= 6
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPremultiplied_IDX])))->converter, (pyArgs[6])))) {
            if (numArgs == 7) {
                overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            } else if (numArgs >= 8
                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[7])))) {
                overloadId = 0; // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_pmul = Shiboken::String::createStaticString("pmul");
            if (PyDict_Contains(kwds, key_pmul) != 0) {
                value = PyDict_GetItem(kwds, key_pmul);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_pmul);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPremultiplied_IDX])))->converter, (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_pmul);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[7] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[7] = value;
                    if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[7]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        uchar cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        uchar cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        uchar cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::AlphaUsage cppArg4{QPixelFormat::UsesAlpha};
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QPixelFormat::AlphaPosition cppArg5{QPixelFormat::AtBeginning};
        pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QPixelFormat::AlphaPremultiplied cppArg6(QPixelFormat::NotPremultiplied);
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);
        ::QPixelFormat::TypeInterpretation cppArg7(QPixelFormat::UnsignedInteger);
        if (pythonToCpp[7])
            pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatRgba(uchar,uchar,uchar,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation)
            QPixelFormat cppResult = qPixelFormatRgba(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qPixelFormatYuv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qPixelFormatYuv";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOO:qPixelFormatYuv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qPixelFormatYuv(QPixelFormat::YUVLayout,uchar=,QPixelFormat::AlphaUsage=,QPixelFormat::AlphaPosition=,QPixelFormat::AlphaPremultiplied=,QPixelFormat::TypeInterpretation=,QPixelFormat::ByteOrder=)->QPixelFormat
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_YUVLayout_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPremultiplied_IDX])))->converter, (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_ByteOrder_IDX])))->converter, (pyArgs[6])))) {
                                overloadId = 0; // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_alfa = Shiboken::String::createStaticString("alfa");
            if (PyDict_Contains(kwds, key_alfa) != 0) {
                value = PyDict_GetItem(kwds, key_alfa);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_alfa);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uchar>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_alfa);
            }
            static PyObject *const key_usage = Shiboken::String::createStaticString("usage");
            if (PyDict_Contains(kwds, key_usage) != 0) {
                value = PyDict_GetItem(kwds, key_usage);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_usage);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaUsage_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_usage);
            }
            static PyObject *const key_position = Shiboken::String::createStaticString("position");
            if (PyDict_Contains(kwds, key_position) != 0) {
                value = PyDict_GetItem(kwds, key_position);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_position);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPosition_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_position);
            }
            static PyObject *const key_p_mul = Shiboken::String::createStaticString("p_mul");
            if (PyDict_Contains(kwds, key_p_mul) != 0) {
                value = PyDict_GetItem(kwds, key_p_mul);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_p_mul);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_AlphaPremultiplied_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_p_mul);
            }
            static PyObject *const key_typeInt = Shiboken::String::createStaticString("typeInt");
            if (PyDict_Contains(kwds, key_typeInt) != 0) {
                value = PyDict_GetItem(kwds, key_typeInt);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_typeInt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_TypeInterpretation_IDX])))->converter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_typeInt);
            }
            static PyObject *const key_b_order = Shiboken::String::createStaticString("b_order");
            if (PyDict_Contains(kwds, key_b_order) != 0) {
                value = PyDict_GetItem(kwds, key_b_order);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_b_order);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_ByteOrder_IDX])))->converter, (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_b_order);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QPixelFormat::YUVLayout cppArg0{QPixelFormat::YUV444};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        uchar cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QPixelFormat::AlphaUsage cppArg2(QPixelFormat::IgnoresAlpha);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QPixelFormat::AlphaPosition cppArg3(QPixelFormat::AtBeginning);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QPixelFormat::AlphaPremultiplied cppArg4(QPixelFormat::NotPremultiplied);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QPixelFormat::TypeInterpretation cppArg5(QPixelFormat::UnsignedByte);
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QPixelFormat::ByteOrder cppArg6(QPixelFormat::LittleEndian);
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qPixelFormatYuv(QPixelFormat::YUVLayout,uchar,QPixelFormat::AlphaUsage,QPixelFormat::AlphaPosition,QPixelFormat::AlphaPremultiplied,QPixelFormat::TypeInterpretation,QPixelFormat::ByteOrder)
            QPixelFormat cppResult = qPixelFormatYuv(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixelFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRed(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qRed(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // qRed(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRed(uint)
            int cppResult = qRed(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRgb(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRgb";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qRgb", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qRgb(int,int,int)->unsigned int
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // qRgb(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRgb(int,int,int)
            unsigned int cppResult = qRgb(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qRgba(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qRgba";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qRgba", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qRgba(int,int,int,int)->unsigned int
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // qRgba(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRgba(int,int,int,int)
            unsigned int cppResult = qRgba(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtGuiModule_qt_set_sequence_auto_mnemonic(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.qt_set_sequence_auto_mnemonic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qt_set_sequence_auto_mnemonic(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // qt_set_sequence_auto_mnemonic(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qt_set_sequence_auto_mnemonic(bool)
            qt_set_sequence_auto_mnemonic(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static PyMethodDef QtGui_methods[] = {
    {"qAlpha", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qAlpha), METH_O, nullptr},
    {"qBlue", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qBlue), METH_O, nullptr},
    {"qFuzzyCompare", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qFuzzyCompare), METH_VARARGS, nullptr},
    {"qGray", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qGray), METH_VARARGS, nullptr},
    {"qGreen", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qGreen), METH_O, nullptr},
    {"qIsGray", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qIsGray), METH_O, nullptr},
    {"qPixelFormatAlpha", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatAlpha), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatCmyk", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatCmyk), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatGrayscale", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatGrayscale), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatHsl", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatHsl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatHsv", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatHsv), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatRgba", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatRgba), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qPixelFormatYuv", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qPixelFormatYuv), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qRed", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRed), METH_O, nullptr},
    {"qRgb", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRgb), METH_VARARGS, nullptr},
    {"qRgba", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qRgba), METH_VARARGS, nullptr},
    {"qt_set_sequence_auto_mnemonic", reinterpret_cast<PyCFunction>(SbkQtGuiModule_qt_set_sequence_auto_mnemonic), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_QtGuiQt(PyObject *module);
PyTypeObject *init_QVector4D(PyObject *module);
PyTypeObject *init_QVector3D(PyObject *module);
PyTypeObject *init_QVector2D(PyObject *module);
PyTypeObject *init_QUndoCommand(PyObject *module);
PyTypeObject *init_QTransform(PyObject *module);
PyTypeObject *init_QTextTableCell(PyObject *module);
PyTypeObject *init_QTextOption(PyObject *module);
PyTypeObject *init_QTextOption_Tab(PyObject *enclosingClass);
PyTypeObject *init_QTextObjectInterface(PyObject *module);
PyTypeObject *init_QTextLine(PyObject *module);
PyTypeObject *init_QTextLength(PyObject *module);
PyTypeObject *init_QTextItem(PyObject *module);
PyTypeObject *init_QTextInlineObject(PyObject *module);
PyTypeObject *init_QTextFragment(PyObject *module);
PyTypeObject *init_QTextFormat(PyObject *module);
PyTypeObject *init_QTextListFormat(PyObject *module);
PyTypeObject *init_QTextFrameFormat(PyObject *module);
PyTypeObject *init_QTextTableFormat(PyObject *module);
PyTypeObject *init_QTextDocumentFragment(PyObject *module);
PyTypeObject *init_QTextCursor(PyObject *module);
PyTypeObject *init_QTextCharFormat(PyObject *module);
PyTypeObject *init_QTextTableCellFormat(PyObject *module);
PyTypeObject *init_QTextImageFormat(PyObject *module);
PyTypeObject *init_QTextBlockUserData(PyObject *module);
PyTypeObject *init_QTextBlockFormat(PyObject *module);
PyTypeObject *init_QTextBlock(PyObject *module);
PyTypeObject *init_QTextBlock_iterator(PyObject *enclosingClass);
PyTypeObject *init_QSurfaceFormat(PyObject *module);
PyTypeObject *init_QSurface(PyObject *module);
PyTypeObject *init_QStandardItem(PyObject *module);
PyTypeObject *init_QShaderVersion(PyObject *module);
PyTypeObject *init_QShaderKey(PyObject *module);
PyTypeObject *init_QShader(PyObject *module);
PyTypeObject *init_QRhiViewport(PyObject *module);
PyTypeObject *init_QRhiVertexInputLayout(PyObject *module);
PyTypeObject *init_QRhiVertexInputBinding(PyObject *module);
PyTypeObject *init_QRhiVertexInputAttribute(PyObject *module);
PyTypeObject *init_QRhiTextureUploadEntry(PyObject *module);
PyTypeObject *init_QRhiTextureUploadDescription(PyObject *module);
PyTypeObject *init_QRhiTextureSubresourceUploadDescription(PyObject *module);
PyTypeObject *init_QRhiTextureRenderTargetDescription(PyObject *module);
PyTypeObject *init_QRhiTextureCopyDescription(PyObject *module);
PyTypeObject *init_QRhiStats(PyObject *module);
PyTypeObject *init_QRhiShaderStage(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBinding(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBindingStaticFields(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBinding_Data(PyObject *enclosingClass);
PyTypeObject *init_QRhiShaderResourceBinding_DataStaticFields(PyObject *module);
PyTypeObject *init_QRhiScissor(PyObject *module);
PyTypeObject *init_QRhiResourceUpdateBatch(PyObject *module);
PyTypeObject *init_QRhiReadbackDescription(PyObject *module);
PyTypeObject *init_QRhiNativeHandles(PyObject *module);
PyTypeObject *init_QRhiInitParams(PyObject *module);
PyTypeObject *init_QRhiNullInitParams(PyObject *module);
PyTypeObject *init_QRhiDepthStencilClearValue(PyObject *module);
PyTypeObject *init_QRhiColorAttachment(PyObject *module);
PyTypeObject *init_QRhi(PyObject *module);
PyTypeObject *init_QRhiStaticFields(PyObject *module);
PyTypeObject *init_QRgba64(PyObject *module);
PyTypeObject *init_QRegion(PyObject *module);
PyTypeObject *init_QRawFont(PyObject *module);
PyTypeObject *init_QQuaternion(PyObject *module);
PyTypeObject *init_QPolygonF(PyObject *module);
PyTypeObject *init_QPolygon(PyObject *module);
PyTypeObject *init_QPointingDeviceUniqueId(PyObject *module);
PyTypeObject *init_QPixmapCache(PyObject *module);
PyTypeObject *init_QPixmapCache_Key(PyObject *enclosingClass);
PyTypeObject *init_QPixelFormat(PyObject *module);
PyTypeObject *init_QPen(PyObject *module);
PyTypeObject *init_QPalette(PyObject *module);
PyTypeObject *init_QPainterPathStroker(PyObject *module);
PyTypeObject *init_QPainterPath(PyObject *module);
PyTypeObject *init_QPainterPath_Element(PyObject *enclosingClass);
PyTypeObject *init_QPaintEngineState(PyObject *module);
PyTypeObject *init_QPaintEngine(PyObject *module);
PyTypeObject *init_QPaintDevice(PyObject *module);
PyTypeObject *init_QPicture(PyObject *module);
PyTypeObject *init_QPagedPaintDevice(PyObject *module);
PyTypeObject *init_QPageSize(PyObject *module);
PyTypeObject *init_QPageRanges(PyObject *module);
PyTypeObject *init_QPageRanges_Range(PyObject *enclosingClass);
PyTypeObject *init_QtGuiHelper_QOverrideCursorGuard(PyObject *module);
PyTypeObject *init_QOpenGLFunctions(PyObject *module);
PyTypeObject *init_QOpenGLExtraFunctions(PyObject *module);
PyTypeObject *init_QtGuiQNativeInterface(PyObject *module);
#if QT_CONFIG(xcb)
PyTypeObject *init_QNativeInterface_QX11Application(PyObject *enclosingClass);
#endif
PyTypeObject *init_QMatrix4x4(PyObject *module);
PyTypeObject *init_QMatrix4x3(PyObject *module);
PyTypeObject *init_QMatrix4x2(PyObject *module);
PyTypeObject *init_QMatrix3x4(PyObject *module);
PyTypeObject *init_QMatrix3x3(PyObject *module);
PyTypeObject *init_QMatrix3x2(PyObject *module);
PyTypeObject *init_QMatrix2x4(PyObject *module);
PyTypeObject *init_QMatrix2x3(PyObject *module);
PyTypeObject *init_QMatrix2x2(PyObject *module);
PyTypeObject *init_QImageIOHandler(PyObject *module);
PyTypeObject *init_QIconEngine(PyObject *module);
PyTypeObject *init_QGradient(PyObject *module);
PyTypeObject *init_QRadialGradient(PyObject *module);
PyTypeObject *init_QLinearGradient(PyObject *module);
PyTypeObject *init_QGlyphRun(PyObject *module);
PyTypeObject *init_QFontMetricsF(PyObject *module);
PyTypeObject *init_QFontMetrics(PyObject *module);
PyTypeObject *init_QFontInfo(PyObject *module);
PyTypeObject *init_QFontDatabase(PyObject *module);
PyTypeObject *init_QFont(PyObject *module);
PyTypeObject *init_QStaticText(PyObject *module);
PyTypeObject *init_QFont_Tag(PyObject *enclosingClass);
PyTypeObject *init_QEventPoint(PyObject *module);
PyTypeObject *init_QDesktopServices(PyObject *module);
PyTypeObject *init_QCursor(PyObject *module);
PyTypeObject *init_QConicalGradient(PyObject *module);
PyTypeObject *init_QColorTransform(PyObject *module);
PyTypeObject *init_QColorSpace(PyObject *module);
PyTypeObject *init_QColor(PyObject *module);
PyTypeObject *init_QtGuiQColorConstants(PyObject *module);
PyTypeObject *init_QtGuiQColorConstantsStaticFields(PyObject *module);
PyTypeObject *init_QtGuiQColorConstants_Svg(PyObject *enclosingClass);
PyTypeObject *init_QtGuiQColorConstants_SvgStaticFields(PyObject *module);
PyTypeObject *init_QBrush(PyObject *module);
PyTypeObject *init_QAccessibleValueInterface(PyObject *module);
PyTypeObject *init_QAccessibleTextInterface(PyObject *module);
PyTypeObject *init_QAccessibleTableCellInterface(PyObject *module);
PyTypeObject *init_QAccessibleInterface(PyObject *module);
PyTypeObject *init_QAccessibleObject(PyObject *module);
PyTypeObject *init_QAccessibleEvent(PyObject *module);
PyTypeObject *init_QAccessibleValueChangeEvent(PyObject *module);
PyTypeObject *init_QAccessibleTextCursorEvent(PyObject *module);
PyTypeObject *init_QAccessibleTextUpdateEvent(PyObject *module);
PyTypeObject *init_QAccessibleTextSelectionEvent(PyObject *module);
PyTypeObject *init_QAccessibleTextRemoveEvent(PyObject *module);
PyTypeObject *init_QAccessibleTextInsertEvent(PyObject *module);
PyTypeObject *init_QAccessibleTableModelChangeEvent(PyObject *module);
PyTypeObject *init_QAccessibleStateChangeEvent(PyObject *module);
PyTypeObject *init_QAccessibleEditableTextInterface(PyObject *module);
PyTypeObject *init_QAccessibleActionInterface(PyObject *module);
PyTypeObject *init_QAccessible(PyObject *module);
PyTypeObject *init_QAccessible_State(PyObject *enclosingClass);
PyTypeObject *init_QAbstractFileIconProvider(PyObject *module);
PyTypeObject *init_QIcon(PyObject *module);
PyTypeObject *init_QTextLayout(PyObject *module);
PyTypeObject *init_QTextLayout_FormatRange(PyObject *enclosingClass);
PyTypeObject *init_QPixmap(PyObject *module);
PyTypeObject *init_QIconEngine_ScaledPixmapArgument(PyObject *enclosingClass);
PyTypeObject *init_QImage(PyObject *module);
PyTypeObject *init_QBitmap(PyObject *module);
PyTypeObject *init_QPainter(PyObject *module);
PyTypeObject *init_QPainter_PixmapFragment(PyObject *enclosingClass);
PyTypeObject *init_QBackingStore(PyObject *module);
PyTypeObject *init_QPageLayout(PyObject *module);
PyTypeObject *init_QKeySequence(PyObject *module);
PyTypeObject *init_QWindow(PyObject *module);
PyTypeObject *init_QPaintDeviceWindow(PyObject *module);
PyTypeObject *init_QRasterWindow(PyObject *module);
PyTypeObject *init_QValidator(PyObject *module);
PyTypeObject *init_QRegularExpressionValidator(PyObject *module);
PyTypeObject *init_QIntValidator(PyObject *module);
PyTypeObject *init_QDoubleValidator(PyObject *module);
PyTypeObject *init_QUndoStack(PyObject *module);
PyTypeObject *init_QUndoGroup(PyObject *module);
PyTypeObject *init_QTextObject(PyObject *module);
PyTypeObject *init_QTextFrame(PyObject *module);
PyTypeObject *init_QTextTable(PyObject *module);
PyTypeObject *init_QTextFrame_iterator(PyObject *enclosingClass);
PyTypeObject *init_QTextBlockGroup(PyObject *module);
PyTypeObject *init_QTextList(PyObject *module);
PyTypeObject *init_QTextDocument(PyObject *module);
PyTypeObject *init_QSyntaxHighlighter(PyObject *module);
PyTypeObject *init_QStyleHints(PyObject *module);
PyTypeObject *init_QShortcut(PyObject *module);
PyTypeObject *init_QSessionManager(PyObject *module);
PyTypeObject *init_QScreen(PyObject *module);
PyTypeObject *init_QPyTextObject(PyObject *module);
PyTypeObject *init_QPdfWriter(PyObject *module);
PyTypeObject *init_QOpenGLContextGroup(PyObject *module);
PyTypeObject *init_QOpenGLContext(PyObject *module);
PyTypeObject *init_QRhiGles2NativeHandles(PyObject *module);
PyTypeObject *init_QRhiGles2InitParams(PyObject *module);
PyTypeObject *init_QOffscreenSurface(PyObject *module);
PyTypeObject *init_QInputMethod(PyObject *module);
PyTypeObject *init_QInputDevice(PyObject *module);
PyTypeObject *init_QPointingDevice(PyObject *module);
PyTypeObject *init_QDrag(PyObject *module);
PyTypeObject *init_QClipboard(PyObject *module);
PyTypeObject *init_QActionGroup(PyObject *module);
PyTypeObject *init_QAction(PyObject *module);
PyTypeObject *init_QAbstractTextDocumentLayout(PyObject *module);
PyTypeObject *init_QAbstractTextDocumentLayout_Selection(PyObject *enclosingClass);
PyTypeObject *init_QAbstractTextDocumentLayout_PaintContext(PyObject *enclosingClass);
PyTypeObject *init_QWindowStateChangeEvent(PyObject *module);
PyTypeObject *init_QWhatsThisClickedEvent(PyObject *module);
PyTypeObject *init_QToolBarChangeEvent(PyObject *module);
PyTypeObject *init_QStatusTipEvent(PyObject *module);
PyTypeObject *init_QShowEvent(PyObject *module);
PyTypeObject *init_QShortcutEvent(PyObject *module);
PyTypeObject *init_QScrollPrepareEvent(PyObject *module);
PyTypeObject *init_QScrollEvent(PyObject *module);
PyTypeObject *init_QResizeEvent(PyObject *module);
PyTypeObject *init_QPlatformSurfaceEvent(PyObject *module);
PyTypeObject *init_QPaintEvent(PyObject *module);
PyTypeObject *init_QMoveEvent(PyObject *module);
PyTypeObject *init_QInputMethodQueryEvent(PyObject *module);
PyTypeObject *init_QInputMethodEvent(PyObject *module);
PyTypeObject *init_QInputMethodEvent_Attribute(PyObject *enclosingClass);
PyTypeObject *init_QInputEvent(PyObject *module);
PyTypeObject *init_QPointerEvent(PyObject *module);
PyTypeObject *init_QTouchEvent(PyObject *module);
PyTypeObject *init_QSinglePointEvent(PyObject *module);
PyTypeObject *init_QWheelEvent(PyObject *module);
PyTypeObject *init_QTabletEvent(PyObject *module);
PyTypeObject *init_QNativeGestureEvent(PyObject *module);
PyTypeObject *init_QMouseEvent(PyObject *module);
PyTypeObject *init_QHoverEvent(PyObject *module);
PyTypeObject *init_QEnterEvent(PyObject *module);
PyTypeObject *init_QKeyEvent(PyObject *module);
PyTypeObject *init_QContextMenuEvent(PyObject *module);
PyTypeObject *init_QIconDragEvent(PyObject *module);
PyTypeObject *init_QHideEvent(PyObject *module);
PyTypeObject *init_QHelpEvent(PyObject *module);
PyTypeObject *init_QFocusEvent(PyObject *module);
PyTypeObject *init_QFileOpenEvent(PyObject *module);
PyTypeObject *init_QExposeEvent(PyObject *module);
PyTypeObject *init_QDropEvent(PyObject *module);
PyTypeObject *init_QDragMoveEvent(PyObject *module);
PyTypeObject *init_QDragEnterEvent(PyObject *module);
PyTypeObject *init_QDragLeaveEvent(PyObject *module);
PyTypeObject *init_QCloseEvent(PyObject *module);
PyTypeObject *init_QChildWindowEvent(PyObject *module);
PyTypeObject *init_QActionEvent(PyObject *module);
PyTypeObject *init_QGuiApplication(PyObject *module);
PyTypeObject *init_QTextDocumentWriter(PyObject *module);
PyTypeObject *init_QShaderCode(PyObject *module);
PyTypeObject *init_QRhiResource(PyObject *module);
PyTypeObject *init_QRhiTexture(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBinding_Data_StorageImageData(PyObject *enclosingClass);
PyTypeObject *init_QRhiShaderResourceBindings(PyObject *module);
PyTypeObject *init_QRhiSampler(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBinding_TextureAndSampler(PyObject *enclosingClass);
PyTypeObject *init_QRhiRenderPassDescriptor(PyObject *module);
PyTypeObject *init_QRhiRenderTarget(PyObject *module);
PyTypeObject *init_QRhiTextureRenderTarget(PyObject *module);
PyTypeObject *init_QRhiRenderBuffer(PyObject *module);
PyTypeObject *init_QRhiSwapChain(PyObject *module);
PyTypeObject *init_QRhiSwapChainRenderTarget(PyObject *module);
PyTypeObject *init_QRhiGraphicsPipeline(PyObject *module);
PyTypeObject *init_QRhiGraphicsPipeline_TargetBlend(PyObject *enclosingClass);
PyTypeObject *init_QRhiGraphicsPipeline_StencilOpState(PyObject *enclosingClass);
PyTypeObject *init_QRhiComputePipeline(PyObject *module);
PyTypeObject *init_QRhiCommandBuffer(PyObject *module);
PyTypeObject *init_QRhiBuffer(PyObject *module);
PyTypeObject *init_QRhiShaderResourceBinding_Data_StorageBufferData(PyObject *enclosingClass);
PyTypeObject *init_QRhiReadbackResult(PyObject *module);
PyTypeObject *init_QRhiDriverInfo(PyObject *module);
PyTypeObject *init_QMovie(PyObject *module);
PyTypeObject *init_QImageWriter(PyObject *module);
PyTypeObject *init_QImageReader(PyObject *module);
PyTypeObject *init_QStandardItemModel(PyObject *module);

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------

// Extended Converters.

// Extended implicit conversions for PySide6.QtCore.QPointF.
static void QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPointF *>(cppOut) = ::QPointF(*reinterpret_cast< ::QPainterPath::Element *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_Element_IDX])))
        return QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF;
    return {};
}


// Primitive Type converters.

// C++ to Python conversion for primitive type 'WId'.
static PyObject *WId_CppToPython_WId(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::WId *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (return-pylong-voidptr)]
    return PyLong_FromVoidPtr(reinterpret_cast<void *>(cppInRef));
    // END of custom code block [file: ../glue/qtgui.cpp (return-pylong-voidptr)]
    // ========================================================================

}
// Python to C++ conversions for type 'WId'.
static void PyLong_PythonToCpp_WId(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtgui.cpp (conversion-pylong)]
    *reinterpret_cast<::WId *>(cppOut) = reinterpret_cast<WId>(PyLong_AsVoidPtr(pyIn));
    // END of custom code block [file: ../glue/qtgui.cpp (conversion-pylong)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_WId_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_WId;
    return {};
}


// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtGui.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector2D>'.
static PyObject *_QList_QVector2D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector2D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector2D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector2D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector2D cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector2D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QVector2D_;
    return {};
}


// Binding for QList<QVector2D>

template <>
struct ShibokenContainerValueConverter<QVector2D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QVector2D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppArg);
    }

    static std::optional<QVector2D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector2D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector2DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector2DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector2DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector2D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector2DList_spec = {
    "2:PySide6.QtGui.QVector2DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector2DList_slots
};

static inline PyTypeObject *createQVector2DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector2DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector2DList_TypeF()
{
    static PyTypeObject *type = createQVector2DListType();
    return type;
}

extern "C" PyObject *createQVector2DList(QList<QVector2D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector2DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector2D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector2DList(const QList<QVector2D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector2DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector2D>>();
    d->m_list = const_cast<QList<QVector2D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector2DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector2DList_TypeF();
}

extern "C" void PythonToCppQVector2DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector2D>>::get(pyArg);
    *reinterpret_cast<QList<QVector2D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector2DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector2DList_Check(pyArg))
        return PythonToCppQVector2DList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector3D>'.
static PyObject *_QList_QVector3D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector3D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector3D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector3D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector3D cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector3D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QVector3D_;
    return {};
}


// Binding for QList<QVector3D>

template <>
struct ShibokenContainerValueConverter<QVector3D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QVector3D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppArg);
    }

    static std::optional<QVector3D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector3D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector3DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector3DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector3DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector3D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector3DList_spec = {
    "2:PySide6.QtGui.QVector3DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector3DList_slots
};

static inline PyTypeObject *createQVector3DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector3DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector3DList_TypeF()
{
    static PyTypeObject *type = createQVector3DListType();
    return type;
}

extern "C" PyObject *createQVector3DList(QList<QVector3D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector3DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector3D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector3DList(const QList<QVector3D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector3DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector3D>>();
    d->m_list = const_cast<QList<QVector3D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector3DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector3DList_TypeF();
}

extern "C" void PythonToCppQVector3DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector3D>>::get(pyArg);
    *reinterpret_cast<QList<QVector3D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector3DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector3DList_Check(pyArg))
        return PythonToCppQVector3DList;
    return {};
}

// C++ to Python conversion for container type 'QList<QVector4D>'.
static PyObject *_QList_QVector4D__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVector4D> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVector4D_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVector4D> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVector4D cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVector4D__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QVector4D_;
    return {};
}


// Binding for QList<QVector4D>

template <>
struct ShibokenContainerValueConverter<QVector4D>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QVector4D &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), &cppArg);
    }

    static std::optional<QVector4D> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QVector4D cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QVector4DList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QVector4DList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QVector4DList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QVector4D>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QVector4DList_spec = {
    "2:PySide6.QtGui.QVector4DList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QVector4DList_slots
};

static inline PyTypeObject *createQVector4DListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QVector4DList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QVector4DList_TypeF()
{
    static PyTypeObject *type = createQVector4DListType();
    return type;
}

extern "C" PyObject *createQVector4DList(QList<QVector4D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector4DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector4D>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQVector4DList(const QList<QVector4D>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QVector4DList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QVector4D>>();
    d->m_list = const_cast<QList<QVector4D> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QVector4DList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QVector4DList_TypeF();
}

extern "C" void PythonToCppQVector4DList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QVector4D>>::get(pyArg);
    *reinterpret_cast<QList<QVector4D>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQVector4DListPythonToCppConvertible(PyObject *pyArg)
{
    if (QVector4DList_Check(pyArg))
        return PythonToCppQVector4DList;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextOption::Tab>'.
static PyObject *_QList_QTextOption_Tab__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextOption::Tab> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextOption_Tab_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextOption::Tab> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextOption::Tab cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextOption_Tab__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_Tab_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextOption_Tab_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGlyphRun>'.
static PyObject *_QList_QGlyphRun__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGlyphRun> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGlyphRun_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGlyphRun> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGlyphRun cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGlyphRun__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QGlyphRun_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextLength>'.
static PyObject *_QList_QTextLength__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextLength> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextLength_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextLength> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextLength cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextLength__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextLength_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,QVariant>'.
static PyObject *_QMap_int_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextLayout::FormatRange>'.
static PyObject *_QList_QTextLayout_FormatRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextLayout::FormatRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLayout_FormatRange_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextLayout_FormatRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextLayout::FormatRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextLayout::FormatRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLayout_FormatRange_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextLayout_FormatRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLayout_FormatRange_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextLayout_FormatRange_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<int,int>'.
static PyObject *std_pair_int_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<int,int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_int_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<int,int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_int_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_int_int_;
    return {};
}

// C++ to Python conversion for container type 'QList<QStandardItem*>'.
static PyObject *_QList_QStandardItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QStandardItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStandardItem_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QStandardItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QStandardItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QStandardItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStandardItem_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QStandardItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStandardItem_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QStandardItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QShaderKey>'.
static PyObject *_QList_QShaderKey__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QShaderKey> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderKey_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QShaderKey_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QShaderKey> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QShaderKey cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderKey_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QShaderKey__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderKey_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QShaderKey_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,std::pair< int,int>>'.
static PyObject *_QMap_int_std_pair_int_int___CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,std::pair< int,int>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_std_pair_int_int__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,std::pair< int,int>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::std::pair<int,int> cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_std_pair_int_int___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_std_pair_int_int__;
    return {};
}

// C++ to Python conversion for container type 'std::array<float,4>'.
static PyObject *std_array_float_4__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::array<float,4> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_array_float_4_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::array<float,4> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - START
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    for (auto oit = std::begin(cppOutRef), oend = std::end(cppOutRef); oit != oend; ++oit) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        float cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyItem, &(cppItem));
        *oit = cppItem;
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_array_float_4__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn))
        return PySequence_PythonToCpp_std_array_float_4_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiVertexInputAttribute>'.
static PyObject *_QList_QRhiVertexInputAttribute__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiVertexInputAttribute> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiVertexInputAttribute> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiVertexInputAttribute cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiVertexInputAttribute__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputAttribute_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiVertexInputBinding>'.
static PyObject *_QList_QRhiVertexInputBinding__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiVertexInputBinding> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiVertexInputBinding_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiVertexInputBinding> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiVertexInputBinding cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiVertexInputBinding__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputBinding_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiVertexInputBinding_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiTextureUploadEntry>'.
static PyObject *_QList_QRhiTextureUploadEntry__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiTextureUploadEntry> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureUploadEntry_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiTextureUploadEntry> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiTextureUploadEntry cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureUploadEntry_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiTextureUploadEntry__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureUploadEntry_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiColorAttachment>'.
static PyObject *_QList_QRhiColorAttachment__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiColorAttachment> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiColorAttachment_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiColorAttachment> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiColorAttachment cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiColorAttachment__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiColorAttachment_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiColorAttachment_;
    return {};
}

// C++ to Python conversion for container type 'std::array<int,4>'.
static PyObject *std_array_int_4__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::array<int,4> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_std_array_int_4_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::array<int,4> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - START
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    for (auto oit = std::begin(cppOutRef), oend = std::end(cppOutRef); oit != oend; ++oit) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        *oit = cppItem;
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cpparray - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_array_int_4__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp_std_array_int_4_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPointF>'.
static PyObject *_QList_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPointF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPointF_;
    return {};
}


// Binding for QList<QPointF>

template <>
struct ShibokenContainerValueConverter<QPointF>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPointF &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppArg);
    }

    static std::optional<QPointF> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPointF cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointFList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointFList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointFList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointFList_spec = {
    "2:PySide6.QtGui.QPointFList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointFList_slots
};

static inline PyTypeObject *createQPointFListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointFList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointFList_TypeF()
{
    static PyTypeObject *type = createQPointFListType();
    return type;
}

extern "C" PyObject *createQPointFList(QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointFList(const QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = const_cast<QList<QPointF> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointFList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointFList_TypeF();
}

extern "C" void PythonToCppQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QList<QPointF>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointFListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToCppQPointFList;
    return {};
}

// C++ to Python conversion for container type 'QList<quint32>'.
static PyObject *_QList_quint32__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<quint32> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_quint32_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<quint32> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        quint32 cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_quint32__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), pyIn))
        return PySequence_PythonToCpp__QList_quint32_;
    return {};
}

// C++ to Python conversion for container type 'QList<QFontDatabase::WritingSystem>'.
static PyObject *_QList_QFontDatabase_WritingSystem__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QFontDatabase::WritingSystem> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontDatabase_WritingSystem_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QFontDatabase::WritingSystem> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QFontDatabase::WritingSystem cppItem{QFontDatabase::Any};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontDatabase_WritingSystem_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontDatabase_WritingSystem_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPoint>'.
static PyObject *_QList_QPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPoint_;
    return {};
}


// Binding for QList<QPoint>

template <>
struct ShibokenContainerValueConverter<QPoint>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPoint &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppArg);
    }

    static std::optional<QPoint> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPoint cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointList_spec = {
    "2:PySide6.QtGui.QPointList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointList_slots
};

static inline PyTypeObject *createQPointListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointList_TypeF()
{
    static PyTypeObject *type = createQPointListType();
    return type;
}

extern "C" PyObject *createQPointList(QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointList(const QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = const_cast<QList<QPoint> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointList_TypeF();
}

extern "C" void PythonToCppQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QList<QPoint>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToCppQPointList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPolygonF>'.
static PyObject *_QList_QPolygonF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPolygonF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPolygonF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPolygonF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPolygonF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPolygonF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPolygonF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPageRanges::Range>'.
static PyObject *_QList_QPageRanges_Range__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPageRanges::Range> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPageRanges_Range_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPageRanges::Range> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPageRanges::Range cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPageRanges_Range__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_Range_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPageRanges_Range_;
    return {};
}

// C++ to Python conversion for container type 'QList<float>'.
static PyObject *_QList_float__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<float> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_float_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<float> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        float cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_float__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyIn))
        return PySequence_PythonToCpp__QList_float_;
    return {};
}

// C++ to Python conversion for container type 'QList<QSize>'.
static PyObject *_QList_QSize__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QSize> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QSize_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QSize> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QSize cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QSize__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QSize_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,QColor>'.
static PyObject *std_pair_qreal_QColor__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<qreal,QColor> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_QColor_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<qreal,QColor> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_QColor__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX])))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_QColor_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< qreal,QColor>>'.
static PyObject *_QList_std_pair_qreal_QColor___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< qreal,QColor>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_QColor__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< qreal,QColor>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<qreal,QColor> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_QColor___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_QColor__;
    return {};
}

// C++ to Python conversion for container type 'QList<qsizetype>'.
static PyObject *_QList_qsizetype__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qsizetype> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qsizetype_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qsizetype> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qsizetype cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qsizetype__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), pyIn))
        return PySequence_PythonToCpp__QList_qsizetype_;
    return {};
}

// C++ to Python conversion for container type 'QList<QFont::Tag>'.
static PyObject *_QList_QFont_Tag__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QFont::Tag> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QFont_Tag_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QFont::Tag> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QFont::Tag cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QFont_Tag__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QFont_Tag_;
    return {};
}

// C++ to Python conversion for container type 'QList<uint16_t>'.
static PyObject *_QList_uint16_t__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<uint16_t> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_uint16_t_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<uint16_t> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        uint16_t cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_uint16_t__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<uint16_t>(), pyIn))
        return PySequence_PythonToCpp__QList_uint16_t_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAccessibleInterface*>'.
static PyObject *_QList_QAccessibleInterfacePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAccessibleInterface*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAccessibleInterface*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAccessibleInterface* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAccessibleInterfacePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
static PyObject *std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->converter, &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->converter, PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX])))->converter, true, PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
static PyObject *_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___;
    return {};
}

// C++ to Python conversion for container type 'QList<unsigned int>'.
static PyObject *_QList_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        unsigned int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyIn))
        return PySequence_PythonToCpp__QList_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLine>'.
static PyObject *_QList_QLine__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLine> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLine_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLine> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLine cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLine__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLine_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLineF>'.
static PyObject *_QList_QLineF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLineF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLineF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLineF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLineF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLineF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLineF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRect>'.
static PyObject *_QList_QRect__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRect> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRect_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRect> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRect cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRect__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRect_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRectF>'.
static PyObject *_QList_QRectF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRectF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRectF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRectF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRectF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRectF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRectF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeySequence>'.
static PyObject *_QList_QKeySequence__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeySequence> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeySequence_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeySequence> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeySequence cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeySequence__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QKeySequence_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QUndoStack*>'.
static PyObject *_QList_QUndoStackPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QUndoStack*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QUndoStack_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QUndoStackPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QUndoStack*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QUndoStack* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QUndoStack_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QUndoStackPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QUndoStack_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QUndoStackPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextFrame*>'.
static PyObject *_QList_QTextFramePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextFrame*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextFramePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextFrame*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextFrame* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextFramePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextFramePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextBlock>'.
static PyObject *_QList_QTextBlock__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextBlock> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextBlock_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextBlock> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextBlock cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextBlock__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextBlock_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextFormat>'.
static PyObject *_QList_QTextFormat__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextFormat> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextFormat_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextFormat> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextFormat cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextFormat__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextFormat_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScreen*>'.
static PyObject *_QList_QScreenPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScreen*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScreenPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScreen*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScreen* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QScreenPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QOpenGLContext*>'.
static PyObject *_QList_QOpenGLContextPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QOpenGLContext*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QOpenGLContextPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QOpenGLContext*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QOpenGLContext* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QOpenGLContextPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QOpenGLContextPTR_;
    return {};
}

// C++ to Python conversion for container type 'QSet<QByteArray>'.
static PyObject *_QSet_QByteArray__CppToPython_PySet(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QSet<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pyset - START
    PyObject *pyOut = PySet_New(nullptr);
    for (const auto &cppItem : cppInRef) {
        PySet_Add(pyOut, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pyset - END

}
static void PySequence_PythonToCpp__QSet_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QSet<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsetcontainer - START
    (cppOutRef).clear();
    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).insert(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsetcontainer - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QSet_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleIterableTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QSet_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<const QInputDevice*>'.
static PyObject *_QList_constQInputDevicePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<const QInputDevice*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_constQInputDevicePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<const QInputDevice*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QInputDevice* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_constQInputDevicePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_constQInputDevicePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAction*>'.
static PyObject *_QList_QActionPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAction*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QActionPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAction*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAction* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QActionPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QActionPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractTextDocumentLayout::Selection>'.
static PyObject *_QList_QAbstractTextDocumentLayout_Selection__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractTextDocumentLayout::Selection> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractTextDocumentLayout::Selection> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractTextDocumentLayout::Selection cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_Selection_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_;
    return {};
}

// C++ to Python conversion for container type 'QList<QInputMethodEvent::Attribute>'.
static PyObject *_QList_QInputMethodEvent_Attribute__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QInputMethodEvent::Attribute> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_Attribute_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QInputMethodEvent::Attribute> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QInputMethodEvent::Attribute cppItem = ::QInputMethodEvent::Attribute(QInputMethodEvent::TextFormat, int(0), int(0));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_Attribute_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_Attribute_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_;
    return {};
}

// C++ to Python conversion for container type 'QList<QEventPoint>'.
static PyObject *_QList_QEventPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QEventPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QEventPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QEventPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QEventPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QEventPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEventPoint_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QEventPoint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWindow*>'.
static PyObject *_QList_QWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiShaderResourceBinding>'.
static PyObject *_QList_QRhiShaderResourceBinding__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiShaderResourceBinding> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiShaderResourceBinding> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiShaderResourceBinding cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiShaderResourceBinding__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBinding_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiShaderStage>'.
static PyObject *_QList_QRhiShaderStage__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiShaderStage> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiShaderStage_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiShaderStage> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiShaderStage cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiShaderStage__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiShaderStage_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRhiGraphicsPipeline::TargetBlend>'.
static PyObject *_QList_QRhiGraphicsPipeline_TargetBlend__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRhiGraphicsPipeline::TargetBlend> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRhiGraphicsPipeline::TargetBlend> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRhiGraphicsPipeline::TargetBlend cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<int,unsigned int>'.
static PyObject *std_pair_int_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<int,unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_int_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<int,unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_int_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_int_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QRhiBuffer*,quint32>'.
static PyObject *std_pair_QRhiBufferPTR_quint32__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QRhiBuffer*,quint32> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QRhiBuffer*,quint32> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX])))->converter, true, Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QRhiBuffer*,quint32>>'.
static PyObject *_QList_std_pair_QRhiBufferPTR_quint32___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QRhiBuffer*,quint32>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QRhiBuffer*,quint32>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QRhiBuffer*,quint32> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QRhiBuffer*,unsigned int>'.
static PyObject *std_pair_QRhiBufferPTR_unsignedint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QRhiBuffer*,unsigned int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QRhiBuffer*,unsigned int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX])))->converter, true, Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModelIndex>'.
static PyObject *_QList_QModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QHash<int,QByteArray>'.
static PyObject *_QHash_int_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<int,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_int_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<int,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QHash_int_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtGui",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtGui_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtGui_SignatureStrings[] = {
    "PySide6.QtGui.qAlpha(rgb:unsigned int)->int",
    "PySide6.QtGui.qBlue(rgb:unsigned int)->int",
    "5:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QTransform,arg__2:PySide6.QtGui.QTransform)->bool",
    "4:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QQuaternion,arg__2:PySide6.QtGui.QQuaternion)->bool",
    "3:PySide6.QtGui.qFuzzyCompare(arg__1:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],arg__2:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])->bool",
    "2:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector2D,arg__2:PySide6.QtGui.QVector2D)->bool",
    "1:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector3D,arg__2:PySide6.QtGui.QVector3D)->bool",
    "0:PySide6.QtGui.qFuzzyCompare(arg__1:PySide6.QtGui.QVector4D,arg__2:PySide6.QtGui.QVector4D)->bool",
    "1:PySide6.QtGui.qGray(rgb:unsigned int)->int",
    "0:PySide6.QtGui.qGray(r:int,g:int,b:int)->int",
    "PySide6.QtGui.qGreen(rgb:unsigned int)->int",
    "PySide6.QtGui.qIsGray(rgb:unsigned int)->bool",
    "PySide6.QtGui.qPixelFormatAlpha(channelSize:uchar,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatCmyk(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatGrayscale(channelSize:uchar,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatHsl(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.FloatingPoint)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatHsv(channelSize:uchar,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.FloatingPoint)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatRgba(red:uchar,green:uchar,blue:uchar,alfa:uchar,usage:PySide6.QtGui.QPixelFormat.AlphaUsage,position:PySide6.QtGui.QPixelFormat.AlphaPosition,pmul:PySide6.QtGui.QPixelFormat.AlphaPremultiplied=QPixelFormat.NotPremultiplied,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedInteger)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qPixelFormatYuv(layout:PySide6.QtGui.QPixelFormat.YUVLayout,alfa:uchar=0,usage:PySide6.QtGui.QPixelFormat.AlphaUsage=QPixelFormat.IgnoresAlpha,position:PySide6.QtGui.QPixelFormat.AlphaPosition=QPixelFormat.AtBeginning,p_mul:PySide6.QtGui.QPixelFormat.AlphaPremultiplied=QPixelFormat.NotPremultiplied,typeInt:PySide6.QtGui.QPixelFormat.TypeInterpretation=QPixelFormat.UnsignedByte,b_order:PySide6.QtGui.QPixelFormat.ByteOrder=QPixelFormat.LittleEndian)->PySide6.QtGui.QPixelFormat",
    "PySide6.QtGui.qRed(rgb:unsigned int)->int",
    "PySide6.QtGui.qRgb(r:int,g:int,b:int)->unsigned int",
    "PySide6.QtGui.qRgba(r:int,g:int,b:int,a:int)->unsigned int",
    "PySide6.QtGui.qt_set_sequence_auto_mnemonic(b:bool)",
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtGui()
{
    if (SbkPySide6_QtGuiModuleObject != nullptr)
        return SbkPySide6_QtGuiModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtGui.QAbstractFileIconProvider"},
        {nullptr, "PySide6.QtGui.QAbstractFileIconProvider.IconType"},
        {nullptr, "PySide6.QtGui.QAbstractFileIconProvider.Option"},
        {nullptr, "PySide6.QtGui.QAbstractTextDocumentLayout"},
        {nullptr, "PySide6.QtGui.QAbstractTextDocumentLayout.PaintContext"},
        {nullptr, "PySide6.QtGui.QAbstractTextDocumentLayout.Selection"},
        {nullptr, "PySide6.QtGui.QAccessible"},
        {nullptr, "PySide6.QtGui.QAccessible.Event"},
        {nullptr, "PySide6.QtGui.QAccessible.InterfaceType"},
        {nullptr, "PySide6.QtGui.QAccessible.RelationFlag"},
        {nullptr, "PySide6.QtGui.QAccessible.Role"},
        {nullptr, "PySide6.QtGui.QAccessible.State"},
        {nullptr, "PySide6.QtGui.QAccessible.Text"},
        {nullptr, "PySide6.QtGui.QAccessible.TextBoundaryType"},
        {nullptr, "PySide6.QtGui.QAccessibleActionInterface"},
        {nullptr, "PySide6.QtGui.QAccessibleEditableTextInterface"},
        {nullptr, "PySide6.QtGui.QAccessibleEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleInterface"},
        {nullptr, "PySide6.QtGui.QAccessibleObject"},
        {nullptr, "PySide6.QtGui.QAccessibleStateChangeEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTableCellInterface"},
        {nullptr, "PySide6.QtGui.QAccessibleTableModelChangeEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTableModelChangeEvent.ModelChangeType"},
        {nullptr, "PySide6.QtGui.QAccessibleTextCursorEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTextInsertEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTextInterface"},
        {nullptr, "PySide6.QtGui.QAccessibleTextRemoveEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTextSelectionEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleTextUpdateEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleValueChangeEvent"},
        {nullptr, "PySide6.QtGui.QAccessibleValueInterface"},
        {nullptr, "PySide6.QtGui.QAction"},
        {nullptr, "PySide6.QtGui.QAction.ActionEvent"},
        {nullptr, "PySide6.QtGui.QAction.MenuRole"},
        {nullptr, "PySide6.QtGui.QAction.Priority"},
        {nullptr, "PySide6.QtGui.QActionEvent"},
        {nullptr, "PySide6.QtGui.QActionGroup"},
        {nullptr, "PySide6.QtGui.QActionGroup.ExclusionPolicy"},
        {nullptr, "PySide6.QtGui.QBackingStore"},
        {nullptr, "PySide6.QtGui.QBitmap"},
        {nullptr, "PySide6.QtGui.QBrush"},
        {nullptr, "PySide6.QtGui.QChildWindowEvent"},
        {nullptr, "PySide6.QtGui.QClipboard"},
        {nullptr, "PySide6.QtGui.QClipboard.Mode"},
        {nullptr, "PySide6.QtGui.QCloseEvent"},
        {nullptr, "PySide6.QtGui.QColor"},
        {nullptr, "PySide6.QtGui.QColor.NameFormat"},
        {nullptr, "PySide6.QtGui.QColor.Spec"},
        {nullptr, "PySide6.QtGui.QColorConstants"},
        {nullptr, "PySide6.QtGui.QColorConstants.Svg"},
        {nullptr, "PySide6.QtGui.QColorSpace"},
        {nullptr, "PySide6.QtGui.QColorSpace.NamedColorSpace"},
        {nullptr, "PySide6.QtGui.QColorSpace.Primaries"},
        {nullptr, "PySide6.QtGui.QColorSpace.TransferFunction"},
        {nullptr, "PySide6.QtGui.QColorTransform"},
        {nullptr, "PySide6.QtGui.QConicalGradient"},
        {nullptr, "PySide6.QtGui.QContextMenuEvent"},
        {nullptr, "PySide6.QtGui.QContextMenuEvent.Reason"},
        {nullptr, "PySide6.QtGui.QCursor"},
        {nullptr, "PySide6.QtGui.QDesktopServices"},
        {nullptr, "PySide6.QtGui.QDoubleValidator"},
        {nullptr, "PySide6.QtGui.QDoubleValidator.Notation"},
        {nullptr, "PySide6.QtGui.QDrag"},
        {nullptr, "PySide6.QtGui.QDragEnterEvent"},
        {nullptr, "PySide6.QtGui.QDragLeaveEvent"},
        {nullptr, "PySide6.QtGui.QDragMoveEvent"},
        {nullptr, "PySide6.QtGui.QDropEvent"},
        {nullptr, "PySide6.QtGui.QEnterEvent"},
        {nullptr, "PySide6.QtGui.QEventPoint"},
        {nullptr, "PySide6.QtGui.QEventPoint.State"},
        {nullptr, "PySide6.QtGui.QExposeEvent"},
        {nullptr, "PySide6.QtGui.QFileOpenEvent"},
        {nullptr, "PySide6.QtGui.QAbstractFileIconProvider.Options"},
        {nullptr, "PySide6.QtGui.QAccessible.Relation"},
        {nullptr, "PySide6.QtGui.QGlyphRun.GlyphRunFlags"},
        {nullptr, "PySide6.QtGui.QImageIOHandler.Transformations"},
        {nullptr, "PySide6.QtGui.QInputDevice.Capabilities"},
        {nullptr, "PySide6.QtGui.QInputDevice.DeviceTypes"},
        {nullptr, "PySide6.QtGui.QMatrix4x4.Flags"},
        {nullptr, "PySide6.QtGui.QOpenGLFunctions.OpenGLFeatures"},
        {nullptr, "PySide6.QtGui.QPaintEngine.DirtyFlags"},
        {nullptr, "PySide6.QtGui.QPaintEngine.PaintEngineFeatures"},
        {nullptr, "PySide6.QtGui.QPainter.PixmapFragmentHints"},
        {nullptr, "PySide6.QtGui.QPainter.RenderHints"},
        {nullptr, "PySide6.QtGui.QPointingDevice.PointerTypes"},
        {nullptr, "PySide6.QtGui.QRawFont.LayoutFlags"},
        {nullptr, "PySide6.QtGui.QRhi.BeginFrameFlags"},
        {nullptr, "PySide6.QtGui.QRhi.EndFrameFlags"},
        {nullptr, "PySide6.QtGui.QRhi.Flags"},
        {nullptr, "PySide6.QtGui.QRhiBuffer.UsageFlags"},
        {nullptr, "PySide6.QtGui.QRhiCommandBuffer.BeginPassFlags"},
        {nullptr, "PySide6.QtGui.QRhiComputePipeline.Flags"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.ColorMask"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.Flags"},
        {nullptr, "PySide6.QtGui.QRhiRenderBuffer.Flags"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.StageFlags"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBindings.UpdateFlags"},
        {nullptr, "PySide6.QtGui.QRhiSwapChain.Flags"},
        {nullptr, "PySide6.QtGui.QRhiTexture.Flags"},
        {nullptr, "PySide6.QtGui.QRhiTextureRenderTarget.Flags"},
        {nullptr, "PySide6.QtGui.QShaderVersion.Flags"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.FormatOptions"},
        {nullptr, "PySide6.QtGui.QTextDocument.FindFlags"},
        {nullptr, "PySide6.QtGui.QTextDocument.MarkdownFeatures"},
        {nullptr, "PySide6.QtGui.QTextFormat.PageBreakFlags"},
        {nullptr, "PySide6.QtGui.QTextItem.RenderFlags"},
        {nullptr, "PySide6.QtGui.QTextLayout.GlyphRunRetrievalFlags"},
        {nullptr, "PySide6.QtGui.QTextOption.Flags"},
        {nullptr, "PySide6.QtGui.QFocusEvent"},
        {nullptr, "PySide6.QtGui.QFont"},
        {nullptr, "PySide6.QtGui.QFont.Capitalization"},
        {nullptr, "PySide6.QtGui.QFont.SpacingType"},
        {nullptr, "PySide6.QtGui.QFont.Stretch"},
        {nullptr, "PySide6.QtGui.QFont.Style"},
        {nullptr, "PySide6.QtGui.QFont.StyleHint"},
        {nullptr, "PySide6.QtGui.QFont.StyleStrategy"},
        {nullptr, "PySide6.QtGui.QFont.Tag"},
        {nullptr, "PySide6.QtGui.QFont.Weight"},
        {nullptr, "PySide6.QtGui.QFontDatabase"},
        {nullptr, "PySide6.QtGui.QFontDatabase.SystemFont"},
        {nullptr, "PySide6.QtGui.QFontDatabase.WritingSystem"},
        {nullptr, "PySide6.QtGui.QFontInfo"},
        {nullptr, "PySide6.QtGui.QFontMetrics"},
        {nullptr, "PySide6.QtGui.QFontMetricsF"},
        {nullptr, "PySide6.QtGui.QGlyphRun"},
        {nullptr, "PySide6.QtGui.QGlyphRun.GlyphRunFlag"},
        {nullptr, "PySide6.QtGui.QGradient"},
        {nullptr, "PySide6.QtGui.QGradient.CoordinateMode"},
        {nullptr, "PySide6.QtGui.QGradient.InterpolationMode"},
        {nullptr, "PySide6.QtGui.QGradient.Preset"},
        {nullptr, "PySide6.QtGui.QGradient.Spread"},
        {nullptr, "PySide6.QtGui.QGradient.Type"},
        {nullptr, "PySide6.QtGui.QGuiApplication"},
        {nullptr, "PySide6.QtGui.QHelpEvent"},
        {nullptr, "PySide6.QtGui.QHideEvent"},
        {nullptr, "PySide6.QtGui.QHoverEvent"},
        {nullptr, "PySide6.QtGui.QIcon"},
        {nullptr, "PySide6.QtGui.QIcon.Mode"},
        {nullptr, "PySide6.QtGui.QIcon.State"},
        {nullptr, "PySide6.QtGui.QIcon.ThemeIcon"},
        {nullptr, "PySide6.QtGui.QIconDragEvent"},
        {nullptr, "PySide6.QtGui.QIconEngine"},
        {nullptr, "PySide6.QtGui.QIconEngine.IconEngineHook"},
        {nullptr, "PySide6.QtGui.QIconEngine.ScaledPixmapArgument"},
        {nullptr, "PySide6.QtGui.QImage"},
        {nullptr, "PySide6.QtGui.QImage.Format"},
        {nullptr, "PySide6.QtGui.QImage.InvertMode"},
        {nullptr, "PySide6.QtGui.QImageIOHandler"},
        {nullptr, "PySide6.QtGui.QImageIOHandler.ImageOption"},
        {nullptr, "PySide6.QtGui.QImageIOHandler.Transformation"},
        {nullptr, "PySide6.QtGui.QImageReader"},
        {nullptr, "PySide6.QtGui.QImageReader.ImageReaderError"},
        {nullptr, "PySide6.QtGui.QImageWriter"},
        {nullptr, "PySide6.QtGui.QImageWriter.ImageWriterError"},
        {nullptr, "PySide6.QtGui.QInputDevice"},
        {nullptr, "PySide6.QtGui.QInputDevice.Capability"},
        {nullptr, "PySide6.QtGui.QInputDevice.DeviceType"},
        {nullptr, "PySide6.QtGui.QInputEvent"},
        {nullptr, "PySide6.QtGui.QInputMethod"},
        {nullptr, "PySide6.QtGui.QInputMethod.Action"},
        {nullptr, "PySide6.QtGui.QInputMethodEvent"},
        {nullptr, "PySide6.QtGui.QInputMethodEvent.Attribute"},
        {nullptr, "PySide6.QtGui.QInputMethodEvent.AttributeType"},
        {nullptr, "PySide6.QtGui.QInputMethodQueryEvent"},
        {nullptr, "PySide6.QtGui.QIntValidator"},
        {nullptr, "PySide6.QtGui.QKeyEvent"},
        {nullptr, "PySide6.QtGui.QKeySequence"},
        {nullptr, "PySide6.QtGui.QKeySequence.SequenceFormat"},
        {nullptr, "PySide6.QtGui.QKeySequence.SequenceMatch"},
        {nullptr, "PySide6.QtGui.QKeySequence.StandardKey"},
        {nullptr, "PySide6.QtGui.QLinearGradient"},
        {nullptr, "PySide6.QtGui.QMatrix2x2"},
        {nullptr, "PySide6.QtGui.QMatrix2x3"},
        {nullptr, "PySide6.QtGui.QMatrix2x4"},
        {nullptr, "PySide6.QtGui.QMatrix3x2"},
        {nullptr, "PySide6.QtGui.QMatrix3x3"},
        {nullptr, "PySide6.QtGui.QMatrix3x4"},
        {nullptr, "PySide6.QtGui.QMatrix4x2"},
        {nullptr, "PySide6.QtGui.QMatrix4x3"},
        {nullptr, "PySide6.QtGui.QMatrix4x4"},
        {nullptr, "PySide6.QtGui.QMatrix4x4.Flag"},
        {nullptr, "PySide6.QtGui.QMouseEvent"},
        {nullptr, "PySide6.QtGui.QMoveEvent"},
        {nullptr, "PySide6.QtGui.QMovie"},
        {nullptr, "PySide6.QtGui.QMovie.CacheMode"},
        {nullptr, "PySide6.QtGui.QMovie.MovieState"},
        {nullptr, "PySide6.QtGui.QNativeGestureEvent"},
        {nullptr, "PySide6.QtGui.QNativeInterface"},
        {nullptr, "+++ unknown entry #188 in QtGui"},
        {nullptr, "PySide6.QtGui.QNativeInterface.QX11Application"},
        {nullptr, "PySide6.QtGui.QOffscreenSurface"},
        {nullptr, "PySide6.QtGui.QOpenGLContext"},
        {nullptr, "PySide6.QtGui.QOpenGLContext.OpenGLModuleType"},
        {nullptr, "PySide6.QtGui.QOpenGLContextGroup"},
        {nullptr, "PySide6.QtGui.QOpenGLExtraFunctions"},
        {nullptr, "PySide6.QtGui.QOpenGLFunctions"},
        {nullptr, "PySide6.QtGui.QOpenGLFunctions.OpenGLFeature"},
        {nullptr, "PySide6.QtGui.QPageLayout"},
        {nullptr, "PySide6.QtGui.QPageLayout.Mode"},
        {nullptr, "PySide6.QtGui.QPageLayout.Orientation"},
        {nullptr, "PySide6.QtGui.QPageLayout.Unit"},
        {nullptr, "PySide6.QtGui.QPageRanges"},
        {nullptr, "PySide6.QtGui.QPageRanges.Range"},
        {nullptr, "PySide6.QtGui.QPageSize"},
        {nullptr, "PySide6.QtGui.QPageSize.PageSizeId"},
        {nullptr, "PySide6.QtGui.QPageSize.SizeMatchPolicy"},
        {nullptr, "PySide6.QtGui.QPageSize.Unit"},
        {nullptr, "PySide6.QtGui.QPagedPaintDevice"},
        {nullptr, "PySide6.QtGui.QPagedPaintDevice.PdfVersion"},
        {nullptr, "PySide6.QtGui.QPaintDevice"},
        {nullptr, "PySide6.QtGui.QPaintDevice.PaintDeviceMetric"},
        {nullptr, "PySide6.QtGui.QPaintDeviceWindow"},
        {nullptr, "PySide6.QtGui.QPaintEngine"},
        {nullptr, "PySide6.QtGui.QPaintEngine.DirtyFlag"},
        {nullptr, "PySide6.QtGui.QPaintEngine.PaintEngineFeature"},
        {nullptr, "PySide6.QtGui.QPaintEngine.PolygonDrawMode"},
        {nullptr, "PySide6.QtGui.QPaintEngine.Type"},
        {nullptr, "PySide6.QtGui.QPaintEngineState"},
        {nullptr, "PySide6.QtGui.QPaintEvent"},
        {nullptr, "PySide6.QtGui.QPainter"},
        {nullptr, "PySide6.QtGui.QPainter.CompositionMode"},
        {nullptr, "PySide6.QtGui.QPainter.PixmapFragment"},
        {nullptr, "PySide6.QtGui.QPainter.PixmapFragmentHint"},
        {nullptr, "PySide6.QtGui.QPainter.RenderHint"},
        {nullptr, "PySide6.QtGui.QPainterPath"},
        {nullptr, "PySide6.QtGui.QPainterPath.Element"},
        {nullptr, "PySide6.QtGui.QPainterPath.ElementType"},
        {nullptr, "PySide6.QtGui.QPainterPathStroker"},
        {nullptr, "PySide6.QtGui.QPalette"},
        {nullptr, "PySide6.QtGui.QPalette.ColorGroup"},
        {nullptr, "PySide6.QtGui.QPalette.ColorRole"},
        {nullptr, "PySide6.QtGui.QPdfWriter"},
        {nullptr, "PySide6.QtGui.QPen"},
        {nullptr, "PySide6.QtGui.QPicture"},
        {nullptr, "PySide6.QtGui.QPixelFormat"},
        {nullptr, "PySide6.QtGui.QPixelFormat.AlphaPosition"},
        {nullptr, "PySide6.QtGui.QPixelFormat.AlphaPremultiplied"},
        {nullptr, "PySide6.QtGui.QPixelFormat.AlphaUsage"},
        {nullptr, "PySide6.QtGui.QPixelFormat.ByteOrder"},
        {nullptr, "PySide6.QtGui.QPixelFormat.ColorModel"},
        {nullptr, "PySide6.QtGui.QPixelFormat.TypeInterpretation"},
        {nullptr, "PySide6.QtGui.QPixelFormat.YUVLayout"},
        {nullptr, "PySide6.QtGui.QPixmap"},
        {nullptr, "PySide6.QtGui.QPixmapCache"},
        {nullptr, "PySide6.QtGui.QPixmapCache.Key"},
        {nullptr, "PySide6.QtGui.QPlatformSurfaceEvent"},
        {nullptr, "PySide6.QtGui.QPlatformSurfaceEvent.SurfaceEventType"},
        {nullptr, "PySide6.QtGui.QPointerEvent"},
        {nullptr, "PySide6.QtGui.QPointingDevice"},
        {nullptr, "PySide6.QtGui.QPointingDevice.GrabTransition"},
        {nullptr, "PySide6.QtGui.QPointingDevice.PointerType"},
        {nullptr, "PySide6.QtGui.QPointingDeviceUniqueId"},
        {nullptr, "PySide6.QtGui.QPolygon"},
        {nullptr, "PySide6.QtGui.QPolygonF"},
        {nullptr, "PySide6.QtGui.QPyTextObject"},
        {nullptr, "PySide6.QtGui.QQuaternion"},
        {nullptr, "PySide6.QtGui.QRadialGradient"},
        {nullptr, "PySide6.QtGui.QRasterWindow"},
        {nullptr, "PySide6.QtGui.QRawFont"},
        {nullptr, "PySide6.QtGui.QRawFont.AntialiasingType"},
        {nullptr, "PySide6.QtGui.QRawFont.LayoutFlag"},
        {nullptr, "PySide6.QtGui.QRegion"},
        {nullptr, "PySide6.QtGui.QRegion.RegionType"},
        {nullptr, "PySide6.QtGui.QRegularExpressionValidator"},
        {nullptr, "PySide6.QtGui.QResizeEvent"},
        {nullptr, "PySide6.QtGui.QRgba64"},
        {nullptr, "PySide6.QtGui.QRhi"},
        {nullptr, "PySide6.QtGui.QRhi.BeginFrameFlag"},
        {nullptr, "PySide6.QtGui.QRhi.EndFrameFlag"},
        {nullptr, "PySide6.QtGui.QRhi.Feature"},
        {nullptr, "PySide6.QtGui.QRhi.Flag"},
        {nullptr, "PySide6.QtGui.QRhi.FrameOpResult"},
        {nullptr, "PySide6.QtGui.QRhi.Implementation"},
        {nullptr, "PySide6.QtGui.QRhi.ResourceLimit"},
        {nullptr, "PySide6.QtGui.QRhiBuffer"},
        {nullptr, "PySide6.QtGui.QRhiBuffer.Type"},
        {nullptr, "PySide6.QtGui.QRhiBuffer.UsageFlag"},
        {nullptr, "PySide6.QtGui.QRhiColorAttachment"},
        {nullptr, "PySide6.QtGui.QRhiCommandBuffer"},
        {nullptr, "PySide6.QtGui.QRhiCommandBuffer.BeginPassFlag"},
        {nullptr, "PySide6.QtGui.QRhiCommandBuffer.IndexFormat"},
        {nullptr, "PySide6.QtGui.QRhiComputePipeline"},
        {nullptr, "PySide6.QtGui.QRhiComputePipeline.Flag"},
        {nullptr, "PySide6.QtGui.QRhiDepthStencilClearValue"},
        {nullptr, "PySide6.QtGui.QRhiDriverInfo"},
        {nullptr, "PySide6.QtGui.QRhiDriverInfo.DeviceType"},
        {nullptr, "PySide6.QtGui.QRhiGles2InitParams"},
        {nullptr, "PySide6.QtGui.QRhiGles2NativeHandles"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.BlendFactor"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.BlendOp"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.ColorMaskComponent"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.CompareOp"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.CullMode"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.Flag"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.FrontFace"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.StencilOp"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend"},
        {nullptr, "PySide6.QtGui.QRhiGraphicsPipeline.Topology"},
        {nullptr, "PySide6.QtGui.QRhiInitParams"},
        {nullptr, "PySide6.QtGui.QRhiNativeHandles"},
        {nullptr, "PySide6.QtGui.QRhiNullInitParams"},
        {nullptr, "PySide6.QtGui.QRhiReadbackDescription"},
        {nullptr, "PySide6.QtGui.QRhiReadbackResult"},
        {nullptr, "PySide6.QtGui.QRhiRenderBuffer"},
        {nullptr, "PySide6.QtGui.QRhiRenderBuffer.Flag"},
        {nullptr, "PySide6.QtGui.QRhiRenderBuffer.Type"},
        {nullptr, "PySide6.QtGui.QRhiRenderPassDescriptor"},
        {nullptr, "PySide6.QtGui.QRhiRenderTarget"},
        {nullptr, "PySide6.QtGui.QRhiResource"},
        {nullptr, "PySide6.QtGui.QRhiResource.Type"},
        {nullptr, "PySide6.QtGui.QRhiResourceUpdateBatch"},
        {nullptr, "PySide6.QtGui.QRhiSampler"},
        {nullptr, "PySide6.QtGui.QRhiSampler.AddressMode"},
        {nullptr, "PySide6.QtGui.QRhiSampler.CompareOp"},
        {nullptr, "PySide6.QtGui.QRhiSampler.Filter"},
        {nullptr, "PySide6.QtGui.QRhiScissor"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.Data"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.Data.StorageBufferData"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.Data.StorageImageData"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.StageFlag"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.TextureAndSampler"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBinding.Type"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBindings"},
        {nullptr, "PySide6.QtGui.QRhiShaderResourceBindings.UpdateFlag"},
        {nullptr, "PySide6.QtGui.QRhiShaderStage"},
        {nullptr, "PySide6.QtGui.QRhiShaderStage.Type"},
        {nullptr, "PySide6.QtGui.QRhiStats"},
        {nullptr, "PySide6.QtGui.QRhiSwapChain"},
        {nullptr, "PySide6.QtGui.QRhiSwapChain.Flag"},
        {nullptr, "PySide6.QtGui.QRhiSwapChain.Format"},
        {nullptr, "PySide6.QtGui.QRhiSwapChain.StereoTargetBuffer"},
        {nullptr, "PySide6.QtGui.QRhiSwapChainRenderTarget"},
        {nullptr, "PySide6.QtGui.QRhiTexture"},
        {nullptr, "PySide6.QtGui.QRhiTexture.Flag"},
        {nullptr, "PySide6.QtGui.QRhiTexture.Format"},
        {nullptr, "PySide6.QtGui.QRhiTextureCopyDescription"},
        {nullptr, "PySide6.QtGui.QRhiTextureRenderTarget"},
        {nullptr, "PySide6.QtGui.QRhiTextureRenderTarget.Flag"},
        {nullptr, "PySide6.QtGui.QRhiTextureRenderTargetDescription"},
        {nullptr, "PySide6.QtGui.QRhiTextureSubresourceUploadDescription"},
        {nullptr, "PySide6.QtGui.QRhiTextureUploadDescription"},
        {nullptr, "PySide6.QtGui.QRhiTextureUploadEntry"},
        {nullptr, "PySide6.QtGui.QRhiVertexInputAttribute"},
        {nullptr, "PySide6.QtGui.QRhiVertexInputAttribute.Format"},
        {nullptr, "PySide6.QtGui.QRhiVertexInputBinding"},
        {nullptr, "PySide6.QtGui.QRhiVertexInputBinding.Classification"},
        {nullptr, "PySide6.QtGui.QRhiVertexInputLayout"},
        {nullptr, "PySide6.QtGui.QRhiViewport"},
        {nullptr, "PySide6.QtGui.QScreen"},
        {nullptr, "PySide6.QtGui.QScrollEvent"},
        {nullptr, "PySide6.QtGui.QScrollEvent.ScrollState"},
        {nullptr, "PySide6.QtGui.QScrollPrepareEvent"},
        {nullptr, "PySide6.QtGui.QSessionManager"},
        {nullptr, "PySide6.QtGui.QSessionManager.RestartHint"},
        {nullptr, "PySide6.QtGui.QShader"},
        {nullptr, "PySide6.QtGui.QShader.SerializedFormatVersion"},
        {nullptr, "PySide6.QtGui.QShader.Source"},
        {nullptr, "PySide6.QtGui.QShader.Stage"},
        {nullptr, "PySide6.QtGui.QShader.Variant"},
        {nullptr, "PySide6.QtGui.QShaderCode"},
        {nullptr, "PySide6.QtGui.QShaderKey"},
        {nullptr, "PySide6.QtGui.QShaderVersion"},
        {nullptr, "PySide6.QtGui.QShaderVersion.Flag"},
        {nullptr, "PySide6.QtGui.QShortcut"},
        {nullptr, "PySide6.QtGui.QShortcutEvent"},
        {nullptr, "PySide6.QtGui.QShowEvent"},
        {nullptr, "PySide6.QtGui.QSinglePointEvent"},
        {nullptr, "PySide6.QtGui.QStandardItem"},
        {nullptr, "PySide6.QtGui.QStandardItem.ItemType"},
        {nullptr, "PySide6.QtGui.QStandardItemModel"},
        {nullptr, "PySide6.QtGui.QStaticText"},
        {nullptr, "PySide6.QtGui.QStaticText.PerformanceHint"},
        {nullptr, "PySide6.QtGui.QStatusTipEvent"},
        {nullptr, "PySide6.QtGui.QStyleHints"},
        {nullptr, "PySide6.QtGui.QSurface"},
        {nullptr, "PySide6.QtGui.QSurface.SurfaceClass"},
        {nullptr, "PySide6.QtGui.QSurface.SurfaceType"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.ColorSpace"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.FormatOption"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.RenderableType"},
        {nullptr, "PySide6.QtGui.QSurfaceFormat.SwapBehavior"},
        {nullptr, "PySide6.QtGui.QSyntaxHighlighter"},
        {nullptr, "PySide6.QtGui.QTabletEvent"},
        {nullptr, "PySide6.QtGui.QTextBlock"},
        {nullptr, "PySide6.QtGui.QTextBlock.iterator"},
        {nullptr, "PySide6.QtGui.QTextBlockFormat"},
        {nullptr, "PySide6.QtGui.QTextBlockFormat.MarkerType"},
        {nullptr, "PySide6.QtGui.QTextBlockGroup"},
        {nullptr, "PySide6.QtGui.QTextBlockUserData"},
        {nullptr, "PySide6.QtGui.QTextCharFormat"},
        {nullptr, "PySide6.QtGui.QTextCharFormat.FontPropertiesInheritanceBehavior"},
        {nullptr, "PySide6.QtGui.QTextCharFormat.UnderlineStyle"},
        {nullptr, "PySide6.QtGui.QTextCharFormat.VerticalAlignment"},
        {nullptr, "PySide6.QtGui.QTextCursor"},
        {nullptr, "PySide6.QtGui.QTextCursor.MoveMode"},
        {nullptr, "PySide6.QtGui.QTextCursor.MoveOperation"},
        {nullptr, "PySide6.QtGui.QTextCursor.SelectionType"},
        {nullptr, "PySide6.QtGui.QTextDocument"},
        {nullptr, "PySide6.QtGui.QTextDocument.FindFlag"},
        {nullptr, "PySide6.QtGui.QTextDocument.MarkdownFeature"},
        {nullptr, "PySide6.QtGui.QTextDocument.MetaInformation"},
        {nullptr, "PySide6.QtGui.QTextDocument.ResourceType"},
        {nullptr, "PySide6.QtGui.QTextDocument.Stacks"},
        {nullptr, "PySide6.QtGui.QTextDocumentFragment"},
        {nullptr, "PySide6.QtGui.QTextDocumentWriter"},
        {nullptr, "PySide6.QtGui.QTextFormat"},
        {nullptr, "PySide6.QtGui.QTextFormat.FormatType"},
        {nullptr, "PySide6.QtGui.QTextFormat.ObjectTypes"},
        {nullptr, "PySide6.QtGui.QTextFormat.PageBreakFlag"},
        {nullptr, "PySide6.QtGui.QTextFormat.Property"},
        {nullptr, "PySide6.QtGui.QTextFragment"},
        {nullptr, "PySide6.QtGui.QTextFrame"},
        {nullptr, "PySide6.QtGui.QTextFrame.iterator"},
        {nullptr, "PySide6.QtGui.QTextFrameFormat"},
        {nullptr, "PySide6.QtGui.QTextFrameFormat.BorderStyle"},
        {nullptr, "PySide6.QtGui.QTextFrameFormat.Position"},
        {nullptr, "PySide6.QtGui.QTextImageFormat"},
        {nullptr, "PySide6.QtGui.QTextInlineObject"},
        {nullptr, "PySide6.QtGui.QTextItem"},
        {nullptr, "PySide6.QtGui.QTextItem.RenderFlag"},
        {nullptr, "PySide6.QtGui.QTextLayout"},
        {nullptr, "PySide6.QtGui.QTextLayout.CursorMode"},
        {nullptr, "PySide6.QtGui.QTextLayout.FormatRange"},
        {nullptr, "PySide6.QtGui.QTextLayout.GlyphRunRetrievalFlag"},
        {nullptr, "PySide6.QtGui.QTextLength"},
        {nullptr, "PySide6.QtGui.QTextLength.Type"},
        {nullptr, "PySide6.QtGui.QTextLine"},
        {nullptr, "PySide6.QtGui.QTextLine.CursorPosition"},
        {nullptr, "PySide6.QtGui.QTextLine.Edge"},
        {nullptr, "PySide6.QtGui.QTextList"},
        {nullptr, "PySide6.QtGui.QTextListFormat"},
        {nullptr, "PySide6.QtGui.QTextListFormat.Style"},
        {nullptr, "PySide6.QtGui.QTextObject"},
        {nullptr, "PySide6.QtGui.QTextObjectInterface"},
        {nullptr, "PySide6.QtGui.QTextOption"},
        {nullptr, "PySide6.QtGui.QTextOption.Flag"},
        {nullptr, "PySide6.QtGui.QTextOption.Tab"},
        {nullptr, "PySide6.QtGui.QTextOption.TabType"},
        {nullptr, "PySide6.QtGui.QTextOption.WrapMode"},
        {nullptr, "PySide6.QtGui.QTextTable"},
        {nullptr, "PySide6.QtGui.QTextTableCell"},
        {nullptr, "PySide6.QtGui.QTextTableCellFormat"},
        {nullptr, "PySide6.QtGui.QTextTableFormat"},
        {nullptr, "PySide6.QtGui.QToolBarChangeEvent"},
        {nullptr, "PySide6.QtGui.QTouchEvent"},
        {nullptr, "PySide6.QtGui.QTransform"},
        {nullptr, "PySide6.QtGui.QTransform.TransformationType"},
        {nullptr, "PySide6.QtGui.QUndoCommand"},
        {nullptr, "PySide6.QtGui.QUndoGroup"},
        {nullptr, "PySide6.QtGui.QUndoStack"},
        {nullptr, "PySide6.QtGui.QValidator"},
        {nullptr, "PySide6.QtGui.QValidator.State"},
        {nullptr, "PySide6.QtGui.QVector2D"},
        {nullptr, "PySide6.QtGui.QVector3D"},
        {nullptr, "PySide6.QtGui.QVector4D"},
        {nullptr, "PySide6.QtGui.QWhatsThisClickedEvent"},
        {nullptr, "PySide6.QtGui.QWheelEvent"},
        {nullptr, "PySide6.QtGui.QWindow"},
        {nullptr, "PySide6.QtGui.QWindow.AncestorMode"},
        {nullptr, "PySide6.QtGui.QWindow.Visibility"},
        {nullptr, "PySide6.QtGui.QWindowStateChangeEvent"},
        {nullptr, "PySide6.QtGui.Qt"},
        {nullptr, "+++ unknown entry #468 in QtGui"},
        {nullptr, "PySide6.QtGui.QOverrideCursorGuard"},
        {nullptr, "PySide6.QtGui.QFont.HintingPreference"},
        {nullptr, "PySide6.QtGui.QTextBlockFormat.LineHeightTypes"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtGuiTypeStructs = cppApi;
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtGuiTypes = reinterpret_cast<PyTypeObject **>(cppApi);

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtGui_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtGuiTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtGui", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtGuiModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "Qt", init_QtGuiQt);
    Shiboken::Module::AddTypeCreationFunction(module, "QVector4D", init_QVector4D);
    Shiboken::Module::AddTypeCreationFunction(module, "QVector3D", init_QVector3D);
    Shiboken::Module::AddTypeCreationFunction(module, "QVector2D", init_QVector2D);
    Shiboken::Module::AddTypeCreationFunction(module, "QUndoCommand", init_QUndoCommand);
    Shiboken::Module::AddTypeCreationFunction(module, "QTransform", init_QTransform);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextTableCell", init_QTextTableCell);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextOption", init_QTextOption);
    Shiboken::Module::AddTypeCreationFunction(module, "Tab", init_QTextOption_Tab, "QTextOption");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextObjectInterface", init_QTextObjectInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextLine", init_QTextLine);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextLength", init_QTextLength);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextItem", init_QTextItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextInlineObject", init_QTextInlineObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextFragment", init_QTextFragment);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextFormat", init_QTextFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextListFormat", init_QTextListFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextFrameFormat", init_QTextFrameFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextTableFormat", init_QTextTableFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextDocumentFragment", init_QTextDocumentFragment);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextCursor", init_QTextCursor);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextCharFormat", init_QTextCharFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextTableCellFormat", init_QTextTableCellFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextImageFormat", init_QTextImageFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBlockUserData", init_QTextBlockUserData);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBlockFormat", init_QTextBlockFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBlock", init_QTextBlock);
    Shiboken::Module::AddTypeCreationFunction(module, "iterator", init_QTextBlock_iterator, "QTextBlock");
    Shiboken::Module::AddTypeCreationFunction(module, "QSurfaceFormat", init_QSurfaceFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QSurface", init_QSurface);
    Shiboken::Module::AddTypeCreationFunction(module, "QStandardItem", init_QStandardItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderVersion", init_QShaderVersion);
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderKey", init_QShaderKey);
    Shiboken::Module::AddTypeCreationFunction(module, "QShader", init_QShader);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiViewport", init_QRhiViewport);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiVertexInputLayout", init_QRhiVertexInputLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiVertexInputBinding", init_QRhiVertexInputBinding);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiVertexInputAttribute", init_QRhiVertexInputAttribute);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureUploadEntry", init_QRhiTextureUploadEntry);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureUploadDescription", init_QRhiTextureUploadDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureSubresourceUploadDescription", init_QRhiTextureSubresourceUploadDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureRenderTargetDescription", init_QRhiTextureRenderTargetDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureCopyDescription", init_QRhiTextureCopyDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiStats", init_QRhiStats);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiShaderStage", init_QRhiShaderStage);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiShaderResourceBinding", init_QRhiShaderResourceBinding);
    Shiboken::Module::AddTypeCreationFunction(module, "Data", init_QRhiShaderResourceBinding_Data, "QRhiShaderResourceBinding");
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiScissor", init_QRhiScissor);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiResourceUpdateBatch", init_QRhiResourceUpdateBatch);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiReadbackDescription", init_QRhiReadbackDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiNativeHandles", init_QRhiNativeHandles);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiInitParams", init_QRhiInitParams);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiNullInitParams", init_QRhiNullInitParams);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiDepthStencilClearValue", init_QRhiDepthStencilClearValue);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiColorAttachment", init_QRhiColorAttachment);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhi", init_QRhi);
    Shiboken::Module::AddTypeCreationFunction(module, "QRgba64", init_QRgba64);
    Shiboken::Module::AddTypeCreationFunction(module, "QRegion", init_QRegion);
    Shiboken::Module::AddTypeCreationFunction(module, "QRawFont", init_QRawFont);
    Shiboken::Module::AddTypeCreationFunction(module, "QQuaternion", init_QQuaternion);
    Shiboken::Module::AddTypeCreationFunction(module, "QPolygonF", init_QPolygonF);
    Shiboken::Module::AddTypeCreationFunction(module, "QPolygon", init_QPolygon);
    Shiboken::Module::AddTypeCreationFunction(module, "QPointingDeviceUniqueId", init_QPointingDeviceUniqueId);
    Shiboken::Module::AddTypeCreationFunction(module, "QPixmapCache", init_QPixmapCache);
    Shiboken::Module::AddTypeCreationFunction(module, "Key", init_QPixmapCache_Key, "QPixmapCache");
    Shiboken::Module::AddTypeCreationFunction(module, "QPixelFormat", init_QPixelFormat);
    Shiboken::Module::AddTypeCreationFunction(module, "QPen", init_QPen);
    Shiboken::Module::AddTypeCreationFunction(module, "QPalette", init_QPalette);
    Shiboken::Module::AddTypeCreationFunction(module, "QPainterPathStroker", init_QPainterPathStroker);
    Shiboken::Module::AddTypeCreationFunction(module, "QPainterPath", init_QPainterPath);
    Shiboken::Module::AddTypeCreationFunction(module, "Element", init_QPainterPath_Element, "QPainterPath");
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintEngineState", init_QPaintEngineState);
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintEngine", init_QPaintEngine);
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintDevice", init_QPaintDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QPicture", init_QPicture);
    Shiboken::Module::AddTypeCreationFunction(module, "QPagedPaintDevice", init_QPagedPaintDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QPageSize", init_QPageSize);
    Shiboken::Module::AddTypeCreationFunction(module, "QPageRanges", init_QPageRanges);
    Shiboken::Module::AddTypeCreationFunction(module, "Range", init_QPageRanges_Range, "QPageRanges");
    Shiboken::Module::AddTypeCreationFunction(module, "QOverrideCursorGuard", init_QtGuiHelper_QOverrideCursorGuard);
    Shiboken::Module::AddTypeCreationFunction(module, "QOpenGLFunctions", init_QOpenGLFunctions);
    Shiboken::Module::AddTypeCreationFunction(module, "QOpenGLExtraFunctions", init_QOpenGLExtraFunctions);
    Shiboken::Module::AddTypeCreationFunction(module, "QNativeInterface", init_QtGuiQNativeInterface);
#if QT_CONFIG(xcb)
    Shiboken::Module::AddTypeCreationFunction(module, "QX11Application", init_QNativeInterface_QX11Application, "QNativeInterface");
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix4x4", init_QMatrix4x4);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix4x3", init_QMatrix4x3);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix4x2", init_QMatrix4x2);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix3x4", init_QMatrix3x4);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix3x3", init_QMatrix3x3);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix3x2", init_QMatrix3x2);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix2x4", init_QMatrix2x4);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix2x3", init_QMatrix2x3);
    Shiboken::Module::AddTypeCreationFunction(module, "QMatrix2x2", init_QMatrix2x2);
    Shiboken::Module::AddTypeCreationFunction(module, "QImageIOHandler", init_QImageIOHandler);
    Shiboken::Module::AddTypeCreationFunction(module, "QIconEngine", init_QIconEngine);
    Shiboken::Module::AddTypeCreationFunction(module, "QGradient", init_QGradient);
    Shiboken::Module::AddTypeCreationFunction(module, "QRadialGradient", init_QRadialGradient);
    Shiboken::Module::AddTypeCreationFunction(module, "QLinearGradient", init_QLinearGradient);
    Shiboken::Module::AddTypeCreationFunction(module, "QGlyphRun", init_QGlyphRun);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontMetricsF", init_QFontMetricsF);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontMetrics", init_QFontMetrics);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontInfo", init_QFontInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontDatabase", init_QFontDatabase);
    Shiboken::Module::AddTypeCreationFunction(module, "QFont", init_QFont);
    Shiboken::Module::AddTypeCreationFunction(module, "QStaticText", init_QStaticText);
    Shiboken::Module::AddTypeCreationFunction(module, "Tag", init_QFont_Tag, "QFont");
    Shiboken::Module::AddTypeCreationFunction(module, "QEventPoint", init_QEventPoint);
    Shiboken::Module::AddTypeCreationFunction(module, "QDesktopServices", init_QDesktopServices);
    Shiboken::Module::AddTypeCreationFunction(module, "QCursor", init_QCursor);
    Shiboken::Module::AddTypeCreationFunction(module, "QConicalGradient", init_QConicalGradient);
    Shiboken::Module::AddTypeCreationFunction(module, "QColorTransform", init_QColorTransform);
    Shiboken::Module::AddTypeCreationFunction(module, "QColorSpace", init_QColorSpace);
    Shiboken::Module::AddTypeCreationFunction(module, "QColor", init_QColor);
    Shiboken::Module::AddTypeCreationFunction(module, "QColorConstants", init_QtGuiQColorConstants);
    Shiboken::Module::AddTypeCreationFunction(module, "Svg", init_QtGuiQColorConstants_Svg, "QColorConstants");
    Shiboken::Module::AddTypeCreationFunction(module, "QBrush", init_QBrush);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleValueInterface", init_QAccessibleValueInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextInterface", init_QAccessibleTextInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTableCellInterface", init_QAccessibleTableCellInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleInterface", init_QAccessibleInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleObject", init_QAccessibleObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleEvent", init_QAccessibleEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleValueChangeEvent", init_QAccessibleValueChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextCursorEvent", init_QAccessibleTextCursorEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextUpdateEvent", init_QAccessibleTextUpdateEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextSelectionEvent", init_QAccessibleTextSelectionEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextRemoveEvent", init_QAccessibleTextRemoveEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTextInsertEvent", init_QAccessibleTextInsertEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleTableModelChangeEvent", init_QAccessibleTableModelChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleStateChangeEvent", init_QAccessibleStateChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleEditableTextInterface", init_QAccessibleEditableTextInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleActionInterface", init_QAccessibleActionInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessible", init_QAccessible);
    Shiboken::Module::AddTypeCreationFunction(module, "State", init_QAccessible_State, "QAccessible");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractFileIconProvider", init_QAbstractFileIconProvider);
    Shiboken::Module::AddTypeCreationFunction(module, "QIcon", init_QIcon);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextLayout", init_QTextLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "FormatRange", init_QTextLayout_FormatRange, "QTextLayout");
    Shiboken::Module::AddTypeCreationFunction(module, "QPixmap", init_QPixmap);
    Shiboken::Module::AddTypeCreationFunction(module, "ScaledPixmapArgument", init_QIconEngine_ScaledPixmapArgument, "QIconEngine");
    Shiboken::Module::AddTypeCreationFunction(module, "QImage", init_QImage);
    Shiboken::Module::AddTypeCreationFunction(module, "QBitmap", init_QBitmap);
    Shiboken::Module::AddTypeCreationFunction(module, "QPainter", init_QPainter);
    Shiboken::Module::AddTypeCreationFunction(module, "PixmapFragment", init_QPainter_PixmapFragment, "QPainter");
    Shiboken::Module::AddTypeCreationFunction(module, "QBackingStore", init_QBackingStore);
    Shiboken::Module::AddTypeCreationFunction(module, "QPageLayout", init_QPageLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QKeySequence", init_QKeySequence);
    Shiboken::Module::AddTypeCreationFunction(module, "QWindow", init_QWindow);
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintDeviceWindow", init_QPaintDeviceWindow);
    Shiboken::Module::AddTypeCreationFunction(module, "QRasterWindow", init_QRasterWindow);
    Shiboken::Module::AddTypeCreationFunction(module, "QValidator", init_QValidator);
    Shiboken::Module::AddTypeCreationFunction(module, "QRegularExpressionValidator", init_QRegularExpressionValidator);
    Shiboken::Module::AddTypeCreationFunction(module, "QIntValidator", init_QIntValidator);
    Shiboken::Module::AddTypeCreationFunction(module, "QDoubleValidator", init_QDoubleValidator);
    Shiboken::Module::AddTypeCreationFunction(module, "QUndoStack", init_QUndoStack);
    Shiboken::Module::AddTypeCreationFunction(module, "QUndoGroup", init_QUndoGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextObject", init_QTextObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextFrame", init_QTextFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextTable", init_QTextTable);
    Shiboken::Module::AddTypeCreationFunction(module, "iterator", init_QTextFrame_iterator, "QTextFrame");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBlockGroup", init_QTextBlockGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextList", init_QTextList);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextDocument", init_QTextDocument);
    Shiboken::Module::AddTypeCreationFunction(module, "QSyntaxHighlighter", init_QSyntaxHighlighter);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleHints", init_QStyleHints);
    Shiboken::Module::AddTypeCreationFunction(module, "QShortcut", init_QShortcut);
    Shiboken::Module::AddTypeCreationFunction(module, "QSessionManager", init_QSessionManager);
    Shiboken::Module::AddTypeCreationFunction(module, "QScreen", init_QScreen);
    Shiboken::Module::AddTypeCreationFunction(module, "QPyTextObject", init_QPyTextObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QPdfWriter", init_QPdfWriter);
    Shiboken::Module::AddTypeCreationFunction(module, "QOpenGLContextGroup", init_QOpenGLContextGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QOpenGLContext", init_QOpenGLContext);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiGles2NativeHandles", init_QRhiGles2NativeHandles);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiGles2InitParams", init_QRhiGles2InitParams);
    Shiboken::Module::AddTypeCreationFunction(module, "QOffscreenSurface", init_QOffscreenSurface);
    Shiboken::Module::AddTypeCreationFunction(module, "QInputMethod", init_QInputMethod);
    Shiboken::Module::AddTypeCreationFunction(module, "QInputDevice", init_QInputDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QPointingDevice", init_QPointingDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QDrag", init_QDrag);
    Shiboken::Module::AddTypeCreationFunction(module, "QClipboard", init_QClipboard);
    Shiboken::Module::AddTypeCreationFunction(module, "QActionGroup", init_QActionGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QAction", init_QAction);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractTextDocumentLayout", init_QAbstractTextDocumentLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "Selection", init_QAbstractTextDocumentLayout_Selection, "QAbstractTextDocumentLayout");
    Shiboken::Module::AddTypeCreationFunction(module, "PaintContext", init_QAbstractTextDocumentLayout_PaintContext, "QAbstractTextDocumentLayout");
    Shiboken::Module::AddTypeCreationFunction(module, "QWindowStateChangeEvent", init_QWindowStateChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QWhatsThisClickedEvent", init_QWhatsThisClickedEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QToolBarChangeEvent", init_QToolBarChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QStatusTipEvent", init_QStatusTipEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QShowEvent", init_QShowEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QShortcutEvent", init_QShortcutEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QScrollPrepareEvent", init_QScrollPrepareEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QScrollEvent", init_QScrollEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QResizeEvent", init_QResizeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QPlatformSurfaceEvent", init_QPlatformSurfaceEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QPaintEvent", init_QPaintEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QMoveEvent", init_QMoveEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QInputMethodQueryEvent", init_QInputMethodQueryEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QInputMethodEvent", init_QInputMethodEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "Attribute", init_QInputMethodEvent_Attribute, "QInputMethodEvent");
    Shiboken::Module::AddTypeCreationFunction(module, "QInputEvent", init_QInputEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QPointerEvent", init_QPointerEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QTouchEvent", init_QTouchEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QSinglePointEvent", init_QSinglePointEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QWheelEvent", init_QWheelEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QTabletEvent", init_QTabletEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QNativeGestureEvent", init_QNativeGestureEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QMouseEvent", init_QMouseEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QHoverEvent", init_QHoverEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QEnterEvent", init_QEnterEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QKeyEvent", init_QKeyEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QContextMenuEvent", init_QContextMenuEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QIconDragEvent", init_QIconDragEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QHideEvent", init_QHideEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QHelpEvent", init_QHelpEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QFocusEvent", init_QFocusEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileOpenEvent", init_QFileOpenEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QExposeEvent", init_QExposeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QDropEvent", init_QDropEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QDragMoveEvent", init_QDragMoveEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QDragEnterEvent", init_QDragEnterEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QDragLeaveEvent", init_QDragLeaveEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QCloseEvent", init_QCloseEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QChildWindowEvent", init_QChildWindowEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QActionEvent", init_QActionEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGuiApplication", init_QGuiApplication);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextDocumentWriter", init_QTextDocumentWriter);
    Shiboken::Module::AddTypeCreationFunction(module, "QShaderCode", init_QShaderCode);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiResource", init_QRhiResource);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTexture", init_QRhiTexture);
    Shiboken::Module::AddTypeCreationFunction(module, "StorageImageData", init_QRhiShaderResourceBinding_Data_StorageImageData, "QRhiShaderResourceBinding", "Data");
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiShaderResourceBindings", init_QRhiShaderResourceBindings);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiSampler", init_QRhiSampler);
    Shiboken::Module::AddTypeCreationFunction(module, "TextureAndSampler", init_QRhiShaderResourceBinding_TextureAndSampler, "QRhiShaderResourceBinding");
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiRenderPassDescriptor", init_QRhiRenderPassDescriptor);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiRenderTarget", init_QRhiRenderTarget);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiTextureRenderTarget", init_QRhiTextureRenderTarget);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiRenderBuffer", init_QRhiRenderBuffer);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiSwapChain", init_QRhiSwapChain);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiSwapChainRenderTarget", init_QRhiSwapChainRenderTarget);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiGraphicsPipeline", init_QRhiGraphicsPipeline);
    Shiboken::Module::AddTypeCreationFunction(module, "TargetBlend", init_QRhiGraphicsPipeline_TargetBlend, "QRhiGraphicsPipeline");
    Shiboken::Module::AddTypeCreationFunction(module, "StencilOpState", init_QRhiGraphicsPipeline_StencilOpState, "QRhiGraphicsPipeline");
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiComputePipeline", init_QRhiComputePipeline);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiCommandBuffer", init_QRhiCommandBuffer);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiBuffer", init_QRhiBuffer);
    Shiboken::Module::AddTypeCreationFunction(module, "StorageBufferData", init_QRhiShaderResourceBinding_Data_StorageBufferData, "QRhiShaderResourceBinding", "Data");
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiReadbackResult", init_QRhiReadbackResult);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiDriverInfo", init_QRhiDriverInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QMovie", init_QMovie);
    Shiboken::Module::AddTypeCreationFunction(module, "QImageWriter", init_QImageWriter);
    Shiboken::Module::AddTypeCreationFunction(module, "QImageReader", init_QImageReader);
    Shiboken::Module::AddTypeCreationFunction(module, "QStandardItemModel", init_QStandardItemModel);

    // Register converter for type 'PySide6.QtGui.WId'.
    SbkPySide6_QtGuiTypeConverters[SBK_WId_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, WId_CppToPython_WId);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_WId_IDX], "WId");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_WId_IDX],
        PyLong_PythonToCpp_WId,
        is_PyLong_PythonToCpp_WId_Convertible);


    // Register converter for type 'QList<int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QVector2D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector2D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector2D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector2D_IDX], "QList<QVector2D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector2D_IDX],
        PySequence_PythonToCpp__QList_QVector2D_,
        is_PySequence_PythonToCpp__QList_QVector2D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector2D_IDX],
        PythonToCppQVector2DList,
        isQVector2DListPythonToCppConvertible);

    // Register converter for type 'QList<QVector3D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector3D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector3D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector3D_IDX], "QList<QVector3D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector3D_IDX],
        PySequence_PythonToCpp__QList_QVector3D_,
        is_PySequence_PythonToCpp__QList_QVector3D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector3D_IDX],
        PythonToCppQVector3DList,
        isQVector3DListPythonToCppConvertible);

    // Register converter for type 'QList<QVector4D>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector4D_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVector4D__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector4D_IDX], "QList<QVector4D>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector4D_IDX],
        PySequence_PythonToCpp__QList_QVector4D_,
        is_PySequence_PythonToCpp__QList_QVector4D__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVector4D_IDX],
        PythonToCppQVector4DList,
        isQVector4DListPythonToCppConvertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qreal_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'QList<QTextOption::Tab>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextOption_Tab__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX], "QList<QTextOption::Tab>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextOption_Tab_IDX],
        PySequence_PythonToCpp__QList_QTextOption_Tab_,
        is_PySequence_PythonToCpp__QList_QTextOption_Tab__Convertible);

    // Register converter for type 'QList<QGlyphRun>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGlyphRun__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX], "QList<QGlyphRun>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QGlyphRun_IDX],
        PySequence_PythonToCpp__QList_QGlyphRun_,
        is_PySequence_PythonToCpp__QList_QGlyphRun__Convertible);

    // Register converter for type 'QList<QTextLength>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLength_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextLength__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLength_IDX], "QList<QTextLength>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLength_IDX],
        PySequence_PythonToCpp__QList_QTextLength_,
        is_PySequence_PythonToCpp__QList_QTextLength__Convertible);

    // Register converter for type 'QMap<int,QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_QVariant_IDX], "QMap<int,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_QVariant_IDX],
        PyDict_PythonToCpp__QMap_int_QVariant_,
        is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible);

    // Register converter for type 'QList<QTextLayout::FormatRange>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLayout_FormatRange_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextLayout_FormatRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLayout_FormatRange_IDX], "QList<QTextLayout::FormatRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextLayout_FormatRange_IDX],
        PySequence_PythonToCpp__QList_QTextLayout_FormatRange_,
        is_PySequence_PythonToCpp__QList_QTextLayout_FormatRange__Convertible);

    // Register converter for type 'std::pair<int,int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_int_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX], "std::pair<int,int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_int_IDX],
        PySequence_PythonToCpp_std_pair_int_int_,
        is_PySequence_PythonToCpp_std_pair_int_int__Convertible);

    // Register converter for type 'QList<QStandardItem*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QStandardItemPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QStandardItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QStandardItemPTR_IDX], "QList<QStandardItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QStandardItemPTR_IDX],
        PySequence_PythonToCpp__QList_QStandardItemPTR_,
        is_PySequence_PythonToCpp__QList_QStandardItemPTR__Convertible);

    // Register converter for type 'QList<QShaderKey>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QShaderKey_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QShaderKey__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QShaderKey_IDX], "QList<QShaderKey>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QShaderKey_IDX],
        PySequence_PythonToCpp__QList_QShaderKey_,
        is_PySequence_PythonToCpp__QList_QShaderKey__Convertible);

    // Register converter for type 'QMap<int,std::pair<int,int>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_std_pair_int_int_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_std_pair_int_int___CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_std_pair_int_int_IDX], "QMap<int,std::pair<int,int>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_int_std_pair_int_int_IDX],
        PyDict_PythonToCpp__QMap_int_std_pair_int_int__,
        is_PyDict_PythonToCpp__QMap_int_std_pair_int_int___Convertible);

    // Register converter for type 'std::array<float,4>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_float_4_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_array_float_4__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_float_4_IDX], "std::array<float,4>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_float_4_IDX],
        PySequence_PythonToCpp_std_array_float_4_,
        is_PySequence_PythonToCpp_std_array_float_4__Convertible);

    // Register converter for type 'QList<QRhiVertexInputAttribute>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputAttribute_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiVertexInputAttribute__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputAttribute_IDX], "QList<QRhiVertexInputAttribute>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputAttribute_IDX],
        PySequence_PythonToCpp__QList_QRhiVertexInputAttribute_,
        is_PySequence_PythonToCpp__QList_QRhiVertexInputAttribute__Convertible);

    // Register converter for type 'QList<QRhiVertexInputBinding>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputBinding_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiVertexInputBinding__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputBinding_IDX], "QList<QRhiVertexInputBinding>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiVertexInputBinding_IDX],
        PySequence_PythonToCpp__QList_QRhiVertexInputBinding_,
        is_PySequence_PythonToCpp__QList_QRhiVertexInputBinding__Convertible);

    // Register converter for type 'QList<QRhiTextureUploadEntry>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiTextureUploadEntry_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiTextureUploadEntry__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiTextureUploadEntry_IDX], "QList<QRhiTextureUploadEntry>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiTextureUploadEntry_IDX],
        PySequence_PythonToCpp__QList_QRhiTextureUploadEntry_,
        is_PySequence_PythonToCpp__QList_QRhiTextureUploadEntry__Convertible);

    // Register converter for type 'QList<QRhiColorAttachment>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiColorAttachment_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiColorAttachment__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiColorAttachment_IDX], "QList<QRhiColorAttachment>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiColorAttachment_IDX],
        PySequence_PythonToCpp__QList_QRhiColorAttachment_,
        is_PySequence_PythonToCpp__QList_QRhiColorAttachment__Convertible);

    // Register converter for type 'std::array<int,4>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_int_4_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_array_int_4__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_int_4_IDX], "std::array<int,4>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_array_int_4_IDX],
        PySequence_PythonToCpp_std_array_int_4_,
        is_PySequence_PythonToCpp_std_array_int_4__Convertible);

    // Register converter for type 'QList<QPointF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], "QList<QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX],
        PySequence_PythonToCpp__QList_QPointF_,
        is_PySequence_PythonToCpp__QList_QPointF__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX],
        PythonToCppQPointFList,
        isQPointFListPythonToCppConvertible);

    // Register converter for type 'QList<quint32>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_quint32__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX], "QList<quint32>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_quint32_IDX],
        PySequence_PythonToCpp__QList_quint32_,
        is_PySequence_PythonToCpp__QList_quint32__Convertible);

    // Register converter for type 'QList<QFontDatabase::WritingSystem>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFontDatabase_WritingSystem_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QFontDatabase_WritingSystem__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFontDatabase_WritingSystem_IDX], "QList<QFontDatabase::WritingSystem>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFontDatabase_WritingSystem_IDX],
        PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem_,
        is_PySequence_PythonToCpp__QList_QFontDatabase_WritingSystem__Convertible);

    // Register converter for type 'QList<QPoint>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], "QList<QPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX],
        PySequence_PythonToCpp__QList_QPoint_,
        is_PySequence_PythonToCpp__QList_QPoint__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX],
        PythonToCppQPointList,
        isQPointListPythonToCppConvertible);

    // Register converter for type 'QList<QPolygonF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPolygonF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPolygonF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPolygonF_IDX], "QList<QPolygonF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPolygonF_IDX],
        PySequence_PythonToCpp__QList_QPolygonF_,
        is_PySequence_PythonToCpp__QList_QPolygonF__Convertible);

    // Register converter for type 'QList<QPageRanges::Range>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPageRanges_Range_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPageRanges_Range__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPageRanges_Range_IDX], "QList<QPageRanges::Range>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPageRanges_Range_IDX],
        PySequence_PythonToCpp__QList_QPageRanges_Range_,
        is_PySequence_PythonToCpp__QList_QPageRanges_Range__Convertible);

    // Register converter for type 'QList<float>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_float__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX], "QList<float>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_float_IDX],
        PySequence_PythonToCpp__QList_float_,
        is_PySequence_PythonToCpp__QList_float__Convertible);

    // Register converter for type 'QList<QSize>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QSize_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QSize__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QSize_IDX], "QList<QSize>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QSize_IDX],
        PySequence_PythonToCpp__QList_QSize_,
        is_PySequence_PythonToCpp__QList_QSize__Convertible);

    // Register converter for type 'std::pair<qreal,QColor>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_QColor__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX], "std::pair<qreal,QColor>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX],
        PySequence_PythonToCpp_std_pair_qreal_QColor_,
        is_PySequence_PythonToCpp_std_pair_qreal_QColor__Convertible);
    // Register converters for type aliases of std::pair<qreal,QColor>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_qreal_QColor_IDX], "QGradientStop");

    // Register converter for type 'QList<std::pair<qreal,QColor>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_qreal_QColor_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_QColor___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_qreal_QColor_IDX], "QList<std::pair<qreal,QColor>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_qreal_QColor_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_QColor__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_QColor___Convertible);

    // Register converter for type 'QList<qsizetype>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qsizetype_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qsizetype__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qsizetype_IDX], "QList<qsizetype>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_qsizetype_IDX],
        PySequence_PythonToCpp__QList_qsizetype_,
        is_PySequence_PythonToCpp__QList_qsizetype__Convertible);

    // Register converter for type 'QList<QFont::Tag>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFont_Tag_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QFont_Tag__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFont_Tag_IDX], "QList<QFont::Tag>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFont_Tag_IDX],
        PySequence_PythonToCpp__QList_QFont_Tag_,
        is_PySequence_PythonToCpp__QList_QFont_Tag__Convertible);

    // Register converter for type 'QList<uint16_t>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_uint16_t__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX], "QList<uint16_t>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_uint16_t_IDX],
        PySequence_PythonToCpp__QList_uint16_t_,
        is_PySequence_PythonToCpp__QList_uint16_t__Convertible);

    // Register converter for type 'QList<QAccessibleInterface*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAccessibleInterfacePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAccessibleInterfacePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAccessibleInterfacePTR_IDX], "QList<QAccessibleInterface*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAccessibleInterfacePTR_IDX],
        PySequence_PythonToCpp__QList_QAccessibleInterfacePTR_,
        is_PySequence_PythonToCpp__QList_QAccessibleInterfacePTR__Convertible);

    // Register converter for type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], "std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX],
        PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__,
        is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible);

    // Register converter for type 'QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], "QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX],
        PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___,
        is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible);

    // Register converter for type 'QList<unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_unsignedint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_unsignedint_IDX], "QList<unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_unsignedint_IDX],
        PySequence_PythonToCpp__QList_unsignedint_,
        is_PySequence_PythonToCpp__QList_unsignedint__Convertible);

    // Register converter for type 'QList<QLine>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLine_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLine__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLine_IDX], "QList<QLine>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLine_IDX],
        PySequence_PythonToCpp__QList_QLine_,
        is_PySequence_PythonToCpp__QList_QLine__Convertible);

    // Register converter for type 'QList<QLineF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLineF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLineF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLineF_IDX], "QList<QLineF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLineF_IDX],
        PySequence_PythonToCpp__QList_QLineF_,
        is_PySequence_PythonToCpp__QList_QLineF__Convertible);

    // Register converter for type 'QList<QRect>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRect_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRect__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRect_IDX], "QList<QRect>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRect_IDX],
        PySequence_PythonToCpp__QList_QRect_,
        is_PySequence_PythonToCpp__QList_QRect__Convertible);

    // Register converter for type 'QList<QRectF>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRectF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRectF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRectF_IDX], "QList<QRectF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRectF_IDX],
        PySequence_PythonToCpp__QList_QRectF_,
        is_PySequence_PythonToCpp__QList_QRectF__Convertible);

    // Register converter for type 'QList<QKeySequence>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeySequence__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX], "QList<QKeySequence>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QKeySequence_IDX],
        PySequence_PythonToCpp__QList_QKeySequence_,
        is_PySequence_PythonToCpp__QList_QKeySequence__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<QUndoStack*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QUndoStackPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QUndoStackPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QUndoStackPTR_IDX], "QList<QUndoStack*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QUndoStackPTR_IDX],
        PySequence_PythonToCpp__QList_QUndoStackPTR_,
        is_PySequence_PythonToCpp__QList_QUndoStackPTR__Convertible);

    // Register converter for type 'QList<QTextFrame*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFramePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextFramePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFramePTR_IDX], "QList<QTextFrame*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFramePTR_IDX],
        PySequence_PythonToCpp__QList_QTextFramePTR_,
        is_PySequence_PythonToCpp__QList_QTextFramePTR__Convertible);

    // Register converter for type 'QList<QTextBlock>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextBlock_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextBlock__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextBlock_IDX], "QList<QTextBlock>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextBlock_IDX],
        PySequence_PythonToCpp__QList_QTextBlock_,
        is_PySequence_PythonToCpp__QList_QTextBlock__Convertible);

    // Register converter for type 'QList<QTextFormat>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFormat_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextFormat__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFormat_IDX], "QList<QTextFormat>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFormat_IDX],
        PySequence_PythonToCpp__QList_QTextFormat_,
        is_PySequence_PythonToCpp__QList_QTextFormat__Convertible);

    // Register converter for type 'QList<QScreen*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QScreenPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScreenPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QScreenPTR_IDX], "QList<QScreen*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QScreenPTR_IDX],
        PySequence_PythonToCpp__QList_QScreenPTR_,
        is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible);

    // Register converter for type 'QList<QOpenGLContext*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QOpenGLContextPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QOpenGLContextPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QOpenGLContextPTR_IDX], "QList<QOpenGLContext*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QOpenGLContextPTR_IDX],
        PySequence_PythonToCpp__QList_QOpenGLContextPTR_,
        is_PySequence_PythonToCpp__QList_QOpenGLContextPTR__Convertible);

    // Register converter for type 'QSet<QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QSet_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PySet_Type, _QSet_QByteArray__CppToPython_PySet);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QSet_QByteArray_IDX], "QSet<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QSet_QByteArray_IDX],
        PySequence_PythonToCpp__QSet_QByteArray_,
        is_PySequence_PythonToCpp__QSet_QByteArray__Convertible);

    // Register converter for type 'QList<const QInputDevice*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_constQInputDevicePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_constQInputDevicePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_constQInputDevicePTR_IDX], "QList<const QInputDevice*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_constQInputDevicePTR_IDX],
        PySequence_PythonToCpp__QList_constQInputDevicePTR_,
        is_PySequence_PythonToCpp__QList_constQInputDevicePTR__Convertible);

    // Register converter for type 'QList<QAction*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QActionPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QActionPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QActionPTR_IDX], "QList<QAction*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QActionPTR_IDX],
        PySequence_PythonToCpp__QList_QActionPTR_,
        is_PySequence_PythonToCpp__QList_QActionPTR__Convertible);

    // Register converter for type 'QList<QAbstractTextDocumentLayout::Selection>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAbstractTextDocumentLayout_Selection_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAbstractTextDocumentLayout_Selection__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAbstractTextDocumentLayout_Selection_IDX], "QList<QAbstractTextDocumentLayout::Selection>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QAbstractTextDocumentLayout_Selection_IDX],
        PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection_,
        is_PySequence_PythonToCpp__QList_QAbstractTextDocumentLayout_Selection__Convertible);

    // Register converter for type 'QList<QInputMethodEvent::Attribute>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QInputMethodEvent_Attribute_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QInputMethodEvent_Attribute__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QInputMethodEvent_Attribute_IDX], "QList<QInputMethodEvent::Attribute>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QInputMethodEvent_Attribute_IDX],
        PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute_,
        is_PySequence_PythonToCpp__QList_QInputMethodEvent_Attribute__Convertible);

    // Register converter for type 'QList<QEventPoint>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QEventPoint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QEventPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QEventPoint_IDX], "QList<QEventPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QEventPoint_IDX],
        PySequence_PythonToCpp__QList_QEventPoint_,
        is_PySequence_PythonToCpp__QList_QEventPoint__Convertible);

    // Register converter for type 'QList<QWindow*>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX], "QList<QWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX],
        PySequence_PythonToCpp__QList_QWindowPTR_,
        is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible);
    // Register converters for type aliases of QList<QWindow*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QWindowPTR_IDX], "QWindowList");

    // Register converter for type 'QList<QRhiShaderResourceBinding>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderResourceBinding_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiShaderResourceBinding__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderResourceBinding_IDX], "QList<QRhiShaderResourceBinding>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderResourceBinding_IDX],
        PySequence_PythonToCpp__QList_QRhiShaderResourceBinding_,
        is_PySequence_PythonToCpp__QList_QRhiShaderResourceBinding__Convertible);

    // Register converter for type 'QList<QRhiShaderStage>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderStage_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiShaderStage__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderStage_IDX], "QList<QRhiShaderStage>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderStage_IDX],
        PySequence_PythonToCpp__QList_QRhiShaderStage_,
        is_PySequence_PythonToCpp__QList_QRhiShaderStage__Convertible);

    // Register converter for type 'QList<QRhiGraphicsPipeline::TargetBlend>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiGraphicsPipeline_TargetBlend_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRhiGraphicsPipeline_TargetBlend__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiGraphicsPipeline_TargetBlend_IDX], "QList<QRhiGraphicsPipeline::TargetBlend>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiGraphicsPipeline_TargetBlend_IDX],
        PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend_,
        is_PySequence_PythonToCpp__QList_QRhiGraphicsPipeline_TargetBlend__Convertible);

    // Register converter for type 'std::pair<int,unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_unsignedint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_int_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_unsignedint_IDX], "std::pair<int,unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_int_unsignedint_IDX],
        PySequence_PythonToCpp_std_pair_int_unsignedint_,
        is_PySequence_PythonToCpp_std_pair_int_unsignedint__Convertible);

    // Register converter for type 'std::pair<QRhiBuffer*,quint32>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QRhiBufferPTR_quint32__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX], "std::pair<QRhiBuffer*,quint32>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_quint32_IDX],
        PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32_,
        is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_quint32__Convertible);

    // Register converter for type 'QList<std::pair<QRhiBuffer*,quint32>>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QRhiBufferPTR_quint32_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QRhiBufferPTR_quint32___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QRhiBufferPTR_quint32_IDX], "QList<std::pair<QRhiBuffer*,quint32>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_QRhiBufferPTR_quint32_IDX],
        PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32__,
        is_PySequence_PythonToCpp__QList_std_pair_QRhiBufferPTR_quint32___Convertible);

    // Register converter for type 'std::pair<QRhiBuffer*,unsigned int>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_unsignedint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QRhiBufferPTR_unsignedint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_unsignedint_IDX], "std::pair<QRhiBuffer*,unsigned int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_std_pair_QRhiBufferPTR_unsignedint_IDX],
        PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint_,
        is_PySequence_PythonToCpp_std_pair_QRhiBufferPTR_unsignedint__Convertible);

    // Register converter for type 'QList<QModelIndex>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QModelIndex_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QModelIndex_IDX], "QList<QModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QModelIndex_IDX],
        PySequence_PythonToCpp__QList_QModelIndex_,
        is_PySequence_PythonToCpp__QList_QModelIndex__Convertible);
    // Register converters for type aliases of QList<QModelIndex>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QModelIndex_IDX], "QModelIndexList");

    // Register converter for type 'QHash<int,QByteArray>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QHash_int_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_int_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QHash_int_QByteArray_IDX], "QHash<int,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QHash_int_QByteArray_IDX],
        PyDict_PythonToCpp__QHash_int_QByteArray_,
        is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector2DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector2DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector3DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector3DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QVector4DList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QVector4DList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointFList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointFList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointList", ob_type);


    // Extended implicit conversions for PySide6.QtCore.QPointF.
    Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX],
        QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF,
        is_QPainterPath_Element_PythonToCpp_PySide6_QtCore_QPointF_Convertible);

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtGuiTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtGuiTypeConverters);

    // Static field initialization
    init_QRhiShaderResourceBindingStaticFields(module);
    init_QRhiShaderResourceBinding_DataStaticFields(module);
    init_QRhiStaticFields(module);
    init_QtGuiQColorConstantsStaticFields(module);
    init_QtGuiQColorConstants_SvgStaticFields(module);

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtGui");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtGui_SignatureStrings);

    return module;
}
