// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qcalendarwidget_wrapper.h"

// Extra includes
#include <QTextCharFormat>

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtGui/qaction.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qcalendarwidget.h>
#include <QtWidgets/qgraphicseffect.h>
#include <QtWidgets/qgraphicsproxywidget.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcalendar.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCalendarWidgetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCalendarWidgetWrapper::QCalendarWidgetWrapper(::QWidget * parent) : QCalendarWidget(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QCalendarWidgetWrapper::actionEvent(::QActionEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QWidget::actionEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "actionEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::changeEvent(::QEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QWidget::changeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::closeEvent(::QCloseEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QWidget::closeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "closeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    if (m_PyMethodCache[5]) {
        return this->::QWidget::contextMenuEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contextMenuEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QWidget::contextMenuEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

int QCalendarWidgetWrapper::devType() const
{
    if (m_PyMethodCache[7])
        return this->::QWidget::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QWidget::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    if (m_PyMethodCache[9]) {
        return this->::QWidget::dragEnterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    if (m_PyMethodCache[10]) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    if (m_PyMethodCache[11]) {
        return this->::QWidget::dragMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::dropEvent(::QDropEvent * event)
{
    if (m_PyMethodCache[12]) {
        return this->::QWidget::dropEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::enterEvent(::QEnterEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QWidget::enterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCalendarWidgetWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[14])
        return this->::QCalendarWidget::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QCalendarWidget::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCalendarWidgetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[15])
        return this->::QCalendarWidget::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QCalendarWidget::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::focusInEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[16]) {
        return this->::QWidget::focusInEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCalendarWidgetWrapper::focusNextPrevChild(bool next)
{
    if (m_PyMethodCache[17])
        return this->::QWidget::focusNextPrevChild(next);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusNextPrevChild";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::focusOutEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[18]) {
        return this->::QWidget::focusOutEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCalendarWidgetWrapper::hasHeightForWidth() const
{
    if (m_PyMethodCache[19])
        return this->::QWidget::hasHeightForWidth();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasHeightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QWidget::hasHeightForWidth();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QCalendarWidgetWrapper::heightForWidth(int arg__1) const
{
    if (m_PyMethodCache[20])
        return this->::QWidget::heightForWidth(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "heightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::hideEvent(::QHideEvent * event)
{
    if (m_PyMethodCache[21]) {
        return this->::QWidget::hideEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hideEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[22]) {
        return this->::QWidget::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QWidget::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    if (m_PyMethodCache[23]) {
        return this->::QWidget::inputMethodEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QVariant QCalendarWidgetWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    if (m_PyMethodCache[24])
        return this->::QWidget::inputMethodQuery(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::keyPressEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[25]) {
        return this->::QCalendarWidget::keyPressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QCalendarWidget::keyPressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[26]) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::leaveEvent(::QEvent * event)
{
    if (m_PyMethodCache[27]) {
        return this->::QWidget::leaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

int QCalendarWidgetWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[28])
        return this->::QWidget::metric(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QCalendarWidgetWrapper::minimumSizeHint() const
{
    if (m_PyMethodCache[29])
        return this->::QCalendarWidget::minimumSizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "minimumSizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QCalendarWidget::minimumSizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[30]) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[31]) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::mousePressEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[32]) {
        return this->::QCalendarWidget::mousePressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QCalendarWidget::mousePressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[33]) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::moveEvent(::QMoveEvent * event)
{
    if (m_PyMethodCache[34]) {
        return this->::QWidget::moveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "moveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCalendarWidgetWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    if (m_PyMethodCache[35]) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nativeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[35] = true;
        gil.release();
        return this->::QWidget::nativeEvent(eventType, message, result);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) && (PySequence_Size(pyResult.object()) == 2)) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<long>(), pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

void QCalendarWidgetWrapper::paintCell(::QPainter * painter, const ::QRect & rect, ::QDate date) const
{
    if (m_PyMethodCache[36]) {
        return this->::QCalendarWidget::paintCell(painter, rect, date);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintCell";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[36] = true;
        gil.release();
        return this->::QCalendarWidget::paintCell(painter, rect, date);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPaintEngine * QCalendarWidgetWrapper::paintEngine() const
{
    if (m_PyMethodCache[37])
        return this->::QWidget::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[37] = true;
        gil.release();
        return this->::QWidget::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::paintEvent(::QPaintEvent * event)
{
    if (m_PyMethodCache[38]) {
        return this->::QWidget::paintEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[38] = true;
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPaintDevice * QCalendarWidgetWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[39])
        return this->::QWidget::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[39] = true;
        gil.release();
        return this->::QWidget::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::resizeEvent(::QResizeEvent * event)
{
    if (m_PyMethodCache[40]) {
        return this->::QCalendarWidget::resizeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resizeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[40] = true;
        gil.release();
        return this->::QCalendarWidget::resizeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::setVisible(bool visible)
{
    if (m_PyMethodCache[41]) {
        return this->::QWidget::setVisible(visible);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[41] = true;
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPainter * QCalendarWidgetWrapper::sharedPainter() const
{
    if (m_PyMethodCache[42])
        return this->::QWidget::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[42] = true;
        gil.release();
        return this->::QWidget::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::showEvent(::QShowEvent * event)
{
    if (m_PyMethodCache[43]) {
        return this->::QWidget::showEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[43] = true;
        gil.release();
        return this->::QWidget::showEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QSize QCalendarWidgetWrapper::sizeHint() const
{
    if (m_PyMethodCache[44])
        return this->::QCalendarWidget::sizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[44] = true;
        gil.release();
        return this->::QCalendarWidget::sizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCalendarWidget", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCalendarWidgetWrapper::tabletEvent(::QTabletEvent * event)
{
    if (m_PyMethodCache[45]) {
        return this->::QWidget::tabletEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "tabletEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[45] = true;
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[46]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[46] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCalendarWidgetWrapper::wheelEvent(::QWheelEvent * event)
{
    if (m_PyMethodCache[47]) {
        return this->::QWidget::wheelEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[47] = true;
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QCalendarWidgetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCalendarWidget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCalendarWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCalendarWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCalendarWidgetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCalendarWidgetWrapper *>(this));
    return QCalendarWidget::qt_metacast(_clname);
}

QCalendarWidgetWrapper::~QCalendarWidgetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCalendarWidget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCalendarWidget >()))
        return -1;

    ::QCalendarWidgetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QCalendarWidget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCalendarWidget::QCalendarWidget(QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QCalendarWidget(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QCalendarWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCalendarWidget(QWidget*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) ::QCalendarWidgetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new ::QCalendarWidgetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCalendarWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QCalendarWidgetFunc_calendar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.calendar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // calendar()const
            QCalendar cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->calendar();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_clearMaximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.clearMaximumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearMaximumDate()
            cppSelf->clearMaximumDate();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_clearMinimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.clearMinimumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearMinimumDate()
            cppSelf->clearMinimumDate();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_dateEditAcceptDelay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.dateEditAcceptDelay";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dateEditAcceptDelay()const
            int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateEditAcceptDelay();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_dateTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.dateTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dateTextFormat", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::dateTextFormat()const->QMap< QDate,QTextCharFormat>
    // 1: QCalendarWidget::dateTextFormat(QDate)const->QTextCharFormat
    if (numArgs == 0) {
        overloadId = 0; // dateTextFormat()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))) {
        overloadId = 1; // dateTextFormat(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // dateTextFormat() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // dateTextFormat()const
                QMap<QDate,QTextCharFormat> cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateTextFormat();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QDate_QTextCharFormat_IDX], &cppResult);
            }
            break;
        }
        case 1: // dateTextFormat(QDate date) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // dateTextFormat(QDate)const
                QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->dateTextFormat(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.event";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.eventFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_firstDayOfWeek(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.firstDayOfWeek";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // firstDayOfWeek()const
            Qt::DayOfWeek cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->firstDayOfWeek();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_headerTextFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.headerTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // headerTextFormat()const
            QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->headerTextFormat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_horizontalHeaderFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.horizontalHeaderFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalHeaderFormat()const
            QCalendarWidget::HorizontalHeaderFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->horizontalHeaderFormat();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_isDateEditEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.isDateEditEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDateEditEnabled()const
            bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isDateEditEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_isGridVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.isGridVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isGridVisible()const
            bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isGridVisible();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_isNavigationBarVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.isNavigationBarVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNavigationBarVisible()const
            bool cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->isNavigationBarVisible();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.keyPressEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_maximumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.maximumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumDate()const
            QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->maximumDate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_minimumDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.minimumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumDate()const
            QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->minimumDate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_minimumSizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.minimumSizeHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumSizeHint()const
            QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::minimumSizeHint()
                : const_cast<const ::QCalendarWidget *>(cppSelf)->minimumSizeHint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_monthShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.monthShown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // monthShown()const
            int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->monthShown();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.mousePressEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_paintCell(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.paintCell";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "paintCell", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::paintCell(QPainter*,QRect,QDate)const
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[2])))) {
        overloadId = 0; // paintCell(QPainter*,QRect,QDate)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QDate cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintCell(QPainter*,QRect,QDate)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::paintCell(cppArg0, *cppArg1, cppArg2)
                : const_cast<const ::QCalendarWidget *>(cppSelf)->paintCell(cppArg0, *cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.resizeEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCalendarWidget::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_selectedDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.selectedDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedDate()const
            QDate cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->selectedDate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_selectionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.selectionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectionMode()const
            QCalendarWidget::SelectionMode cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->selectionMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_setCalendar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setCalendar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setCalendar(QCalendar)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArg)))) {
        overloadId = 0; // setCalendar(QCalendar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCalendar cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCalendar(QCalendar)
            cppSelf->setCalendar(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setCurrentPage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setCurrentPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCurrentPage", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setCurrentPage(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setCurrentPage(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentPage(int,int)
            cppSelf->setCurrentPage(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateEditAcceptDelay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setDateEditAcceptDelay";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setDateEditAcceptDelay(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDateEditAcceptDelay(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateEditAcceptDelay(int)
            cppSelf->setDateEditAcceptDelay(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateEditEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setDateEditEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setDateEditEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDateEditEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateEditEnabled(bool)
            cppSelf->setDateEditEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setDateRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setDateRange(QDate,QDate)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateRange(QDate,QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDate cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateRange(QDate,QDate)
            cppSelf->setDateRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setDateTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setDateTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTextFormat", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setDateTextFormat(QDate,QTextCharFormat)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setDateTextFormat(QDate,QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextCharFormat cppArg1_local;
        ::QTextCharFormat *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDateTextFormat(QDate,QTextCharFormat)
            cppSelf->setDateTextFormat(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setFirstDayOfWeek(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setFirstDayOfWeek";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setFirstDayOfWeek(Qt::DayOfWeek)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFirstDayOfWeek(Qt::DayOfWeek)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstDayOfWeek(Qt::DayOfWeek)
            cppSelf->setFirstDayOfWeek(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setGridVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setGridVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setGridVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setGridVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridVisible(bool)
            cppSelf->setGridVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setHeaderTextFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setHeaderTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setHeaderTextFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setHeaderTextFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeaderTextFormat(QTextCharFormat)
            cppSelf->setHeaderTextFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setHorizontalHeaderFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setHorizontalHeaderFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCalendarWidget::HorizontalHeaderFormat cppArg0{QCalendarWidget::NoHorizontalHeader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalHeaderFormat(QCalendarWidget::HorizontalHeaderFormat)
            cppSelf->setHorizontalHeaderFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setMaximumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setMaximumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setMaximumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMaximumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumDate(QDate)
            cppSelf->setMaximumDate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setMinimumDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setMinimumDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setMinimumDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setMinimumDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumDate(QDate)
            cppSelf->setMinimumDate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setNavigationBarVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setNavigationBarVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setNavigationBarVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setNavigationBarVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNavigationBarVisible(bool)
            cppSelf->setNavigationBarVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setSelectedDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setSelectedDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setSelectedDate(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // setSelectedDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectedDate(QDate)
            cppSelf->setSelectedDate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setSelectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setSelectionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setSelectionMode(QCalendarWidget::SelectionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectionMode(QCalendarWidget::SelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCalendarWidget::SelectionMode cppArg0{QCalendarWidget::NoSelection};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionMode(QCalendarWidget::SelectionMode)
            cppSelf->setSelectionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setVerticalHeaderFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setVerticalHeaderFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCalendarWidget::VerticalHeaderFormat cppArg0{QCalendarWidget::NoVerticalHeader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalHeaderFormat(QCalendarWidget::VerticalHeaderFormat)
            cppSelf->setVerticalHeaderFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_setWeekdayTextFormat(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.setWeekdayTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setWeekdayTextFormat", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCalendarWidget::setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTextCharFormat cppArg1_local;
        ::QTextCharFormat *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setWeekdayTextFormat(Qt::DayOfWeek,QTextCharFormat)
            cppSelf->setWeekdayTextFormat(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showNextMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showNextMonth";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showNextMonth()
            cppSelf->showNextMonth();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showNextYear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showNextYear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showNextYear()
            cppSelf->showNextYear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showPreviousMonth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showPreviousMonth";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showPreviousMonth()
            cppSelf->showPreviousMonth();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showPreviousYear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showPreviousYear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showPreviousYear()
            cppSelf->showPreviousYear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showSelectedDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showSelectedDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showSelectedDate()
            cppSelf->showSelectedDate();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_showToday(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.showToday";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showToday()
            cppSelf->showToday();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_sizeHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.sizeHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeHint()const
            QSize cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QCalendarWidget *>(cppSelf)->::QCalendarWidget::sizeHint()
                : const_cast<const ::QCalendarWidget *>(cppSelf)->sizeHint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_updateCell(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.updateCell";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::updateCell(QDate)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // updateCell(QDate)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCell(QDate)
            cppSelf->updateCell(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_updateCells(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.updateCells";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateCells()
            cppSelf->updateCells();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCalendarWidgetFunc_verticalHeaderFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.verticalHeaderFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // verticalHeaderFormat()const
            QCalendarWidget::VerticalHeaderFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->verticalHeaderFormat();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_weekdayTextFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.weekdayTextFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCalendarWidget::weekdayTextFormat(Qt::DayOfWeek)const->QTextCharFormat
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // weekdayTextFormat(Qt::DayOfWeek)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt::DayOfWeek cppArg0 = static_cast< ::Qt::DayOfWeek>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // weekdayTextFormat(Qt::DayOfWeek)const
            QTextCharFormat cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->weekdayTextFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCalendarWidgetFunc_yearShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QCalendarWidget.yearShown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // yearShown()const
            int cppResult = const_cast<const ::QCalendarWidget *>(cppSelf)->yearShown();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCalendarWidget_PropertyStrings[] = {
    "dateEditAcceptDelay::",
    "dateEditEnabled:isDateEditEnabled:",
    "firstDayOfWeek::",
    "gridVisible:isGridVisible:",
    "horizontalHeaderFormat::",
    "maximumDate::",
    "minimumDate::",
    "navigationBarVisible:isNavigationBarVisible:",
    "selectedDate::",
    "selectionMode::",
    "verticalHeaderFormat::",
    nullptr // Sentinel
};

static const char *Sbk_QCalendarWidget_EnumFlagInfo[] = {
    "HorizontalHeaderFormat:Enum",
    "SelectionMode:Enum",
    "VerticalHeaderFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCalendarWidget_methods[] = {
    {"calendar", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_calendar), METH_NOARGS, nullptr},
    {"clearMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_clearMaximumDate), METH_NOARGS, nullptr},
    {"clearMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_clearMinimumDate), METH_NOARGS, nullptr},
    {"dateEditAcceptDelay", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_dateEditAcceptDelay), METH_NOARGS, nullptr},
    {"dateTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_dateTextFormat), METH_VARARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_eventFilter), METH_VARARGS, nullptr},
    {"firstDayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_firstDayOfWeek), METH_NOARGS, nullptr},
    {"headerTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_headerTextFormat), METH_NOARGS, nullptr},
    {"horizontalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_horizontalHeaderFormat), METH_NOARGS, nullptr},
    {"isDateEditEnabled", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isDateEditEnabled), METH_NOARGS, nullptr},
    {"isGridVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isGridVisible), METH_NOARGS, nullptr},
    {"isNavigationBarVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_isNavigationBarVisible), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_keyPressEvent), METH_O, nullptr},
    {"maximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_maximumDate), METH_NOARGS, nullptr},
    {"minimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_minimumDate), METH_NOARGS, nullptr},
    {"minimumSizeHint", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_minimumSizeHint), METH_NOARGS, nullptr},
    {"monthShown", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_monthShown), METH_NOARGS, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_mousePressEvent), METH_O, nullptr},
    {"paintCell", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_paintCell), METH_VARARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_resizeEvent), METH_O, nullptr},
    {"selectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_selectedDate), METH_NOARGS, nullptr},
    {"selectionMode", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_selectionMode), METH_NOARGS, nullptr},
    {"setCalendar", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setCalendar), METH_O, nullptr},
    {"setCurrentPage", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setCurrentPage), METH_VARARGS, nullptr},
    {"setDateEditAcceptDelay", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateEditAcceptDelay), METH_O, nullptr},
    {"setDateEditEnabled", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateEditEnabled), METH_O, nullptr},
    {"setDateRange", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateRange), METH_VARARGS, nullptr},
    {"setDateTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setDateTextFormat), METH_VARARGS, nullptr},
    {"setFirstDayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setFirstDayOfWeek), METH_O, nullptr},
    {"setGridVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setGridVisible), METH_O, nullptr},
    {"setHeaderTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setHeaderTextFormat), METH_O, nullptr},
    {"setHorizontalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setHorizontalHeaderFormat), METH_O, nullptr},
    {"setMaximumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setMaximumDate), METH_O, nullptr},
    {"setMinimumDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setMinimumDate), METH_O, nullptr},
    {"setNavigationBarVisible", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setNavigationBarVisible), METH_O, nullptr},
    {"setSelectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setSelectedDate), METH_O, nullptr},
    {"setSelectionMode", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setSelectionMode), METH_O, nullptr},
    {"setVerticalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setVerticalHeaderFormat), METH_O, nullptr},
    {"setWeekdayTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_setWeekdayTextFormat), METH_VARARGS, nullptr},
    {"showNextMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showNextMonth), METH_NOARGS, nullptr},
    {"showNextYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showNextYear), METH_NOARGS, nullptr},
    {"showPreviousMonth", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showPreviousMonth), METH_NOARGS, nullptr},
    {"showPreviousYear", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showPreviousYear), METH_NOARGS, nullptr},
    {"showSelectedDate", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showSelectedDate), METH_NOARGS, nullptr},
    {"showToday", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_showToday), METH_NOARGS, nullptr},
    {"sizeHint", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_sizeHint), METH_NOARGS, nullptr},
    {"updateCell", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_updateCell), METH_O, nullptr},
    {"updateCells", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_updateCells), METH_NOARGS, nullptr},
    {"verticalHeaderFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_verticalHeaderFormat), METH_NOARGS, nullptr},
    {"weekdayTextFormat", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_weekdayTextFormat), METH_O, nullptr},
    {"yearShown", reinterpret_cast<PyCFunction>(Sbk_QCalendarWidgetFunc_yearShown), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCalendarWidget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCalendarWidget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCalendarWidgetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCalendarWidget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCalendarWidget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QCalendarWidgetSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QCalendarWidget *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCalendarWidget_Type = nullptr;
static PyTypeObject *Sbk_QCalendarWidget_TypeF(void)
{
    return _Sbk_QCalendarWidget_Type;
}

static PyType_Slot Sbk_QCalendarWidget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCalendarWidget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCalendarWidget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCalendarWidget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCalendarWidget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCalendarWidget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCalendarWidget_spec = {
    "2:PySide6.QtWidgets.QCalendarWidget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCalendarWidget_slots
};

} //extern "C"

static void *Sbk_QCalendarWidget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCalendarWidget *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QCalendarWidget *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QCalendarWidget_HorizontalHeaderFormat_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::HorizontalHeaderFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::HorizontalHeaderFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QCalendarWidget_HorizontalHeaderFormat_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX])))
        return QCalendarWidget_HorizontalHeaderFormat_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat;
    return {};
}
static PyObject *QCalendarWidget_HorizontalHeaderFormat_CppToPython_QCalendarWidget_HorizontalHeaderFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCalendarWidget::HorizontalHeaderFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX]), castCppIn);

}

static void QCalendarWidget_VerticalHeaderFormat_PythonToCpp_QCalendarWidget_VerticalHeaderFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::VerticalHeaderFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::VerticalHeaderFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QCalendarWidget_VerticalHeaderFormat_PythonToCpp_QCalendarWidget_VerticalHeaderFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX])))
        return QCalendarWidget_VerticalHeaderFormat_PythonToCpp_QCalendarWidget_VerticalHeaderFormat;
    return {};
}
static PyObject *QCalendarWidget_VerticalHeaderFormat_CppToPython_QCalendarWidget_VerticalHeaderFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCalendarWidget::VerticalHeaderFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX]), castCppIn);

}

static void QCalendarWidget_SelectionMode_PythonToCpp_QCalendarWidget_SelectionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCalendarWidget::SelectionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCalendarWidget::SelectionMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCalendarWidget_SelectionMode_PythonToCpp_QCalendarWidget_SelectionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX])))
        return QCalendarWidget_SelectionMode_PythonToCpp_QCalendarWidget_SelectionMode;
    return {};
}
static PyObject *QCalendarWidget_SelectionMode_CppToPython_QCalendarWidget_SelectionMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCalendarWidget::SelectionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCalendarWidget_PythonToCpp_QCalendarWidget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCalendarWidget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCalendarWidget_PythonToCpp_QCalendarWidget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCalendarWidget_TypeF()))
        return QCalendarWidget_PythonToCpp_QCalendarWidget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCalendarWidget_PTR_CppToPython_QCalendarWidget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCalendarWidget *>(const_cast<void *>(cppIn)), Sbk_QCalendarWidget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCalendarWidget_SignatureStrings[] = {
    "PySide6.QtWidgets.QCalendarWidget(self,parent:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QCalendarWidget.calendar(self)->PySide6.QtCore.QCalendar",
    "PySide6.QtWidgets.QCalendarWidget.clearMaximumDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.clearMinimumDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.dateEditAcceptDelay(self)->int",
    "1:PySide6.QtWidgets.QCalendarWidget.dateTextFormat(self)->QMap[PySide6.QtCore.QDate, PySide6.QtGui.QTextCharFormat]",
    "0:PySide6.QtWidgets.QCalendarWidget.dateTextFormat(self,date:PySide6.QtCore.QDate)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QCalendarWidget.eventFilter(self,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QCalendarWidget.firstDayOfWeek(self)->PySide6.QtCore.Qt.DayOfWeek",
    "PySide6.QtWidgets.QCalendarWidget.headerTextFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.horizontalHeaderFormat(self)->PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat",
    "PySide6.QtWidgets.QCalendarWidget.isDateEditEnabled(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.isGridVisible(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.isNavigationBarVisible(self)->bool",
    "PySide6.QtWidgets.QCalendarWidget.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QCalendarWidget.maximumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.minimumDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.minimumSizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QCalendarWidget.monthShown(self)->int",
    "PySide6.QtWidgets.QCalendarWidget.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QCalendarWidget.paintCell(self,painter:PySide6.QtGui.QPainter,rect:PySide6.QtCore.QRect,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QCalendarWidget.selectedDate(self)->PySide6.QtCore.QDate",
    "PySide6.QtWidgets.QCalendarWidget.selectionMode(self)->PySide6.QtWidgets.QCalendarWidget.SelectionMode",
    "PySide6.QtWidgets.QCalendarWidget.setCalendar(self,calendar:PySide6.QtCore.QCalendar)",
    "PySide6.QtWidgets.QCalendarWidget.setCurrentPage(self,year:int,month:int)",
    "PySide6.QtWidgets.QCalendarWidget.setDateEditAcceptDelay(self,delay:int)",
    "PySide6.QtWidgets.QCalendarWidget.setDateEditEnabled(self,enable:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setDateRange(self,min:PySide6.QtCore.QDate,max:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setDateTextFormat(self,date:PySide6.QtCore.QDate,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setFirstDayOfWeek(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek)",
    "PySide6.QtWidgets.QCalendarWidget.setGridVisible(self,show:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setHeaderTextFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setHorizontalHeaderFormat(self,format:PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setMaximumDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setMinimumDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setNavigationBarVisible(self,visible:bool)",
    "PySide6.QtWidgets.QCalendarWidget.setSelectedDate(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.setSelectionMode(self,mode:PySide6.QtWidgets.QCalendarWidget.SelectionMode)",
    "PySide6.QtWidgets.QCalendarWidget.setVerticalHeaderFormat(self,format:PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat)",
    "PySide6.QtWidgets.QCalendarWidget.setWeekdayTextFormat(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QCalendarWidget.showNextMonth(self)",
    "PySide6.QtWidgets.QCalendarWidget.showNextYear(self)",
    "PySide6.QtWidgets.QCalendarWidget.showPreviousMonth(self)",
    "PySide6.QtWidgets.QCalendarWidget.showPreviousYear(self)",
    "PySide6.QtWidgets.QCalendarWidget.showSelectedDate(self)",
    "PySide6.QtWidgets.QCalendarWidget.showToday(self)",
    "PySide6.QtWidgets.QCalendarWidget.sizeHint(self)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QCalendarWidget.updateCell(self,date:PySide6.QtCore.QDate)",
    "PySide6.QtWidgets.QCalendarWidget.updateCells(self)",
    "PySide6.QtWidgets.QCalendarWidget.verticalHeaderFormat(self)->PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat",
    "PySide6.QtWidgets.QCalendarWidget.weekdayTextFormat(self,dayOfWeek:PySide6.QtCore.Qt.DayOfWeek)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QCalendarWidget.yearShown(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QCalendarWidget(PyObject *module)
{
    _Sbk_QCalendarWidget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCalendarWidget",
        "QCalendarWidget*",
        &Sbk_QCalendarWidget_spec,
        &Shiboken::callCppDestructor< ::QCalendarWidget >,
        Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QCalendarWidget_TypeF(); // references _Sbk_QCalendarWidget_Type
    InitSignatureStrings(pyType, QCalendarWidget_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCalendarWidget_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCalendarWidget_PythonToCpp_QCalendarWidget_PTR,
        is_QCalendarWidget_PythonToCpp_QCalendarWidget_PTR_Convertible,
        QCalendarWidget_PTR_CppToPython_QCalendarWidget);

    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget");
    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget*");
    Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCalendarWidget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCalendarWidgetWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QCalendarWidget_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QCalendarWidget_TypeF(), &Sbk_QCalendarWidgetSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCalendarWidget_TypeF(), &Sbk_QCalendarWidget_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCalendarWidget_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HorizontalHeaderFormat'.
    const char *HorizontalHeaderFormat_Initializer[] = {
        "NoHorizontalHeader",
        "SingleLetterDayNames",
        "ShortDayNames",
        "LongDayNames",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HorizontalHeaderFormat_InitializerValues[] = {
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::NoHorizontalHeader),   //  0x00  0
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::SingleLetterDayNames), //  0x01  1
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::ShortDayNames),        //  0x02  2
        uint8_t(QCalendarWidget::HorizontalHeaderFormat::LongDayNames)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat",
        HorizontalHeaderFormat_Initializer, HorizontalHeaderFormat_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_HorizontalHeaderFormat_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::HorizontalHeaderFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_HorizontalHeaderFormat_CppToPython_QCalendarWidget_HorizontalHeaderFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCalendarWidget_HorizontalHeaderFormat_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat,
            is_QCalendarWidget_HorizontalHeaderFormat_PythonToCpp_QCalendarWidget_HorizontalHeaderFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::HorizontalHeaderFormat");
        Shiboken::Conversions::registerConverterName(converter, "HorizontalHeaderFormat");
    }
    // End of 'HorizontalHeaderFormat' enum.

    // Initialization of enum 'VerticalHeaderFormat'.
    const char *VerticalHeaderFormat_Initializer[] = {
        "NoVerticalHeader",
        "ISOWeekNumbers",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t VerticalHeaderFormat_InitializerValues[] = {
        uint8_t(QCalendarWidget::VerticalHeaderFormat::NoVerticalHeader), //  0x00  0
        uint8_t(QCalendarWidget::VerticalHeaderFormat::ISOWeekNumbers)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat",
        VerticalHeaderFormat_Initializer, VerticalHeaderFormat_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_VerticalHeaderFormat_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::VerticalHeaderFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_VerticalHeaderFormat_CppToPython_QCalendarWidget_VerticalHeaderFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCalendarWidget_VerticalHeaderFormat_PythonToCpp_QCalendarWidget_VerticalHeaderFormat,
            is_QCalendarWidget_VerticalHeaderFormat_PythonToCpp_QCalendarWidget_VerticalHeaderFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::VerticalHeaderFormat");
        Shiboken::Conversions::registerConverterName(converter, "VerticalHeaderFormat");
    }
    // End of 'VerticalHeaderFormat' enum.

    // Initialization of enum 'SelectionMode'.
    const char *SelectionMode_Initializer[] = {
        "NoSelection",
        "SingleSelection",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionMode_InitializerValues[] = {
        uint8_t(QCalendarWidget::SelectionMode::NoSelection),    //  0x00  0
        uint8_t(QCalendarWidget::SelectionMode::SingleSelection) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCalendarWidget_TypeF(),
        "2:PySide6.QtWidgets.QCalendarWidget.SelectionMode",
        SelectionMode_Initializer, SelectionMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_SelectionMode_IDX].type = EType;
    // Register converter for enum 'QCalendarWidget::SelectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCalendarWidget_SelectionMode_CppToPython_QCalendarWidget_SelectionMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCalendarWidget_SelectionMode_PythonToCpp_QCalendarWidget_SelectionMode,
            is_QCalendarWidget_SelectionMode_PythonToCpp_QCalendarWidget_SelectionMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCalendarWidget::SelectionMode");
        Shiboken::Conversions::registerConverterName(converter, "SelectionMode");
    }
    // End of 'SelectionMode' enum.

    PySide::Signal::registerSignals(pyType, &::QCalendarWidget::staticMetaObject);
    qRegisterMetaType< ::QCalendarWidget::HorizontalHeaderFormat >("QCalendarWidget::HorizontalHeaderFormat");
    qRegisterMetaType< ::QCalendarWidget::VerticalHeaderFormat >("QCalendarWidget::VerticalHeaderFormat");
    qRegisterMetaType< ::QCalendarWidget::SelectionMode >("QCalendarWidget::SelectionMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCalendarWidget::staticMetaObject, sizeof(QCalendarWidgetWrapper));

    return pyType;
}
