// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyle_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtWidgets/qapplication.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QStyleWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QStyleWrapper::QStyleWrapper() : QStyle()
{
    resetPyMethodCache();
    // ... middle
}

void QStyleWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::drawComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QPainter * p, const ::QWidget * widget) const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawComplexControl");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawComplexControl";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawComplexControl");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };

    const bool invalidateArg3 = Py_REFCNT(pyArgArray[2]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
    bool invalidateArg3 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 2)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(pyArgArray[2]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 2));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::drawControl(::QStyle::ControlElement element, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget) const
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawControl");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawControl";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawControl");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX])))->converter, &element),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };

    const bool invalidateArg3 = Py_REFCNT(pyArgArray[2]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX])))->converter, &element),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
    bool invalidateArg3 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 2)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(pyArgArray[2]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 2));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::drawItemPixmap(::QPainter * painter, const ::QRect & rect, int alignment, const ::QPixmap & pixmap) const
{
    if (m_PyMethodCache[6]) {
        return this->::QStyle::drawItemPixmap(painter, rect, alignment, pixmap);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawItemPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QStyle::drawItemPixmap(painter, rect, alignment, pixmap);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &alignment),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNiN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        alignment,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::drawItemText(::QPainter * painter, const ::QRect & rect, int flags, const ::QPalette & pal, bool enabled, const ::QString & text, ::QPalette::ColorRole textRole) const
{
    if (m_PyMethodCache[7]) {
        return this->::QStyle::drawItemText(painter, rect, flags, pal, enabled, text, textRole);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawItemText";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QStyle::drawItemText(painter, rect, flags, pal, enabled, text, textRole);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[7] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &flags),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &pal),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &enabled),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, &textRole)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNiNNNN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect),
        flags,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &pal),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &enabled),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, &textRole)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 7, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
    Py_DECREF(pyArgArray[4]);
    Py_DECREF(pyArgArray[5]);
    Py_DECREF(pyArgArray[6]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::drawPrimitive(::QStyle::PrimitiveElement pe, const ::QStyleOption * opt, ::QPainter * p, const ::QWidget * widget) const
{
    if (m_PyMethodCache[8]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawPrimitive");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawPrimitive";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.drawPrimitive");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX])))->converter, &pe),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };

    const bool invalidateArg3 = Py_REFCNT(pyArgArray[2]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX])))->converter, &pe),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), p),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
    bool invalidateArg3 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 2)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(pyArgArray[2]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 2));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QStyleWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[9])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QStyleWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[10])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPixmap QStyleWrapper::generatedIconPixmap(::QIcon::Mode iconMode, const ::QPixmap & pixmap, const ::QStyleOption * opt) const
{
    if (m_PyMethodCache[11]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.generatedIconPixmap");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "generatedIconPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.generatedIconPixmap");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_Mode_IDX])))->converter, &iconMode),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_Mode_IDX])))->converter, &iconMode),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QPixmap >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPixmap cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QStyle::SubControl QStyleWrapper::hitTestComplexControl(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, const ::QPoint & pt, const ::QWidget * widget) const
{
    if (m_PyMethodCache[12]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.hitTestComplexControl");
        return QStyle::SC_None;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QStyle::SC_None;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hitTestComplexControl";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.hitTestComplexControl");
        return QStyle::SC_None;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &pt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &pt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QStyle::SC_None;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QStyle::SubControl >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QStyle::SC_None;
    }
    ::QStyle::SubControl cppResult{QStyle::SC_None};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRect QStyleWrapper::itemPixmapRect(const ::QRect & r, int flags, const ::QPixmap & pixmap) const
{
    if (m_PyMethodCache[13])
        return this->::QStyle::itemPixmapRect(r, flags, pixmap);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "itemPixmapRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QStyle::itemPixmapRect(r, flags, pixmap);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &flags),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NiN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r),
        flags,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &pixmap)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QRect >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRect cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRect QStyleWrapper::itemTextRect(const ::QFontMetrics & fm, const ::QRect & r, int flags, bool enabled, const ::QString & text) const
{
    if (m_PyMethodCache[14])
        return this->::QStyle::itemTextRect(fm, r, flags, enabled, text);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "itemTextRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QStyle::itemTextRect(fm, r, flags, enabled, text);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[5] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &fm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &flags),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &enabled),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNiNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &fm),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &r),
        flags,
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &enabled),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 5, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
    Py_DECREF(pyArgArray[4]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QRect >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRect cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QStyleWrapper::layoutSpacing(::QSizePolicy::ControlType control1, ::QSizePolicy::ControlType control2, ::Qt::Orientation orientation, const ::QStyleOption * option, const ::QWidget * widget) const
{
    if (m_PyMethodCache[15]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.layoutSpacing");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "layoutSpacing";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.layoutSpacing");
        return 0;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[5] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, &control1),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, &control2),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, &orientation),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, &control1),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, &control2),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, &orientation),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 5, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
    Py_DECREF(pyArgArray[4]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QStyleWrapper::pixelMetric(::QStyle::PixelMetric metric, const ::QStyleOption * option, const ::QWidget * widget) const
{
    if (m_PyMethodCache[16]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.pixelMetric");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "pixelMetric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.pixelMetric");
        return 0;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX])))->converter, &metric),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX])))->converter, &metric),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStyleWrapper::polish(::QApplication * application)
{
    if (m_PyMethodCache[17]) {
        return this->::QStyle::polish(application);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "polish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QStyle::polish(application);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), application)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), application)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::polish(::QPalette & palette)
{
    if (m_PyMethodCache[18]) {
        return this->::QStyle::polish(palette);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "polish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QStyle::polish(palette);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &palette)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &palette)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::polish(::QWidget * widget)
{
    if (m_PyMethodCache[19]) {
        return this->::QStyle::polish(widget);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "polish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QStyle::polish(widget);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QSize QStyleWrapper::sizeFromContents(::QStyle::ContentsType ct, const ::QStyleOption * opt, const ::QSize & contentsSize, const ::QWidget * w) const
{
    if (m_PyMethodCache[20]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.sizeFromContents");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeFromContents";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.sizeFromContents");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX])))->converter, &ct),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &contentsSize),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), w)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX])))->converter, &ct),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &contentsSize),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), w)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QIcon QStyleWrapper::standardIcon(::QStyle::StandardPixmap standardIcon, const ::QStyleOption * option, const ::QWidget * widget) const
{
    if (m_PyMethodCache[21]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.standardIcon");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "standardIcon";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.standardIcon");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, &standardIcon),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, &standardIcon),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QIcon >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QIcon cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPalette QStyleWrapper::standardPalette() const
{
    if (m_PyMethodCache[22])
        return this->::QStyle::standardPalette();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "standardPalette";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QStyle::standardPalette();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QPalette >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPalette cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPixmap QStyleWrapper::standardPixmap(::QStyle::StandardPixmap standardPixmap, const ::QStyleOption * opt, const ::QWidget * widget) const
{
    if (m_PyMethodCache[23]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.standardPixmap");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "standardPixmap";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.standardPixmap");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, &standardPixmap),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, &standardPixmap),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QPixmap >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QPixmap cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QStyleWrapper::styleHint(::QStyle::StyleHint stylehint, const ::QStyleOption * opt, const ::QWidget * widget, ::QStyleHintReturn * returnData) const
{
    if (m_PyMethodCache[24]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.styleHint");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "styleHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.styleHint");
        return 0;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX])))->converter, &stylehint),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), returnData)
    };

    const bool invalidateArg4 = Py_REFCNT(pyArgArray[3]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX])))->converter, &stylehint),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), opt),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), returnData)
    ));
    bool invalidateArg4 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 3)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    if (invalidateArg4)
        Shiboken::Object::invalidate(pyArgArray[3]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg4)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 3));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRect QStyleWrapper::subControlRect(::QStyle::ComplexControl cc, const ::QStyleOptionComplex * opt, ::QStyle::SubControl sc, const ::QWidget * widget) const
{
    if (m_PyMethodCache[25]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.subControlRect");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "subControlRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.subControlRect");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))->converter, &sc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, &cc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), opt),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))->converter, &sc),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QRect >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRect cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRect QStyleWrapper::subElementRect(::QStyle::SubElement subElement, const ::QStyleOption * option, const ::QWidget * widget) const
{
    if (m_PyMethodCache[26]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.subElementRect");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "subElementRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        Shiboken::Errors::setPureVirtualMethodError("QStyle.subElementRect");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX])))->converter, &subElement),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX])))->converter, &subElement),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), option),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QStyle", funcName, Shiboken::SbkType< QRect >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRect cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QStyleWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[27]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::unpolish(::QApplication * application)
{
    if (m_PyMethodCache[28]) {
        return this->::QStyle::unpolish(application);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "unpolish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QStyle::unpolish(application);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), application)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), application)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QStyleWrapper::unpolish(::QWidget * widget)
{
    if (m_PyMethodCache[29]) {
        return this->::QStyle::unpolish(widget);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "unpolish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QStyle::unpolish(widget);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), widget)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QStyleWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QStyle::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QStyleWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QStyle::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QStyleWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QStyleWrapper *>(this));
    return QStyle::qt_metacast(_clname);
}

QStyleWrapper::~QStyleWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyle_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QStyle");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyle >()))
        return -1;

    ::QStyleWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QStyle()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) ::QStyleWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new ::QStyleWrapper();
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyle >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QStyleFunc_alignedRect(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.alignedRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "alignedRect", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)->QRect
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[3])))) {
        overloadId = 0; // alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::AlignmentFlag> cppArg1 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSize cppArg2_local;
        ::QSize *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRect cppArg3_local;
        ::QRect *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);


        if (Shiboken::Errors::occurred() == nullptr) {
            // alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)
            QRect cppResult = ::QStyle::alignedRect(cppArg0, cppArg1, *cppArg2, *cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_combinedLayoutSpacing(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.combinedLayoutSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:combinedLayoutSpacing", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*=,QWidget*=)const->int
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[4])))) {
                overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QSizePolicy::ControlType> cppArg0 = QFlags<QSizePolicy::ControlType>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QSizePolicy::ControlType> cppArg1 = QFlags<QSizePolicy::ControlType>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::Qt::Orientation cppArg2 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QStyleOption *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QWidget *cppArg4 = nullptr;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
            int cppResult = const_cast<const ::QStyle *>(cppSelf)->combinedLayoutSpacing(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_drawComplexControl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.drawComplexControl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:drawComplexControl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*=)const
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::ComplexControl cppArg0{QStyle::CC_SpinBox};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionComplex *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPainter *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.drawComplexControl");
                return {};
            }
            const_cast<const ::QStyle *>(cppSelf)->drawComplexControl(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_drawControl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.drawControl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:drawControl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*=)const
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::ControlElement cppArg0{QStyle::CE_PushButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPainter *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.drawControl");
                return {};
            }
            const_cast<const ::QStyle *>(cppSelf)->drawControl(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_drawItemPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.drawItemPixmap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawItemPixmap", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[3])))) {
        overloadId = 0; // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QPixmap cppArg3_local;
        ::QPixmap *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QStyle *>(cppSelf)->::QStyle::drawItemPixmap(cppArg0, *cppArg1, cppArg2, *cppArg3)
                : const_cast<const ::QStyle *>(cppSelf)->drawItemPixmap(cppArg0, *cppArg1, cppArg2, *cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_drawItemText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.drawItemText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 6, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOO:drawItemText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole=)const
    if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, (pyArgs[6])))) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_textRole = Shiboken::String::createStaticString("textRole");
            if (PyDict_Contains(kwds, key_textRole) != 0) {
                value = PyDict_GetItem(kwds, key_textRole);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_textRole);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_ColorRole_IDX])))->converter, (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_textRole);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QPalette cppArg3_local;
        ::QPalette *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);

        bool cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QString cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        ::QPalette::ColorRole cppArg6(QPalette::NoRole);
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QStyle *>(cppSelf)->::QStyle::drawItemText(cppArg0, *cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6)
                : const_cast<const ::QStyle *>(cppSelf)->drawItemText(cppArg0, *cppArg1, cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_drawPrimitive(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.drawPrimitive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:drawPrimitive", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*=)const
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::PrimitiveElement cppArg0{QStyle::PE_Frame};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPainter *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.drawPrimitive");
                return {};
            }
            const_cast<const ::QStyle *>(cppSelf)->drawPrimitive(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_generatedIconPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.generatedIconPixmap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "generatedIconPixmap", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const->QPixmap
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_Mode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[2])))) {
        overloadId = 0; // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QIcon::Mode cppArg0{QIcon::Normal};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPixmap cppArg1_local;
        ::QPixmap *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QStyleOption *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.generatedIconPixmap");
                return {};
            }
            QPixmap cppResult = const_cast<const ::QStyle *>(cppSelf)->generatedIconPixmap(cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_hitTestComplexControl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.hitTestComplexControl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:hitTestComplexControl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*=)const->QStyle::SubControl
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::ComplexControl cppArg0{QStyle::CC_SpinBox};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionComplex *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPoint cppArg2_local;
        ::QPoint *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.hitTestComplexControl");
                return {};
            }
            QStyle::SubControl cppResult = const_cast<const ::QStyle *>(cppSelf)->hitTestComplexControl(cppArg0, cppArg1, *cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_itemPixmapRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.itemPixmapRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemPixmapRect", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::itemPixmapRect(QRect,int,QPixmap)const->QRect
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[2])))) {
        overloadId = 0; // itemPixmapRect(QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRect cppArg0_local;
        ::QRect *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPixmap cppArg2_local;
        ::QPixmap *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // itemPixmapRect(QRect,int,QPixmap)const
            QRect cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QStyle *>(cppSelf)->::QStyle::itemPixmapRect(*cppArg0, cppArg1, *cppArg2)
                : const_cast<const ::QStyle *>(cppSelf)->itemPixmapRect(*cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_itemTextRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.itemTextRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemTextRect", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::itemTextRect(QFontMetrics,QRect,int,bool,QString)const->QRect
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
        overloadId = 0; // itemTextRect(QFontMetrics,QRect,int,bool,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFontMetrics cppArg0_local = ::QFontMetrics(::QFont());
        ::QFontMetrics *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        bool cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemTextRect(QFontMetrics,QRect,int,bool,QString)const
            QRect cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QStyle *>(cppSelf)->::QStyle::itemTextRect(*cppArg0, *cppArg1, cppArg2, cppArg3, cppArg4)
                : const_cast<const ::QStyle *>(cppSelf)->itemTextRect(*cppArg0, *cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_layoutSpacing(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.layoutSpacing";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:layoutSpacing", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*=,const QWidget*=)const->int
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QSizePolicy_ControlType_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX])))->converter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[4])))) {
                overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QSizePolicy::ControlType cppArg0 = static_cast< ::QSizePolicy::ControlType>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QSizePolicy::ControlType cppArg1 = static_cast< ::QSizePolicy::ControlType>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::Qt::Orientation cppArg2 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QStyleOption *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QWidget *cppArg4 = nullptr;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.layoutSpacing");
                return {};
            }
            int cppResult = const_cast<const ::QStyle *>(cppSelf)->layoutSpacing(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QString cppResult = const_cast<const ::QStyle *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_pixelMetric(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.pixelMetric";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:pixelMetric", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::pixelMetric(QStyle::PixelMetric,const QStyleOption*=,const QWidget*=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::PixelMetric cppArg0{QStyle::PM_ButtonMargin};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.pixelMetric");
                return {};
            }
            int cppResult = const_cast<const ::QStyle *>(cppSelf)->pixelMetric(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_polish(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.polish";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyle::polish(QWidget*)
    // 1: QStyle::polish(QPalette&)
    // 2: QStyle::polish(QApplication*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), (pyArg)))) {
        overloadId = 2; // polish(QApplication*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArg)))) {
        overloadId = 1; // polish(QPalette&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // polish(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // polish(QWidget * widget)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // polish(QWidget*)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QStyle::polish(cppArg0)
                    : cppSelf->polish(cppArg0);
            }
            break;
        }
        case 1: // polish(QPalette & palette)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPalette cppArg0_local;
            ::QPalette *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // polish(QPalette&)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QStyle::polish(*cppArg0)
                    : cppSelf->polish(*cppArg0);
            }
            break;
        }
        case 2: // polish(QApplication * application)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QApplication *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // polish(QApplication*)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QStyle::polish(cppArg0)
                    : cppSelf->polish(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_proxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.proxy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // proxy()const
            const QStyle * cppResult = const_cast<const ::QStyle *>(cppSelf)->proxy();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_sizeFromContents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.sizeFromContents";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:sizeFromContents", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*=)const->QSize
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_w = Shiboken::String::createStaticString("w");
            if (PyDict_Contains(kwds, key_w) != 0) {
                value = PyDict_GetItem(kwds, key_w);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_w);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_w);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::ContentsType cppArg0{QStyle::CT_PushButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSize cppArg2_local;
        ::QSize *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.sizeFromContents");
                return {};
            }
            QSize cppResult = const_cast<const ::QStyle *>(cppSelf)->sizeFromContents(cppArg0, cppArg1, *cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_sliderPositionFromValue(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.sliderPositionFromValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:sliderPositionFromValue", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::sliderPositionFromValue(int,int,int,int,bool=)->int
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // sliderPositionFromValue(int,int,int,int,bool)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
            overloadId = 0; // sliderPositionFromValue(int,int,int,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_upsideDown = Shiboken::String::createStaticString("upsideDown");
            if (PyDict_Contains(kwds, key_upsideDown) != 0) {
                value = PyDict_GetItem(kwds, key_upsideDown);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_upsideDown);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_upsideDown);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        bool cppArg4 = false;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sliderPositionFromValue(int,int,int,int,bool)
            int cppResult = ::QStyle::sliderPositionFromValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_sliderValueFromPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.sliderValueFromPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:sliderValueFromPosition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::sliderValueFromPosition(int,int,int,int,bool=)->int
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // sliderValueFromPosition(int,int,int,int,bool)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
            overloadId = 0; // sliderValueFromPosition(int,int,int,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_upsideDown = Shiboken::String::createStaticString("upsideDown");
            if (PyDict_Contains(kwds, key_upsideDown) != 0) {
                value = PyDict_GetItem(kwds, key_upsideDown);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_upsideDown);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_upsideDown);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        bool cppArg4 = false;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sliderValueFromPosition(int,int,int,int,bool)
            int cppResult = ::QStyle::sliderValueFromPosition(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_standardIcon(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.standardIcon";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:standardIcon", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::standardIcon(QStyle::StandardPixmap,const QStyleOption*=,const QWidget*=)const->QIcon
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_option = Shiboken::String::createStaticString("option");
            if (PyDict_Contains(kwds, key_option) != 0) {
                value = PyDict_GetItem(kwds, key_option);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_option);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_option);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::StandardPixmap cppArg0{QStyle::SP_TitleBarMenuButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.standardIcon");
                return {};
            }
            QIcon cppResult = const_cast<const ::QStyle *>(cppSelf)->standardIcon(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_standardPalette(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.standardPalette";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardPalette()const
            QPalette cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QStyle *>(cppSelf)->::QStyle::standardPalette()
                : const_cast<const ::QStyle *>(cppSelf)->standardPalette();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_standardPixmap(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.standardPixmap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:standardPixmap", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::standardPixmap(QStyle::StandardPixmap,const QStyleOption*=,const QWidget*=)const->QPixmap
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_opt = Shiboken::String::createStaticString("opt");
            if (PyDict_Contains(kwds, key_opt) != 0) {
                value = PyDict_GetItem(kwds, key_opt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_opt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_opt);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::StandardPixmap cppArg0{QStyle::SP_TitleBarMenuButton};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.standardPixmap");
                return {};
            }
            QPixmap cppResult = const_cast<const ::QStyle *>(cppSelf)->standardPixmap(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_styleHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.styleHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:styleHint", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::styleHint(QStyle::StyleHint,const QStyleOption*=,const QWidget*=,QStyleHintReturn*=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), (pyArgs[3])))) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_opt = Shiboken::String::createStaticString("opt");
            if (PyDict_Contains(kwds, key_opt) != 0) {
                value = PyDict_GetItem(kwds, key_opt);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_opt);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_opt);
            }
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            static PyObject *const key_returnData = Shiboken::String::createStaticString("returnData");
            if (PyDict_Contains(kwds, key_returnData) != 0) {
                value = PyDict_GetItem(kwds, key_returnData);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_returnData);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_returnData);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::StyleHint cppArg0{QStyle::SH_EtchDisabledText};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QStyleHintReturn *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.styleHint");
                return {};
            }
            int cppResult = const_cast<const ::QStyle *>(cppSelf)->styleHint(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_subControlRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.subControlRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:subControlRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*=)const->QRect
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))->converter, (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3])))) {
            overloadId = 0; // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::ComplexControl cppArg0{QStyle::CC_SpinBox};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOptionComplex *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QStyle::SubControl cppArg2{QStyle::SC_None};
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QWidget *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.subControlRect");
                return {};
            }
            QRect cppResult = const_cast<const ::QStyle *>(cppSelf)->subControlRect(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_subElementRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.subElementRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:subElementRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStyle::subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*=)const->QRect
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_widget = Shiboken::String::createStaticString("widget");
            if (PyDict_Contains(kwds, key_widget) != 0) {
                value = PyDict_GetItem(kwds, key_widget);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_widget);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_widget);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QStyle::SubElement cppArg0{QStyle::SE_PushButtonContents};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QStyleOption *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QStyle.subElementRect");
                return {};
            }
            QRect cppResult = const_cast<const ::QStyle *>(cppSelf)->subElementRect(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_unpolish(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.unpolish";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStyle::unpolish(QWidget*)
    // 1: QStyle::unpolish(QApplication*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]), (pyArg)))) {
        overloadId = 1; // unpolish(QApplication*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // unpolish(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // unpolish(QWidget * widget)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // unpolish(QWidget*)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QStyle::unpolish(cppArg0)
                    : cppSelf->unpolish(cppArg0);
            }
            break;
        }
        case 1: // unpolish(QApplication * application)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QApplication *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // unpolish(QApplication*)
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QStyle::unpolish(cppArg0)
                    : cppSelf->unpolish(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QStyleFunc_visualAlignment(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.visualAlignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "visualAlignment", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)->QFlags<Qt::AlignmentFlag>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::AlignmentFlag> cppArg1 = QFlags<Qt::AlignmentFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)
            QFlags<Qt::AlignmentFlag> cppResult = ::QStyle::visualAlignment(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_visualPos(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.visualPos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "visualPos", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::visualPos(Qt::LayoutDirection,QRect,QPoint)->QPoint
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
        overloadId = 0; // visualPos(Qt::LayoutDirection,QRect,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPoint cppArg2_local;
        ::QPoint *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualPos(Qt::LayoutDirection,QRect,QPoint)
            QPoint cppResult = ::QStyle::visualPos(cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStyleFunc_visualRect(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyle.visualRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "visualRect", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QStyle::visualRect(Qt::LayoutDirection,QRect,QRect)->QRect
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
        overloadId = 0; // visualRect(Qt::LayoutDirection,QRect,QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRect cppArg2_local;
        ::QRect *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // visualRect(Qt::LayoutDirection,QRect,QRect)
            QRect cppResult = ::QStyle::visualRect(cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStyle_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyle_EnumFlagInfo[] = {
    "ComplexControl:IntEnum",
    "ContentsType:IntEnum",
    "ControlElement:IntEnum",
    "PixelMetric:IntEnum",
    "PrimitiveElement:IntEnum",
    "RequestSoftwareInputPanel:Enum",
    "StandardPixmap:IntEnum",
    "StateFlag:Flag:State",
    "StyleHint:IntEnum",
    "SubControl:Flag:SubControls",
    "SubElement:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyle_methods[] = {
    {"alignedRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_alignedRect), METH_VARARGS|METH_STATIC, nullptr},
    {"combinedLayoutSpacing", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_combinedLayoutSpacing), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawComplexControl", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_drawComplexControl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawControl", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_drawControl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawItemPixmap", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_drawItemPixmap), METH_VARARGS, nullptr},
    {"drawItemText", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_drawItemText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawPrimitive", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_drawPrimitive), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"generatedIconPixmap", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_generatedIconPixmap), METH_VARARGS, nullptr},
    {"hitTestComplexControl", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_hitTestComplexControl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"itemPixmapRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_itemPixmapRect), METH_VARARGS, nullptr},
    {"itemTextRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_itemTextRect), METH_VARARGS, nullptr},
    {"layoutSpacing", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_layoutSpacing), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_name), METH_NOARGS, nullptr},
    {"pixelMetric", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_pixelMetric), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"polish", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_polish), METH_O, nullptr},
    {"proxy", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_proxy), METH_NOARGS, nullptr},
    {"sizeFromContents", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_sizeFromContents), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"sliderPositionFromValue", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_sliderPositionFromValue), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"sliderValueFromPosition", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_sliderValueFromPosition), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"standardIcon", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_standardIcon), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"standardPalette", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_standardPalette), METH_NOARGS, nullptr},
    {"standardPixmap", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_standardPixmap), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"styleHint", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_styleHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"subControlRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_subControlRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"subElementRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_subElementRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"unpolish", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_unpolish), METH_O, nullptr},
    {"visualAlignment", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_visualAlignment), METH_VARARGS|METH_STATIC, nullptr},
    {"visualPos", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_visualPos), METH_VARARGS|METH_STATIC, nullptr},
    {"visualRect", reinterpret_cast<PyCFunction>(Sbk_QStyleFunc_visualRect), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QStyle_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QStyle *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QStyleWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QStyle_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyle_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyle_Type = nullptr;
static PyTypeObject *Sbk_QStyle_TypeF(void)
{
    return _Sbk_QStyle_Type;
}

static PyType_Slot Sbk_QStyle_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QStyle_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyle_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyle_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyle_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyle_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyle_spec = {
    "2:PySide6.QtWidgets.QStyle",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyle_slots
};

} //extern "C"

static void *Sbk_QStyle_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QStyle *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QStyle_StateFlag_PythonToCpp_QStyle_StateFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::StateFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::StateFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_StateFlag_PythonToCpp_QStyle_StateFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StateFlag_IDX])))
        return QStyle_StateFlag_PythonToCpp_QStyle_StateFlag;
    return {};
}
static PyObject *QStyle_StateFlag_CppToPython_QStyle_StateFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::StateFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StateFlag_IDX]), castCppIn);

}

static void QStyle_PrimitiveElement_PythonToCpp_QStyle_PrimitiveElement(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::PrimitiveElement>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::PrimitiveElement *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_PrimitiveElement_PythonToCpp_QStyle_PrimitiveElement_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX])))
        return QStyle_PrimitiveElement_PythonToCpp_QStyle_PrimitiveElement;
    return {};
}
static PyObject *QStyle_PrimitiveElement_CppToPython_QStyle_PrimitiveElement(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::PrimitiveElement *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX]), castCppIn);

}

static void QStyle_ControlElement_PythonToCpp_QStyle_ControlElement(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::ControlElement>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::ControlElement *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_ControlElement_PythonToCpp_QStyle_ControlElement_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX])))
        return QStyle_ControlElement_PythonToCpp_QStyle_ControlElement;
    return {};
}
static PyObject *QStyle_ControlElement_CppToPython_QStyle_ControlElement(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::ControlElement *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX]), castCppIn);

}

static void QStyle_SubElement_PythonToCpp_QStyle_SubElement(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::SubElement>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::SubElement *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_SubElement_PythonToCpp_QStyle_SubElement_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX])))
        return QStyle_SubElement_PythonToCpp_QStyle_SubElement;
    return {};
}
static PyObject *QStyle_SubElement_CppToPython_QStyle_SubElement(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::SubElement *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX]), castCppIn);

}

static void QStyle_ComplexControl_PythonToCpp_QStyle_ComplexControl(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::ComplexControl>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::ComplexControl *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_ComplexControl_PythonToCpp_QStyle_ComplexControl_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX])))
        return QStyle_ComplexControl_PythonToCpp_QStyle_ComplexControl;
    return {};
}
static PyObject *QStyle_ComplexControl_CppToPython_QStyle_ComplexControl(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::ComplexControl *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX]), castCppIn);

}

static void QStyle_SubControl_PythonToCpp_QStyle_SubControl(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::SubControl>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::SubControl *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_SubControl_PythonToCpp_QStyle_SubControl_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX])))
        return QStyle_SubControl_PythonToCpp_QStyle_SubControl;
    return {};
}
static PyObject *QStyle_SubControl_CppToPython_QStyle_SubControl(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::SubControl *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX]), castCppIn);

}

static void QStyle_PixelMetric_PythonToCpp_QStyle_PixelMetric(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::PixelMetric>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::PixelMetric *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_PixelMetric_PythonToCpp_QStyle_PixelMetric_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX])))
        return QStyle_PixelMetric_PythonToCpp_QStyle_PixelMetric;
    return {};
}
static PyObject *QStyle_PixelMetric_CppToPython_QStyle_PixelMetric(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::PixelMetric *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX]), castCppIn);

}

static void QStyle_ContentsType_PythonToCpp_QStyle_ContentsType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::ContentsType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::ContentsType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_ContentsType_PythonToCpp_QStyle_ContentsType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX])))
        return QStyle_ContentsType_PythonToCpp_QStyle_ContentsType;
    return {};
}
static PyObject *QStyle_ContentsType_CppToPython_QStyle_ContentsType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::ContentsType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX]), castCppIn);

}

static void QStyle_RequestSoftwareInputPanel_PythonToCpp_QStyle_RequestSoftwareInputPanel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::RequestSoftwareInputPanel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::RequestSoftwareInputPanel *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_RequestSoftwareInputPanel_PythonToCpp_QStyle_RequestSoftwareInputPanel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_RequestSoftwareInputPanel_IDX])))
        return QStyle_RequestSoftwareInputPanel_PythonToCpp_QStyle_RequestSoftwareInputPanel;
    return {};
}
static PyObject *QStyle_RequestSoftwareInputPanel_CppToPython_QStyle_RequestSoftwareInputPanel(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::RequestSoftwareInputPanel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_RequestSoftwareInputPanel_IDX]), castCppIn);

}

static void QStyle_StyleHint_PythonToCpp_QStyle_StyleHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::StyleHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::StyleHint *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_StyleHint_PythonToCpp_QStyle_StyleHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX])))
        return QStyle_StyleHint_PythonToCpp_QStyle_StyleHint;
    return {};
}
static PyObject *QStyle_StyleHint_CppToPython_QStyle_StyleHint(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::StyleHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX]), castCppIn);

}

static void QStyle_StandardPixmap_PythonToCpp_QStyle_StandardPixmap(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyle::StandardPixmap>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyle::StandardPixmap *>(cppOut) = value;

}
static PythonToCppFunc is_QStyle_StandardPixmap_PythonToCpp_QStyle_StandardPixmap_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX])))
        return QStyle_StandardPixmap_PythonToCpp_QStyle_StandardPixmap;
    return {};
}
static PyObject *QStyle_StandardPixmap_CppToPython_QStyle_StandardPixmap(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyle::StandardPixmap *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyle_PythonToCpp_QStyle_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyle_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyle_PythonToCpp_QStyle_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyle_TypeF()))
        return QStyle_PythonToCpp_QStyle_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyle_PTR_CppToPython_QStyle(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QStyle *>(const_cast<void *>(cppIn)), Sbk_QStyle_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStyle_SignatureStrings[] = {
    "PySide6.QtWidgets.QStyle(self)",
    "PySide6.QtWidgets.QStyle.alignedRect(direction:PySide6.QtCore.Qt.LayoutDirection,alignment:PySide6.QtCore.Qt.AlignmentFlag,size:PySide6.QtCore.QSize,rectangle:PySide6.QtCore.QRect)->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QStyle.combinedLayoutSpacing(self,controls1:PySide6.QtWidgets.QSizePolicy.ControlType,controls2:PySide6.QtWidgets.QSizePolicy.ControlType,orientation:PySide6.QtCore.Qt.Orientation,option:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr)->int",
    "PySide6.QtWidgets.QStyle.drawComplexControl(self,cc:PySide6.QtWidgets.QStyle.ComplexControl,opt:PySide6.QtWidgets.QStyleOptionComplex,p:PySide6.QtGui.QPainter,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QStyle.drawControl(self,element:PySide6.QtWidgets.QStyle.ControlElement,opt:PySide6.QtWidgets.QStyleOption,p:PySide6.QtGui.QPainter,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QStyle.drawItemPixmap(self,painter:PySide6.QtGui.QPainter,rect:PySide6.QtCore.QRect,alignment:int,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage, QString])",
    "PySide6.QtWidgets.QStyle.drawItemText(self,painter:PySide6.QtGui.QPainter,rect:PySide6.QtCore.QRect,flags:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],enabled:bool,text:QString,textRole:PySide6.QtGui.QPalette.ColorRole=QPalette.NoRole)",
    "PySide6.QtWidgets.QStyle.drawPrimitive(self,pe:PySide6.QtWidgets.QStyle.PrimitiveElement,opt:PySide6.QtWidgets.QStyleOption,p:PySide6.QtGui.QPainter,widget:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QStyle.generatedIconPixmap(self,iconMode:PySide6.QtGui.QIcon.Mode,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage, QString],opt:PySide6.QtWidgets.QStyleOption)->PySide6.QtGui.QPixmap",
    "PySide6.QtWidgets.QStyle.hitTestComplexControl(self,cc:PySide6.QtWidgets.QStyle.ComplexControl,opt:PySide6.QtWidgets.QStyleOptionComplex,pt:PySide6.QtCore.QPoint,widget:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtWidgets.QStyle.SubControl",
    "PySide6.QtWidgets.QStyle.itemPixmapRect(self,r:PySide6.QtCore.QRect,flags:int,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage, QString])->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QStyle.itemTextRect(self,fm:PySide6.QtGui.QFontMetrics,r:PySide6.QtCore.QRect,flags:int,enabled:bool,text:QString)->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QStyle.layoutSpacing(self,control1:PySide6.QtWidgets.QSizePolicy.ControlType,control2:PySide6.QtWidgets.QSizePolicy.ControlType,orientation:PySide6.QtCore.Qt.Orientation,option:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr)->int",
    "PySide6.QtWidgets.QStyle.name(self)->QString",
    "PySide6.QtWidgets.QStyle.pixelMetric(self,metric:PySide6.QtWidgets.QStyle.PixelMetric,option:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr)->int",
    "2:PySide6.QtWidgets.QStyle.polish(self,widget:PySide6.QtWidgets.QWidget)",
    "1:PySide6.QtWidgets.QStyle.polish(self,palette:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor])",
    "0:PySide6.QtWidgets.QStyle.polish(self,application:PySide6.QtWidgets.QApplication)",
    "PySide6.QtWidgets.QStyle.proxy(self)->PySide6.QtWidgets.QStyle",
    "PySide6.QtWidgets.QStyle.sizeFromContents(self,ct:PySide6.QtWidgets.QStyle.ContentsType,opt:PySide6.QtWidgets.QStyleOption,contentsSize:PySide6.QtCore.QSize,w:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtCore.QSize",
    "PySide6.QtWidgets.QStyle.sliderPositionFromValue(min:int,max:int,val:int,space:int,upsideDown:bool=false)->int",
    "PySide6.QtWidgets.QStyle.sliderValueFromPosition(min:int,max:int,pos:int,space:int,upsideDown:bool=false)->int",
    "PySide6.QtWidgets.QStyle.standardIcon(self,standardIcon:PySide6.QtWidgets.QStyle.StandardPixmap,option:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtGui.QIcon",
    "PySide6.QtWidgets.QStyle.standardPalette(self)->PySide6.QtGui.QPalette",
    "PySide6.QtWidgets.QStyle.standardPixmap(self,standardPixmap:PySide6.QtWidgets.QStyle.StandardPixmap,opt:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtGui.QPixmap",
    "PySide6.QtWidgets.QStyle.styleHint(self,stylehint:PySide6.QtWidgets.QStyle.StyleHint,opt:PySide6.QtWidgets.QStyleOption=nullptr,widget:PySide6.QtWidgets.QWidget=nullptr,returnData:PySide6.QtWidgets.QStyleHintReturn=nullptr)->int",
    "PySide6.QtWidgets.QStyle.subControlRect(self,cc:PySide6.QtWidgets.QStyle.ComplexControl,opt:PySide6.QtWidgets.QStyleOptionComplex,sc:PySide6.QtWidgets.QStyle.SubControl,widget:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QStyle.subElementRect(self,subElement:PySide6.QtWidgets.QStyle.SubElement,option:PySide6.QtWidgets.QStyleOption,widget:PySide6.QtWidgets.QWidget=nullptr)->PySide6.QtCore.QRect",
    "1:PySide6.QtWidgets.QStyle.unpolish(self,widget:PySide6.QtWidgets.QWidget)",
    "0:PySide6.QtWidgets.QStyle.unpolish(self,application:PySide6.QtWidgets.QApplication)",
    "PySide6.QtWidgets.QStyle.visualAlignment(direction:PySide6.QtCore.Qt.LayoutDirection,alignment:PySide6.QtCore.Qt.AlignmentFlag)->PySide6.QtCore.Qt.AlignmentFlag",
    "PySide6.QtWidgets.QStyle.visualPos(direction:PySide6.QtCore.Qt.LayoutDirection,boundingRect:PySide6.QtCore.QRect,logicalPos:PySide6.QtCore.QPoint)->PySide6.QtCore.QPoint",
    "PySide6.QtWidgets.QStyle.visualRect(direction:PySide6.QtCore.Qt.LayoutDirection,boundingRect:PySide6.QtCore.QRect,logicalRect:PySide6.QtCore.QRect)->PySide6.QtCore.QRect",
    nullptr}; // Sentinel

PyTypeObject *init_QStyle(PyObject *module)
{
    _Sbk_QStyle_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyle",
        "QStyle*",
        &Sbk_QStyle_spec,
        &Shiboken::callCppDestructor< ::QStyle >,
        Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]),
        0,
        0);
    auto *pyType = Sbk_QStyle_TypeF(); // references _Sbk_QStyle_Type
    InitSignatureStrings(pyType, QStyle_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyle_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyle_PythonToCpp_QStyle_PTR,
        is_QStyle_PythonToCpp_QStyle_PTR_Convertible,
        QStyle_PTR_CppToPython_QStyle);

    Shiboken::Conversions::registerConverterName(converter, "QStyle");
    Shiboken::Conversions::registerConverterName(converter, "QStyle*");
    Shiboken::Conversions::registerConverterName(converter, "QStyle&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyle).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyle_TypeF(), &Sbk_QStyle_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyle_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StateFlag'.
    const char *StateFlag_Initializer[] = {
        "State_None",
        "State_Enabled",
        "State_Raised",
        "State_Sunken",
        "State_Off",
        "State_NoChange",
        "State_On",
        "State_DownArrow",
        "State_Horizontal",
        "State_HasFocus",
        "State_Top",
        "State_Bottom",
        "State_FocusAtBorder",
        "State_AutoRaise",
        "State_MouseOver",
        "State_UpArrow",
        "State_Selected",
        "State_Active",
        "State_Window",
        "State_Open",
        "State_Children",
        "State_Item",
        "State_Sibling",
        "State_Editing",
        "State_KeyboardFocusChange",
        "State_ReadOnly",
        "State_Small",
        "State_Mini",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StateFlag_InitializerValues[] = {
        uint32_t(QStyle::StateFlag::State_None),                //  0x00000000  0
        uint32_t(QStyle::StateFlag::State_Enabled),             //  0x00000001  1
        uint32_t(QStyle::StateFlag::State_Raised),              //  0x00000002  2
        uint32_t(QStyle::StateFlag::State_Sunken),              //  0x00000004  4
        uint32_t(QStyle::StateFlag::State_Off),                 //  0x00000008  8
        uint32_t(QStyle::StateFlag::State_NoChange),            //  0x00000010  16
        uint32_t(QStyle::StateFlag::State_On),                  //  0x00000020  32
        uint32_t(QStyle::StateFlag::State_DownArrow),           //  0x00000040  64
        uint32_t(QStyle::StateFlag::State_Horizontal),          //  0x00000080  128
        uint32_t(QStyle::StateFlag::State_HasFocus),            //  0x00000100  256
        uint32_t(QStyle::StateFlag::State_Top),                 //  0x00000200  512
        uint32_t(QStyle::StateFlag::State_Bottom),              //  0x00000400  1024
        uint32_t(QStyle::StateFlag::State_FocusAtBorder),       //  0x00000800  2048
        uint32_t(QStyle::StateFlag::State_AutoRaise),           //  0x00001000  4096
        uint32_t(QStyle::StateFlag::State_MouseOver),           //  0x00002000  8192
        uint32_t(QStyle::StateFlag::State_UpArrow),             //  0x00004000  16384
        uint32_t(QStyle::StateFlag::State_Selected),            //  0x00008000  32768
        uint32_t(QStyle::StateFlag::State_Active),              //  0x00010000  65536
        uint32_t(QStyle::StateFlag::State_Window),              //  0x00020000  131072
        uint32_t(QStyle::StateFlag::State_Open),                //  0x00040000  262144
        uint32_t(QStyle::StateFlag::State_Children),            //  0x00080000  524288
        uint32_t(QStyle::StateFlag::State_Item),                //  0x00100000  1048576
        uint32_t(QStyle::StateFlag::State_Sibling),             //  0x00200000  2097152
        uint32_t(QStyle::StateFlag::State_Editing),             //  0x00400000  4194304
        uint32_t(QStyle::StateFlag::State_KeyboardFocusChange), //  0x00800000  8388608
        uint32_t(QStyle::StateFlag::State_ReadOnly),            //  0x02000000  33554432
        uint32_t(QStyle::StateFlag::State_Small),               //  0x04000000  67108864
        uint32_t(QStyle::StateFlag::State_Mini)                 //  0x08000000  134217728
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.StateFlag",
        StateFlag_Initializer, StateFlag_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StateFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_StateFlag_IDX].type =
        EType;
    // Register converter for enum 'QStyle::StateFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_StateFlag_CppToPython_QStyle_StateFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_StateFlag_PythonToCpp_QStyle_StateFlag,
            is_QStyle_StateFlag_PythonToCpp_QStyle_StateFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::StateFlag");
        Shiboken::Conversions::registerConverterName(converter, "StateFlag");
        // Register converter for flag 'QFlags<QStyle::StateFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QStyle::StateFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QStyle::State");
    }
    // End of 'StateFlag' enum/flags.

    // Initialization of enum 'PrimitiveElement'.
    const char *PrimitiveElement_Initializer[] = {
        "PE_Frame",
        "PE_FrameDefaultButton",
        "PE_FrameDockWidget",
        "PE_FrameFocusRect",
        "PE_FrameGroupBox",
        "PE_FrameLineEdit",
        "PE_FrameMenu",
        "PE_FrameStatusBarItem",
        "PE_FrameTabWidget",
        "PE_FrameWindow",
        "PE_FrameButtonBevel",
        "PE_FrameButtonTool",
        "PE_FrameTabBarBase",
        "PE_PanelButtonCommand",
        "PE_PanelButtonBevel",
        "PE_PanelButtonTool",
        "PE_PanelMenuBar",
        "PE_PanelToolBar",
        "PE_PanelLineEdit",
        "PE_IndicatorArrowDown",
        "PE_IndicatorArrowLeft",
        "PE_IndicatorArrowRight",
        "PE_IndicatorArrowUp",
        "PE_IndicatorBranch",
        "PE_IndicatorButtonDropDown",
        "PE_IndicatorItemViewItemCheck",
        "PE_IndicatorCheckBox",
        "PE_IndicatorDockWidgetResizeHandle",
        "PE_IndicatorHeaderArrow",
        "PE_IndicatorMenuCheckMark",
        "PE_IndicatorProgressChunk",
        "PE_IndicatorRadioButton",
        "PE_IndicatorSpinDown",
        "PE_IndicatorSpinMinus",
        "PE_IndicatorSpinPlus",
        "PE_IndicatorSpinUp",
        "PE_IndicatorToolBarHandle",
        "PE_IndicatorToolBarSeparator",
        "PE_PanelTipLabel",
        "PE_IndicatorTabTear",
        "PE_IndicatorTabTearLeft",
        "PE_PanelScrollAreaCorner",
        "PE_Widget",
        "PE_IndicatorColumnViewArrow",
        "PE_IndicatorItemViewItemDrop",
        "PE_PanelItemViewItem",
        "PE_PanelItemViewRow",
        "PE_PanelStatusBar",
        "PE_IndicatorTabClose",
        "PE_PanelMenu",
        "PE_IndicatorTabTearRight",
        "PE_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t PrimitiveElement_InitializerValues[] = {
        uint32_t(QStyle::PrimitiveElement::PE_Frame),                           //  0x00000000  0
        uint32_t(QStyle::PrimitiveElement::PE_FrameDefaultButton),              //  0x00000001  1
        uint32_t(QStyle::PrimitiveElement::PE_FrameDockWidget),                 //  0x00000002  2
        uint32_t(QStyle::PrimitiveElement::PE_FrameFocusRect),                  //  0x00000003  3
        uint32_t(QStyle::PrimitiveElement::PE_FrameGroupBox),                   //  0x00000004  4
        uint32_t(QStyle::PrimitiveElement::PE_FrameLineEdit),                   //  0x00000005  5
        uint32_t(QStyle::PrimitiveElement::PE_FrameMenu),                       //  0x00000006  6
        uint32_t(QStyle::PrimitiveElement::PE_FrameStatusBarItem),              //  0x00000007  7
        uint32_t(QStyle::PrimitiveElement::PE_FrameTabWidget),                  //  0x00000008  8
        uint32_t(QStyle::PrimitiveElement::PE_FrameWindow),                     //  0x00000009  9
        uint32_t(QStyle::PrimitiveElement::PE_FrameButtonBevel),                //  0x0000000a  10
        uint32_t(QStyle::PrimitiveElement::PE_FrameButtonTool),                 //  0x0000000b  11
        uint32_t(QStyle::PrimitiveElement::PE_FrameTabBarBase),                 //  0x0000000c  12
        uint32_t(QStyle::PrimitiveElement::PE_PanelButtonCommand),              //  0x0000000d  13
        uint32_t(QStyle::PrimitiveElement::PE_PanelButtonBevel),                //  0x0000000e  14
        uint32_t(QStyle::PrimitiveElement::PE_PanelButtonTool),                 //  0x0000000f  15
        uint32_t(QStyle::PrimitiveElement::PE_PanelMenuBar),                    //  0x00000010  16
        uint32_t(QStyle::PrimitiveElement::PE_PanelToolBar),                    //  0x00000011  17
        uint32_t(QStyle::PrimitiveElement::PE_PanelLineEdit),                   //  0x00000012  18
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorArrowDown),              //  0x00000013  19
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorArrowLeft),              //  0x00000014  20
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorArrowRight),             //  0x00000015  21
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorArrowUp),                //  0x00000016  22
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorBranch),                 //  0x00000017  23
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorButtonDropDown),         //  0x00000018  24
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorItemViewItemCheck),      //  0x00000019  25
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorCheckBox),               //  0x0000001a  26
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorDockWidgetResizeHandle), //  0x0000001b  27
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorHeaderArrow),            //  0x0000001c  28
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorMenuCheckMark),          //  0x0000001d  29
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorProgressChunk),          //  0x0000001e  30
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorRadioButton),            //  0x0000001f  31
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorSpinDown),               //  0x00000020  32
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorSpinMinus),              //  0x00000021  33
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorSpinPlus),               //  0x00000022  34
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorSpinUp),                 //  0x00000023  35
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorToolBarHandle),          //  0x00000024  36
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorToolBarSeparator),       //  0x00000025  37
        uint32_t(QStyle::PrimitiveElement::PE_PanelTipLabel),                   //  0x00000026  38
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorTabTear),                //  0x00000027  39
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorTabTearLeft),            //  0x00000027  39
        uint32_t(QStyle::PrimitiveElement::PE_PanelScrollAreaCorner),           //  0x00000028  40
        uint32_t(QStyle::PrimitiveElement::PE_Widget),                          //  0x00000029  41
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorColumnViewArrow),        //  0x0000002a  42
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorItemViewItemDrop),       //  0x0000002b  43
        uint32_t(QStyle::PrimitiveElement::PE_PanelItemViewItem),               //  0x0000002c  44
        uint32_t(QStyle::PrimitiveElement::PE_PanelItemViewRow),                //  0x0000002d  45
        uint32_t(QStyle::PrimitiveElement::PE_PanelStatusBar),                  //  0x0000002e  46
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorTabClose),               //  0x0000002f  47
        uint32_t(QStyle::PrimitiveElement::PE_PanelMenu),                       //  0x00000030  48
        uint32_t(QStyle::PrimitiveElement::PE_IndicatorTabTearRight),           //  0x00000031  49
        uint32_t(QStyle::PrimitiveElement::PE_CustomBase)                       //  0x0f000000  251658240
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.PrimitiveElement",
        PrimitiveElement_Initializer, PrimitiveElement_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PrimitiveElement_IDX].type = EType;
    // Register converter for enum 'QStyle::PrimitiveElement'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_PrimitiveElement_CppToPython_QStyle_PrimitiveElement);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_PrimitiveElement_PythonToCpp_QStyle_PrimitiveElement,
            is_QStyle_PrimitiveElement_PythonToCpp_QStyle_PrimitiveElement_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::PrimitiveElement");
        Shiboken::Conversions::registerConverterName(converter, "PrimitiveElement");
    }
    // End of 'PrimitiveElement' enum.

    // Initialization of enum 'ControlElement'.
    const char *ControlElement_Initializer[] = {
        "CE_PushButton",
        "CE_PushButtonBevel",
        "CE_PushButtonLabel",
        "CE_CheckBox",
        "CE_CheckBoxLabel",
        "CE_RadioButton",
        "CE_RadioButtonLabel",
        "CE_TabBarTab",
        "CE_TabBarTabShape",
        "CE_TabBarTabLabel",
        "CE_ProgressBar",
        "CE_ProgressBarGroove",
        "CE_ProgressBarContents",
        "CE_ProgressBarLabel",
        "CE_MenuItem",
        "CE_MenuScroller",
        "CE_MenuVMargin",
        "CE_MenuHMargin",
        "CE_MenuTearoff",
        "CE_MenuEmptyArea",
        "CE_MenuBarItem",
        "CE_MenuBarEmptyArea",
        "CE_ToolButtonLabel",
        "CE_Header",
        "CE_HeaderSection",
        "CE_HeaderLabel",
        "CE_ToolBoxTab",
        "CE_SizeGrip",
        "CE_Splitter",
        "CE_RubberBand",
        "CE_DockWidgetTitle",
        "CE_ScrollBarAddLine",
        "CE_ScrollBarSubLine",
        "CE_ScrollBarAddPage",
        "CE_ScrollBarSubPage",
        "CE_ScrollBarSlider",
        "CE_ScrollBarFirst",
        "CE_ScrollBarLast",
        "CE_FocusFrame",
        "CE_ComboBoxLabel",
        "CE_ToolBar",
        "CE_ToolBoxTabShape",
        "CE_ToolBoxTabLabel",
        "CE_HeaderEmptyArea",
        "CE_ColumnViewGrip",
        "CE_ItemViewItem",
        "CE_ShapedFrame",
        "CE_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t ControlElement_InitializerValues[] = {
        uint32_t(QStyle::ControlElement::CE_PushButton),          //  0x00000000  0
        uint32_t(QStyle::ControlElement::CE_PushButtonBevel),     //  0x00000001  1
        uint32_t(QStyle::ControlElement::CE_PushButtonLabel),     //  0x00000002  2
        uint32_t(QStyle::ControlElement::CE_CheckBox),            //  0x00000003  3
        uint32_t(QStyle::ControlElement::CE_CheckBoxLabel),       //  0x00000004  4
        uint32_t(QStyle::ControlElement::CE_RadioButton),         //  0x00000005  5
        uint32_t(QStyle::ControlElement::CE_RadioButtonLabel),    //  0x00000006  6
        uint32_t(QStyle::ControlElement::CE_TabBarTab),           //  0x00000007  7
        uint32_t(QStyle::ControlElement::CE_TabBarTabShape),      //  0x00000008  8
        uint32_t(QStyle::ControlElement::CE_TabBarTabLabel),      //  0x00000009  9
        uint32_t(QStyle::ControlElement::CE_ProgressBar),         //  0x0000000a  10
        uint32_t(QStyle::ControlElement::CE_ProgressBarGroove),   //  0x0000000b  11
        uint32_t(QStyle::ControlElement::CE_ProgressBarContents), //  0x0000000c  12
        uint32_t(QStyle::ControlElement::CE_ProgressBarLabel),    //  0x0000000d  13
        uint32_t(QStyle::ControlElement::CE_MenuItem),            //  0x0000000e  14
        uint32_t(QStyle::ControlElement::CE_MenuScroller),        //  0x0000000f  15
        uint32_t(QStyle::ControlElement::CE_MenuVMargin),         //  0x00000010  16
        uint32_t(QStyle::ControlElement::CE_MenuHMargin),         //  0x00000011  17
        uint32_t(QStyle::ControlElement::CE_MenuTearoff),         //  0x00000012  18
        uint32_t(QStyle::ControlElement::CE_MenuEmptyArea),       //  0x00000013  19
        uint32_t(QStyle::ControlElement::CE_MenuBarItem),         //  0x00000014  20
        uint32_t(QStyle::ControlElement::CE_MenuBarEmptyArea),    //  0x00000015  21
        uint32_t(QStyle::ControlElement::CE_ToolButtonLabel),     //  0x00000016  22
        uint32_t(QStyle::ControlElement::CE_Header),              //  0x00000017  23
        uint32_t(QStyle::ControlElement::CE_HeaderSection),       //  0x00000018  24
        uint32_t(QStyle::ControlElement::CE_HeaderLabel),         //  0x00000019  25
        uint32_t(QStyle::ControlElement::CE_ToolBoxTab),          //  0x0000001a  26
        uint32_t(QStyle::ControlElement::CE_SizeGrip),            //  0x0000001b  27
        uint32_t(QStyle::ControlElement::CE_Splitter),            //  0x0000001c  28
        uint32_t(QStyle::ControlElement::CE_RubberBand),          //  0x0000001d  29
        uint32_t(QStyle::ControlElement::CE_DockWidgetTitle),     //  0x0000001e  30
        uint32_t(QStyle::ControlElement::CE_ScrollBarAddLine),    //  0x0000001f  31
        uint32_t(QStyle::ControlElement::CE_ScrollBarSubLine),    //  0x00000020  32
        uint32_t(QStyle::ControlElement::CE_ScrollBarAddPage),    //  0x00000021  33
        uint32_t(QStyle::ControlElement::CE_ScrollBarSubPage),    //  0x00000022  34
        uint32_t(QStyle::ControlElement::CE_ScrollBarSlider),     //  0x00000023  35
        uint32_t(QStyle::ControlElement::CE_ScrollBarFirst),      //  0x00000024  36
        uint32_t(QStyle::ControlElement::CE_ScrollBarLast),       //  0x00000025  37
        uint32_t(QStyle::ControlElement::CE_FocusFrame),          //  0x00000026  38
        uint32_t(QStyle::ControlElement::CE_ComboBoxLabel),       //  0x00000027  39
        uint32_t(QStyle::ControlElement::CE_ToolBar),             //  0x00000028  40
        uint32_t(QStyle::ControlElement::CE_ToolBoxTabShape),     //  0x00000029  41
        uint32_t(QStyle::ControlElement::CE_ToolBoxTabLabel),     //  0x0000002a  42
        uint32_t(QStyle::ControlElement::CE_HeaderEmptyArea),     //  0x0000002b  43
        uint32_t(QStyle::ControlElement::CE_ColumnViewGrip),      //  0x0000002c  44
        uint32_t(QStyle::ControlElement::CE_ItemViewItem),        //  0x0000002d  45
        uint32_t(QStyle::ControlElement::CE_ShapedFrame),         //  0x0000002e  46
        uint32_t(QStyle::ControlElement::CE_CustomBase)           //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.ControlElement",
        ControlElement_Initializer, ControlElement_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ControlElement_IDX].type = EType;
    // Register converter for enum 'QStyle::ControlElement'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_ControlElement_CppToPython_QStyle_ControlElement);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_ControlElement_PythonToCpp_QStyle_ControlElement,
            is_QStyle_ControlElement_PythonToCpp_QStyle_ControlElement_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::ControlElement");
        Shiboken::Conversions::registerConverterName(converter, "ControlElement");
    }
    // End of 'ControlElement' enum.

    // Initialization of enum 'SubElement'.
    const char *SubElement_Initializer[] = {
        "SE_PushButtonContents",
        "SE_PushButtonFocusRect",
        "SE_CheckBoxIndicator",
        "SE_CheckBoxContents",
        "SE_CheckBoxFocusRect",
        "SE_CheckBoxClickRect",
        "SE_RadioButtonIndicator",
        "SE_RadioButtonContents",
        "SE_RadioButtonFocusRect",
        "SE_RadioButtonClickRect",
        "SE_ComboBoxFocusRect",
        "SE_SliderFocusRect",
        "SE_ProgressBarGroove",
        "SE_ProgressBarContents",
        "SE_ProgressBarLabel",
        "SE_ToolBoxTabContents",
        "SE_HeaderLabel",
        "SE_HeaderArrow",
        "SE_TabWidgetTabBar",
        "SE_TabWidgetTabPane",
        "SE_TabWidgetTabContents",
        "SE_TabWidgetLeftCorner",
        "SE_TabWidgetRightCorner",
        "SE_ItemViewItemCheckIndicator",
        "SE_TabBarTearIndicator",
        "SE_TabBarTearIndicatorLeft",
        "SE_TreeViewDisclosureItem",
        "SE_LineEditContents",
        "SE_FrameContents",
        "SE_DockWidgetCloseButton",
        "SE_DockWidgetFloatButton",
        "SE_DockWidgetTitleBarText",
        "SE_DockWidgetIcon",
        "SE_CheckBoxLayoutItem",
        "SE_ComboBoxLayoutItem",
        "SE_DateTimeEditLayoutItem",
        "SE_LabelLayoutItem",
        "SE_ProgressBarLayoutItem",
        "SE_PushButtonLayoutItem",
        "SE_RadioButtonLayoutItem",
        "SE_SliderLayoutItem",
        "SE_SpinBoxLayoutItem",
        "SE_ToolButtonLayoutItem",
        "SE_FrameLayoutItem",
        "SE_GroupBoxLayoutItem",
        "SE_TabWidgetLayoutItem",
        "SE_ItemViewItemDecoration",
        "SE_ItemViewItemText",
        "SE_ItemViewItemFocusRect",
        "SE_TabBarTabLeftButton",
        "SE_TabBarTabRightButton",
        "SE_TabBarTabText",
        "SE_ShapedFrameContents",
        "SE_ToolBarHandle",
        "SE_TabBarScrollLeftButton",
        "SE_TabBarScrollRightButton",
        "SE_TabBarTearIndicatorRight",
        "SE_PushButtonBevel",
        "SE_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t SubElement_InitializerValues[] = {
        uint32_t(QStyle::SubElement::SE_PushButtonContents),         //  0x00000000  0
        uint32_t(QStyle::SubElement::SE_PushButtonFocusRect),        //  0x00000001  1
        uint32_t(QStyle::SubElement::SE_CheckBoxIndicator),          //  0x00000002  2
        uint32_t(QStyle::SubElement::SE_CheckBoxContents),           //  0x00000003  3
        uint32_t(QStyle::SubElement::SE_CheckBoxFocusRect),          //  0x00000004  4
        uint32_t(QStyle::SubElement::SE_CheckBoxClickRect),          //  0x00000005  5
        uint32_t(QStyle::SubElement::SE_RadioButtonIndicator),       //  0x00000006  6
        uint32_t(QStyle::SubElement::SE_RadioButtonContents),        //  0x00000007  7
        uint32_t(QStyle::SubElement::SE_RadioButtonFocusRect),       //  0x00000008  8
        uint32_t(QStyle::SubElement::SE_RadioButtonClickRect),       //  0x00000009  9
        uint32_t(QStyle::SubElement::SE_ComboBoxFocusRect),          //  0x0000000a  10
        uint32_t(QStyle::SubElement::SE_SliderFocusRect),            //  0x0000000b  11
        uint32_t(QStyle::SubElement::SE_ProgressBarGroove),          //  0x0000000c  12
        uint32_t(QStyle::SubElement::SE_ProgressBarContents),        //  0x0000000d  13
        uint32_t(QStyle::SubElement::SE_ProgressBarLabel),           //  0x0000000e  14
        uint32_t(QStyle::SubElement::SE_ToolBoxTabContents),         //  0x0000000f  15
        uint32_t(QStyle::SubElement::SE_HeaderLabel),                //  0x00000010  16
        uint32_t(QStyle::SubElement::SE_HeaderArrow),                //  0x00000011  17
        uint32_t(QStyle::SubElement::SE_TabWidgetTabBar),            //  0x00000012  18
        uint32_t(QStyle::SubElement::SE_TabWidgetTabPane),           //  0x00000013  19
        uint32_t(QStyle::SubElement::SE_TabWidgetTabContents),       //  0x00000014  20
        uint32_t(QStyle::SubElement::SE_TabWidgetLeftCorner),        //  0x00000015  21
        uint32_t(QStyle::SubElement::SE_TabWidgetRightCorner),       //  0x00000016  22
        uint32_t(QStyle::SubElement::SE_ItemViewItemCheckIndicator), //  0x00000017  23
        uint32_t(QStyle::SubElement::SE_TabBarTearIndicator),        //  0x00000018  24
        uint32_t(QStyle::SubElement::SE_TabBarTearIndicatorLeft),    //  0x00000018  24
        uint32_t(QStyle::SubElement::SE_TreeViewDisclosureItem),     //  0x00000019  25
        uint32_t(QStyle::SubElement::SE_LineEditContents),           //  0x0000001a  26
        uint32_t(QStyle::SubElement::SE_FrameContents),              //  0x0000001b  27
        uint32_t(QStyle::SubElement::SE_DockWidgetCloseButton),      //  0x0000001c  28
        uint32_t(QStyle::SubElement::SE_DockWidgetFloatButton),      //  0x0000001d  29
        uint32_t(QStyle::SubElement::SE_DockWidgetTitleBarText),     //  0x0000001e  30
        uint32_t(QStyle::SubElement::SE_DockWidgetIcon),             //  0x0000001f  31
        uint32_t(QStyle::SubElement::SE_CheckBoxLayoutItem),         //  0x00000020  32
        uint32_t(QStyle::SubElement::SE_ComboBoxLayoutItem),         //  0x00000021  33
        uint32_t(QStyle::SubElement::SE_DateTimeEditLayoutItem),     //  0x00000022  34
        uint32_t(QStyle::SubElement::SE_LabelLayoutItem),            //  0x00000023  35
        uint32_t(QStyle::SubElement::SE_ProgressBarLayoutItem),      //  0x00000024  36
        uint32_t(QStyle::SubElement::SE_PushButtonLayoutItem),       //  0x00000025  37
        uint32_t(QStyle::SubElement::SE_RadioButtonLayoutItem),      //  0x00000026  38
        uint32_t(QStyle::SubElement::SE_SliderLayoutItem),           //  0x00000027  39
        uint32_t(QStyle::SubElement::SE_SpinBoxLayoutItem),          //  0x00000028  40
        uint32_t(QStyle::SubElement::SE_ToolButtonLayoutItem),       //  0x00000029  41
        uint32_t(QStyle::SubElement::SE_FrameLayoutItem),            //  0x0000002a  42
        uint32_t(QStyle::SubElement::SE_GroupBoxLayoutItem),         //  0x0000002b  43
        uint32_t(QStyle::SubElement::SE_TabWidgetLayoutItem),        //  0x0000002c  44
        uint32_t(QStyle::SubElement::SE_ItemViewItemDecoration),     //  0x0000002d  45
        uint32_t(QStyle::SubElement::SE_ItemViewItemText),           //  0x0000002e  46
        uint32_t(QStyle::SubElement::SE_ItemViewItemFocusRect),      //  0x0000002f  47
        uint32_t(QStyle::SubElement::SE_TabBarTabLeftButton),        //  0x00000030  48
        uint32_t(QStyle::SubElement::SE_TabBarTabRightButton),       //  0x00000031  49
        uint32_t(QStyle::SubElement::SE_TabBarTabText),              //  0x00000032  50
        uint32_t(QStyle::SubElement::SE_ShapedFrameContents),        //  0x00000033  51
        uint32_t(QStyle::SubElement::SE_ToolBarHandle),              //  0x00000034  52
        uint32_t(QStyle::SubElement::SE_TabBarScrollLeftButton),     //  0x00000035  53
        uint32_t(QStyle::SubElement::SE_TabBarScrollRightButton),    //  0x00000036  54
        uint32_t(QStyle::SubElement::SE_TabBarTearIndicatorRight),   //  0x00000037  55
        uint32_t(QStyle::SubElement::SE_PushButtonBevel),            //  0x00000038  56
        uint32_t(QStyle::SubElement::SE_CustomBase)                  //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.SubElement",
        SubElement_Initializer, SubElement_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubElement_IDX].type = EType;
    // Register converter for enum 'QStyle::SubElement'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_SubElement_CppToPython_QStyle_SubElement);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_SubElement_PythonToCpp_QStyle_SubElement,
            is_QStyle_SubElement_PythonToCpp_QStyle_SubElement_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::SubElement");
        Shiboken::Conversions::registerConverterName(converter, "SubElement");
    }
    // End of 'SubElement' enum.

    // Initialization of enum 'ComplexControl'.
    const char *ComplexControl_Initializer[] = {
        "CC_SpinBox",
        "CC_ComboBox",
        "CC_ScrollBar",
        "CC_Slider",
        "CC_ToolButton",
        "CC_TitleBar",
        "CC_Dial",
        "CC_GroupBox",
        "CC_MdiControls",
        "CC_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t ComplexControl_InitializerValues[] = {
        uint32_t(QStyle::ComplexControl::CC_SpinBox),     //  0x00000000  0
        uint32_t(QStyle::ComplexControl::CC_ComboBox),    //  0x00000001  1
        uint32_t(QStyle::ComplexControl::CC_ScrollBar),   //  0x00000002  2
        uint32_t(QStyle::ComplexControl::CC_Slider),      //  0x00000003  3
        uint32_t(QStyle::ComplexControl::CC_ToolButton),  //  0x00000004  4
        uint32_t(QStyle::ComplexControl::CC_TitleBar),    //  0x00000005  5
        uint32_t(QStyle::ComplexControl::CC_Dial),        //  0x00000006  6
        uint32_t(QStyle::ComplexControl::CC_GroupBox),    //  0x00000007  7
        uint32_t(QStyle::ComplexControl::CC_MdiControls), //  0x00000008  8
        uint32_t(QStyle::ComplexControl::CC_CustomBase)   //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.ComplexControl",
        ComplexControl_Initializer, ComplexControl_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ComplexControl_IDX].type = EType;
    // Register converter for enum 'QStyle::ComplexControl'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_ComplexControl_CppToPython_QStyle_ComplexControl);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_ComplexControl_PythonToCpp_QStyle_ComplexControl,
            is_QStyle_ComplexControl_PythonToCpp_QStyle_ComplexControl_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::ComplexControl");
        Shiboken::Conversions::registerConverterName(converter, "ComplexControl");
    }
    // End of 'ComplexControl' enum.

    // Initialization of enum 'SubControl'.
    const char *SubControl_Initializer[] = {
        "SC_None",
        "SC_ScrollBarAddLine",
        "SC_ScrollBarSubLine",
        "SC_ScrollBarAddPage",
        "SC_ScrollBarSubPage",
        "SC_ScrollBarFirst",
        "SC_ScrollBarLast",
        "SC_ScrollBarSlider",
        "SC_ScrollBarGroove",
        "SC_SpinBoxUp",
        "SC_SpinBoxDown",
        "SC_SpinBoxFrame",
        "SC_SpinBoxEditField",
        "SC_ComboBoxFrame",
        "SC_ComboBoxEditField",
        "SC_ComboBoxArrow",
        "SC_ComboBoxListBoxPopup",
        "SC_SliderGroove",
        "SC_SliderHandle",
        "SC_SliderTickmarks",
        "SC_ToolButton",
        "SC_ToolButtonMenu",
        "SC_TitleBarSysMenu",
        "SC_TitleBarMinButton",
        "SC_TitleBarMaxButton",
        "SC_TitleBarCloseButton",
        "SC_TitleBarNormalButton",
        "SC_TitleBarShadeButton",
        "SC_TitleBarUnshadeButton",
        "SC_TitleBarContextHelpButton",
        "SC_TitleBarLabel",
        "SC_DialGroove",
        "SC_DialHandle",
        "SC_DialTickmarks",
        "SC_GroupBoxCheckBox",
        "SC_GroupBoxLabel",
        "SC_GroupBoxContents",
        "SC_GroupBoxFrame",
        "SC_MdiMinButton",
        "SC_MdiNormalButton",
        "SC_MdiCloseButton",
        "SC_CustomBase",
        "SC_All",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t SubControl_InitializerValues[] = {
        uint32_t(QStyle::SubControl::SC_None),                      //  0x00000000  0
        uint32_t(QStyle::SubControl::SC_ScrollBarAddLine),          //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_ScrollBarSubLine),          //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_ScrollBarAddPage),          //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_ScrollBarSubPage),          //  0x00000008  8
        uint32_t(QStyle::SubControl::SC_ScrollBarFirst),            //  0x00000010  16
        uint32_t(QStyle::SubControl::SC_ScrollBarLast),             //  0x00000020  32
        uint32_t(QStyle::SubControl::SC_ScrollBarSlider),           //  0x00000040  64
        uint32_t(QStyle::SubControl::SC_ScrollBarGroove),           //  0x00000080  128
        uint32_t(QStyle::SubControl::SC_SpinBoxUp),                 //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_SpinBoxDown),               //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_SpinBoxFrame),              //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_SpinBoxEditField),          //  0x00000008  8
        uint32_t(QStyle::SubControl::SC_ComboBoxFrame),             //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_ComboBoxEditField),         //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_ComboBoxArrow),             //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_ComboBoxListBoxPopup),      //  0x00000008  8
        uint32_t(QStyle::SubControl::SC_SliderGroove),              //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_SliderHandle),              //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_SliderTickmarks),           //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_ToolButton),                //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_ToolButtonMenu),            //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_TitleBarSysMenu),           //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_TitleBarMinButton),         //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_TitleBarMaxButton),         //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_TitleBarCloseButton),       //  0x00000008  8
        uint32_t(QStyle::SubControl::SC_TitleBarNormalButton),      //  0x00000010  16
        uint32_t(QStyle::SubControl::SC_TitleBarShadeButton),       //  0x00000020  32
        uint32_t(QStyle::SubControl::SC_TitleBarUnshadeButton),     //  0x00000040  64
        uint32_t(QStyle::SubControl::SC_TitleBarContextHelpButton), //  0x00000080  128
        uint32_t(QStyle::SubControl::SC_TitleBarLabel),             //  0x00000100  256
        uint32_t(QStyle::SubControl::SC_DialGroove),                //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_DialHandle),                //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_DialTickmarks),             //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_GroupBoxCheckBox),          //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_GroupBoxLabel),             //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_GroupBoxContents),          //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_GroupBoxFrame),             //  0x00000008  8
        uint32_t(QStyle::SubControl::SC_MdiMinButton),              //  0x00000001  1
        uint32_t(QStyle::SubControl::SC_MdiNormalButton),           //  0x00000002  2
        uint32_t(QStyle::SubControl::SC_MdiCloseButton),            //  0x00000004  4
        uint32_t(QStyle::SubControl::SC_CustomBase),                //  0xf0000000  4026531840
        uint32_t(QStyle::SubControl::SC_All)                        //  0xffffffff  4294967295
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.SubControl",
        SubControl_Initializer, SubControl_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_SubControl_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QStyle_SubControl_IDX].type =
        EType;
    // Register converter for enum 'QStyle::SubControl'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_SubControl_CppToPython_QStyle_SubControl);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_SubControl_PythonToCpp_QStyle_SubControl,
            is_QStyle_SubControl_PythonToCpp_QStyle_SubControl_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::SubControl");
        Shiboken::Conversions::registerConverterName(converter, "SubControl");
        // Register converter for flag 'QFlags<QStyle::SubControl>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QStyle::SubControl>");
        Shiboken::Conversions::registerConverterName(converter, "QStyle::SubControls");
    }
    // End of 'SubControl' enum/flags.

    // Initialization of enum 'PixelMetric'.
    const char *PixelMetric_Initializer[] = {
        "PM_ButtonMargin",
        "PM_ButtonDefaultIndicator",
        "PM_MenuButtonIndicator",
        "PM_ButtonShiftHorizontal",
        "PM_ButtonShiftVertical",
        "PM_DefaultFrameWidth",
        "PM_SpinBoxFrameWidth",
        "PM_ComboBoxFrameWidth",
        "PM_MaximumDragDistance",
        "PM_ScrollBarExtent",
        "PM_ScrollBarSliderMin",
        "PM_SliderThickness",
        "PM_SliderControlThickness",
        "PM_SliderLength",
        "PM_SliderTickmarkOffset",
        "PM_SliderSpaceAvailable",
        "PM_DockWidgetSeparatorExtent",
        "PM_DockWidgetHandleExtent",
        "PM_DockWidgetFrameWidth",
        "PM_TabBarTabOverlap",
        "PM_TabBarTabHSpace",
        "PM_TabBarTabVSpace",
        "PM_TabBarBaseHeight",
        "PM_TabBarBaseOverlap",
        "PM_ProgressBarChunkWidth",
        "PM_SplitterWidth",
        "PM_TitleBarHeight",
        "PM_MenuScrollerHeight",
        "PM_MenuHMargin",
        "PM_MenuVMargin",
        "PM_MenuPanelWidth",
        "PM_MenuTearoffHeight",
        "PM_MenuDesktopFrameWidth",
        "PM_MenuBarPanelWidth",
        "PM_MenuBarItemSpacing",
        "PM_MenuBarVMargin",
        "PM_MenuBarHMargin",
        "PM_IndicatorWidth",
        "PM_IndicatorHeight",
        "PM_ExclusiveIndicatorWidth",
        "PM_ExclusiveIndicatorHeight",
        "PM_DialogButtonsSeparator",
        "PM_DialogButtonsButtonWidth",
        "PM_DialogButtonsButtonHeight",
        "PM_MdiSubWindowFrameWidth",
        "PM_MdiSubWindowMinimizedWidth",
        "PM_HeaderMargin",
        "PM_HeaderMarkSize",
        "PM_HeaderGripMargin",
        "PM_TabBarTabShiftHorizontal",
        "PM_TabBarTabShiftVertical",
        "PM_TabBarScrollButtonWidth",
        "PM_ToolBarFrameWidth",
        "PM_ToolBarHandleExtent",
        "PM_ToolBarItemSpacing",
        "PM_ToolBarItemMargin",
        "PM_ToolBarSeparatorExtent",
        "PM_ToolBarExtensionExtent",
        "PM_SpinBoxSliderHeight",
        "PM_ToolBarIconSize",
        "PM_ListViewIconSize",
        "PM_IconViewIconSize",
        "PM_SmallIconSize",
        "PM_LargeIconSize",
        "PM_FocusFrameVMargin",
        "PM_FocusFrameHMargin",
        "PM_ToolTipLabelFrameWidth",
        "PM_CheckBoxLabelSpacing",
        "PM_TabBarIconSize",
        "PM_SizeGripSize",
        "PM_DockWidgetTitleMargin",
        "PM_MessageBoxIconSize",
        "PM_ButtonIconSize",
        "PM_DockWidgetTitleBarButtonMargin",
        "PM_RadioButtonLabelSpacing",
        "PM_LayoutLeftMargin",
        "PM_LayoutTopMargin",
        "PM_LayoutRightMargin",
        "PM_LayoutBottomMargin",
        "PM_LayoutHorizontalSpacing",
        "PM_LayoutVerticalSpacing",
        "PM_TabBar_ScrollButtonOverlap",
        "PM_TextCursorWidth",
        "PM_TabCloseIndicatorWidth",
        "PM_TabCloseIndicatorHeight",
        "PM_ScrollView_ScrollBarSpacing",
        "PM_ScrollView_ScrollBarOverlap",
        "PM_SubMenuOverlap",
        "PM_TreeViewIndentation",
        "PM_HeaderDefaultSectionSizeHorizontal",
        "PM_HeaderDefaultSectionSizeVertical",
        "PM_TitleBarButtonIconSize",
        "PM_TitleBarButtonSize",
        "PM_LineEditIconSize",
        "PM_LineEditIconMargin",
        "PM_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t PixelMetric_InitializerValues[] = {
        uint32_t(QStyle::PixelMetric::PM_ButtonMargin),                       //  0x00000000  0
        uint32_t(QStyle::PixelMetric::PM_ButtonDefaultIndicator),             //  0x00000001  1
        uint32_t(QStyle::PixelMetric::PM_MenuButtonIndicator),                //  0x00000002  2
        uint32_t(QStyle::PixelMetric::PM_ButtonShiftHorizontal),              //  0x00000003  3
        uint32_t(QStyle::PixelMetric::PM_ButtonShiftVertical),                //  0x00000004  4
        uint32_t(QStyle::PixelMetric::PM_DefaultFrameWidth),                  //  0x00000005  5
        uint32_t(QStyle::PixelMetric::PM_SpinBoxFrameWidth),                  //  0x00000006  6
        uint32_t(QStyle::PixelMetric::PM_ComboBoxFrameWidth),                 //  0x00000007  7
        uint32_t(QStyle::PixelMetric::PM_MaximumDragDistance),                //  0x00000008  8
        uint32_t(QStyle::PixelMetric::PM_ScrollBarExtent),                    //  0x00000009  9
        uint32_t(QStyle::PixelMetric::PM_ScrollBarSliderMin),                 //  0x0000000a  10
        uint32_t(QStyle::PixelMetric::PM_SliderThickness),                    //  0x0000000b  11
        uint32_t(QStyle::PixelMetric::PM_SliderControlThickness),             //  0x0000000c  12
        uint32_t(QStyle::PixelMetric::PM_SliderLength),                       //  0x0000000d  13
        uint32_t(QStyle::PixelMetric::PM_SliderTickmarkOffset),               //  0x0000000e  14
        uint32_t(QStyle::PixelMetric::PM_SliderSpaceAvailable),               //  0x0000000f  15
        uint32_t(QStyle::PixelMetric::PM_DockWidgetSeparatorExtent),          //  0x00000010  16
        uint32_t(QStyle::PixelMetric::PM_DockWidgetHandleExtent),             //  0x00000011  17
        uint32_t(QStyle::PixelMetric::PM_DockWidgetFrameWidth),               //  0x00000012  18
        uint32_t(QStyle::PixelMetric::PM_TabBarTabOverlap),                   //  0x00000013  19
        uint32_t(QStyle::PixelMetric::PM_TabBarTabHSpace),                    //  0x00000014  20
        uint32_t(QStyle::PixelMetric::PM_TabBarTabVSpace),                    //  0x00000015  21
        uint32_t(QStyle::PixelMetric::PM_TabBarBaseHeight),                   //  0x00000016  22
        uint32_t(QStyle::PixelMetric::PM_TabBarBaseOverlap),                  //  0x00000017  23
        uint32_t(QStyle::PixelMetric::PM_ProgressBarChunkWidth),              //  0x00000018  24
        uint32_t(QStyle::PixelMetric::PM_SplitterWidth),                      //  0x00000019  25
        uint32_t(QStyle::PixelMetric::PM_TitleBarHeight),                     //  0x0000001a  26
        uint32_t(QStyle::PixelMetric::PM_MenuScrollerHeight),                 //  0x0000001b  27
        uint32_t(QStyle::PixelMetric::PM_MenuHMargin),                        //  0x0000001c  28
        uint32_t(QStyle::PixelMetric::PM_MenuVMargin),                        //  0x0000001d  29
        uint32_t(QStyle::PixelMetric::PM_MenuPanelWidth),                     //  0x0000001e  30
        uint32_t(QStyle::PixelMetric::PM_MenuTearoffHeight),                  //  0x0000001f  31
        uint32_t(QStyle::PixelMetric::PM_MenuDesktopFrameWidth),              //  0x00000020  32
        uint32_t(QStyle::PixelMetric::PM_MenuBarPanelWidth),                  //  0x00000021  33
        uint32_t(QStyle::PixelMetric::PM_MenuBarItemSpacing),                 //  0x00000022  34
        uint32_t(QStyle::PixelMetric::PM_MenuBarVMargin),                     //  0x00000023  35
        uint32_t(QStyle::PixelMetric::PM_MenuBarHMargin),                     //  0x00000024  36
        uint32_t(QStyle::PixelMetric::PM_IndicatorWidth),                     //  0x00000025  37
        uint32_t(QStyle::PixelMetric::PM_IndicatorHeight),                    //  0x00000026  38
        uint32_t(QStyle::PixelMetric::PM_ExclusiveIndicatorWidth),            //  0x00000027  39
        uint32_t(QStyle::PixelMetric::PM_ExclusiveIndicatorHeight),           //  0x00000028  40
        uint32_t(QStyle::PixelMetric::PM_DialogButtonsSeparator),             //  0x00000029  41
        uint32_t(QStyle::PixelMetric::PM_DialogButtonsButtonWidth),           //  0x0000002a  42
        uint32_t(QStyle::PixelMetric::PM_DialogButtonsButtonHeight),          //  0x0000002b  43
        uint32_t(QStyle::PixelMetric::PM_MdiSubWindowFrameWidth),             //  0x0000002c  44
        uint32_t(QStyle::PixelMetric::PM_MdiSubWindowMinimizedWidth),         //  0x0000002d  45
        uint32_t(QStyle::PixelMetric::PM_HeaderMargin),                       //  0x0000002e  46
        uint32_t(QStyle::PixelMetric::PM_HeaderMarkSize),                     //  0x0000002f  47
        uint32_t(QStyle::PixelMetric::PM_HeaderGripMargin),                   //  0x00000030  48
        uint32_t(QStyle::PixelMetric::PM_TabBarTabShiftHorizontal),           //  0x00000031  49
        uint32_t(QStyle::PixelMetric::PM_TabBarTabShiftVertical),             //  0x00000032  50
        uint32_t(QStyle::PixelMetric::PM_TabBarScrollButtonWidth),            //  0x00000033  51
        uint32_t(QStyle::PixelMetric::PM_ToolBarFrameWidth),                  //  0x00000034  52
        uint32_t(QStyle::PixelMetric::PM_ToolBarHandleExtent),                //  0x00000035  53
        uint32_t(QStyle::PixelMetric::PM_ToolBarItemSpacing),                 //  0x00000036  54
        uint32_t(QStyle::PixelMetric::PM_ToolBarItemMargin),                  //  0x00000037  55
        uint32_t(QStyle::PixelMetric::PM_ToolBarSeparatorExtent),             //  0x00000038  56
        uint32_t(QStyle::PixelMetric::PM_ToolBarExtensionExtent),             //  0x00000039  57
        uint32_t(QStyle::PixelMetric::PM_SpinBoxSliderHeight),                //  0x0000003a  58
        uint32_t(QStyle::PixelMetric::PM_ToolBarIconSize),                    //  0x0000003b  59
        uint32_t(QStyle::PixelMetric::PM_ListViewIconSize),                   //  0x0000003c  60
        uint32_t(QStyle::PixelMetric::PM_IconViewIconSize),                   //  0x0000003d  61
        uint32_t(QStyle::PixelMetric::PM_SmallIconSize),                      //  0x0000003e  62
        uint32_t(QStyle::PixelMetric::PM_LargeIconSize),                      //  0x0000003f  63
        uint32_t(QStyle::PixelMetric::PM_FocusFrameVMargin),                  //  0x00000040  64
        uint32_t(QStyle::PixelMetric::PM_FocusFrameHMargin),                  //  0x00000041  65
        uint32_t(QStyle::PixelMetric::PM_ToolTipLabelFrameWidth),             //  0x00000042  66
        uint32_t(QStyle::PixelMetric::PM_CheckBoxLabelSpacing),               //  0x00000043  67
        uint32_t(QStyle::PixelMetric::PM_TabBarIconSize),                     //  0x00000044  68
        uint32_t(QStyle::PixelMetric::PM_SizeGripSize),                       //  0x00000045  69
        uint32_t(QStyle::PixelMetric::PM_DockWidgetTitleMargin),              //  0x00000046  70
        uint32_t(QStyle::PixelMetric::PM_MessageBoxIconSize),                 //  0x00000047  71
        uint32_t(QStyle::PixelMetric::PM_ButtonIconSize),                     //  0x00000048  72
        uint32_t(QStyle::PixelMetric::PM_DockWidgetTitleBarButtonMargin),     //  0x00000049  73
        uint32_t(QStyle::PixelMetric::PM_RadioButtonLabelSpacing),            //  0x0000004a  74
        uint32_t(QStyle::PixelMetric::PM_LayoutLeftMargin),                   //  0x0000004b  75
        uint32_t(QStyle::PixelMetric::PM_LayoutTopMargin),                    //  0x0000004c  76
        uint32_t(QStyle::PixelMetric::PM_LayoutRightMargin),                  //  0x0000004d  77
        uint32_t(QStyle::PixelMetric::PM_LayoutBottomMargin),                 //  0x0000004e  78
        uint32_t(QStyle::PixelMetric::PM_LayoutHorizontalSpacing),            //  0x0000004f  79
        uint32_t(QStyle::PixelMetric::PM_LayoutVerticalSpacing),              //  0x00000050  80
        uint32_t(QStyle::PixelMetric::PM_TabBar_ScrollButtonOverlap),         //  0x00000051  81
        uint32_t(QStyle::PixelMetric::PM_TextCursorWidth),                    //  0x00000052  82
        uint32_t(QStyle::PixelMetric::PM_TabCloseIndicatorWidth),             //  0x00000053  83
        uint32_t(QStyle::PixelMetric::PM_TabCloseIndicatorHeight),            //  0x00000054  84
        uint32_t(QStyle::PixelMetric::PM_ScrollView_ScrollBarSpacing),        //  0x00000055  85
        uint32_t(QStyle::PixelMetric::PM_ScrollView_ScrollBarOverlap),        //  0x00000056  86
        uint32_t(QStyle::PixelMetric::PM_SubMenuOverlap),                     //  0x00000057  87
        uint32_t(QStyle::PixelMetric::PM_TreeViewIndentation),                //  0x00000058  88
        uint32_t(QStyle::PixelMetric::PM_HeaderDefaultSectionSizeHorizontal), //  0x00000059  89
        uint32_t(QStyle::PixelMetric::PM_HeaderDefaultSectionSizeVertical),   //  0x0000005a  90
        uint32_t(QStyle::PixelMetric::PM_TitleBarButtonIconSize),             //  0x0000005b  91
        uint32_t(QStyle::PixelMetric::PM_TitleBarButtonSize),                 //  0x0000005c  92
        uint32_t(QStyle::PixelMetric::PM_LineEditIconSize),                   //  0x0000005d  93
        uint32_t(QStyle::PixelMetric::PM_LineEditIconMargin),                 //  0x0000005e  94
        uint32_t(QStyle::PixelMetric::PM_CustomBase)                          //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.PixelMetric",
        PixelMetric_Initializer, PixelMetric_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_PixelMetric_IDX].type = EType;
    // Register converter for enum 'QStyle::PixelMetric'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_PixelMetric_CppToPython_QStyle_PixelMetric);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_PixelMetric_PythonToCpp_QStyle_PixelMetric,
            is_QStyle_PixelMetric_PythonToCpp_QStyle_PixelMetric_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::PixelMetric");
        Shiboken::Conversions::registerConverterName(converter, "PixelMetric");
    }
    // End of 'PixelMetric' enum.

    // Initialization of enum 'ContentsType'.
    const char *ContentsType_Initializer[] = {
        "CT_PushButton",
        "CT_CheckBox",
        "CT_RadioButton",
        "CT_ToolButton",
        "CT_ComboBox",
        "CT_Splitter",
        "CT_ProgressBar",
        "CT_MenuItem",
        "CT_MenuBarItem",
        "CT_MenuBar",
        "CT_Menu",
        "CT_TabBarTab",
        "CT_Slider",
        "CT_ScrollBar",
        "CT_LineEdit",
        "CT_SpinBox",
        "CT_SizeGrip",
        "CT_TabWidget",
        "CT_DialogButtons",
        "CT_HeaderSection",
        "CT_GroupBox",
        "CT_MdiControls",
        "CT_ItemViewItem",
        "CT_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t ContentsType_InitializerValues[] = {
        uint32_t(QStyle::ContentsType::CT_PushButton),    //  0x00000000  0
        uint32_t(QStyle::ContentsType::CT_CheckBox),      //  0x00000001  1
        uint32_t(QStyle::ContentsType::CT_RadioButton),   //  0x00000002  2
        uint32_t(QStyle::ContentsType::CT_ToolButton),    //  0x00000003  3
        uint32_t(QStyle::ContentsType::CT_ComboBox),      //  0x00000004  4
        uint32_t(QStyle::ContentsType::CT_Splitter),      //  0x00000005  5
        uint32_t(QStyle::ContentsType::CT_ProgressBar),   //  0x00000006  6
        uint32_t(QStyle::ContentsType::CT_MenuItem),      //  0x00000007  7
        uint32_t(QStyle::ContentsType::CT_MenuBarItem),   //  0x00000008  8
        uint32_t(QStyle::ContentsType::CT_MenuBar),       //  0x00000009  9
        uint32_t(QStyle::ContentsType::CT_Menu),          //  0x0000000a  10
        uint32_t(QStyle::ContentsType::CT_TabBarTab),     //  0x0000000b  11
        uint32_t(QStyle::ContentsType::CT_Slider),        //  0x0000000c  12
        uint32_t(QStyle::ContentsType::CT_ScrollBar),     //  0x0000000d  13
        uint32_t(QStyle::ContentsType::CT_LineEdit),      //  0x0000000e  14
        uint32_t(QStyle::ContentsType::CT_SpinBox),       //  0x0000000f  15
        uint32_t(QStyle::ContentsType::CT_SizeGrip),      //  0x00000010  16
        uint32_t(QStyle::ContentsType::CT_TabWidget),     //  0x00000011  17
        uint32_t(QStyle::ContentsType::CT_DialogButtons), //  0x00000012  18
        uint32_t(QStyle::ContentsType::CT_HeaderSection), //  0x00000013  19
        uint32_t(QStyle::ContentsType::CT_GroupBox),      //  0x00000014  20
        uint32_t(QStyle::ContentsType::CT_MdiControls),   //  0x00000015  21
        uint32_t(QStyle::ContentsType::CT_ItemViewItem),  //  0x00000016  22
        uint32_t(QStyle::ContentsType::CT_CustomBase)     //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.ContentsType",
        ContentsType_Initializer, ContentsType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_ContentsType_IDX].type = EType;
    // Register converter for enum 'QStyle::ContentsType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_ContentsType_CppToPython_QStyle_ContentsType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_ContentsType_PythonToCpp_QStyle_ContentsType,
            is_QStyle_ContentsType_PythonToCpp_QStyle_ContentsType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::ContentsType");
        Shiboken::Conversions::registerConverterName(converter, "ContentsType");
    }
    // End of 'ContentsType' enum.

    // Initialization of enum 'RequestSoftwareInputPanel'.
    const char *RequestSoftwareInputPanel_Initializer[] = {
        "RSIP_OnMouseClickAndAlreadyFocused",
        "RSIP_OnMouseClick",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RequestSoftwareInputPanel_InitializerValues[] = {
        uint8_t(QStyle::RequestSoftwareInputPanel::RSIP_OnMouseClickAndAlreadyFocused), //  0x00  0
        uint8_t(QStyle::RequestSoftwareInputPanel::RSIP_OnMouseClick)                   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.RequestSoftwareInputPanel",
        RequestSoftwareInputPanel_Initializer, RequestSoftwareInputPanel_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_RequestSoftwareInputPanel_IDX].type = EType;
    // Register converter for enum 'QStyle::RequestSoftwareInputPanel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_RequestSoftwareInputPanel_CppToPython_QStyle_RequestSoftwareInputPanel);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_RequestSoftwareInputPanel_PythonToCpp_QStyle_RequestSoftwareInputPanel,
            is_QStyle_RequestSoftwareInputPanel_PythonToCpp_QStyle_RequestSoftwareInputPanel_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::RequestSoftwareInputPanel");
        Shiboken::Conversions::registerConverterName(converter, "RequestSoftwareInputPanel");
    }
    // End of 'RequestSoftwareInputPanel' enum.

    // Initialization of enum 'StyleHint'.
    const char *StyleHint_Initializer[] = {
        "SH_EtchDisabledText",
        "SH_DitherDisabledText",
        "SH_ScrollBar_MiddleClickAbsolutePosition",
        "SH_ScrollBar_ScrollWhenPointerLeavesControl",
        "SH_TabBar_SelectMouseType",
        "SH_TabBar_Alignment",
        "SH_Header_ArrowAlignment",
        "SH_Slider_SnapToValue",
        "SH_Slider_SloppyKeyEvents",
        "SH_ProgressDialog_CenterCancelButton",
        "SH_ProgressDialog_TextLabelAlignment",
        "SH_PrintDialog_RightAlignButtons",
        "SH_MainWindow_SpaceBelowMenuBar",
        "SH_FontDialog_SelectAssociatedText",
        "SH_Menu_AllowActiveAndDisabled",
        "SH_Menu_SpaceActivatesItem",
        "SH_Menu_SubMenuPopupDelay",
        "SH_ScrollView_FrameOnlyAroundContents",
        "SH_MenuBar_AltKeyNavigation",
        "SH_ComboBox_ListMouseTracking",
        "SH_Menu_MouseTracking",
        "SH_MenuBar_MouseTracking",
        "SH_ItemView_ChangeHighlightOnFocus",
        "SH_Widget_ShareActivation",
        "SH_Workspace_FillSpaceOnMaximize",
        "SH_ComboBox_Popup",
        "SH_TitleBar_NoBorder",
        "SH_Slider_StopMouseOverSlider",
        "SH_BlinkCursorWhenTextSelected",
        "SH_RichText_FullWidthSelection",
        "SH_Menu_Scrollable",
        "SH_GroupBox_TextLabelVerticalAlignment",
        "SH_GroupBox_TextLabelColor",
        "SH_Menu_SloppySubMenus",
        "SH_Table_GridLineColor",
        "SH_LineEdit_PasswordCharacter",
        "SH_DialogButtons_DefaultButton",
        "SH_ToolBox_SelectedPageTitleBold",
        "SH_TabBar_PreferNoArrows",
        "SH_ScrollBar_LeftClickAbsolutePosition",
        "SH_ListViewExpand_SelectMouseType",
        "SH_UnderlineShortcut",
        "SH_SpinBox_AnimateButton",
        "SH_SpinBox_KeyPressAutoRepeatRate",
        "SH_SpinBox_ClickAutoRepeatRate",
        "SH_Menu_FillScreenWithScroll",
        "SH_ToolTipLabel_Opacity",
        "SH_DrawMenuBarSeparator",
        "SH_TitleBar_ModifyNotification",
        "SH_Button_FocusPolicy",
        "SH_MessageBox_UseBorderForButtonSpacing",
        "SH_TitleBar_AutoRaise",
        "SH_ToolButton_PopupDelay",
        "SH_FocusFrame_Mask",
        "SH_RubberBand_Mask",
        "SH_WindowFrame_Mask",
        "SH_SpinControls_DisableOnBounds",
        "SH_Dial_BackgroundRole",
        "SH_ComboBox_LayoutDirection",
        "SH_ItemView_EllipsisLocation",
        "SH_ItemView_ShowDecorationSelected",
        "SH_ItemView_ActivateItemOnSingleClick",
        "SH_ScrollBar_ContextMenu",
        "SH_ScrollBar_RollBetweenButtons",
        "SH_Slider_AbsoluteSetButtons",
        "SH_Slider_PageSetButtons",
        "SH_Menu_KeyboardSearch",
        "SH_TabBar_ElideMode",
        "SH_DialogButtonLayout",
        "SH_ComboBox_PopupFrameStyle",
        "SH_MessageBox_TextInteractionFlags",
        "SH_DialogButtonBox_ButtonsHaveIcons",
        "SH_MessageBox_CenterButtons",
        "SH_Menu_SelectionWrap",
        "SH_ItemView_MovementWithoutUpdatingSelection",
        "SH_ToolTip_Mask",
        "SH_FocusFrame_AboveWidget",
        "SH_TextControl_FocusIndicatorTextCharFormat",
        "SH_WizardStyle",
        "SH_ItemView_ArrowKeysNavigateIntoChildren",
        "SH_Menu_Mask",
        "SH_Menu_FlashTriggeredItem",
        "SH_Menu_FadeOutOnHide",
        "SH_SpinBox_ClickAutoRepeatThreshold",
        "SH_ItemView_PaintAlternatingRowColorsForEmptyArea",
        "SH_FormLayoutWrapPolicy",
        "SH_TabWidget_DefaultTabPosition",
        "SH_ToolBar_Movable",
        "SH_FormLayoutFieldGrowthPolicy",
        "SH_FormLayoutFormAlignment",
        "SH_FormLayoutLabelAlignment",
        "SH_ItemView_DrawDelegateFrame",
        "SH_TabBar_CloseButtonPosition",
        "SH_DockWidget_ButtonsHaveFrame",
        "SH_ToolButtonStyle",
        "SH_RequestSoftwareInputPanel",
        "SH_ScrollBar_Transient",
        "SH_Menu_SupportsSections",
        "SH_ToolTip_WakeUpDelay",
        "SH_ToolTip_FallAsleepDelay",
        "SH_Widget_Animate",
        "SH_Splitter_OpaqueResize",
        "SH_ComboBox_UseNativePopup",
        "SH_LineEdit_PasswordMaskDelay",
        "SH_TabBar_ChangeCurrentDelay",
        "SH_Menu_SubMenuUniDirection",
        "SH_Menu_SubMenuUniDirectionFailCount",
        "SH_Menu_SubMenuSloppySelectOtherActions",
        "SH_Menu_SubMenuSloppyCloseTimeout",
        "SH_Menu_SubMenuResetWhenReenteringParent",
        "SH_Menu_SubMenuDontStartSloppyOnLeave",
        "SH_ItemView_ScrollMode",
        "SH_TitleBar_ShowToolTipsOnButtons",
        "SH_Widget_Animation_Duration",
        "SH_ComboBox_AllowWheelScrolling",
        "SH_SpinBox_ButtonsInsideFrame",
        "SH_SpinBox_StepModifier",
        "SH_TabBar_AllowWheelScrolling",
        "SH_Table_AlwaysDrawLeftTopGridLines",
        "SH_SpinBox_SelectOnStep",
        "SH_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StyleHint_InitializerValues[] = {
        uint32_t(QStyle::StyleHint::SH_EtchDisabledText),                               //  0x00000000  0
        uint32_t(QStyle::StyleHint::SH_DitherDisabledText),                             //  0x00000001  1
        uint32_t(QStyle::StyleHint::SH_ScrollBar_MiddleClickAbsolutePosition),          //  0x00000002  2
        uint32_t(QStyle::StyleHint::SH_ScrollBar_ScrollWhenPointerLeavesControl),       //  0x00000003  3
        uint32_t(QStyle::StyleHint::SH_TabBar_SelectMouseType),                         //  0x00000004  4
        uint32_t(QStyle::StyleHint::SH_TabBar_Alignment),                               //  0x00000005  5
        uint32_t(QStyle::StyleHint::SH_Header_ArrowAlignment),                          //  0x00000006  6
        uint32_t(QStyle::StyleHint::SH_Slider_SnapToValue),                             //  0x00000007  7
        uint32_t(QStyle::StyleHint::SH_Slider_SloppyKeyEvents),                         //  0x00000008  8
        uint32_t(QStyle::StyleHint::SH_ProgressDialog_CenterCancelButton),              //  0x00000009  9
        uint32_t(QStyle::StyleHint::SH_ProgressDialog_TextLabelAlignment),              //  0x0000000a  10
        uint32_t(QStyle::StyleHint::SH_PrintDialog_RightAlignButtons),                  //  0x0000000b  11
        uint32_t(QStyle::StyleHint::SH_MainWindow_SpaceBelowMenuBar),                   //  0x0000000c  12
        uint32_t(QStyle::StyleHint::SH_FontDialog_SelectAssociatedText),                //  0x0000000d  13
        uint32_t(QStyle::StyleHint::SH_Menu_AllowActiveAndDisabled),                    //  0x0000000e  14
        uint32_t(QStyle::StyleHint::SH_Menu_SpaceActivatesItem),                        //  0x0000000f  15
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuPopupDelay),                         //  0x00000010  16
        uint32_t(QStyle::StyleHint::SH_ScrollView_FrameOnlyAroundContents),             //  0x00000011  17
        uint32_t(QStyle::StyleHint::SH_MenuBar_AltKeyNavigation),                       //  0x00000012  18
        uint32_t(QStyle::StyleHint::SH_ComboBox_ListMouseTracking),                     //  0x00000013  19
        uint32_t(QStyle::StyleHint::SH_Menu_MouseTracking),                             //  0x00000014  20
        uint32_t(QStyle::StyleHint::SH_MenuBar_MouseTracking),                          //  0x00000015  21
        uint32_t(QStyle::StyleHint::SH_ItemView_ChangeHighlightOnFocus),                //  0x00000016  22
        uint32_t(QStyle::StyleHint::SH_Widget_ShareActivation),                         //  0x00000017  23
        uint32_t(QStyle::StyleHint::SH_Workspace_FillSpaceOnMaximize),                  //  0x00000018  24
        uint32_t(QStyle::StyleHint::SH_ComboBox_Popup),                                 //  0x00000019  25
        uint32_t(QStyle::StyleHint::SH_TitleBar_NoBorder),                              //  0x0000001a  26
        uint32_t(QStyle::StyleHint::SH_Slider_StopMouseOverSlider),                     //  0x0000001b  27
        uint32_t(QStyle::StyleHint::SH_BlinkCursorWhenTextSelected),                    //  0x0000001c  28
        uint32_t(QStyle::StyleHint::SH_RichText_FullWidthSelection),                    //  0x0000001d  29
        uint32_t(QStyle::StyleHint::SH_Menu_Scrollable),                                //  0x0000001e  30
        uint32_t(QStyle::StyleHint::SH_GroupBox_TextLabelVerticalAlignment),            //  0x0000001f  31
        uint32_t(QStyle::StyleHint::SH_GroupBox_TextLabelColor),                        //  0x00000020  32
        uint32_t(QStyle::StyleHint::SH_Menu_SloppySubMenus),                            //  0x00000021  33
        uint32_t(QStyle::StyleHint::SH_Table_GridLineColor),                            //  0x00000022  34
        uint32_t(QStyle::StyleHint::SH_LineEdit_PasswordCharacter),                     //  0x00000023  35
        uint32_t(QStyle::StyleHint::SH_DialogButtons_DefaultButton),                    //  0x00000024  36
        uint32_t(QStyle::StyleHint::SH_ToolBox_SelectedPageTitleBold),                  //  0x00000025  37
        uint32_t(QStyle::StyleHint::SH_TabBar_PreferNoArrows),                          //  0x00000026  38
        uint32_t(QStyle::StyleHint::SH_ScrollBar_LeftClickAbsolutePosition),            //  0x00000027  39
        uint32_t(QStyle::StyleHint::SH_ListViewExpand_SelectMouseType),                 //  0x00000028  40
        uint32_t(QStyle::StyleHint::SH_UnderlineShortcut),                              //  0x00000029  41
        uint32_t(QStyle::StyleHint::SH_SpinBox_AnimateButton),                          //  0x0000002a  42
        uint32_t(QStyle::StyleHint::SH_SpinBox_KeyPressAutoRepeatRate),                 //  0x0000002b  43
        uint32_t(QStyle::StyleHint::SH_SpinBox_ClickAutoRepeatRate),                    //  0x0000002c  44
        uint32_t(QStyle::StyleHint::SH_Menu_FillScreenWithScroll),                      //  0x0000002d  45
        uint32_t(QStyle::StyleHint::SH_ToolTipLabel_Opacity),                           //  0x0000002e  46
        uint32_t(QStyle::StyleHint::SH_DrawMenuBarSeparator),                           //  0x0000002f  47
        uint32_t(QStyle::StyleHint::SH_TitleBar_ModifyNotification),                    //  0x00000030  48
        uint32_t(QStyle::StyleHint::SH_Button_FocusPolicy),                             //  0x00000031  49
        uint32_t(QStyle::StyleHint::SH_MessageBox_UseBorderForButtonSpacing),           //  0x00000032  50
        uint32_t(QStyle::StyleHint::SH_TitleBar_AutoRaise),                             //  0x00000033  51
        uint32_t(QStyle::StyleHint::SH_ToolButton_PopupDelay),                          //  0x00000034  52
        uint32_t(QStyle::StyleHint::SH_FocusFrame_Mask),                                //  0x00000035  53
        uint32_t(QStyle::StyleHint::SH_RubberBand_Mask),                                //  0x00000036  54
        uint32_t(QStyle::StyleHint::SH_WindowFrame_Mask),                               //  0x00000037  55
        uint32_t(QStyle::StyleHint::SH_SpinControls_DisableOnBounds),                   //  0x00000038  56
        uint32_t(QStyle::StyleHint::SH_Dial_BackgroundRole),                            //  0x00000039  57
        uint32_t(QStyle::StyleHint::SH_ComboBox_LayoutDirection),                       //  0x0000003a  58
        uint32_t(QStyle::StyleHint::SH_ItemView_EllipsisLocation),                      //  0x0000003b  59
        uint32_t(QStyle::StyleHint::SH_ItemView_ShowDecorationSelected),                //  0x0000003c  60
        uint32_t(QStyle::StyleHint::SH_ItemView_ActivateItemOnSingleClick),             //  0x0000003d  61
        uint32_t(QStyle::StyleHint::SH_ScrollBar_ContextMenu),                          //  0x0000003e  62
        uint32_t(QStyle::StyleHint::SH_ScrollBar_RollBetweenButtons),                   //  0x0000003f  63
        uint32_t(QStyle::StyleHint::SH_Slider_AbsoluteSetButtons),                      //  0x00000040  64
        uint32_t(QStyle::StyleHint::SH_Slider_PageSetButtons),                          //  0x00000041  65
        uint32_t(QStyle::StyleHint::SH_Menu_KeyboardSearch),                            //  0x00000042  66
        uint32_t(QStyle::StyleHint::SH_TabBar_ElideMode),                               //  0x00000043  67
        uint32_t(QStyle::StyleHint::SH_DialogButtonLayout),                             //  0x00000044  68
        uint32_t(QStyle::StyleHint::SH_ComboBox_PopupFrameStyle),                       //  0x00000045  69
        uint32_t(QStyle::StyleHint::SH_MessageBox_TextInteractionFlags),                //  0x00000046  70
        uint32_t(QStyle::StyleHint::SH_DialogButtonBox_ButtonsHaveIcons),               //  0x00000047  71
        uint32_t(QStyle::StyleHint::SH_MessageBox_CenterButtons),                       //  0x00000048  72
        uint32_t(QStyle::StyleHint::SH_Menu_SelectionWrap),                             //  0x00000049  73
        uint32_t(QStyle::StyleHint::SH_ItemView_MovementWithoutUpdatingSelection),      //  0x0000004a  74
        uint32_t(QStyle::StyleHint::SH_ToolTip_Mask),                                   //  0x0000004b  75
        uint32_t(QStyle::StyleHint::SH_FocusFrame_AboveWidget),                         //  0x0000004c  76
        uint32_t(QStyle::StyleHint::SH_TextControl_FocusIndicatorTextCharFormat),       //  0x0000004d  77
        uint32_t(QStyle::StyleHint::SH_WizardStyle),                                    //  0x0000004e  78
        uint32_t(QStyle::StyleHint::SH_ItemView_ArrowKeysNavigateIntoChildren),         //  0x0000004f  79
        uint32_t(QStyle::StyleHint::SH_Menu_Mask),                                      //  0x00000050  80
        uint32_t(QStyle::StyleHint::SH_Menu_FlashTriggeredItem),                        //  0x00000051  81
        uint32_t(QStyle::StyleHint::SH_Menu_FadeOutOnHide),                             //  0x00000052  82
        uint32_t(QStyle::StyleHint::SH_SpinBox_ClickAutoRepeatThreshold),               //  0x00000053  83
        uint32_t(QStyle::StyleHint::SH_ItemView_PaintAlternatingRowColorsForEmptyArea), //  0x00000054  84
        uint32_t(QStyle::StyleHint::SH_FormLayoutWrapPolicy),                           //  0x00000055  85
        uint32_t(QStyle::StyleHint::SH_TabWidget_DefaultTabPosition),                   //  0x00000056  86
        uint32_t(QStyle::StyleHint::SH_ToolBar_Movable),                                //  0x00000057  87
        uint32_t(QStyle::StyleHint::SH_FormLayoutFieldGrowthPolicy),                    //  0x00000058  88
        uint32_t(QStyle::StyleHint::SH_FormLayoutFormAlignment),                        //  0x00000059  89
        uint32_t(QStyle::StyleHint::SH_FormLayoutLabelAlignment),                       //  0x0000005a  90
        uint32_t(QStyle::StyleHint::SH_ItemView_DrawDelegateFrame),                     //  0x0000005b  91
        uint32_t(QStyle::StyleHint::SH_TabBar_CloseButtonPosition),                     //  0x0000005c  92
        uint32_t(QStyle::StyleHint::SH_DockWidget_ButtonsHaveFrame),                    //  0x0000005d  93
        uint32_t(QStyle::StyleHint::SH_ToolButtonStyle),                                //  0x0000005e  94
        uint32_t(QStyle::StyleHint::SH_RequestSoftwareInputPanel),                      //  0x0000005f  95
        uint32_t(QStyle::StyleHint::SH_ScrollBar_Transient),                            //  0x00000060  96
        uint32_t(QStyle::StyleHint::SH_Menu_SupportsSections),                          //  0x00000061  97
        uint32_t(QStyle::StyleHint::SH_ToolTip_WakeUpDelay),                            //  0x00000062  98
        uint32_t(QStyle::StyleHint::SH_ToolTip_FallAsleepDelay),                        //  0x00000063  99
        uint32_t(QStyle::StyleHint::SH_Widget_Animate),                                 //  0x00000064  100
        uint32_t(QStyle::StyleHint::SH_Splitter_OpaqueResize),                          //  0x00000065  101
        uint32_t(QStyle::StyleHint::SH_ComboBox_UseNativePopup),                        //  0x00000066  102
        uint32_t(QStyle::StyleHint::SH_LineEdit_PasswordMaskDelay),                     //  0x00000067  103
        uint32_t(QStyle::StyleHint::SH_TabBar_ChangeCurrentDelay),                      //  0x00000068  104
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuUniDirection),                       //  0x00000069  105
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuUniDirectionFailCount),              //  0x0000006a  106
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuSloppySelectOtherActions),           //  0x0000006b  107
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuSloppyCloseTimeout),                 //  0x0000006c  108
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuResetWhenReenteringParent),          //  0x0000006d  109
        uint32_t(QStyle::StyleHint::SH_Menu_SubMenuDontStartSloppyOnLeave),             //  0x0000006e  110
        uint32_t(QStyle::StyleHint::SH_ItemView_ScrollMode),                            //  0x0000006f  111
        uint32_t(QStyle::StyleHint::SH_TitleBar_ShowToolTipsOnButtons),                 //  0x00000070  112
        uint32_t(QStyle::StyleHint::SH_Widget_Animation_Duration),                      //  0x00000071  113
        uint32_t(QStyle::StyleHint::SH_ComboBox_AllowWheelScrolling),                   //  0x00000072  114
        uint32_t(QStyle::StyleHint::SH_SpinBox_ButtonsInsideFrame),                     //  0x00000073  115
        uint32_t(QStyle::StyleHint::SH_SpinBox_StepModifier),                           //  0x00000074  116
        uint32_t(QStyle::StyleHint::SH_TabBar_AllowWheelScrolling),                     //  0x00000075  117
        uint32_t(QStyle::StyleHint::SH_Table_AlwaysDrawLeftTopGridLines),               //  0x00000076  118
        uint32_t(QStyle::StyleHint::SH_SpinBox_SelectOnStep),                           //  0x00000077  119
        uint32_t(QStyle::StyleHint::SH_CustomBase)                                      //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.StyleHint",
        StyleHint_Initializer, StyleHint_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StyleHint_IDX].type = EType;
    // Register converter for enum 'QStyle::StyleHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_StyleHint_CppToPython_QStyle_StyleHint);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_StyleHint_PythonToCpp_QStyle_StyleHint,
            is_QStyle_StyleHint_PythonToCpp_QStyle_StyleHint_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::StyleHint");
        Shiboken::Conversions::registerConverterName(converter, "StyleHint");
    }
    // End of 'StyleHint' enum.

    // Initialization of enum 'StandardPixmap'.
    const char *StandardPixmap_Initializer[] = {
        "SP_TitleBarMenuButton",
        "SP_TitleBarMinButton",
        "SP_TitleBarMaxButton",
        "SP_TitleBarCloseButton",
        "SP_TitleBarNormalButton",
        "SP_TitleBarShadeButton",
        "SP_TitleBarUnshadeButton",
        "SP_TitleBarContextHelpButton",
        "SP_DockWidgetCloseButton",
        "SP_MessageBoxInformation",
        "SP_MessageBoxWarning",
        "SP_MessageBoxCritical",
        "SP_MessageBoxQuestion",
        "SP_DesktopIcon",
        "SP_TrashIcon",
        "SP_ComputerIcon",
        "SP_DriveFDIcon",
        "SP_DriveHDIcon",
        "SP_DriveCDIcon",
        "SP_DriveDVDIcon",
        "SP_DriveNetIcon",
        "SP_DirOpenIcon",
        "SP_DirClosedIcon",
        "SP_DirLinkIcon",
        "SP_DirLinkOpenIcon",
        "SP_FileIcon",
        "SP_FileLinkIcon",
        "SP_ToolBarHorizontalExtensionButton",
        "SP_ToolBarVerticalExtensionButton",
        "SP_FileDialogStart",
        "SP_FileDialogEnd",
        "SP_FileDialogToParent",
        "SP_FileDialogNewFolder",
        "SP_FileDialogDetailedView",
        "SP_FileDialogInfoView",
        "SP_FileDialogContentsView",
        "SP_FileDialogListView",
        "SP_FileDialogBack",
        "SP_DirIcon",
        "SP_DialogOkButton",
        "SP_DialogCancelButton",
        "SP_DialogHelpButton",
        "SP_DialogOpenButton",
        "SP_DialogSaveButton",
        "SP_DialogCloseButton",
        "SP_DialogApplyButton",
        "SP_DialogResetButton",
        "SP_DialogDiscardButton",
        "SP_DialogYesButton",
        "SP_DialogNoButton",
        "SP_ArrowUp",
        "SP_ArrowDown",
        "SP_ArrowLeft",
        "SP_ArrowRight",
        "SP_ArrowBack",
        "SP_ArrowForward",
        "SP_DirHomeIcon",
        "SP_CommandLink",
        "SP_VistaShield",
        "SP_BrowserReload",
        "SP_BrowserStop",
        "SP_MediaPlay",
        "SP_MediaStop",
        "SP_MediaPause",
        "SP_MediaSkipForward",
        "SP_MediaSkipBackward",
        "SP_MediaSeekForward",
        "SP_MediaSeekBackward",
        "SP_MediaVolume",
        "SP_MediaVolumeMuted",
        "SP_LineEditClearButton",
        "SP_DialogYesToAllButton",
        "SP_DialogNoToAllButton",
        "SP_DialogSaveAllButton",
        "SP_DialogAbortButton",
        "SP_DialogRetryButton",
        "SP_DialogIgnoreButton",
        "SP_RestoreDefaultsButton",
        "SP_TabCloseButton",
        "NStandardPixmap",
        "SP_CustomBase",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StandardPixmap_InitializerValues[] = {
        uint32_t(QStyle::StandardPixmap::SP_TitleBarMenuButton),               //  0x00000000  0
        uint32_t(QStyle::StandardPixmap::SP_TitleBarMinButton),                //  0x00000001  1
        uint32_t(QStyle::StandardPixmap::SP_TitleBarMaxButton),                //  0x00000002  2
        uint32_t(QStyle::StandardPixmap::SP_TitleBarCloseButton),              //  0x00000003  3
        uint32_t(QStyle::StandardPixmap::SP_TitleBarNormalButton),             //  0x00000004  4
        uint32_t(QStyle::StandardPixmap::SP_TitleBarShadeButton),              //  0x00000005  5
        uint32_t(QStyle::StandardPixmap::SP_TitleBarUnshadeButton),            //  0x00000006  6
        uint32_t(QStyle::StandardPixmap::SP_TitleBarContextHelpButton),        //  0x00000007  7
        uint32_t(QStyle::StandardPixmap::SP_DockWidgetCloseButton),            //  0x00000008  8
        uint32_t(QStyle::StandardPixmap::SP_MessageBoxInformation),            //  0x00000009  9
        uint32_t(QStyle::StandardPixmap::SP_MessageBoxWarning),                //  0x0000000a  10
        uint32_t(QStyle::StandardPixmap::SP_MessageBoxCritical),               //  0x0000000b  11
        uint32_t(QStyle::StandardPixmap::SP_MessageBoxQuestion),               //  0x0000000c  12
        uint32_t(QStyle::StandardPixmap::SP_DesktopIcon),                      //  0x0000000d  13
        uint32_t(QStyle::StandardPixmap::SP_TrashIcon),                        //  0x0000000e  14
        uint32_t(QStyle::StandardPixmap::SP_ComputerIcon),                     //  0x0000000f  15
        uint32_t(QStyle::StandardPixmap::SP_DriveFDIcon),                      //  0x00000010  16
        uint32_t(QStyle::StandardPixmap::SP_DriveHDIcon),                      //  0x00000011  17
        uint32_t(QStyle::StandardPixmap::SP_DriveCDIcon),                      //  0x00000012  18
        uint32_t(QStyle::StandardPixmap::SP_DriveDVDIcon),                     //  0x00000013  19
        uint32_t(QStyle::StandardPixmap::SP_DriveNetIcon),                     //  0x00000014  20
        uint32_t(QStyle::StandardPixmap::SP_DirOpenIcon),                      //  0x00000015  21
        uint32_t(QStyle::StandardPixmap::SP_DirClosedIcon),                    //  0x00000016  22
        uint32_t(QStyle::StandardPixmap::SP_DirLinkIcon),                      //  0x00000017  23
        uint32_t(QStyle::StandardPixmap::SP_DirLinkOpenIcon),                  //  0x00000018  24
        uint32_t(QStyle::StandardPixmap::SP_FileIcon),                         //  0x00000019  25
        uint32_t(QStyle::StandardPixmap::SP_FileLinkIcon),                     //  0x0000001a  26
        uint32_t(QStyle::StandardPixmap::SP_ToolBarHorizontalExtensionButton), //  0x0000001b  27
        uint32_t(QStyle::StandardPixmap::SP_ToolBarVerticalExtensionButton),   //  0x0000001c  28
        uint32_t(QStyle::StandardPixmap::SP_FileDialogStart),                  //  0x0000001d  29
        uint32_t(QStyle::StandardPixmap::SP_FileDialogEnd),                    //  0x0000001e  30
        uint32_t(QStyle::StandardPixmap::SP_FileDialogToParent),               //  0x0000001f  31
        uint32_t(QStyle::StandardPixmap::SP_FileDialogNewFolder),              //  0x00000020  32
        uint32_t(QStyle::StandardPixmap::SP_FileDialogDetailedView),           //  0x00000021  33
        uint32_t(QStyle::StandardPixmap::SP_FileDialogInfoView),               //  0x00000022  34
        uint32_t(QStyle::StandardPixmap::SP_FileDialogContentsView),           //  0x00000023  35
        uint32_t(QStyle::StandardPixmap::SP_FileDialogListView),               //  0x00000024  36
        uint32_t(QStyle::StandardPixmap::SP_FileDialogBack),                   //  0x00000025  37
        uint32_t(QStyle::StandardPixmap::SP_DirIcon),                          //  0x00000026  38
        uint32_t(QStyle::StandardPixmap::SP_DialogOkButton),                   //  0x00000027  39
        uint32_t(QStyle::StandardPixmap::SP_DialogCancelButton),               //  0x00000028  40
        uint32_t(QStyle::StandardPixmap::SP_DialogHelpButton),                 //  0x00000029  41
        uint32_t(QStyle::StandardPixmap::SP_DialogOpenButton),                 //  0x0000002a  42
        uint32_t(QStyle::StandardPixmap::SP_DialogSaveButton),                 //  0x0000002b  43
        uint32_t(QStyle::StandardPixmap::SP_DialogCloseButton),                //  0x0000002c  44
        uint32_t(QStyle::StandardPixmap::SP_DialogApplyButton),                //  0x0000002d  45
        uint32_t(QStyle::StandardPixmap::SP_DialogResetButton),                //  0x0000002e  46
        uint32_t(QStyle::StandardPixmap::SP_DialogDiscardButton),              //  0x0000002f  47
        uint32_t(QStyle::StandardPixmap::SP_DialogYesButton),                  //  0x00000030  48
        uint32_t(QStyle::StandardPixmap::SP_DialogNoButton),                   //  0x00000031  49
        uint32_t(QStyle::StandardPixmap::SP_ArrowUp),                          //  0x00000032  50
        uint32_t(QStyle::StandardPixmap::SP_ArrowDown),                        //  0x00000033  51
        uint32_t(QStyle::StandardPixmap::SP_ArrowLeft),                        //  0x00000034  52
        uint32_t(QStyle::StandardPixmap::SP_ArrowRight),                       //  0x00000035  53
        uint32_t(QStyle::StandardPixmap::SP_ArrowBack),                        //  0x00000036  54
        uint32_t(QStyle::StandardPixmap::SP_ArrowForward),                     //  0x00000037  55
        uint32_t(QStyle::StandardPixmap::SP_DirHomeIcon),                      //  0x00000038  56
        uint32_t(QStyle::StandardPixmap::SP_CommandLink),                      //  0x00000039  57
        uint32_t(QStyle::StandardPixmap::SP_VistaShield),                      //  0x0000003a  58
        uint32_t(QStyle::StandardPixmap::SP_BrowserReload),                    //  0x0000003b  59
        uint32_t(QStyle::StandardPixmap::SP_BrowserStop),                      //  0x0000003c  60
        uint32_t(QStyle::StandardPixmap::SP_MediaPlay),                        //  0x0000003d  61
        uint32_t(QStyle::StandardPixmap::SP_MediaStop),                        //  0x0000003e  62
        uint32_t(QStyle::StandardPixmap::SP_MediaPause),                       //  0x0000003f  63
        uint32_t(QStyle::StandardPixmap::SP_MediaSkipForward),                 //  0x00000040  64
        uint32_t(QStyle::StandardPixmap::SP_MediaSkipBackward),                //  0x00000041  65
        uint32_t(QStyle::StandardPixmap::SP_MediaSeekForward),                 //  0x00000042  66
        uint32_t(QStyle::StandardPixmap::SP_MediaSeekBackward),                //  0x00000043  67
        uint32_t(QStyle::StandardPixmap::SP_MediaVolume),                      //  0x00000044  68
        uint32_t(QStyle::StandardPixmap::SP_MediaVolumeMuted),                 //  0x00000045  69
        uint32_t(QStyle::StandardPixmap::SP_LineEditClearButton),              //  0x00000046  70
        uint32_t(QStyle::StandardPixmap::SP_DialogYesToAllButton),             //  0x00000047  71
        uint32_t(QStyle::StandardPixmap::SP_DialogNoToAllButton),              //  0x00000048  72
        uint32_t(QStyle::StandardPixmap::SP_DialogSaveAllButton),              //  0x00000049  73
        uint32_t(QStyle::StandardPixmap::SP_DialogAbortButton),                //  0x0000004a  74
        uint32_t(QStyle::StandardPixmap::SP_DialogRetryButton),                //  0x0000004b  75
        uint32_t(QStyle::StandardPixmap::SP_DialogIgnoreButton),               //  0x0000004c  76
        uint32_t(QStyle::StandardPixmap::SP_RestoreDefaultsButton),            //  0x0000004d  77
        uint32_t(QStyle::StandardPixmap::SP_TabCloseButton),                   //  0x0000004e  78
        uint32_t(QStyle::StandardPixmap::NStandardPixmap),                     //  0x0000004f  79
        uint32_t(QStyle::StandardPixmap::SP_CustomBase)                        //  0xf0000000  4026531840
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyle_TypeF(),
        "2:PySide6.QtWidgets.QStyle.StandardPixmap",
        StandardPixmap_Initializer, StandardPixmap_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_StandardPixmap_IDX].type = EType;
    // Register converter for enum 'QStyle::StandardPixmap'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyle_StandardPixmap_CppToPython_QStyle_StandardPixmap);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyle_StandardPixmap_PythonToCpp_QStyle_StandardPixmap,
            is_QStyle_StandardPixmap_PythonToCpp_QStyle_StandardPixmap_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyle::StandardPixmap");
        Shiboken::Conversions::registerConverterName(converter, "StandardPixmap");
    }
    // End of 'StandardPixmap' enum.

    qRegisterMetaType< ::QStyle::StateFlag >("QStyle::StateFlag");
    qRegisterMetaType< ::QStyle::PrimitiveElement >("QStyle::PrimitiveElement");
    qRegisterMetaType< ::QStyle::ControlElement >("QStyle::ControlElement");
    qRegisterMetaType< ::QStyle::SubElement >("QStyle::SubElement");
    qRegisterMetaType< ::QStyle::ComplexControl >("QStyle::ComplexControl");
    qRegisterMetaType< ::QStyle::SubControl >("QStyle::SubControl");
    qRegisterMetaType< ::QStyle::PixelMetric >("QStyle::PixelMetric");
    qRegisterMetaType< ::QStyle::ContentsType >("QStyle::ContentsType");
    qRegisterMetaType< ::QStyle::RequestSoftwareInputPanel >("QStyle::RequestSoftwareInputPanel");
    qRegisterMetaType< ::QStyle::StyleHint >("QStyle::StyleHint");
    qRegisterMetaType< ::QStyle::StandardPixmap >("QStyle::StandardPixmap");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QStyle::staticMetaObject, sizeof(QStyleWrapper));

    return pyType;
}
